(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    999630,      25536]
NotebookOptionsPosition[    980652,      25009]
NotebookOutlinePosition[    981211,      25031]
CellTagsIndexPosition[    981168,      25028]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
On-the-Fly Exact Computation of Bisimilarity Distances\
\>", "Title",
 CellChangeTimes->{3.559289200697814*^9}],

Cell["\<\
Tutorial for the prototype implementation\
\>", "Subtitle",
 CellChangeTimes->{{3.559301899440158*^9, 3.559301929064122*^9}}],

Cell["\<\
Authors: Giorgio Bacci, Giovanni Bacci, Kim G. Larsen, and Radu Mardare\
\>", "Subsubtitle",
 CellChangeTimes->{{3.559289239962391*^9, 3.559289248012012*^9}, {
  3.559289280494467*^9, 3.55928928427775*^9}}],

Cell[TextData[{
 "This is a tutorial for the prototype implementation of our on-the-fly \
algorithm for computing the bisimilarity pseudometric of ",
 ButtonBox["Desharnais et al.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1016/j.tcs.2003.09.013"], None},
  ButtonNote->"http://dx.doi.org/10.1016/j.tcs.2003.09.013"],
 "\nThis algorithm has been presented in a paper submitted to TACAS 2013 by \
the same authors of this tutorial, the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " notebook of this tutorial is available ",
 ButtonBox["here",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://people.cs.aau.dk/~mardare/projects/tools/mc_dist.zip"], None},
  
  ButtonNote->"http://people.cs.aau.dk/~mardare/projects/tools/mc_dist.zip"],
 "."
}], "Text",
 CellChangeTimes->{{3.559289413890732*^9, 3.5592895519493093`*^9}, {
  3.559289584798902*^9, 3.55929005674139*^9}, {3.559295092006178*^9, 
  3.559295274248143*^9}, {3.559295347895853*^9, 3.559295420742426*^9}, {
  3.559301737272998*^9, 3.559301886671125*^9}, {3.559563724800871*^9, 
  3.5595638266156178`*^9}, {3.559563908420285*^9, 3.559563930779663*^9}}],

Cell[CellGroupData[{

Cell["Tutorial", "Section",
 CellChangeTimes->{{3.559290148825745*^9, 3.559290150895509*^9}, 
   3.5592927703473682`*^9, {3.559295431055097*^9, 3.559295443070603*^9}}],

Cell[CellGroupData[{

Cell["\<\
Encoding and manipulating Markov Chains\
\>", "Subsection",
 CellChangeTimes->{
  3.5592901588038397`*^9, {3.559290191101569*^9, 3.5592902100814962`*^9}, {
   3.559302025323431*^9, 3.559302031891165*^9}}],

Cell[TextData[{
 "A Markov chain \[ScriptCapitalM] is encoded as a term of the form MC[\[Pi], \
\[ScriptL]] where \[Pi] and \[ScriptL] are respectively the transition \
funtion and the label function of \[ScriptCapitalM].\nThe set of states is \
implicitly respresented as a list of integer numbers {1,..., n} indicating \
the indices of \[Pi] and ",
 "\[ScriptL].",
 "\nThe label function \[ScriptL] is encoded as a vector ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["l", "1"], ",", "...", ",", " ", 
     SubscriptBox["l", "n"]}], "}"}], TraditionalForm]]],
 " (of integers) indicating that the i-th state in \[ScriptCapitalM] is \
labelled ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "i"], TraditionalForm]]],
 ".\nThe transition function \[Pi] is encoded as a n \[Cross] n matrix of the \
form {{\[Pi](1,1),..., \[Pi](1,n)},...,{\[Pi](n,1),..., \[Pi](n,n)}}."
}], "Text",
 CellChangeTimes->{{3.5592902174659853`*^9, 3.559290361278048*^9}, {
  3.559290472992955*^9, 3.559290610316268*^9}, {3.55929065124218*^9, 
  3.559291092594887*^9}, {3.559295324822625*^9, 3.559295343087195*^9}, {
  3.559295464187489*^9, 3.559295465344006*^9}, {3.559295521594593*^9, 
  3.5592956210634403`*^9}, {3.559295686052862*^9, 3.559295698772468*^9}}],

Cell[TextData[{
 "For instance we can encode the Markov chain \[ScriptCapitalM] = ",
 StyleBox["MC[tm, labels]", "Program"],
 " by defining the variables ",
 StyleBox["tm", "Program"],
 " and ",
 StyleBox["labels", "Program"],
 " as follows:"
}], "Text",
 CellChangeTimes->{{3.559291270048073*^9, 3.559291305511608*^9}, {
  3.5592914372439404`*^9, 3.5592915621462917`*^9}, {3.559291820864118*^9, 
  3.55929183689345*^9}, {3.559295648906727*^9, 3.5592956530425863`*^9}, {
  3.5592957590963306`*^9, 3.5592957676777487`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"labels", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1"}],
     "}"}]}], ";", " ", 
  RowBox[{"tm", "=", 
   RowBox[{"(", "\[NoBreak]", GridBox[{
      {"0", 
       FractionBox["1", "3"], 
       FractionBox["1", "3"], 
       FractionBox["1", "6"], "0", 
       FractionBox["1", "6"], "0"},
      {"0", "0", 
       FractionBox["2", "5"], 
       FractionBox["2", "5"], "0", 
       FractionBox["1", "5"], "0"},
      {"0", 
       FractionBox["1", "2"], 
       FractionBox["1", "2"], "0", "0", "0", "0"},
      {
       FractionBox["1", "3"], 
       FractionBox["1", "3"], 
       FractionBox["1", "3"], "0", "0", "0", "0"},
      {
       FractionBox["2", "5"], 
       FractionBox["2", "5"], 
       FractionBox["1", "5"], "0", "0", "0", "0"},
      {
       FractionBox["1", "2"], 
       FractionBox["1", "10"], "0", 
       FractionBox["1", "5"], "0", 
       FractionBox["1", "5"], "0"},
      {"0", 
       FractionBox["1", "5"], 
       FractionBox["1", "3"], "0", 
       FractionBox["1", "10"], 
       FractionBox["1", "5"], 
       FractionBox["1", "6"]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
        "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.7]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.559291106023691*^9, 3.559291123273951*^9}, {
  3.5592911985278*^9, 3.559291262790923*^9}, {3.559291310139451*^9, 
  3.55929131164038*^9}, {3.559291354846352*^9, 3.5592913753750687`*^9}, {
  3.559291420176618*^9, 3.559291426548358*^9}, {3.559291576586495*^9, 
  3.5592915784593973`*^9}}],

Cell["\<\
The Markov chain \[ScriptCapitalM] can be displayed by means of its undelying \
graph. Labels are displayed using different colors.\
\>", "Text",
 CellChangeTimes->{{3.559291587218378*^9, 3.5592917846602783`*^9}, {
  3.559291874479889*^9, 3.5592918865437307`*^9}, {3.559292667567462*^9, 
  3.559292705895445*^9}, {3.5592957035881157`*^9, 3.559295737621191*^9}, {
  3.55929578875921*^9, 3.559295820255541*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotMC", "[", 
  RowBox[{"MC", "[", 
   RowBox[{"tm", ",", "labels"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 6, 5, 
      7}, {{{1, 2}, {1, 3}, {1, 4}, {1, 5}, {2, 3}, {2, 4}, {2, 5}, {3, 2}, {
       3, 3}, {4, 1}, {4, 2}, {4, 3}, {6, 1}, {6, 2}, {6, 3}, {5, 1}, {5, 
       2}, {5, 4}, {5, 5}, {7, 2}, {7, 3}, {7, 6}, {7, 5}, {7, 7}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[1, 4] -> Rational[1, 6], DirectedEdge[4, 3] -> 
         Rational[1, 3], DirectedEdge[4, 1] -> Rational[1, 3], 
         DirectedEdge[3, 2] -> Rational[1, 2], DirectedEdge[1, 3] -> 
         Rational[1, 3], DirectedEdge[6, 6] -> Rational[1, 5], 
         DirectedEdge[7, 2] -> Rational[1, 5], DirectedEdge[6, 2] -> 
         Rational[1, 10], DirectedEdge[5, 2] -> Rational[2, 5], 
         DirectedEdge[3, 3] -> Rational[1, 2], DirectedEdge[2, 3] -> 
         Rational[2, 5], DirectedEdge[1, 6] -> Rational[1, 6], 
         DirectedEdge[5, 3] -> Rational[1, 5], DirectedEdge[7, 7] -> 
         Rational[1, 6], DirectedEdge[7, 5] -> Rational[1, 10], 
         DirectedEdge[6, 1] -> Rational[1, 2], DirectedEdge[2, 4] -> 
         Rational[2, 5], DirectedEdge[7, 3] -> Rational[1, 3], 
         DirectedEdge[1, 2] -> Rational[1, 3], DirectedEdge[4, 2] -> 
         Rational[1, 3], DirectedEdge[6, 4] -> Rational[1, 5], 
         DirectedEdge[7, 6] -> Rational[1, 5], DirectedEdge[2, 6] -> 
         Rational[1, 5], DirectedEdge[5, 1] -> Rational[2, 5]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, VertexStyle -> {1 -> Hue[
           Rational[1, 2]], 6 -> Hue[
           Rational[1, 3]], 5 -> Hue[
           Rational[1, 2]], 2 -> Hue[
           Rational[1, 3]], 4 -> Hue[
           Rational[1, 2]], 3 -> Hue[
           Rational[1, 2]], 7 -> Hue[
           Rational[1, 2]]}}]], Typeset`boxes = GraphicsGroupBox[{{
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.6603817607870491, 0.0002541816649996864}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.9784807989410997, 0.730420034702753}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1.2956615349847862`, 0.}, 0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.30126506638559325`}, 0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.34952880220430516`, 1.2165012808126008`}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.9585266693822878`, 0.29954277809763374`}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.6108566048159387`, 1.2154270339091147`}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"]}, {
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       Arrowheads[{{0.03409704806107404, 0.7}}], {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            0.5795092383917769, 0.007634210979828526}, {0.5591075440465004, 
            0.009991863003401324}, {0.5388427932725773, 
            0.013327658454734825`}, {0.5187618547516044, 
            0.01763388224586071}, {0.49891117204087976`, 
            0.022900574864619105`}, {0.47933665615790433`, 
            0.02911555540919819}, {0.46008357939655264`, 
            0.036264449760344375`}, {0.44119647062049266`, 
            0.044330723826084384`}, {0.1770437663056732, 
            0.16473507771432172`}, {0.15856630796120683`, 
            0.17370007567030932`}, {0.14054123504771898`, 
            0.1835430631073529}, {0.12301023627939925`, 0.1942412749863316}, {
            0.10601385766683047`, 0.20576996828958866`}, {0.0895914087414435, 
            0.2181024792470299}, {0.0737808716397228, 0.2312102850045724}, {
            0.058618813257435176`, 0.24506306959231688`}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            0.5825927629638842, 0.11721643628966855`}, {0.5636370460772446, 
            0.14726043317075801`}, {0.5461477008778064, 0.1781810372362065}, {
            0.5301651770390258, 0.20990673475446703`}, {0.5157264392307017, 
            0.24236414995931366`}, {0.5028648816264183, 0.2754782147546395}, {
            0.4916102506688984, 0.30917234233330504`}, {0.48198857627189373`, 
            0.34336860430848826`}, {0.3576473928387963, 0.8298674439675283}, {
            0.34968092818463115`, 0.8644867506069065}, {0.34338809825664196`, 
            0.8994490337528158}, {0.3387834572255426, 0.9346734320053349}, {
            0.33587765478827536`, 0.9700784777399886}, {0.33467741153719943`, 
            1.0055822855275427`}, {0.33518550341658404`, 
            1.0411027415201035`}, {0.3374007553023536, 1.0765576933655079`}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            1.038979522890317, 0.665001905539635}, {1.0538772786744781`, 
            0.6480946829149593}, {1.067944943449333, 0.6304907597139465}, {
            1.081149981265711, 0.6122308506081247}, {1.093461851273651, 
            0.5933571874450702}, {1.1048520783578308`, 0.5739134215738284}, {
            1.1152943189953288`, 0.5539445228872849}, {1.1247644221833988`, 
            0.533496675814985}, {1.2516367166008733`, 0.24132866193388397`}, {
            1.2601127797138196`, 0.22044915862585002`}, {1.267575199159787, 
            0.1991862895744425}, {1.2740067157202997`, 
            0.17758923192723736`}, {1.2793924544676956`, 
            0.15570793574923072`}, {1.2837199591681268`, 
            0.1335930084974264}, {1.286979221090562, 0.11129559797499539`}, {
            1.2891627021551604`, 0.0888672740357129}, 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.8910030621917313, 0.6489256901675073}, {0.8683909477268812, 
            0.6288538701654175}, {0.8448399719305763, 0.6098924035077549}, {
            0.8204046039249983, 0.5920851446170732}, {0.7951413582706036, 
            0.5754732784433558}, {0.7691086642582272, 0.5600952252107205}, {
            0.7423667307727637, 0.5459865515584301}, {0.7149774070409708, 
            0.5331798882817278}, {0.32358508746453113`, 
            0.36151790095486414`}, {0.2956117200090208, 
            0.35004286753588076`}, {0.267119006139278, 
            0.33992600363916103`}, {0.2381728443185544, 0.3311907077302483}, {
            0.2088401817527125, 0.323857182959291}, {0.1791888595535189, 
            0.31794239043483197`}, {0.14928745583449557`, 
            0.31346000999585033`}, {0.11920512710222034`, 0.3104204085727825}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.8940865867638388, 0.7585079154773475}, {0.8729204497576257, 
            0.7661224403327744}, {0.8521448795358056, 0.7747457822892267}, {
            0.8318079262124198, 0.7843579971256796}, {0.8119566254604258, 
            0.7949368535380505}, {0.7926368897267413, 0.8064578845561621}, {
            0.7738934020451096, 0.8188944441313909}, {0.7557695126923718, 
            0.8322177687641322}, {0.5041887139976542, 1.0266502672080708`}, {
            0.48672634023244515`, 1.040829542472478}, {0.4699658693482009, 
            1.0558319742846243`}, {0.4539460652646978, 1.0716228647492516`}, {
            0.43870397887415746`, 1.088165692409691}, {0.424274862349275, 
            1.105422196715345}, {0.4106920876113567, 1.1233524665113817`}, {
            0.39798706914713866`, 1.141915032345974}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            1.2351628110355692`, 0.06541812916311807}, {1.2202650552514083`, 
            0.08232535178779374}, {1.2061973904765533`, 
            0.09992927498880652}, {1.1929923526601751`, 
            0.11818918409462845`}, {1.1806804826522352`, 
            0.13706284725768295`}, {1.1692902555680553`, 
            0.15650661312892467`}, {1.1588480149305571`, 
            0.17647551181546817`}, {1.1493779117424876`, 
            0.19692335888776805`}, {1.0225056173250129`, 
            0.48909137276886905`}, {1.0140295542120663`, 
            0.5099708760769031}, {1.0065671347660994`, 0.5312337451283105}, {
            1.0001356182055865`, 0.5528308027755157}, {0.9947498794581904, 
            0.5747120989535224}, {0.9904223747577594, 0.5968270262053267}, {
            0.9871631128353242, 0.6191244367277576}, {0.9849796317707257, 
            0.6415527606670401}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03409704806107404], 
           ArrowBox[{
             DynamicLocation["VertexID$3", Automatic, Center], {
             1.3316984936476595`, 0.0024464607999724053`}, {
             1.3990971851013647`, -0.0021748927820189057`}, {
             1.4627654249967341`, -0.024764619367952018`}, {
             1.518005056817486, -0.06365579567967233}, {
             1.5607398812431714`, -0.1159785947247099}, {
             1.5878164438328062`, -0.17787205380506133`}, {
             1.5972367322465162`, -0.24476897962982594`}, {
             1.5883056119954437`, -0.31173296703845055`}, {
             1.5616821212574032`, -0.37382266231490535`}, {
             1.519330839651725, -0.4264563916617613}, {
             1.4643769195302823`, -0.46575024845754565`}, {
             1.4008754772012695`, -0.48880469142927285`}, {
             1.3335123609865764`, -0.4939185053139661}, {
             1.267258376800128, -0.4807143355928746}, {
             1.2070024863604631`, -0.45016653393834216`}, {
             1.1571910447855922`, -0.4045292596240849}, {
             1.1214996986648502`, -0.34717014238287447`}, {
             1.102562155646314, -0.28232178093077115`}, {
             1.1017758399603554`, -0.21476941438271044`}, {
             1.119198774793573, -0.1494978136638756}, {
             1.1535453006875935`, -0.0913234492271848}, {
             1.2022809459072816`, -0.044539077866417004`}, {
             1.2618094481790085`, -0.012596974994399018`}, 
             DynamicLocation["VertexID$3", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$9"], 
         InsetBox[
          FormBox[
           FractionBox["1", "2"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$9", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.08087252239527226, 0.2938850370707644}, {0.10127421674054889`, 
            0.29152738504719167`}, {0.12153896751447191`, 
            0.2881915895958581}, {0.14161990603544478`, 0.2838853658047322}, {
            0.1614705887461695, 0.27861867318597383`}, {0.18104510462914486`, 
            0.27240369264139475`}, {0.20029818139049657`, 
            0.26525479829024856`}, {0.21918529016655655`, 
            0.2571885242245086}, {0.483337994481376, 0.13678417033627122`}, {
            0.5018154528258424, 0.12781917238028362`}, {0.5198405257393302, 
            0.11797618494324008`}, {0.5373715245076499, 
            0.10727797306426134`}, {0.5543679031202187, 
            0.09574927976100422}, {0.5707903520456057, 0.08341676880356308}, {
            0.5866008891473264, 0.07030896304602052}, {0.601762947529614, 
            0.056456178458275996`}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.0874777367493684, 0.382759410920839}, {0.11008985121421863`, 
            0.40283123092292883`}, {0.13364082701052352`, 
            0.42179269758059146`}, {0.15807619501610146`, 
            0.43959995647127315`}, {0.1833394406704962, 
            0.45621182264499044`}, {0.20937213468287258`, 
            0.47158987587762585`}, {0.23611406816833613`, 
            0.48569854952991626`}, {0.26350339190012906`, 
            0.4985052128066184}, {0.6548957114765686, 0.6701672001334822}, {
            0.6828690789320789, 0.6816422335524656}, {0.7113617928018217, 
            0.6917590974491853}, {0.7403079546225453, 0.700494393358098}, {
            0.7696406171883873, 0.7078279181290553}, {0.7992919393875808, 
            0.7137427106535144}, {0.8291933431066041, 0.718225091092496}, {
            0.8592756718388793, 0.7212646925155637}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            0.4273178000274703, 1.099539026187932}, {0.4462735169141097, 
            1.0694950293068426`}, {0.46376286211354795`, 1.038574425241394}, {
            0.4797453859523285, 1.0068487277231335`}, {0.4941841237606527, 
            0.9743913125182869}, {0.5070456813649362, 0.941277247722961}, {
            0.5183003123224559, 0.9075831201442955}, {0.5279219867194608, 
            0.8733868581691123}, {0.6522631701525582, 0.38688801851007215`}, {
            0.6602296348067234, 0.35226871187069414`}, {0.6665224647347125, 
            0.31730642872478465`}, {0.6711271057658118, 
            0.28208203047226565`}, {0.6740329082030792, 
            0.24667698473761202`}, {0.675233151454155, 
            0.21117317695005786`}, {0.6747250595747704, 
            0.17565272095749704`}, {0.6725098076890009, 0.1401977691120927}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            0.4339230143815664, 1.1884134000380067`}, {0.45508915138777933`, 
            1.18079887518258}, {0.4758647216095995, 1.1721755332261274`}, {
            0.4962016749329851, 1.1625633183896746`}, {0.5160529756849793, 
            1.1519844619773036`}, {0.5353727114186639, 1.1404634309591923`}, {
            0.5541161991002954, 1.1280268713839634`}, {0.5722400884530332, 
            1.114703546751222}, {0.8238208871477508, 0.9202710483072831}, {
            0.8412832609129599, 0.906091773042876}, {0.8580437317972041, 
            0.8910893412307299}, {0.8740635358807072, 0.8752984507661024}, {
            0.8893056222712475, 0.8587556231056631}, {0.9037347387961301, 
            0.8414991188000092}, {0.9173175135340483, 0.8235688490039725}, {
            0.9300225319982663, 0.8050062831693804}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03409704806107404], 
           ArrowBox[{
             DynamicLocation["VertexID$5", Automatic, Center], {
             0.34625879692286965`, 1.2143266644022779`}, {0.2823474224647387, 
             1.183864734298579}, {0.21245888666336202`, 1.172542829233187}, {
             0.14219904565336292`, 1.1812690948731792`}, {0.07720353847378109,
              1.2093435853803816`}, {0.02268574466487633, 
             1.254514407035293}, {-0.016981388116551893`, 
             1.3131583457474105`}, {-0.03861610427788875, 
             1.380571490069482}, {-0.040483053308164346`, 
             1.4513465384416904`}, {-0.022432484643077982`, 
             1.5198065263297778`}, {0.014087740635086443`, 
             1.5804601834033802`}, {0.06614828473772144, 
             1.6284423959253937`}, {0.12957329940612272`, 
             1.6599044442548203`}, {0.19927537647684057`, 
             1.6723227139731724`}, {0.26966361592796995`, 
             1.6647011184879386`}, {0.33509207970389215`, 
             1.6376509965160713`}, {0.39031266021683875`, 
             1.5933420757598258`}, {0.43089603831630224`, 
             1.5353284360463406`}, {0.45358696510525065`, 
             1.4682634316682848`}, {0.45656536995719926`, 
             1.3975264393989781`}, {0.4395923508988953, 
             1.3287913712400208`}, {0.40402933726806994`, 
             1.267571562090826}, {0.35272888758297094`, 1.21877753752965}, 
             DynamicLocation["VertexID$5", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$16"], 
         InsetBox[
          FormBox[
           FractionBox["1", "5"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$16", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$6", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03409704806107404], 
           ArrowBox[{
             DynamicLocation["VertexID$7", Automatic, Center], {
             1.607660749505789, 1.217709225818059}, {1.5564509461251854`, 
             1.2665983760304527`}, {1.5210016129951018`, 
             1.3278840819609745`}, {1.504156190163565, 1.3966505323593832`}, {
             1.5072658722984513`, 1.467381875113427}, {1.5300812274940454`, 
             1.5344046513769403`}, {1.5707722045492414`, 1.592342871552085}, {
             1.6260749239059247`, 1.6365492308516925`}, {1.691553477943308, 
             1.6634778760449354`}, {1.7619557412644598`, 1.670968823250013}, {
             1.8316346509397479`, 1.6584212132292522`}, {1.8950011652361018`, 
             1.6268415071397393`}, {1.9469725683858392`, 
             1.5787627568916562`}, {1.9833801622493974`, 
             1.5180414255505512`}, {2.0013036433597398`, 
             1.4495480551001398`}, {1.9993053445031501`, 
             1.3787765935322889`}, {1.9775455519951968`, 
             1.3114037176787166`}, {1.9377696488936318`, 
             1.2528334991096777`}, {1.8831681154089122`, 
             1.2077639360777699`}, {1.818120616073073, 1.1798101205792724`}, {
             1.7478447007891487`, 1.1712142668243057`}, {1.6779772979359264`, 
             1.182665860133346}, {1.6141225685450251`, 1.2132463523658918`}, 
             DynamicLocation["VertexID$7", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$24"], 
         InsetBox[
          FormBox[
           FractionBox["1", "6"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$24", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}}}]}, 
    DynamicBox[GraphComputation`NetworkGraphicsBox[
     1, Typeset`graph, Typeset`boxes], {
     CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
      SynchronousUpdating -> False, TrackedSymbols :> {}},
     ImageSizeCache->{{4.760693309010097, 
      448.1774255630267}, {-243.35496690880723`, 244.09403080504416`}}]]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.5592917887948503`*^9, 3.559300923004487*^9, 
  3.559368287629298*^9, 3.559563500751689*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "Another way to encode a transition function is by means of a list of terms \
of the form ",
 StyleBox["Edge[i,\[Pi](i,j),j]", "Program"],
 ", for 1 \[LessEqual] ",
 StyleBox["i", "Program"],
 ", ",
 StyleBox["j", "Program"],
 " \[LessEqual] n."
}], "Text",
 CellChangeTimes->{{3.55929189280665*^9, 3.559292003719589*^9}, {
  3.559292078905615*^9, 3.5592920810659437`*^9}, {3.559295828456867*^9, 
  3.559296004853971*^9}, {3.559296063888274*^9, 3.559296114959593*^9}, {
  3.559296145345255*^9, 3.559296224179035*^9}, {3.559296304430197*^9, 
  3.559296305349704*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EdgesList", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "3"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "3"}], ",", "3"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "6"}], ",", "4"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "6"}], ",", "6"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"2", ",", 
       RowBox[{"2", "/", "5"}], ",", "4"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"2", ",", 
       RowBox[{"2", "/", "5"}], ",", "3"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"2", ",", 
       RowBox[{"1", "/", "5"}], ",", "6"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"3", ",", 
       RowBox[{"1", "/", "2"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"3", ",", 
       RowBox[{"1", "/", "2"}], ",", "3"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"1", "/", "3"}], ",", "1"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"1", "/", "3"}], ",", "3"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"1", "/", "3"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"1", "/", "5"}], ",", "3"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"2", "/", "5"}], ",", "1"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"2", "/", "5"}], ",", "2"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"1", "/", "2"}], ",", "1"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"1", "/", "10"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"1", "/", "5"}], ",", "4"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"1", "/", "5"}], ",", "6"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"1", "/", "3"}], ",", "3"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"1", "/", "5"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"1", "/", "10"}], ",", "5"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"1", "/", "5"}], ",", "6"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"1", "/", "6"}], ",", "7"}], "]"}]}], "}"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.547971555364769*^9, 3.547971798684469*^9}, {
   3.547971852250057*^9, 3.54797186003193*^9}, {3.548731146234764*^9, 
   3.548731238070322*^9}, {3.549855487546175*^9, 3.549855683923971*^9}, {
   3.549855715896656*^9, 3.549855851553895*^9}, 3.5498559706441708`*^9, {
   3.549856116104793*^9, 3.549856118890915*^9}, {3.549856171892847*^9, 
   3.549856235937093*^9}, {3.549857188071733*^9, 3.5498571884785023`*^9}, {
   3.54985838583355*^9, 3.549858385936768*^9}, {3.557855184828906*^9, 
   3.557855207537613*^9}, {3.558794802480484*^9, 3.5587948464733143`*^9}, {
   3.559288040701201*^9, 3.559288102281488*^9}, {3.559290383643318*^9, 
   3.559290447420854*^9}, {3.559292010778562*^9, 3.559292037337121*^9}}],

Cell[TextData[{
 StyleBox["EdgesList", "Program"],
 " is then transformed in a transtition matrix using the function ",
 StyleBox["TransitionMatrix[n,EdgeList]", "Program"]
}], "Text",
 CellChangeTimes->{{3.559292064763349*^9, 3.559292270614938*^9}, {
   3.5592962749883966`*^9, 3.5592962886778*^9}, 3.5592963215285463`*^9, {
   3.559296393792281*^9, 3.559296417120447*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TransitionMatrix", "[", 
   RowBox[{"7", ",", "EdgesList"}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.559292298103937*^9, 3.559292342091784*^9}, {
  3.5592963707610807`*^9, 3.559296381851776*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", 
      FractionBox["1", "3"], 
      FractionBox["1", "3"], 
      FractionBox["1", "6"], "0", 
      FractionBox["1", "6"], "0"},
     {"0", "0", 
      FractionBox["2", "5"], 
      FractionBox["2", "5"], "0", 
      FractionBox["1", "5"], "0"},
     {"0", 
      FractionBox["1", "2"], 
      FractionBox["1", "2"], "0", "0", "0", "0"},
     {
      FractionBox["1", "3"], 
      FractionBox["1", "3"], 
      FractionBox["1", "3"], "0", "0", "0", "0"},
     {
      FractionBox["2", "5"], 
      FractionBox["2", "5"], 
      FractionBox["1", "5"], "0", "0", "0", "0"},
     {
      FractionBox["1", "2"], 
      FractionBox["1", "10"], "0", 
      FractionBox["1", "5"], "0", 
      FractionBox["1", "5"], "0"},
     {"0", 
      FractionBox["1", "5"], 
      FractionBox["1", "3"], "0", 
      FractionBox["1", "10"], 
      FractionBox["1", "5"], 
      FractionBox["1", "6"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {7, 7}, 0, {
     1, {{0, 4, 7, 9, 12, 15, 19, 24}, {{2}, {3}, {4}, {6}, {4}, {3}, {6}, {
       2}, {3}, {1}, {3}, {2}, {3}, {1}, {2}, {1}, {2}, {4}, {6}, {3}, {2}, {
       5}, {6}, {7}}}, {
      Rational[1, 3], Rational[1, 3], Rational[1, 6], Rational[1, 6], 
       Rational[2, 5], Rational[2, 5], Rational[1, 5], Rational[1, 2], 
       Rational[1, 2], Rational[1, 3], Rational[1, 3], Rational[1, 3], 
       Rational[1, 5], Rational[2, 5], Rational[2, 5], Rational[1, 2], 
       Rational[1, 10], Rational[1, 5], Rational[1, 5], Rational[1, 3], 
       Rational[1, 5], Rational[1, 10], Rational[1, 5], Rational[
       1, 6]}}]]]]], "Output",
 CellChangeTimes->{{3.559292306484222*^9, 3.55929234285944*^9}, 
   3.559296384569816*^9, 3.559368287776456*^9, 3.559563500900271*^9}]
}, Open  ]],

Cell[TextData[{
 "One can check if the encoding corresponds to a well-formed MC by calling ",
 StyleBox["MarkovChainQ", "Program"]
}], "Text",
 CellChangeTimes->{{3.559292410492507*^9, 3.559292528005828*^9}, 
   3.559292596933975*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MarkovChainQ", "[", 
  RowBox[{"MC", "[", 
   RowBox[{"tm", ",", "labels"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.559292599821102*^9, 3.559292615533887*^9}}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.5592926187033663`*^9, 3.5593009331857023`*^9, 
  3.559368287831923*^9, 3.559563500961618*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "Given a sequence of Markov chains ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[ScriptCapitalM]", "1"], ",", "...", ",", " ", 
    SubscriptBox["\[ScriptCapitalM]", "k"]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " they can be joined together using the function ",
 StyleBox["JoinMC", "Program"]
}], "Text",
 CellChangeTimes->{{3.559302047201599*^9, 3.559302257569882*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M1", " ", "=", " ", 
   RowBox[{"MC", "[", 
    RowBox[{
     RowBox[{"TransitionMatrix", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Edge", "[", 
          RowBox[{"1", ",", "1", ",", "1"}], "]"}], ",", 
         RowBox[{"Edge", "[", 
          RowBox[{"2", ",", 
           RowBox[{"1", "/", "3"}], ",", "1"}], "]"}], ",", 
         RowBox[{"Edge", "[", 
          RowBox[{"2", ",", 
           RowBox[{"2", "/", "3"}], ",", "2"}], "]"}]}], "}"}]}], "]"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M2", " ", "=", 
   RowBox[{"MC", "[", 
    RowBox[{
     RowBox[{"TransitionMatrix", "[", 
      RowBox[{"2", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Edge", "[", 
          RowBox[{"1", ",", 
           RowBox[{"1", "/", "2"}], ",", "1"}], "]"}], ",", 
         RowBox[{"Edge", "[", 
          RowBox[{"1", ",", 
           RowBox[{"1", "/", "2"}], ",", "2"}], "]"}], ",", 
         RowBox[{"Edge", "[", 
          RowBox[{"2", ",", 
           RowBox[{"1", "/", "3"}], ",", "1"}], "]"}], ",", 
         RowBox[{"Edge", "[", 
          RowBox[{"2", ",", 
           RowBox[{"2", "/", "3"}], ",", "2"}], "]"}]}], "}"}]}], "]"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"2", ",", "1"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"M3", "=", 
   RowBox[{"MC", "[", 
    RowBox[{
     RowBox[{"TransitionMatrix", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Edge", "[", 
          RowBox[{"1", ",", 
           RowBox[{"1", "/", "4"}], ",", "1"}], "]"}], ",", 
         RowBox[{"Edge", "[", 
          RowBox[{"1", ",", 
           RowBox[{"3", "/", "4"}], ",", "2"}], "]"}], ",", 
         RowBox[{"Edge", "[", 
          RowBox[{"2", ",", 
           RowBox[{"1", "/", "3"}], ",", "1"}], "]"}], ",", 
         RowBox[{"Edge", "[", 
          RowBox[{"2", ",", 
           RowBox[{"2", "/", "3"}], ",", "2"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Edge", "[", 
          RowBox[{"3", ",", 
           RowBox[{"3", "/", "5"}], ",", "2"}], "]"}], ",", 
         RowBox[{"Edge", "[", 
          RowBox[{"3", ",", 
           RowBox[{"2", "/", "5"}], ",", "1"}], "]"}]}], "}"}]}], "]"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"2", ",", "2", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"JoinMC", "[", 
   RowBox[{"M1", ",", "M2", ",", "M3"}], "]"}], "//", "PlotMC"}]}], "Input",
 CellChangeTimes->{{3.559302266820766*^9, 3.559302547093886*^9}, {
  3.559303249870447*^9, 3.559303291377852*^9}, {3.559303439943088*^9, 
  3.559303470265479*^9}, {3.5593035166011057`*^9, 3.559303601404265*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 6, 
      7}, {{{1, 1}, {2, 1}, {2, 2}, {3, 3}, {3, 4}, {4, 3}, {4, 4}, {5, 5}, {
       5, 6}, {6, 5}, {6, 6}, {7, 6}, {7, 5}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[6, 5] -> Rational[1, 3], DirectedEdge[4, 3] -> 
         Rational[1, 3], DirectedEdge[2, 2] -> Rational[2, 3], 
         DirectedEdge[5, 5] -> Rational[1, 4], DirectedEdge[6, 6] -> 
         Rational[2, 3], DirectedEdge[3, 3] -> Rational[1, 2], 
         DirectedEdge[2, 1] -> Rational[1, 3], DirectedEdge[7, 5] -> 
         Rational[2, 5], DirectedEdge[3, 4] -> Rational[1, 2], 
         DirectedEdge[4, 4] -> Rational[2, 3], DirectedEdge[5, 6] -> 
         Rational[3, 4], DirectedEdge[1, 1] -> 1, DirectedEdge[7, 6] -> 
         Rational[3, 5]}, VertexLabels -> {"Name"}, VertexSize -> {0.1}, 
       VertexStyle -> {1 -> Hue[
           Rational[1, 2]], 6 -> Hue[
           Rational[1, 3]], 5 -> Hue[
           Rational[1, 3]], 2 -> Hue[
           Rational[1, 3]], 4 -> Hue[
           Rational[1, 2]], 3 -> Hue[
           Rational[1, 3]], 7 -> Hue[
           Rational[1, 2]]}}]], Typeset`boxes = GraphicsGroupBox[{{
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.8903148606510924`, -3.535189074365146}, 
            0.049999996078859424`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.8903148606510924, -3.535189074365146}, 
            0.049999996078859424`], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.670944581953277, -0.8903148606510924}, 
            0.049999996078859424`], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.670944581953277, -0.8903148606510924}, 
            0.049999996078859424`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.8903148606510924, -1.7545593530629606`}, 
            0.049999996078859424`], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.3933870238654442`, -0.8903148606510924}, 
            0.049999996078859424`], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.3933933940885901, -0.8867639283090876}, 
            0.049999996078859424`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"]}, {
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       Arrowheads[{{0.024784229664803016`, 0.7}}], {{
         TagBox[{
           Arrowheads[0.024784229664803016`], 
           ArrowBox[{
             DynamicLocation["VertexID$1", Automatic, Center], {
             1.890376544410614, -3.53126248727373}, {
             1.9015019782316942`, -3.4613424065167484`}, {
             1.9317841607167683`, -3.3973456691412327`}, {
             1.978794116118853, -3.3444055419798433`}, {
             2.0387611108854795`, -3.3067684258651697`}, {
             2.1068751094130582`, -3.2874532459448296`}, {
             2.177672593656444, -3.288009299519249}, {
             2.245474799469116, -3.3083919847620256`}, {
             2.304843218130901, -3.3469663782941224`}, {
             2.3510158266555985`, -3.400638374649718}, {
             2.3802890562420913`, -3.4651028687557495`}, {
             2.3903148606510927`, -3.535189074365145}, {
             2.3802890562420913`, -3.605275279974541}, {
             2.351015826655599, -3.6697397740805724`}, {
             2.3048432181309018`, -3.7234117704361682`}, {
             2.2454747994691164`, -3.7619861639682655`}, {
             2.1776725936564443`, -3.782368849211042}, {
             2.1068751094130587`, -3.7829249027854615`}, {
             2.0387611108854804`, -3.7636097228651217`}, {
             1.9787941161188534`, -3.7259726067504477`}, {
             1.9317841607167687`, -3.6730324795890588`}, {
             1.9015019782316942`, -3.609035742213543}, {
             1.890376544410614, -3.5391156614565618`}, 
             DynamicLocation["VertexID$1", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          DynamicLocation["EdgeLabelID$1", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.024784229664803016`], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.024784229664803016`], 
           ArrowBox[{
             DynamicLocation["VertexID$2", Automatic, Center], {
             0.890253176891571, -3.5391156614565618`}, {
             0.8791277430704909, -3.6090357422135435`}, {
             0.8488455605854166, -3.6730324795890588`}, {
             0.801835605183332, -3.725972606750448}, {
             0.7418686104167052, -3.7636097228651217`}, {
             0.6737546118891268, -3.782924902785462}, {
             0.602957127645741, -3.7823688492110423`}, {
             0.5351549218330689, -3.761986163968266}, {
             0.4757865031712838, -3.723411770436169}, {
             0.4296138946465864, -3.6697397740805733`}, {
             0.4003406650600937, -3.605275279974542}, {
             0.39031486065109244`, -3.535189074365146}, {
             0.4003406650600937, -3.46510286875575}, {
             0.4296138946465864, -3.4006383746497186`}, {
             0.4757865031712838, -3.346966378294123}, {
             0.5351549218330689, -3.308391984762026}, {
             0.602957127645741, -3.2880092995192496`}, {
             0.6737546118891267, -3.28745324594483}, {
             0.7418686104167052, -3.30676842586517}, {
             0.8018356051833319, -3.3444055419798437`}, {
             0.8488455605854166, -3.3973456691412327`}, {
             0.8791277430704909, -3.461342406516749}, {
             0.890253176891571, -3.53126248727373}, 
             DynamicLocation["VertexID$2", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$3"], 
         InsetBox[
          FormBox[
           FractionBox["2", "3"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$3", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {{
         TagBox[{
           Arrowheads[0.024784229664803016`], 
           ArrowBox[{
             DynamicLocation["VertexID$3", Automatic, Center], {
             4.671006265712799, -0.8863882735596766}, {
             4.682131699533879, -0.816468192802695}, {
             4.712413882018953, -0.7524714554271793}, {
             4.759423837421037, -0.69953132826579}, {
             4.819390832187664, -0.6618942121511163}, {
             4.887504830715242, -0.6425790322307763}, {
             4.958302314958628, -0.6431350858051956}, {
             5.0261045207713, -0.6635177710479722}, {
             5.085472939433085, -0.7020921645800688}, {
             5.131645547957783, -0.7557641609356647}, {
             5.160918777544276, -0.820228655041696}, {
             5.170944581953277, -0.8903148606510918}, {
             5.160918777544276, -0.9604010662604877}, {
             5.131645547957783, -1.024865560366519}, {
             5.085472939433086, -1.078537556722115}, {
             5.026104520771301, -1.117111950254212}, {
             4.958302314958629, -1.1374946354969884`}, {
             4.887504830715243, -1.1380506890714082`}, {
             4.819390832187665, -1.1187355091510682`}, {
             4.759423837421037, -1.0810983930363944`}, {
             4.712413882018953, -1.0281582658750055`}, {
             4.682131699533879, -0.9641615284994896}, {
             4.671006265712799, -0.8942414477425081}, 
             DynamicLocation["VertexID$3", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$4"], 
         InsetBox[
          FormBox[
           FractionBox["1", "2"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$4", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.024784229664803016`], 
          ArrowBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            4.5653304175898795`, -0.9272798181782821}, {
            4.5384037557411485`, -0.9359832176713812}, {
            4.511089791290761, -0.9433819761520534}, {
            4.483451696469021, -0.9494589816380541}, {
            4.455553393160812, -0.9542001791213367}, {
            4.427459405065901, -0.9575946030747303}, {
            4.399234708467367, -0.9596344028132078}, {
            4.370944581953277, -0.9603148606510927}, {
            3.970944581953278, -0.9603148606510927}, {
            3.942654455439188, -0.9596344028132078}, {
            3.9144297588406545`, -0.9575946030747303}, {
            3.8863357707457435`, -0.9542001791213367}, {
            3.8584374674375335`, -0.949458981638054}, {
            3.830799372615794, -0.9433819761520533}, {
            3.803485408165406, -0.935983217671381}, {
            3.7765587463166757`, -0.927279818178282}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024784229664803016`], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            3.776558746316676, -0.8533499031239032}, {
            3.8034854081654066`, -0.8446465036308042}, {
            3.830799372615794, -0.8372477451501319}, {
            3.858437467437534, -0.8311707396641312}, {
            3.886335770745744, -0.8264295421808486}, {
            3.9144297588406545`, -0.823035118227455}, {
            3.9426544554391882`, -0.8209953184889776}, {
            3.9709445819532783`, -0.8203148606510926}, {
            4.370944581953277, -0.8203148606510926}, {
            4.399234708467367, -0.8209953184889776}, {
            4.427459405065901, -0.823035118227455}, {
            4.455553393160812, -0.8264295421808486}, {
            4.483451696469022, -0.8311707396641314}, {
            4.511089791290761, -0.837247745150132}, {
            4.5384037557411485`, -0.8446465036308043}, {
            4.5653304175898795`, -0.8533499031239034}, 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.024784229664803016`], 
           ArrowBox[{
             DynamicLocation["VertexID$4", Automatic, Center], {
             3.6708828981937556`, -0.8942414477425082}, {
             3.6597574643726754`, -0.9641615284994898}, {
             3.6294752818876015`, -1.0281582658750055`}, {
             3.5824653264855164`, -1.0810983930363947`}, {
             3.52249833171889, -1.1187355091510685`}, {
             3.4543843331913116`, -1.1380506890714084`}, {
             3.383586848947926, -1.1374946354969888`}, {
             3.315784643135254, -1.1171119502542124`}, {
             3.2564162244734685`, -1.0785375567221156`}, {
             3.2102436159487713`, -1.0248655603665198`}, {
             3.1809703863622785`, -0.9604010662604884}, {
             3.170944581953277, -0.8903148606510924}, {
             3.1809703863622785`, -0.8202286550416965}, {
             3.210243615948771, -0.7557641609356652}, {
             3.2564162244734685`, -0.7020921645800694}, {
             3.3157846431352533`, -0.6635177710479726}, {
             3.383586848947926, -0.6431350858051961}, {
             3.4543843331913116`, -0.6425790322307765}, {
             3.52249833171889, -0.6618942121511165}, {
             3.5824653264855164`, -0.6995313282657901}, {
             3.629475281887601, -0.7524714554271794}, {
             3.6597574643726754`, -0.8164681928026952}, {
             3.6708828981937556`, -0.8863882735596766}, 
             DynamicLocation["VertexID$4", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$7"], 
         InsetBox[
          FormBox[
           FractionBox["2", "3"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$7", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {{
         TagBox[{
           Arrowheads[0.024784229664803016`], 
           ArrowBox[{
             DynamicLocation["VertexID$5", Automatic, Center], {
             0.8942412039423022, -1.754634979990745}, {
             0.9641213367352035, -1.7660086342683141`}, {
             1.0280101366746317`, -1.796517882260995}, {
             1.0807829947389866`, -1.8437155349833352`}, {
             1.1182069269813384`, -1.9038158034211636`}, {
             1.1372801080273687`, -1.9719979619053634`}, {
             1.1364726516411212`, -2.0427930251863824`}, {
             1.115849325016305, -2.1105224233064406`}, {
             1.0770643537100937`, -2.1697534875511044`}, {
             1.0232287339228654`, -2.2157352123219765`}, {
             0.9586606951894786, -2.2447793398678852`}, {
             0.8885393292147992, -2.254556200541141}, {
             0.818489167763729, -2.244281578822645}, {
             0.754129031187833, -2.2147796163334954`}, {
             0.7006213350723303, -2.1684167062955115`}, {
             0.6622580057407472, -2.1089116818574385`}, {
             0.6421162189074132, -2.0410375233437614`}, {
             0.6418115751567046, -1.970238510900336}, {
             0.6613685103852849, -1.9021935312527214`}, {
             0.6992183357650297, -1.8423605663462252`}, {
             0.7523250644439254, -1.795538901063951}, {
             0.8164289322512014, -1.7654841659473923`}, {
             0.8863880792740694, -1.7546070928754725`}, 
             DynamicLocation["VertexID$5", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$8"], 
         InsetBox[
          FormBox[
           FractionBox["1", "4"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$8", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.024784229664803016`], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            0.9114996458283515, -1.6446868520448823`}, {
            0.9175238347755625, -1.617037194832768}, {
            0.9248703936899723, -1.5897091420566145`}, {
            0.9335223313174357, -1.562765898530461}, {
            0.9434596373003428, -1.5362697790745639`}, {
            0.9546593284579364, -1.510282064392552}, {
            0.967095501942227, -1.4848628593403137`}, {
            0.9807393951465676, -1.4600709539143955`}, {
            1.181968260432308, -1.1143731569496484`}, {
            1.1967883175140694`, -1.090265890316692}, {
            1.2127502623775648`, -1.0668990181983735`}, {
            1.229817177948421, -1.0443265839185627`}, {
            1.2479495915560563`, -1.0226007934109478`}, {
            1.2671055662267854`, -1.0017718944762104`}, {
            1.2872407976764082`, -0.9818880605680016}, {
            1.3083087167779617`, -0.9629952793765113}, 
            DynamicLocation["VertexID$6", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$9"], 
        InsetBox[
         FormBox[
          FractionBox["3", "4"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$9", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024784229664803016`], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], {
            1.3722022386881854`, -1.0001873616691712`}, {
            1.3661780497409743`, -1.0278370188812853`}, {
            1.3588314908265646`, -1.0551650716574388`}, {
            1.3501795531991014`, -1.0821083151835922`}, {
            1.3402422472161941`, -1.1086044346394899`}, {
            1.3290425560586003`, -1.1345921493215014`}, {
            1.3166063825743097`, -1.1600113543737398`}, {
            1.3029624893699694`, -1.184803259799658}, {
            1.101733624084229, -1.530501056764405}, {
            1.0869135670024674`, -1.5546083233973613`}, {
            1.070951622138972, -1.57797519551568}, {
            1.0538847065681156`, -1.6005476297954908`}, {
            1.0357522929604803`, -1.6222734203031055`}, {
            1.0165963182897517`, -1.6431023192378431`}, {
            0.9964610868401286, -1.662986153146052}, {
            0.9753931677385752, -1.681878934337542}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.024784229664803016`], 
           ArrowBox[{
             DynamicLocation["VertexID$6", Automatic, Center], {
             1.3914893467749365`, -0.8868767343106528}, {
             1.366399148410081, -0.8206719390403534}, {
             1.3608765263814873`, -0.7500879917385812}, {
             1.3753644578416058`, -0.6807865284583807}, {
             1.4087008457666192`, -0.6183263154353444}, {
             1.4582117323662724`, -0.5677173727583202}, {
             1.5199257809371598`, -0.5330191137276394}, {
             1.588892822273322, -0.5170147336988423}, {
             1.6595809145859095`, -0.5209879661331684}, {
             1.7263200682064945`, -0.5446201125608209}, {
             1.7837570433017689`, -0.5860156058260892}, {
             1.8272847406458006`, -0.6418540561510798}, {
             1.853411743422024, -0.7076565841929512}, {
             1.8600423685958332`, -0.7781450781517137}, {
             1.8466447645497805`, -0.847665558419008}, {
             1.8142935716375326`, -0.9106416911037369}, {
             1.7655837237945335`, -0.9620220734873076}, {
             1.7044223052974277`, -0.9976854140233812}, {
             1.6357151581294935`, -1.014771106833856}, {
             1.5649733776088315`, -1.0119086848634764`}, {
             1.497871259809306, -0.9893277469381225}, {
             1.439791158423113, -0.9488395413253812}, {
             1.3953917587256268`, -0.8936916830054709}, 
             DynamicLocation["VertexID$6", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$11"], 
         InsetBox[
          FormBox[
           FractionBox["2", "3"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$11", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.024784229664803016`], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$6", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox[
          FractionBox["3", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024784229664803016`], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}}]}, 
    DynamicBox[GraphComputation`NetworkGraphicsBox[
     1, Typeset`graph, Typeset`boxes], {
     CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
      SynchronousUpdating -> False, TrackedSymbols :> {}},
     ImageSizeCache->{{7.960693309010086, 
      554.9062932836006}, {-186.2393066909899, 185.2393066909899}}]]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImageSize->{700., Automatic}]], "Output",
 CellChangeTimes->{{3.559303455323085*^9, 3.5593034711015*^9}, {
   3.559303533162944*^9, 3.55930355418781*^9}, {3.5593036032122173`*^9, 
   3.5593036069832077`*^9}, 3.559368287923834*^9, 3.5595635010614557`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Run the on-the-fly algorithm", "Subsection",
 CellChangeTimes->{{3.559292749537469*^9, 3.559292784161332*^9}}],

Cell["\<\
Given a MC \[ScriptCapitalM] = MC[\[Pi],\[ScriptL]], a discount factor \
\[Lambda] \[Element] (0,1], and a list of pairs of states Q, the bisimilarity \
distance of the pairs in Q can be computed as\
\>", "Text",
 CellChangeTimes->{{3.55929279002621*^9, 3.559292975541119*^9}, {
  3.559293163747102*^9, 3.5592933072146997`*^9}, {3.559296536698812*^9, 
  3.5592965424339314`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{"MC", "[", 
    RowBox[{"tm", ",", "labels"}], "]"}]}], ";", " ", 
  RowBox[{"\[Lambda]", " ", "=", " ", "1"}], ";", " ", 
  RowBox[{"Q", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"ComputeDistances", "[", 
  RowBox[{"M", ",", "\[Lambda]", ",", "Q"}], "]"}]}], "Input",
 CellChangeTimes->{{3.559292979708026*^9, 3.559293010991379*^9}, {
  3.559293055529606*^9, 3.5592930865255623`*^9}, {3.55929314693382*^9, 
  3.55929314763829*^9}, {3.559293314376917*^9, 3.559293327355328*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["1", "5"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["472", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.559293126854739*^9, 3.5592931486963673`*^9}, {
   3.559293320924827*^9, 3.559293328487162*^9}, 3.559296554852174*^9, 
   3.559300897462916*^9, 3.559300936340206*^9, 3.559368287995039*^9, 
   3.559563501169026*^9}]
}, Open  ]],

Cell[TextData[{
 "If one is interested is tracing the computation he can set the option ",
 StyleBox["Verbose", "Program"],
 " as ",
 StyleBox["True", "Program"]
}], "Text",
 CellChangeTimes->{{3.559293356367012*^9, 3.559293415423354*^9}, {
  3.559296578666943*^9, 3.55929657901906*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComputeDistances", "[", 
  RowBox[{"M", ",", "\[Lambda]", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], ",", 
   RowBox[{"Verbose", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559293448300482*^9, 3.559293472436658*^9}, {
  3.559293601615106*^9, 3.559293603181941*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pairs to compute: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Pairs to compute: ", {{1, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.5595635012128277`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Picked pair: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Picked pair: ", {{1, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.5595635012157087`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501217761*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.5595635012204523`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501223737*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501226429*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {2, 2}, 0, {
       1, {{0, 2, 3}, {{1}, {2}, {2}}}, {1, Rational[-1, 6], 1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["5", "6"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
         Rational[5, 6], 
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["11", "12"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 3}, {{1}, {2}, {2}}}, {1, Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,4)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
       Rational[5, 6], 
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[11, 12], 
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501229396*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {1, 4}, " reduced cost: ", -2, 
   " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.55956350123284*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501235114*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501237726*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501241116*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["5", "6"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "5"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]], 
   MatrixForm[{"d(1,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)"}], "=", 
   MatrixForm[{
     Rational[1, 5]}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501244094*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["3", "10"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 4}, " reduced cost: ", 
   Rational[-3, 10], " for introducing ", {1, 3}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501247141*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.5595635012494383`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501252016*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.5595635012548723`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["5", "6"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "5"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]], 
   MatrixForm[{"d(1,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)"}], "=", 
   MatrixForm[{
     Rational[1, 5]}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501257751*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total solved TPs: \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Total solved TPs: ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501260738*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Execution Time: \"\>", "\[InvisibleSpace]", 
   "0.03406700000000029`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Execution Time: ", 0.03406700000000029, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559293455986113*^9, 3.55929347503756*^9}, 
   3.559293603919457*^9, 3.559296567024651*^9, 3.55936828806078*^9, 
   3.559563501262743*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
   FractionBox["1", "5"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559293456166003*^9, 3.559293475093073*^9}, 
   3.5592936039757233`*^9, 3.5592965670813227`*^9, 3.559368288099497*^9, 
   3.5595635012648907`*^9}]
}, Open  ]],

Cell[TextData[{
 "If one is iterestes in computing the distance between all pair of states it \
suffices to ask for ",
 StyleBox["All", "Program"],
 " pairs"
}], "Text",
 CellChangeTimes->{{3.5593007248752117`*^9, 3.5593008502717876`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComputeDistances", "[", 
  RowBox[{"M", ",", "\[Lambda]", ",", "All"}], "]"}]], "Input",
 CellChangeTimes->{{3.559293448300482*^9, 3.559293472436658*^9}, {
  3.559293601615106*^9, 3.559293603181941*^9}, {3.55930071342197*^9, 
  3.559300719870195*^9}, {3.5593009588707333`*^9, 3.559301007199597*^9}, {
  3.5593010551482897`*^9, 3.5593010571385117`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["43", "815"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["1", "5"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["1831", "12225"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "6"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "7"}], "}"}], "\[Rule]", 
    FractionBox["8171", "61125"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "5"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
    FractionBox["23", "163"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "7"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["43", "815"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["143", "815"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["472", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "6"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "7"}], "}"}], "\[Rule]", 
    FractionBox["627", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["1", "5"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["143", "815"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["286", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "6"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "7"}], "}"}], "\[Rule]", 
    FractionBox["22507", "183375"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["1831", "12225"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["472", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["286", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "5"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "6"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"5", ",", "7"}], "}"}], "\[Rule]", 
    FractionBox["13297", "183375"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "1"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "2"}], "}"}], "\[Rule]", 
    FractionBox["23", "163"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "3"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "4"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "5"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "6"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"6", ",", "7"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "1"}], "}"}], "\[Rule]", 
    FractionBox["8171", "61125"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "3"}], "}"}], "\[Rule]", 
    FractionBox["627", "4075"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["22507", "183375"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "5"}], "}"}], "\[Rule]", 
    FractionBox["13297", "183375"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "6"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"7", ",", "7"}], "}"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559300941754623*^9, {3.559300983464848*^9, 3.559301008042636*^9}, 
   3.559301059337799*^9, 3.559368288254915*^9, 3.559563501429984*^9}]
}, Open  ]],

Cell["\<\
The output is returned as a set of ArrayRules, so that one can easily \
transform it into a matrix using the function SparseArray\
\>", "Text",
 CellChangeTimes->{{3.559301069792654*^9, 3.5593011708574257`*^9}, {
  3.559301251398644*^9, 3.559301257484355*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SparseArray", "[", 
   RowBox[{
    RowBox[{"ComputeDistances", "[", 
     RowBox[{"M", ",", "\[Lambda]", ",", "All"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"7", ",", "7"}], "}"}]}], "]"}], "//", "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.55930117525793*^9, 3.559301216110014*^9}, {
  3.5593012782632217`*^9, 3.5593012851194983`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1", 
      FractionBox["43", "815"], 
      FractionBox["1", "5"], 
      FractionBox["1831", "12225"], "1", 
      FractionBox["8171", "61125"]},
     {"1", "0", "1", "1", "1", 
      FractionBox["23", "163"], "1"},
     {
      FractionBox["43", "815"], "1", "0", 
      FractionBox["143", "815"], 
      FractionBox["472", "4075"], "1", 
      FractionBox["627", "4075"]},
     {
      FractionBox["1", "5"], "1", 
      FractionBox["143", "815"], "0", 
      FractionBox["286", "4075"], "1", 
      FractionBox["22507", "183375"]},
     {
      FractionBox["1831", "12225"], "1", 
      FractionBox["472", "4075"], 
      FractionBox["286", "4075"], "0", "1", 
      FractionBox["10351", "122250"]},
     {"1", 
      FractionBox["23", "163"], "1", "1", "1", "0", "1"},
     {
      FractionBox["8171", "61125"], "1", 
      FractionBox["627", "4075"], 
      FractionBox["22507", "183375"], 
      FractionBox["10351", "122250"], "1", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {7, 7}, 0, {
     1, {{0, 6, 12, 18, 24, 30, 36, 42}, {{2}, {3}, {4}, {5}, {6}, {7}, {1}, {
       3}, {4}, {5}, {6}, {7}, {1}, {2}, {4}, {5}, {6}, {7}, {1}, {2}, {3}, {
       5}, {6}, {7}, {1}, {2}, {3}, {4}, {6}, {7}, {1}, {2}, {3}, {4}, {5}, {
       7}, {1}, {2}, {3}, {4}, {5}, {6}}}, {
      1, Rational[43, 815], Rational[1, 5], Rational[1831, 12225], 1, 
       Rational[8171, 61125], 1, 1, 1, 1, Rational[23, 163], 1, Rational[
       43, 815], 1, Rational[143, 815], Rational[472, 4075], 1, Rational[
       627, 4075], Rational[1, 5], 1, Rational[143, 815], Rational[286, 4075],
        1, Rational[22507, 183375], Rational[1831, 12225], 1, Rational[
       472, 4075], Rational[286, 4075], 1, Rational[10351, 122250], 1, 
       Rational[23, 163], 1, 1, 1, 1, Rational[8171, 61125], 1, Rational[
       627, 4075], Rational[22507, 183375], Rational[10351, 122250], 
       1}}]]]]], "Output",
 CellChangeTimes->{{3.559301200512209*^9, 3.559301216983152*^9}, {
   3.5593012801260033`*^9, 3.559301285657709*^9}, 3.559368288452284*^9, 
   3.55956350161639*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Examples", "Section",
 CellChangeTimes->{{3.5487310498981857`*^9, 3.5487310576573887`*^9}, {
  3.558792322659335*^9, 3.558792324619794*^9}}],

Cell[CellGroupData[{

Cell["\<\
Example taken from the paper submitted at TACAS 2013\
\>", "Subsection",
 CellChangeTimes->{{3.54797203051853*^9, 3.5479720358404837`*^9}, {
  3.549855483188773*^9, 3.549855483282074*^9}, {3.558684424569099*^9, 
  3.558684425854336*^9}, {3.559288001610284*^9, 3.55928801079865*^9}, {
  3.559296625949349*^9, 3.559296636171339*^9}, {3.5593037031601877`*^9, 
  3.559303722477625*^9}, {3.5595633316739407`*^9, 3.5595633327132807`*^9}}],

Cell["\<\
Here we use the MC presented in the paper submitted at TACAS 2013 in order to \
show most of the features of our on-the-fly algorithm.\
\>", "Text",
 CellChangeTimes->{{3.559563234524556*^9, 3.559563415900241*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EdgesPaper", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "3"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "3"}], ",", "3"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "6"}], ",", "4"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "6"}], ",", "6"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"2", ",", 
       RowBox[{"2", "/", "5"}], ",", "4"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"2", ",", 
       RowBox[{"2", "/", "5"}], ",", "3"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"2", ",", 
       RowBox[{"1", "/", "5"}], ",", "6"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"3", ",", 
       RowBox[{"1", "/", "2"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"3", ",", 
       RowBox[{"1", "/", "2"}], ",", "3"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"1", "/", "3"}], ",", "1"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"1", "/", "3"}], ",", "3"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"1", "/", "3"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"1", "/", "5"}], ",", "3"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"2", "/", "5"}], ",", "1"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"2", "/", "5"}], ",", "2"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"1", "/", "2"}], ",", "1"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"1", "/", "10"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"1", "/", "5"}], ",", "4"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"1", "/", "5"}], ",", "6"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"1", "/", "3"}], ",", "3"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"1", "/", "5"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"1", "/", "10"}], ",", "5"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"1", "/", "5"}], ",", "6"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"1", "/", "6"}], ",", "7"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labelsPaper", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "1", ",", "1", ",", "1", ",", "2", ",", "1"}],
     "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mcPaper", "=", 
   RowBox[{"MC", "[", 
    RowBox[{
     RowBox[{"TransitionMatrix", "[", 
      RowBox[{
       RowBox[{"Length", "@", "labelsPaper"}], ",", "EdgesPaper"}], "]"}], 
     ",", "labelsPaper"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"PlotMC", "[", "mcPaper", "]"}]}], "Input",
 CellChangeTimes->{{3.547971555364769*^9, 3.547971798684469*^9}, {
   3.547971852250057*^9, 3.54797186003193*^9}, {3.548731146234764*^9, 
   3.548731238070322*^9}, {3.549855487546175*^9, 3.549855683923971*^9}, {
   3.549855715896656*^9, 3.549855851553895*^9}, 3.5498559706441708`*^9, {
   3.549856116104793*^9, 3.549856118890915*^9}, {3.549856171892847*^9, 
   3.549856235937093*^9}, {3.549857188071733*^9, 3.5498571884785023`*^9}, {
   3.54985838583355*^9, 3.549858385936768*^9}, {3.557855184828906*^9, 
   3.557855207537613*^9}, {3.558794802480484*^9, 3.5587948464733143`*^9}, {
   3.559288040701201*^9, 3.559288102281488*^9}, {3.55929665937422*^9, 
   3.559296680582912*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 6, 5, 
      7}, {{{1, 2}, {1, 3}, {1, 4}, {1, 5}, {2, 4}, {2, 3}, {2, 5}, {3, 2}, {
       3, 3}, {4, 1}, {4, 3}, {4, 2}, {6, 3}, {6, 1}, {6, 2}, {5, 1}, {5, 
       2}, {5, 4}, {5, 5}, {7, 3}, {7, 2}, {7, 6}, {7, 5}, {7, 7}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[1, 4] -> Rational[1, 6], DirectedEdge[4, 3] -> 
         Rational[1, 3], DirectedEdge[4, 1] -> Rational[1, 3], 
         DirectedEdge[3, 2] -> Rational[1, 2], DirectedEdge[1, 3] -> 
         Rational[1, 3], DirectedEdge[6, 6] -> Rational[1, 5], 
         DirectedEdge[7, 2] -> Rational[1, 5], DirectedEdge[6, 2] -> 
         Rational[1, 10], DirectedEdge[5, 2] -> Rational[2, 5], 
         DirectedEdge[3, 3] -> Rational[1, 2], DirectedEdge[2, 3] -> 
         Rational[2, 5], DirectedEdge[1, 6] -> Rational[1, 6], 
         DirectedEdge[5, 3] -> Rational[1, 5], DirectedEdge[7, 7] -> 
         Rational[1, 6], DirectedEdge[7, 5] -> Rational[1, 10], 
         DirectedEdge[6, 1] -> Rational[1, 2], DirectedEdge[2, 4] -> 
         Rational[2, 5], DirectedEdge[7, 3] -> Rational[1, 3], 
         DirectedEdge[1, 2] -> Rational[1, 3], DirectedEdge[4, 2] -> 
         Rational[1, 3], DirectedEdge[6, 4] -> Rational[1, 5], 
         DirectedEdge[7, 6] -> Rational[1, 5], DirectedEdge[2, 6] -> 
         Rational[1, 5], DirectedEdge[5, 1] -> Rational[2, 5]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, VertexStyle -> {1 -> Hue[
           Rational[1, 2]], 6 -> Hue[
           Rational[1, 3]], 5 -> Hue[
           Rational[1, 2]], 2 -> Hue[
           Rational[1, 3]], 4 -> Hue[
           Rational[1, 2]], 3 -> Hue[
           Rational[1, 2]], 7 -> Hue[
           Rational[1, 2]]}}]], Typeset`boxes = GraphicsGroupBox[{{
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.6603817607870491, 0.0002541816649996864}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.9784807989410997, 0.730420034702753}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1.2956615349847862`, 0.}, 0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.30126506638559325`}, 0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.34952880220430516`, 1.2165012808126008`}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.9585266693822878`, 0.29954277809763374`}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.6108566048159387`, 1.2154270339091147`}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"]}, {
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       Arrowheads[{{0.03409704806107404, 0.7}}], {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            0.5795092383917769, 0.007634210979828526}, {0.5591075440465004, 
            0.009991863003401324}, {0.5388427932725773, 
            0.013327658454734825`}, {0.5187618547516044, 
            0.01763388224586071}, {0.49891117204087976`, 
            0.022900574864619105`}, {0.47933665615790433`, 
            0.02911555540919819}, {0.46008357939655264`, 
            0.036264449760344375`}, {0.44119647062049266`, 
            0.044330723826084384`}, {0.1770437663056732, 
            0.16473507771432172`}, {0.15856630796120683`, 
            0.17370007567030932`}, {0.14054123504771898`, 
            0.1835430631073529}, {0.12301023627939925`, 0.1942412749863316}, {
            0.10601385766683047`, 0.20576996828958866`}, {0.0895914087414435, 
            0.2181024792470299}, {0.0737808716397228, 0.2312102850045724}, {
            0.058618813257435176`, 0.24506306959231688`}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            0.5825927629638842, 0.11721643628966855`}, {0.5636370460772446, 
            0.14726043317075801`}, {0.5461477008778064, 0.1781810372362065}, {
            0.5301651770390258, 0.20990673475446703`}, {0.5157264392307017, 
            0.24236414995931366`}, {0.5028648816264183, 0.2754782147546395}, {
            0.4916102506688984, 0.30917234233330504`}, {0.48198857627189373`, 
            0.34336860430848826`}, {0.3576473928387963, 0.8298674439675283}, {
            0.34968092818463115`, 0.8644867506069065}, {0.34338809825664196`, 
            0.8994490337528158}, {0.3387834572255426, 0.9346734320053349}, {
            0.33587765478827536`, 0.9700784777399886}, {0.33467741153719943`, 
            1.0055822855275427`}, {0.33518550341658404`, 
            1.0411027415201035`}, {0.3374007553023536, 1.0765576933655079`}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.8910030621917313, 0.6489256901675073}, {0.8683909477268812, 
            0.6288538701654175}, {0.8448399719305763, 0.6098924035077549}, {
            0.8204046039249983, 0.5920851446170732}, {0.7951413582706036, 
            0.5754732784433558}, {0.7691086642582272, 0.5600952252107205}, {
            0.7423667307727637, 0.5459865515584301}, {0.7149774070409708, 
            0.5331798882817278}, {0.32358508746453113`, 
            0.36151790095486414`}, {0.2956117200090208, 
            0.35004286753588076`}, {0.267119006139278, 
            0.33992600363916103`}, {0.2381728443185544, 0.3311907077302483}, {
            0.2088401817527125, 0.323857182959291}, {0.1791888595535189, 
            0.31794239043483197`}, {0.14928745583449557`, 
            0.31346000999585033`}, {0.11920512710222034`, 0.3104204085727825}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            1.038979522890317, 0.665001905539635}, {1.0538772786744781`, 
            0.6480946829149593}, {1.067944943449333, 0.6304907597139465}, {
            1.081149981265711, 0.6122308506081247}, {1.093461851273651, 
            0.5933571874450702}, {1.1048520783578308`, 0.5739134215738284}, {
            1.1152943189953288`, 0.5539445228872849}, {1.1247644221833988`, 
            0.533496675814985}, {1.2516367166008733`, 0.24132866193388397`}, {
            1.2601127797138196`, 0.22044915862585002`}, {1.267575199159787, 
            0.1991862895744425}, {1.2740067157202997`, 
            0.17758923192723736`}, {1.2793924544676956`, 
            0.15570793574923072`}, {1.2837199591681268`, 
            0.1335930084974264}, {1.286979221090562, 0.11129559797499539`}, {
            1.2891627021551604`, 0.0888672740357129}, 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.8940865867638388, 0.7585079154773475}, {0.8729204497576257, 
            0.7661224403327744}, {0.8521448795358056, 0.7747457822892267}, {
            0.8318079262124198, 0.7843579971256796}, {0.8119566254604258, 
            0.7949368535380505}, {0.7926368897267413, 0.8064578845561621}, {
            0.7738934020451096, 0.8188944441313909}, {0.7557695126923718, 
            0.8322177687641322}, {0.5041887139976542, 1.0266502672080708`}, {
            0.48672634023244515`, 1.040829542472478}, {0.4699658693482009, 
            1.0558319742846243`}, {0.4539460652646978, 1.0716228647492516`}, {
            0.43870397887415746`, 1.088165692409691}, {0.424274862349275, 
            1.105422196715345}, {0.4106920876113567, 1.1233524665113817`}, {
            0.39798706914713866`, 1.141915032345974}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            1.2351628110355692`, 0.06541812916311807}, {1.2202650552514083`, 
            0.08232535178779374}, {1.2061973904765533`, 
            0.09992927498880652}, {1.1929923526601751`, 
            0.11818918409462845`}, {1.1806804826522352`, 
            0.13706284725768295`}, {1.1692902555680553`, 
            0.15650661312892467`}, {1.1588480149305571`, 
            0.17647551181546817`}, {1.1493779117424876`, 
            0.19692335888776805`}, {1.0225056173250129`, 
            0.48909137276886905`}, {1.0140295542120663`, 
            0.5099708760769031}, {1.0065671347660994`, 0.5312337451283105}, {
            1.0001356182055865`, 0.5528308027755157}, {0.9947498794581904, 
            0.5747120989535224}, {0.9904223747577594, 0.5968270262053267}, {
            0.9871631128353242, 0.6191244367277576}, {0.9849796317707257, 
            0.6415527606670401}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03409704806107404], 
           ArrowBox[{
             DynamicLocation["VertexID$3", Automatic, Center], {
             1.3316984936476595`, 0.0024464607999724053`}, {
             1.3990971851013647`, -0.0021748927820189057`}, {
             1.4627654249967341`, -0.024764619367952018`}, {
             1.518005056817486, -0.0636557956796723}, {
             1.5607398812431714`, -0.11597859472470987`}, {
             1.5878164438328062`, -0.1778720538050613}, {
             1.597236732246516, -0.24476897962982588`}, {
             1.5883056119954437`, -0.31173296703845044`}, {
             1.5616821212574032`, -0.37382266231490524`}, {
             1.519330839651725, -0.4264563916617612}, {
             1.4643769195302823`, -0.46575024845754553`}, {
             1.4008754772012695`, -0.48880469142927274`}, {
             1.3335123609865764`, -0.49391850531396597`}, {
             1.267258376800128, -0.48071433559287446`}, {
             1.2070024863604631`, -0.45016653393834205`}, {
             1.1571910447855922`, -0.4045292596240848}, {
             1.1214996986648502`, -0.34717014238287436`}, {
             1.102562155646314, -0.2823217809307711}, {
             1.1017758399603554`, -0.21476941438271038`}, {
             1.119198774793573, -0.14949781366387557`}, {
             1.1535453006875935`, -0.09132344922718477}, {
             1.2022809459072816`, -0.044539077866417004`}, {
             1.2618094481790085`, -0.012596974994399018`}, 
             DynamicLocation["VertexID$3", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$9"], 
         InsetBox[
          FormBox[
           FractionBox["1", "2"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$9", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.08087252239527226, 0.2938850370707644}, {0.10127421674054889`, 
            0.29152738504719167`}, {0.12153896751447191`, 
            0.2881915895958581}, {0.14161990603544478`, 0.2838853658047322}, {
            0.1614705887461695, 0.27861867318597383`}, {0.18104510462914486`, 
            0.27240369264139475`}, {0.20029818139049657`, 
            0.26525479829024856`}, {0.21918529016655655`, 
            0.2571885242245086}, {0.483337994481376, 0.13678417033627122`}, {
            0.5018154528258424, 0.12781917238028362`}, {0.5198405257393302, 
            0.11797618494324008`}, {0.5373715245076499, 
            0.10727797306426134`}, {0.5543679031202187, 
            0.09574927976100422}, {0.5707903520456057, 0.08341676880356308}, {
            0.5866008891473264, 0.07030896304602052}, {0.601762947529614, 
            0.056456178458275996`}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.0874777367493684, 0.382759410920839}, {0.11008985121421863`, 
            0.40283123092292883`}, {0.13364082701052352`, 
            0.42179269758059146`}, {0.15807619501610146`, 
            0.43959995647127315`}, {0.1833394406704962, 
            0.45621182264499044`}, {0.20937213468287258`, 
            0.47158987587762585`}, {0.23611406816833613`, 
            0.48569854952991626`}, {0.26350339190012906`, 
            0.4985052128066184}, {0.6548957114765686, 0.6701672001334822}, {
            0.6828690789320789, 0.6816422335524656}, {0.7113617928018217, 
            0.6917590974491853}, {0.7403079546225453, 0.700494393358098}, {
            0.7696406171883873, 0.7078279181290553}, {0.7992919393875808, 
            0.7137427106535144}, {0.8291933431066041, 0.718225091092496}, {
            0.8592756718388793, 0.7212646925155637}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            0.4273178000274703, 1.099539026187932}, {0.4462735169141097, 
            1.0694950293068426`}, {0.46376286211354795`, 1.038574425241394}, {
            0.4797453859523285, 1.0068487277231335`}, {0.4941841237606527, 
            0.9743913125182869}, {0.5070456813649362, 0.941277247722961}, {
            0.5183003123224559, 0.9075831201442955}, {0.5279219867194608, 
            0.8733868581691123}, {0.6522631701525582, 0.38688801851007215`}, {
            0.6602296348067234, 0.35226871187069414`}, {0.6665224647347125, 
            0.31730642872478465`}, {0.6711271057658118, 
            0.28208203047226565`}, {0.6740329082030792, 
            0.24667698473761202`}, {0.675233151454155, 
            0.21117317695005786`}, {0.6747250595747704, 
            0.17565272095749704`}, {0.6725098076890009, 0.1401977691120927}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            0.4339230143815664, 1.1884134000380067`}, {0.45508915138777933`, 
            1.18079887518258}, {0.4758647216095995, 1.1721755332261274`}, {
            0.4962016749329851, 1.1625633183896746`}, {0.5160529756849793, 
            1.1519844619773036`}, {0.5353727114186639, 1.1404634309591923`}, {
            0.5541161991002954, 1.1280268713839634`}, {0.5722400884530332, 
            1.114703546751222}, {0.8238208871477508, 0.9202710483072831}, {
            0.8412832609129599, 0.906091773042876}, {0.8580437317972041, 
            0.8910893412307299}, {0.8740635358807072, 0.8752984507661024}, {
            0.8893056222712475, 0.8587556231056631}, {0.9037347387961301, 
            0.8414991188000092}, {0.9173175135340483, 0.8235688490039725}, {
            0.9300225319982663, 0.8050062831693804}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03409704806107404], 
           ArrowBox[{
             DynamicLocation["VertexID$5", Automatic, Center], {
             0.34625879692286965`, 1.2143266644022779`}, {0.2823474224647387, 
             1.183864734298579}, {0.21245888666336205`, 1.172542829233187}, {
             0.14219904565336294`, 1.1812690948731792`}, {0.07720353847378114,
              1.2093435853803816`}, {0.022685744664876384`, 
             1.254514407035293}, {-0.01698138811655181, 
             1.3131583457474105`}, {-0.038616104277888696`, 
             1.380571490069482}, {-0.04048305330816429, 
             1.4513465384416904`}, {-0.0224324846430779, 
             1.5198065263297778`}, {0.014087740635086499`, 
             1.5804601834033802`}, {0.0661482847377215, 
             1.6284423959253937`}, {0.12957329940612278`, 
             1.6599044442548203`}, {0.19927537647684063`, 
             1.6723227139731724`}, {0.26966361592796995`, 
             1.6647011184879386`}, {0.33509207970389215`, 
             1.6376509965160713`}, {0.39031266021683875`, 
             1.5933420757598256`}, {0.43089603831630224`, 
             1.5353284360463406`}, {0.45358696510525065`, 
             1.4682634316682848`}, {0.4565653699571992, 
             1.3975264393989781`}, {0.4395923508988953, 
             1.3287913712400208`}, {0.40402933726806994`, 
             1.267571562090826}, {0.35272888758297094`, 1.21877753752965}, 
             DynamicLocation["VertexID$5", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$16"], 
         InsetBox[
          FormBox[
           FractionBox["1", "5"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$16", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$6", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03409704806107404], 
           ArrowBox[{
             DynamicLocation["VertexID$7", Automatic, Center], {
             1.6076607495057893`, 1.217709225818059}, {1.5564509461251854`, 
             1.2665983760304527`}, {1.5210016129951018`, 
             1.3278840819609745`}, {1.5041561901635652`, 
             1.3966505323593832`}, {1.5072658722984513`, 1.467381875113427}, {
             1.5300812274940454`, 1.5344046513769403`}, {1.5707722045492414`, 
             1.592342871552085}, {1.626074923905925, 1.6365492308516925`}, {
             1.691553477943308, 1.6634778760449354`}, {1.7619557412644598`, 
             1.670968823250013}, {1.8316346509397479`, 1.6584212132292522`}, {
             1.8950011652361018`, 1.6268415071397393`}, {1.9469725683858392`, 
             1.5787627568916562`}, {1.9833801622493974`, 
             1.5180414255505512`}, {2.0013036433597398`, 
             1.4495480551001398`}, {1.9993053445031501`, 
             1.3787765935322889`}, {1.9775455519951968`, 
             1.3114037176787166`}, {1.9377696488936318`, 
             1.2528334991096777`}, {1.8831681154089122`, 
             1.2077639360777699`}, {1.818120616073073, 1.1798101205792724`}, {
             1.7478447007891487`, 1.1712142668243057`}, {1.6779772979359264`, 
             1.182665860133346}, {1.6141225685450251`, 1.2132463523658918`}, 
             DynamicLocation["VertexID$7", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$24"], 
         InsetBox[
          FormBox[
           FractionBox["1", "6"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$24", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}}}]}, 
    DynamicBox[GraphComputation`NetworkGraphicsBox[
     1, Typeset`graph, Typeset`boxes], {
     CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
      SynchronousUpdating -> False, TrackedSymbols :> {}},
     ImageSizeCache->{{1.7606933090100982`, 
      288.6353385756221}, {-156.31296287425948`, 159.17067848673815`}}]]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.559282901652236*^9, 3.559288107048532*^9, 
  3.559290102268177*^9, 3.5592966889186773`*^9, 3.559299854555287*^9, 
  3.559300571040485*^9, 3.5593682887098722`*^9, 3.559561288442525*^9, 
  3.559563501867509*^9}]
}, Open  ]],

Cell["\<\
Let us compute the distance between the state 1 and 4, namely d(1,4)\
\>", "Text",
 CellChangeTimes->{{3.55930472457067*^9, 3.5593047657638893`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComputeDistances", "[", 
  RowBox[{"mcPaper", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], ",", " ", 
   RowBox[{"Verbose", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559280648876001*^9, 3.559280666970271*^9}, {
   3.559281485366975*^9, 3.5592814854943*^9}, {3.559281705565312*^9, 
   3.559281708090787*^9}, {3.559288114041607*^9, 3.559288127092181*^9}, {
   3.5592881703589563`*^9, 3.559288173912812*^9}, 3.559288794513839*^9, {
   3.559288827768854*^9, 3.559288834289609*^9}, {3.55929669614686*^9, 
   3.559296696259295*^9}, {3.559297128972578*^9, 3.559297129408716*^9}, {
   3.559306122098216*^9, 3.559306122406487*^9}, {3.559311462052354*^9, 
   3.559311463033885*^9}, {3.5593117152654667`*^9, 3.559311716121128*^9}, {
   3.559314252974621*^9, 3.559314253730104*^9}, {3.5595613007723427`*^9, 
   3.559561371547716*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pairs to compute: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Pairs to compute: ", {{1, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.559563501960063*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Picked pair: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Picked pair: ", {{1, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.559563501965333*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.559563501968099*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.5595635019710627`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.559563501975091*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.5595635019783373`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {2, 2}, 0, {
       1, {{0, 2, 3}, {{1}, {2}, {2}}}, {1, Rational[-1, 6], 1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["5", "6"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
         Rational[5, 6], 
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["11", "12"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 3}, {{1}, {2}, {2}}}, {1, Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,4)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
       Rational[5, 6], 
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[11, 12], 
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.559563501981299*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {1, 4}, " reduced cost: ", -2, 
   " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.5595635019845753`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.5595635019867887`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.55956350198941*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.559563501992401*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["5", "6"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "5"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]], 
   MatrixForm[{"d(1,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)"}], "=", 
   MatrixForm[{
     Rational[1, 5]}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.55956350199517*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["3", "10"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 4}, " reduced cost: ", 
   Rational[-3, 10], " for introducing ", {1, 3}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.559563501998281*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.5595635020006237`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.5595635020031223`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.559563502006032*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["5", "6"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "5"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {Rational[5, 6]}}]], 
   MatrixForm[{"d(1,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,4)"}], "=", 
   MatrixForm[{
     Rational[1, 5]}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.5595635020089073`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total solved TPs: \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Total solved TPs: ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.559563502011861*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Execution Time: \"\>", "\[InvisibleSpace]", 
   "0.03796099999999569`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Execution Time: ", 0.03796099999999569, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5593142545598307`*^9, 3.559368288833126*^9, 3.559561291696768*^9, {
   3.559561325667207*^9, 3.559561372211198*^9}, 3.5595635020139027`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
   FractionBox["1", "5"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559283062260519*^9, 3.559283141481842*^9, 3.559283429519863*^9, 
   3.559287899080534*^9, 3.559288127938177*^9, 3.559288174828513*^9, 
   3.559288645745462*^9, 3.559288761246047*^9, {3.5592887951671*^9, 
   3.559288834995525*^9}, 3.559290105497293*^9, 3.559296697919303*^9, {
   3.559297120179008*^9, 3.5592971300608263`*^9}, 3.559299854710971*^9, 
   3.559300574782845*^9, 3.55930612328936*^9, 3.559311463753718*^9, 
   3.559311717208878*^9, 3.559314254623217*^9, 3.559368288886137*^9, 
   3.5595612917670527`*^9, {3.559561325748827*^9, 3.559561372289369*^9}, 
   3.5595635020160027`*^9}]
}, Open  ]],

Cell["\<\
Looking the execution trace we see that during the computation of d(1,4) an \
over-approximation for the distance d(3,4) is computed. 
This happens because the we encountered a coupling that demands d(3,4) for \
computing an over-approximation of d(1,4). 
However, the first improvement of the current coupling makes the computation \
of d(3,4) no more demanded for d(1,4), so that no further improvement on \
(3,4) is made.\
\>", "Text",
 CellChangeTimes->{{3.5593038027299967`*^9, 3.559304305686409*^9}, {
  3.559304573166234*^9, 3.559304682875122*^9}}],

Cell["\<\
On the other hand, as shown in the execution trace that follows, the exact \
computation of d(3,4) demands an exact computation of d(1,3), d(1,4) and \
d(2,6)\
\>", "Text",
 CellChangeTimes->{{3.55930468716146*^9, 3.559304697434*^9}, {
  3.5593047727723007`*^9, 3.559304869775578*^9}, {3.5593050081153173`*^9, 
  3.5593050109707203`*^9}, {3.5593051195620403`*^9, 3.55930515393615*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComputeDistances", "[", 
  RowBox[{"mcPaper", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], ",", " ", 
   RowBox[{"Verbose", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5593048838664207`*^9, 3.559304883928726*^9}, {
  3.559306130529502*^9, 3.559306130847048*^9}, {3.559311451716378*^9, 
  3.559311452465706*^9}, {3.559311487245051*^9, 3.5593114880664673`*^9}, {
  3.5593117029367933`*^9, 3.559311735169549*^9}, {3.559314266587071*^9, 
  3.559314273234703*^9}, {3.5595614134557047`*^9, 3.559561441574979*^9}, {
  3.559561495687004*^9, 3.5595615995856657`*^9}, {3.559562352908433*^9, 
  3.559562377344582*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pairs to compute: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Pairs to compute: ", {{3, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502060442*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Picked pair: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Picked pair: ", {{3, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502065133*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.5595635020680037`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502070756*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.5595635020755568`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {1}}]], 
   MatrixForm[{"d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(3,4)"}], "=", 
   MatrixForm[{
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502079439*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {3, 4}, " reduced cost: ", -1, 
   " for introducing ", {2, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502084667*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502088331*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502091958*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502095745*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502100293*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {2, 2}, 0, {
       1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
        1, Rational[-1, 6], Rational[-1, 6], 1}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "3"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
         Rational[1, 3], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["13", "35"]},
        {
         FractionBox["8", "35"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
      1, Rational[-1, 6], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
       Rational[1, 3], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[13, 35], 
     Rational[8, 35]}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502103808*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {1, 3}, " reduced cost: ", -1, 
   " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.55956350210772*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502110145*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502113171*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.55956350211637*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502119645*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502122841*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502125458*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}], 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", "1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 3, 5, 8, 10}, {{1}, {3}, {4}, {2}, {4}, {3}, {1}, {2}, {1}, {
         4}}}, {1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 1, 
         Rational[-2, 5], Rational[-1, 10], Rational[-1, 6], 1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["5", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
         Rational[5, 6], 
         Rational[1, 10], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["127", "1955"]},
        {
         FractionBox["1687", "1955"]},
        {
         FractionBox["83", "391"]},
        {
         FractionBox["347", "1955"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 3, 5, 8, 10}, {{1}, {3}, {4}, {2}, {4}, {3}, {1}, {2}, {1}, {
       4}}}, {1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 1, 
       Rational[-2, 5], Rational[-1, 10], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
       Rational[5, 6], 
       Rational[1, 10], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[127, 1955], 
     Rational[1687, 1955], 
     Rational[83, 391], 
     Rational[347, 1955]}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.55956350212868*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {1, 4}, " reduced cost: ", -2, 
   " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502132976*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502135283*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502138029*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.55956350214145*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.5595635021450663`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.5595635021485777`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.55956350215138*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}], 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 3, 6, 9, 11}, {{1}, {3}, {4}, {2}, {1}, {4}, {3}, {1}, {2}, {
         1}, {4}}}, {
        1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 
         Rational[-1, 6], 1, Rational[-2, 5], Rational[-1, 10], 
         Rational[-1, 6], 1}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["1", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
         Rational[1, 6], 
         Rational[1, 10], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["103", "1949"]},
        {
         FractionBox["399", "1949"]},
        {
         FractionBox["276", "1949"]},
        {
         FractionBox["342", "1949"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 3, 6, 9, 11}, {{1}, {3}, {4}, {2}, {1}, {4}, {3}, {1}, {2}, {
       1}, {4}}}, {
      1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 
       Rational[-1, 6], 1, Rational[-2, 5], Rational[-1, 10], Rational[-1, 6],
        1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
       Rational[1, 6], 
       Rational[1, 10], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[103, 1949], 
     Rational[399, 1949], 
     Rational[276, 1949], 
     Rational[342, 1949]}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502154726*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["46", "1949"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 4}, " reduced cost: ", 
   Rational[-46, 1949], " for introducing ", {3, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502158991*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.5595635021615753`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502164061*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502167248*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502170923*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502174361*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502177277*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}], 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", 
        FractionBox["5", "6"], "0", "0"},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 3, 4, 7, 9}, {{1}, {3}, {4}, {2}, {3}, {1}, {2}, {1}, {4}}}, {
        1, Rational[-1, 6], Rational[-1, 6], Rational[5, 6], 1, 
         Rational[-2, 5], Rational[-1, 10], Rational[-1, 6], 1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["1", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
         Rational[1, 6], 
         Rational[1, 10], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["43", "815"]},
        {
         FractionBox["1", "5"]},
        {
         FractionBox["23", "163"]},
        {
         FractionBox["143", "815"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 3, 4, 7, 9}, {{1}, {3}, {4}, {2}, {3}, {1}, {2}, {1}, {4}}}, {
      1, Rational[-1, 6], Rational[-1, 6], Rational[5, 6], 1, Rational[-2, 5],
        Rational[-1, 10], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
       Rational[1, 6], 
       Rational[1, 10], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[43, 815], 
     Rational[1, 5], 
     Rational[23, 163], 
     Rational[143, 815]}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502180295*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total solved TPs: \"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["Total solved TPs: ", 4],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.5595635021843452`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Execution Time: \"\>", "\[InvisibleSpace]", 
   "0.09048299999999898`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Execution Time: ", 0.09048299999999898, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559562354587451*^9, 3.5595623790088167`*^9}, 
   3.559563502186496*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
   FractionBox["143", "815"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5593048848353577`*^9, 3.5593061317541723`*^9, 3.5593114534218616`*^9, 
   3.559311489113224*^9, {3.559311708850245*^9, 3.559311736016592*^9}, {
   3.559314268629867*^9, 3.559314274024948*^9}, 3.5593682890544643`*^9, 
   3.559561385052425*^9, 3.559561446807169*^9, {3.5595614983477097`*^9, 
   3.55956160035608*^9}, {3.55956235465364*^9, 3.559562379143865*^9}, 
   3.5595635021886587`*^9}]
}, Open  ]],

Cell["\<\
We have seen that the exact computation of d(3,4) demands for the exact \
compuatation of d(1,3), d(1,4), d(2,6). 
One would claim that if we ask for the exact computation of d(3,4), d(1,4) \
and d(2,6) the compuatation will do the same steps made for d(3,4). 
In some sense this is true, since we will need to compute the same set of \
distances, however we have seen that the exact computation of d(1,4) does not \
need an exact compuation of the remaining pairs.
Thus, considering the pair (1,4) before (3,4) will allow us to reduce the \
size of the linear equation systems computed for d(3,4).\
\>", "Text",
 CellChangeTimes->{{3.559305199635118*^9, 3.559305914445759*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComputeDistances", "[", 
  RowBox[{"mcPaper", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}]}], "}"}], ",", " ", 
   RowBox[{"Verbose", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.55930493318233*^9, 3.559304955828421*^9}, {
  3.559306150154635*^9, 3.559306150728084*^9}, {3.559308153723977*^9, 
  3.559308153865499*^9}, {3.5593108394498*^9, 3.5593108457740793`*^9}, {
  3.559310918747622*^9, 3.5593109219236403`*^9}, {3.559311447060152*^9, 
  3.5593114478821373`*^9}, {3.559314307526905*^9, 3.559314308236081*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pairs to compute: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}]}], "}"}]}],
  SequenceForm["Pairs to compute: ", {{1, 4}, {2, 6}, {3, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502230482*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Picked pair: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "}"}]}],
  SequenceForm["Picked pair: ", {{2, 6}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502234111*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{2, 6}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502236614*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502240286*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635022454453`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502249752*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635022544622`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502258108*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", "1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {"0", "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 2, 4, 7, 8}, {{1}, {4}, {2}, {4}, {3}, {1}, {2}, {4}}}, {
        1, Rational[-1, 6], 1, Rational[-1, 6], 1, Rational[-2, 5], 
         Rational[-1, 10], 1}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "3"]},
        {
         FractionBox["5", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {
         Rational[1, 3], 
         Rational[5, 6], 
         Rational[1, 10], 
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["5", "12"]},
        {
         FractionBox["11", "12"]},
        {
         FractionBox["43", "120"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 2, 4, 7, 8}, {{1}, {4}, {2}, {4}, {3}, {1}, {2}, {4}}}, {
      1, Rational[-1, 6], 1, Rational[-1, 6], 1, Rational[-2, 5], 
       Rational[-1, 10], 1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {
       Rational[1, 3], 
       Rational[5, 6], 
       Rational[1, 10], 
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[5, 12], 
     Rational[11, 12], 
     Rational[43, 120], 
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502261602*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["197", "120"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 3}, " reduced cost: ", 
   Rational[-197, 120], " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635022668037`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{2, 6}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502269401*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635022725573`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502276367*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502281732*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.55956350228559*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635022896013`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}], 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", "1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {"0", "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 3, 5, 8, 9}, {{1}, {3}, {4}, {2}, {4}, {3}, {1}, {2}, {4}}}, {
        1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 1, 
         Rational[-2, 5], Rational[-1, 10], 1}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["5", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
         Rational[5, 6], 
         Rational[1, 10], 
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["83", "672"]},
        {
         FractionBox["11", "12"]},
        {
         FractionBox["27", "112"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 3, 5, 8, 9}, {{1}, {3}, {4}, {2}, {4}, {3}, {1}, {2}, {4}}}, {
      1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 1, 
       Rational[-2, 5], Rational[-1, 10], 1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
       Rational[5, 6], 
       Rational[1, 10], 
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[83, 672], 
     Rational[11, 12], 
     Rational[27, 112], 
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502294025*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "2"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {1, 4}, " reduced cost: ", -2, 
   " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502300852*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{2, 6}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502304237*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502308722*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502314806*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502321191*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502325363*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635023286667`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}], 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {"0", "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 3, 6, 9, 10}, {{1}, {3}, {4}, {2}, {1}, {4}, {3}, {1}, {2}, {
         4}}}, {1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 
         Rational[-1, 6], 1, Rational[-2, 5], Rational[-1, 10], 1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["1", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
         Rational[1, 6], 
         Rational[1, 10], 
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["15", "134"]},
        {
         FractionBox["18", "67"]},
        {
         FractionBox["23", "134"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 3, 6, 9, 10}, {{1}, {3}, {4}, {2}, {1}, {4}, {3}, {1}, {2}, {
       4}}}, {1, Rational[-1, 6], Rational[-1, 6], 1, Rational[-1, 6], 
       Rational[-1, 6], 1, Rational[-2, 5], Rational[-1, 10], 1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
       Rational[1, 6], 
       Rational[1, 10], 
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[15, 134], 
     Rational[18, 67], 
     Rational[23, 134], 
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502332033*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["23", "67"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 4}, " reduced cost: ", 
   Rational[-23, 67], " for introducing ", {3, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635023361483`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{2, 6}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502338485*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635023410263`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635023444977`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502347918*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.55956350235105*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502353936*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}], 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", 
        FractionBox["5", "6"], "0", "0"},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {"0", "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 3, 4, 7, 8}, {{1}, {3}, {4}, {2}, {3}, {1}, {2}, {4}}}, {
        1, Rational[-1, 6], Rational[-1, 6], Rational[5, 6], 1, 
         Rational[-2, 5], Rational[-1, 10], 1}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["1", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
         Rational[1, 6], 
         Rational[1, 10], 
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["31", "280"]},
        {
         FractionBox["1", "5"]},
        {
         FractionBox["23", "140"]},
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 3, 4, 7, 8}, {{1}, {3}, {4}, {2}, {3}, {1}, {2}, {4}}}, {
      1, Rational[-1, 6], Rational[-1, 6], Rational[5, 6], 1, Rational[-2, 5],
        Rational[-1, 10], 1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
       Rational[1, 6], 
       Rational[1, 10], 
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[31, 280], 
     Rational[1, 5], 
     Rational[23, 140], 
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502356848*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["529", "280"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {3, 4}, " reduced cost: ", 
   Rational[-529, 280], " for introducing ", {2, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.55956350236101*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{2, 6}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502363256*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502365714*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635023691483`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502372658*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502376197*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635023788843`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}], 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", 
        FractionBox["5", "6"], "0", "0"},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 3, 4, 7, 9}, {{1}, {3}, {4}, {2}, {3}, {1}, {2}, {1}, {4}}}, {
        1, Rational[-1, 6], Rational[-1, 6], Rational[5, 6], 1, 
         Rational[-2, 5], Rational[-1, 10], Rational[-1, 6], 1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["1", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
         Rational[1, 6], 
         Rational[1, 10], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["43", "815"]},
        {
         FractionBox["1", "5"]},
        {
         FractionBox["23", "163"]},
        {
         FractionBox["143", "815"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 3, 4, 7, 9}, {{1}, {3}, {4}, {2}, {3}, {1}, {2}, {1}, {4}}}, {
      1, Rational[-1, 6], Rational[-1, 6], Rational[5, 6], 1, Rational[-2, 5],
        Rational[-1, 10], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
       Rational[1, 6], 
       Rational[1, 10], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[43, 815], 
     Rational[1, 5], 
     Rational[23, 163], 
     Rational[143, 815]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502381874*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["4", "163"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 4}, " reduced cost: ", 
   Rational[-4, 163], " for introducing ", {3, 3}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502386126*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{2, 6}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502388485*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502391013*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"1", "2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502394582*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm], 
       TagBox["\<\"6\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "10"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"3", "4", "6"}, {"1", "2", "4", "6"}}]]]}]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502397777*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502401433*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502404043*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", "0", 
        RowBox[{"-", 
         FractionBox["1", "6"]}], 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {"0", 
        FractionBox["5", "6"], "0", "0"},
       {
        RowBox[{"-", 
         FractionBox["2", "5"]}], 
        RowBox[{"-", 
         FractionBox["1", "10"]}], "1", "0"},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "0", "0", "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {4, 4}, 0, {
       1, {{0, 3, 4, 7, 9}, {{1}, {3}, {4}, {2}, {3}, {1}, {2}, {1}, {4}}}, {
        1, Rational[-1, 6], Rational[-1, 6], Rational[5, 6], 1, 
         Rational[-2, 5], Rational[-1, 10], Rational[-1, 6], 1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["1", "6"]},
        {
         FractionBox["1", "10"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
         Rational[1, 6], 
         Rational[1, 10], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(1,4)\"\>"},
        {"\<\"d(2,6)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["43", "815"]},
        {
         FractionBox["1", "5"]},
        {
         FractionBox["23", "163"]},
        {
         FractionBox["143", "815"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 3, 4, 7, 9}, {{1}, {3}, {4}, {2}, {3}, {1}, {2}, {1}, {4}}}, {
      1, Rational[-1, 6], Rational[-1, 6], Rational[5, 6], 1, Rational[-2, 5],
        Rational[-1, 10], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {4}, 0, {1, {{0, 4}, {{1}, {2}, {3}, {4}}}, {0, 
       Rational[1, 6], 
       Rational[1, 10], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(1,4)", "d(2,6)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[43, 815], 
     Rational[1, 5], 
     Rational[23, 163], 
     Rational[143, 815]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.5595635024069767`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total solved TPs: \"\>", "\[InvisibleSpace]", "5"}],
  SequenceForm["Total solved TPs: ", 5],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502411172*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Execution Time: \"\>", "\[InvisibleSpace]", 
   "0.13286899999999946`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Execution Time: ", 0.13286899999999946`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559314308948777*^9, 3.559368289101899*^9, 
  3.559562392612831*^9, 3.559563502413096*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["1", "5"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "6"}], "}"}], "\[Rule]", 
    FractionBox["23", "163"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
    FractionBox["143", "815"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559304961854267*^9, {3.5593050507744904`*^9, 3.559305055766686*^9}, 
   3.559306151586478*^9, {3.559308155909326*^9, 3.5593081698379793`*^9}, {
   3.559310041592722*^9, 3.559310053929261*^9}, 3.559310846666932*^9, 
   3.5593109230495377`*^9, 3.559311392690226*^9, 3.559311448589919*^9, {
   3.559314304888461*^9, 3.5593143091427393`*^9}, 3.55936828921422*^9, 
   3.5595623927233667`*^9, 3.559563502415098*^9}]
}, Open  ]],

Cell["\<\
Another way to limit the exploration of the MC is to give estimates for some \
distances. For instance, we have seen that for computing the distance d(3,4) \
we need to solve exactly
the problem for the pair (2,6). Assume we have an over-approximation of the \
exact value for d(2,6), we can use this information in order to further \
reduce the exploration of the MC. \
\>", "Text",
 CellChangeTimes->{{3.559562431233766*^9, 3.559562815138789*^9}, {
  3.559562848899838*^9, 3.559562862172022*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComputeDistances", "[", 
  RowBox[{"mcPaper", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], ",", " ", 
   RowBox[{"Verbose", "\[Rule]", "True"}], ",", 
   RowBox[{"Estimates", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"2", ",", "6"}], "}"}], "->", 
      FractionBox["25", "163"]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559562881433319*^9, 3.55956291088018*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pairs to compute: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Pairs to compute: ", {{3, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502580245*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Picked pair: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}]}],
  SequenceForm["Picked pair: ", {{3, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502582884*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.55956350258526*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.559562914856456*^9, 3.559563502587838*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502590644*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {1}}]]]], 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
         Rational[1, 2]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "2"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[SparseArray[Automatic, {1, 1}, 0, {1, {{0, 1}, {{1}}}, {1}}]], 
   MatrixForm[{"d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {1}, 0, {1, {{0, 1}, {{1}}}, {
       Rational[1, 2]}}]], ";  Solution:", 
   MatrixForm[{"d(3,4)"}], "=", 
   MatrixForm[{
     Rational[1, 2]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502594022*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {3, 4}, " reduced cost: ", -1, 
   " for introducing ", {2, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502596994*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502599091*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502601894*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.559562914856456*^9, 3.5595635026049623`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.55956350260754*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {2, 2}, 0, {
       1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
        1, Rational[-1, 6], Rational[-1, 6], 1}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "3"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
         Rational[1, 3], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["13", "35"]},
        {
         FractionBox["8", "35"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
      1, Rational[-1, 6], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
       Rational[1, 3], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[13, 35], 
     Rational[8, 35]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502610458*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["301", "163"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"4", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 3}, " reduced cost: ", 
   Rational[-301, 163], " for introducing ", {4, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502613668*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{3, 4}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502616033*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "6"}, {"2", "3"}}]]]}]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502618495*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"1\"\>",
        HoldForm], 
       TagBox["\<\"2\"\>",
        HoldForm], 
       TagBox["\<\"3\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["1", "3"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"2", "3"}, {"1", "2", "3"}}]]]}]], "Print",\

 CellChangeTimes->{3.559562914856456*^9, 3.5595635026215363`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502624176*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["1", "6"]}]},
       {
        RowBox[{"-", 
         FractionBox["1", "6"]}], "1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {2, 2}, 0, {
       1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
        1, Rational[-1, 6], Rational[-1, 6], 1}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["25", "978"]},
        {
         FractionBox["1", "6"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
         Rational[25, 978], 
         Rational[1, 6]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(3,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["313", "5705"]},
        {
         FractionBox["1003", "5705"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 4}, {{1}, {2}, {1}, {2}}}, {
      1, Rational[-1, 6], Rational[-1, 6], 1}}]], 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
       Rational[25, 978], 
       Rational[1, 6]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(3,4)"}], "=", 
   MatrixForm[{
     Rational[313, 5705], 
     Rational[1003, 5705]}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502626997*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total solved TPs: \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Total solved TPs: ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.5595635026301327`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Execution Time: \"\>", "\[InvisibleSpace]", 
   "0.03180799999999806`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Execution Time: ", 0.03180799999999806, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{3.559562914856456*^9, 3.559563502632156*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", 
   FractionBox["1003", "5705"]}], "}"}]], "Output",
 CellChangeTimes->{3.559562914911862*^9, 3.5595635026341057`*^9}]
}, Open  ]],

Cell[TextData[{
 "Using the estimate ",
 Cell[BoxData[
  FractionBox["25", "163"]],
  CellChangeTimes->{{3.559562881433319*^9, 3.55956291088018*^9}}],
 " for the distance d(2,6) we considerably reduced the number of steps for \
computing a good over-approximation for d(3,4)."
}], "Text",
 CellChangeTimes->{{3.559562939048815*^9, 3.559563189181788*^9}, {
  3.559563434509242*^9, 3.559563450957526*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unfair Tossing Coins", "Subsection",
 CellChangeTimes->{{3.5595557268165503`*^9, 3.559555735558082*^9}, {
  3.559563456453014*^9, 3.5595634660690823`*^9}}],

Cell["\<\
In this example we model two unfair flipping coins. \
\>", "Text",
 CellChangeTimes->{{3.55955697332421*^9, 3.559557085605113*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"EdgesCoin", "[", "e_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{
        RowBox[{"1", "/", "2"}], "-", "e"}], ",", "1"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{
        RowBox[{"1", "/", "2"}], "+", "e"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"2", ",", 
       RowBox[{
        RowBox[{"1", "/", "2"}], "-", "e"}], ",", "2"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"2", ",", 
       RowBox[{
        RowBox[{"1", "/", "2"}], "+", "e"}], ",", "1"}], "]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labelCoin", ":=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"mcCoin", "=", 
    RowBox[{"JoinMC", "[", 
     RowBox[{
      RowBox[{"MC", "[", 
       RowBox[{
        RowBox[{"TransitionMatrix", "[", 
         RowBox[{"2", ",", 
          RowBox[{"EdgesCoin", "[", 
           RowBox[{"1", "/", "10"}], "]"}]}], "]"}], ",", "labelCoin"}], 
       "]"}], ",", 
      RowBox[{"MC", "[", 
       RowBox[{
        RowBox[{"TransitionMatrix", "[", 
         RowBox[{"2", ",", 
          RowBox[{"EdgesCoin", "[", 
           RowBox[{"1", "/", "9"}], "]"}]}], "]"}], ",", "labelCoin"}], 
       "]"}]}], "]"}]}], ")"}], "//", "PlotMC"}]}], "Input",
 CellChangeTimes->{{3.559555739345084*^9, 3.5595559175198708`*^9}, {
  3.5595559597027683`*^9, 3.559555970268635*^9}, {3.559556197132947*^9, 
  3.559556225915945*^9}, {3.5595563821706867`*^9, 3.559556386258169*^9}, {
  3.559556669696356*^9, 3.559556670400485*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 
      4}, {{{1, 1}, {1, 2}, {2, 2}, {2, 1}, {3, 3}, {3, 4}, {4, 4}, {4, 3}}, 
       Null}, {EdgeLabels -> {
        DirectedEdge[4, 3] -> Rational[11, 18], DirectedEdge[2, 2] -> 
         Rational[2, 5], DirectedEdge[3, 3] -> Rational[7, 18], 
         DirectedEdge[2, 1] -> Rational[3, 5], DirectedEdge[3, 4] -> 
         Rational[11, 18], DirectedEdge[4, 4] -> Rational[7, 18], 
         DirectedEdge[1, 2] -> Rational[3, 5], DirectedEdge[1, 1] -> 
         Rational[2, 5]}, VertexLabels -> {"Name"}, VertexSize -> {0.1}, 
       VertexStyle -> {1 -> Hue[
           Rational[1, 2]], 2 -> Hue[
           Rational[1, 3]], 4 -> Hue[
           Rational[1, 3]], 3 -> Hue[
           Rational[1, 2]]}}]], Typeset`boxes = GraphicsGroupBox[{{
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1.87501, -0.8750100000000001}, 0.05], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0.8750100000000001, -0.8750100000000001}, 0.05], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1.87501, -2.62503}, 0.05], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0.8750100000000001, -2.62503}, 0.05], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"]}, {
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       Arrowheads[{{0.03543588419012232, 0.7}}], {{
         TagBox[{
           Arrowheads[0.03543588419012232], 
           ArrowBox[{
             DynamicLocation["VertexID$1", Automatic, Center], {
             1.8750716837595214`, -0.8710834129085843}, {
             1.8861971175806016`, -0.8011633321516026}, {
             1.9164793000656757`, -0.7371665947760869}, {
             1.9634892554677603`, -0.6842264676146976}, {
             2.023456250234387, -0.646589351500024}, {
             2.0915702487619656`, -0.6272741715796839}, {
             2.1623677330053512`, -0.6278302251541032}, {
             2.2301699388180234`, -0.6482129103968797}, {
             2.2895383574798087`, -0.6867873039289765}, {
             2.335710966004506, -0.7404593002845723}, {
             2.3649841955909987`, -0.8049237943906036}, {
             2.37501, -0.8750099999999994}, {
             2.364984195590999, -0.9450962056093953}, {
             2.3357109660045063`, -1.0095606997154267`}, {
             2.2895383574798087`, -1.0632326960710228`}, {
             2.230169938818024, -1.1018070896031196`}, {
             2.1623677330053517`, -1.122189774845896}, {
             2.091570248761966, -1.1227458284203158`}, {
             2.023456250234388, -1.1034306484999759`}, {
             1.9634892554677608`, -1.065793532385302}, {
             1.9164793000656761`, -1.0128534052239129`}, {
             1.8861971175806016`, -0.9488566678483972}, {
             1.8750716837595214`, -0.8789365870914158}, 
             DynamicLocation["VertexID$1", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$1"], 
         InsetBox[
          FormBox[
           FractionBox["2", "5"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$1", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03543588419012232], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            1.769395835636602, -0.9119749575271896}, {
            1.7424691737878715`, -0.9206783570202887}, {
            1.7151552093374838`, -0.928077115500961}, {
            1.6875171145157442`, -0.9341541209869616}, {
            1.6596188112075343`, -0.9388953184702442}, {
            1.6315248231126234`, -0.9422897424236378}, {
            1.60330012651409, -0.9443295421621153}, {
            1.57501, -0.9450100000000002}, {
            1.1750100000000003`, -0.9450100000000002}, {
            1.1467198734859103`, -0.9443295421621153}, {
            1.1184951768873768`, -0.9422897424236378}, {
            1.090401188792466, -0.9388953184702442}, {
            1.0625028854842562`, -0.9341541209869615}, {
            1.0348647906625166`, -0.9280771155009608}, {
            1.0075508262121289`, -0.9206783570202886}, {
            0.9806241643633983, -0.9119749575271895}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["3", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03543588419012232], 
           ArrowBox[{
             DynamicLocation["VertexID$2", Automatic, Center], {
             0.8749483162404788, -0.8789365870914159}, {
             0.8638228824193985, -0.9488566678483974}, {
             0.8335406999343242, -1.012853405223913}, {
             0.7865307445322396, -1.0657935323853023`}, {
             0.7265637497656128, -1.1034306484999759`}, {
             0.6584497512380344, -1.122745828420316}, {
             0.5876522669946487, -1.1221897748458964`}, {
             0.5198500611819765, -1.10180708960312}, {
             0.4604816425201914, -1.0632326960710232`}, {
             0.414309033995494, -1.0095606997154274`}, {
             0.3850358044090013, -0.945096205609396}, {
             0.37501000000000007`, -0.8750100000000001}, {
             0.3850358044090013, -0.8049237943906041}, {
             0.41430903399549396`, -0.7404593002845729}, {
             0.4604816425201914, -0.6867873039289769}, {
             0.5198500611819765, -0.6482129103968801}, {
             0.5876522669946487, -0.6278302251541037}, {
             0.6584497512380343, -0.6272741715796841}, {
             0.7265637497656128, -0.6465893515000242}, {
             0.7865307445322395, -0.6842264676146977}, {
             0.8335406999343242, -0.737166594776087}, {
             0.8638228824193985, -0.8011633321516028}, {
             0.8749483162404788, -0.8710834129085843}, 
             DynamicLocation["VertexID$2", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$3"], 
         InsetBox[
          FormBox[
           FractionBox["2", "5"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$3", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03543588419012232], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.9806241643633986, -0.8380450424728106}, {
            1.007550826212129, -0.8293416429797116}, {
            1.0348647906625168`, -0.8219428844990393}, {
            1.0625028854842564`, -0.8158658790130386}, {
            1.0904011887924663`, -0.811124681529756}, {
            1.1184951768873772`, -0.8077302575763624}, {
            1.1467198734859105`, -0.805690457837885}, {
            1.1750100000000006`, -0.80501}, {1.5750100000000002`, -0.80501}, {
            1.6033001265140903`, -0.805690457837885}, {
            1.6315248231126238`, -0.8077302575763624}, {
            1.6596188112075345`, -0.811124681529756}, {
            1.6875171145157444`, -0.8158658790130388}, {
            1.715155209337484, -0.8219428844990394}, {
            1.7424691737878717`, -0.8293416429797117}, {
            1.7693958356366024`, -0.8380450424728108}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["3", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03543588419012232], 
           ArrowBox[{
             DynamicLocation["VertexID$3", Automatic, Center], {
             1.8750716837595214`, -2.6211034129085844`}, {
             1.8861971175806016`, -2.5511833321516026`}, {
             1.9164793000656757`, -2.487186594776087}, {
             1.9634892554677603`, -2.4342464676146975`}, {
             2.023456250234387, -2.396609351500024}, {
             2.0915702487619656`, -2.377294171579684}, {
             2.1623677330053512`, -2.3778502251541034`}, {
             2.2301699388180234`, -2.39823291039688}, {
             2.2895383574798087`, -2.4368073039289766`}, {
             2.335710966004506, -2.4904793002845724`}, {
             2.3649841955909987`, -2.5549437943906037`}, {
             2.37501, -2.6250299999999993`}, {
             2.364984195590999, -2.6951162056093954`}, {
             2.3357109660045063`, -2.7595806997154266`}, {
             2.2895383574798087`, -2.8132526960710225`}, {
             2.230169938818024, -2.8518270896031197`}, {
             2.1623677330053517`, -2.872209774845896}, {
             2.091570248761966, -2.8727658284203157`}, {
             2.023456250234388, -2.853450648499976}, {
             1.9634892554677608`, -2.815813532385302}, {
             1.9164793000656761`, -2.762873405223913}, {
             1.8861971175806016`, -2.6988766678483973`}, {
             1.8750716837595214`, -2.628956587091416}, 
             DynamicLocation["VertexID$3", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$5"], 
         InsetBox[
          FormBox[
           FractionBox["7", "18"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$5", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03543588419012232], 
          ArrowBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            1.769395835636602, -2.66199495752719}, {
            1.7424691737878715`, -2.670698357020289}, {
            1.7151552093374838`, -2.6780971155009614`}, {
            1.6875171145157442`, -2.6841741209869623`}, {
            1.6596188112075343`, -2.6889153184702446`}, {
            1.6315248231126234`, -2.6923097424236384`}, {
            1.60330012651409, -2.694349542162116}, {
            1.57501, -2.695030000000001}, {
            1.1750100000000003`, -2.695030000000001}, {
            1.1467198734859103`, -2.694349542162116}, {
            1.1184951768873768`, -2.6923097424236384`}, {
            1.090401188792466, -2.6889153184702446`}, {
            1.0625028854842562`, -2.684174120986962}, {
            1.0348647906625166`, -2.6780971155009614`}, {
            1.0075508262121289`, -2.670698357020289}, {
            0.9806241643633983, -2.66199495752719}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["11", "18"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03543588419012232], 
           ArrowBox[{
             DynamicLocation["VertexID$4", Automatic, Center], {
             0.8749483162404788, -2.628956587091416}, {
             0.8638228824193985, -2.6988766678483977`}, {
             0.8335406999343242, -2.762873405223913}, {
             0.7865307445322396, -2.8158135323853024`}, {
             0.7265637497656128, -2.853450648499976}, {
             0.6584497512380344, -2.872765828420316}, {
             0.5876522669946487, -2.8722097748458966`}, {
             0.5198500611819765, -2.85182708960312}, {
             0.4604816425201914, -2.8132526960710234`}, {
             0.414309033995494, -2.7595806997154275`}, {
             0.3850358044090013, -2.6951162056093962`}, {
             0.37501000000000007`, -2.62503}, {
             0.3850358044090013, -2.554943794390604}, {
             0.41430903399549396`, -2.490479300284573}, {
             0.4604816425201914, -2.436807303928977}, {
             0.5198500611819765, -2.3982329103968802`}, {
             0.5876522669946487, -2.377850225154104}, {
             0.6584497512380343, -2.3772941715796843`}, {
             0.7265637497656128, -2.3966093515000244`}, {
             0.7865307445322395, -2.434246467614698}, {
             0.8335406999343242, -2.487186594776087}, {
             0.8638228824193985, -2.551183332151603}, {
             0.8749483162404788, -2.6211034129085844`}, 
             DynamicLocation["VertexID$4", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$7"], 
         InsetBox[
          FormBox[
           FractionBox["7", "18"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$7", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03543588419012232], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.9806241643633986, -2.5880650424728113`}, {
            1.007550826212129, -2.579361642979712}, {
            1.0348647906625168`, -2.57196288449904}, {
            1.0625028854842564`, -2.565885879013039}, {
            1.0904011887924663`, -2.5611446815297567`}, {
            1.1184951768873772`, -2.557750257576363}, {
            1.1467198734859105`, -2.5557104578378853`}, {
            1.1750100000000006`, -2.5550300000000004`}, {
            1.5750100000000002`, -2.5550300000000004`}, {
            1.6033001265140903`, -2.5557104578378853`}, {
            1.6315248231126238`, -2.557750257576363}, {
            1.6596188112075345`, -2.5611446815297567`}, {
            1.6875171145157444`, -2.5658858790130394`}, {
            1.715155209337484, -2.57196288449904}, {
            1.7424691737878717`, -2.579361642979712}, {
            1.7693958356366024`, -2.5880650424728113`}, 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["11", "18"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}}]}, 
    DynamicBox[GraphComputation`NetworkGraphicsBox[
     1, Typeset`graph, Typeset`boxes], {
     CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
      SynchronousUpdating -> False, TrackedSymbols :> {}},
     ImageSizeCache->{{-4.274288705963856, 
      185.8742887059639}, {-103.2393066909899, 100.2393066909899}}]]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImageSize->{227., Automatic}]], "Output",
 CellChangeTimes->{
  3.559555921335478*^9, 3.5595559749805193`*^9, {3.559556198672084*^9, 
   3.5595562271382837`*^9}, 3.5595563870048122`*^9, 3.559556680080902*^9, 
   3.5595635028617287`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComputeDistances", "[", 
  RowBox[{"mc", ",", "1", ",", "All", ",", 
   RowBox[{"Verbose", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559555989153636*^9, 3.55955602887342*^9}, {
  3.5595562396558437`*^9, 3.5595562448081703`*^9}, {3.5595562775209513`*^9, 
  3.559556288888566*^9}, {3.559556476976575*^9, 3.5595564773102427`*^9}, {
  3.5595565183764257`*^9, 3.5595565916884117`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pairs to compute: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}]}], "}"}]}],
  SequenceForm["Pairs to compute: ", {{1, 3}, {2, 4}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559556284098523*^9, 3.559556289391117*^9}, 
   3.5595563915788107`*^9, 3.559556478123526*^9, 3.559556519075934*^9, {
   3.5595565510288877`*^9, 3.5595565921006393`*^9}, 3.559556689958233*^9, 
   3.559563502926708*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Picked pair: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], "}"}]}],
  SequenceForm["Picked pair: ", {{1, 3}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559556284098523*^9, 3.559556289391117*^9}, 
   3.5595563915788107`*^9, 3.559556478123526*^9, 3.559556519075934*^9, {
   3.5595565510288877`*^9, 3.5595565921006393`*^9}, 3.559556689958233*^9, 
   3.55956350292938*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm["Reachable states from ", {{1, 3}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559556284098523*^9, 3.559556289391117*^9}, 
   3.5595563915788107`*^9, 3.559556478123526*^9, 3.559556519075934*^9, {
   3.5595565510288877`*^9, 3.5595565921006393`*^9}, 3.559556689958233*^9, 
   3.5595635029314938`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"3\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm]},
      {
       TagBox["\<\"1\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["7", "18"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "90"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["3", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"1", "2"}, {"3", "4"}}]]]}]], "Print",
 CellChangeTimes->{{3.559556284098523*^9, 3.559556289391117*^9}, 
   3.5595563915788107`*^9, 3.559556478123526*^9, 3.559556519075934*^9, {
   3.5595565510288877`*^9, 3.5595565921006393`*^9}, 3.559556689958233*^9, 
   3.5595635029340067`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "4"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"3\"\>",
        HoldForm], 
       TagBox["\<\"4\"\>",
        HoldForm]},
      {
       TagBox["\<\"1\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["3", "5"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "90"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["7", "18"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"1", "2"}, {"3", "4"}}]]]}]], "Print",
 CellChangeTimes->{{3.559556284098523*^9, 3.559556289391117*^9}, 
   3.5595563915788107`*^9, 3.559556478123526*^9, 3.559556519075934*^9, {
   3.5595565510288877`*^9, 3.5595565921006393`*^9}, 3.559556689958233*^9, 
   3.559563502937243*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559556284098523*^9, 3.559556289391117*^9}, 
   3.5595563915788107`*^9, 3.559556478123526*^9, 3.559556519075934*^9, {
   3.5595565510288877`*^9, 3.5595565921006393`*^9}, 3.559556689958233*^9, 
   3.559563502939638*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        FractionBox["11", "18"], 
        RowBox[{"-", 
         FractionBox["3", "5"]}]},
       {
        RowBox[{"-", 
         FractionBox["3", "5"]}], 
        FractionBox["11", "18"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {2, 2}, 0, {
       1, {{0, 2, 4}, {{1}, {2}, {2}, {1}}}, {
        Rational[11, 18], Rational[-3, 5], Rational[11, 18], 
         Rational[-3, 5]}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(2,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["1", "90"]},
        {
         FractionBox["1", "90"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
         Rational[1, 90], 
         Rational[1, 90]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,3)\"\>"},
        {"\<\"d(2,4)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"1"},
        {"1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {2, 2}, 0, {
     1, {{0, 2, 4}, {{1}, {2}, {2}, {1}}}, {
      Rational[11, 18], Rational[-3, 5], Rational[11, 18], 
       Rational[-3, 5]}}]], 
   MatrixForm[{"d(1,3)", "d(2,4)"}], "==", 
   MatrixForm[
    SparseArray[Automatic, {2}, 0, {1, {{0, 2}, {{1}, {2}}}, {
       Rational[1, 90], 
       Rational[1, 90]}}]], ";  Solution:", 
   MatrixForm[{"d(1,3)", "d(2,4)"}], "=", 
   MatrixForm[{1, 1}]],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559556284098523*^9, 3.559556289391117*^9}, 
   3.5595563915788107`*^9, 3.559556478123526*^9, 3.559556519075934*^9, {
   3.5595565510288877`*^9, 3.5595565921006393`*^9}, 3.559556689958233*^9, 
   3.559563502942692*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total solved TPs: \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["Total solved TPs: ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559556284098523*^9, 3.559556289391117*^9}, 
   3.5595563915788107`*^9, 3.559556478123526*^9, 3.559556519075934*^9, {
   3.5595565510288877`*^9, 3.5595565921006393`*^9}, 3.559556689958233*^9, 
   3.5595635029459953`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Execution Time: \"\>", "\[InvisibleSpace]", 
   "0.009969000000005224`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Execution Time: ", 0.009969000000005224, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.559556284098523*^9, 3.559556289391117*^9}, 
   3.5595563915788107`*^9, 3.559556478123526*^9, 3.559556519075934*^9, {
   3.5595565510288877`*^9, 3.5595565921006393`*^9}, 3.559556689958233*^9, 
   3.559563502948152*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "3"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "1"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "4"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "1"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "3"}], "}"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "1"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "2"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "3"}], "}"}], "\[Rule]", "1"}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "4"}], "}"}], "\[Rule]", "0"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.559556012421309*^9, 3.559556032636599*^9}, 
   3.5595561127499447`*^9, 3.5595561718596992`*^9, {3.559556230439062*^9, 
   3.559556245584263*^9}, {3.559556284126275*^9, 3.559556289422288*^9}, 
   3.559556391607053*^9, 3.559556478153302*^9, 3.5595565191066837`*^9, {
   3.559556551059443*^9, 3.559556592132011*^9}, 3.559556689981245*^9, 
   3.559563502950696*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Craps Game", "Subsection",
 CellChangeTimes->{{3.558672880800664*^9, 3.5586728823581543`*^9}, 
   3.5595578883018208`*^9, {3.5595587555906754`*^9, 3.559558758877635*^9}}],

Cell[TextData[{
 "Here we present two different MCs modeling two slightly different versions \
for the \[OpenCurlyDoubleQuote]craps game\[CloseCurlyDoubleQuote]. These \
models have both been taken from the book ",
 ButtonBox["Principles of Model Checking, ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://books.google.de/books/about/Principles_of_model_checking.html?\
hl=de&id=nDQiAQAAIAAJ"], None},
  ButtonNote->
   "http://books.google.de/books/about/Principles_of_model_checking.html?hl=\
de&id=nDQiAQAAIAAJ"],
 "Examples 10.4 and 10.23 respectivelty. We compare the two models by means \
of the distance beteween their initial states."
}], "Text",
 CellChangeTimes->{{3.558671429012618*^9, 3.558671448608567*^9}, {
  3.559557272870656*^9, 3.55955727776505*^9}, {3.559557911234665*^9, 
  3.559557918663082*^9}, {3.5595579534041758`*^9, 3.559558154365631*^9}, {
  3.5595582892103252`*^9, 3.5595584431404953`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"start", "=", "1"}], ";", 
   RowBox[{"won", "=", "2"}], ";", " ", 
   RowBox[{"lost", "=", "3"}], ";", 
   RowBox[{"other", "=", "4"}], ";"}], " ", 
  RowBox[{"(*", " ", "labels", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"labelsGame1", "=", 
   RowBox[{"{", 
    RowBox[{
    "start", ",", "won", ",", "lost", ",", "other", ",", "other", ",", 
     "other", ",", "other", ",", "other", ",", "other"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"edgeGame1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "12"}], ",", "4"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "12"}], ",", "9"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "9"}], ",", "5"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "9"}], ",", "8"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"5", "/", "36"}], ",", "6"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"5", "/", "36"}], ",", "7"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"2", "/", "9"}], ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "9"}], ",", "lost"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"won", ",", "1", ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"lost", ",", "1", ",", "lost"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"3", "/", "4"}], ",", "4"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"1", "/", "12"}], ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"1", "/", "6"}], ",", "lost"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"9", ",", "1", ",", "9"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"13", "/", "18"}], ",", "5"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"1", "/", "9"}], ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"1", "/", "6"}], ",", "lost"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"8", ",", "1", ",", "8"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"13", "/", "18"}], ",", "6"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"1", "/", "9"}], ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"1", "/", "6"}], ",", "lost"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", "1", ",", "7"}], "]"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.558670584337625*^9, 3.558670587455317*^9}, {
  3.558670788498439*^9, 3.5586708486931343`*^9}, {3.5586708952750063`*^9, 
  3.558670928818719*^9}, {3.558671010672637*^9, 3.5586712567563963`*^9}, {
  3.55867131706483*^9, 3.558671419741489*^9}, {3.558671507146534*^9, 
  3.5586715462369003`*^9}, {3.55867159925712*^9, 3.558671615947254*^9}, {
  3.5586717009373913`*^9, 3.558671703545013*^9}, {3.5586717477008963`*^9, 
  3.558671751554617*^9}, {3.558671914787162*^9, 3.558672010716824*^9}, {
  3.558672448525922*^9, 3.558672450005805*^9}, {3.558672602349402*^9, 
  3.5586726055298023`*^9}, {3.559557229630104*^9, 3.559557244013598*^9}, {
  3.559557281415942*^9, 3.5595573858314743`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"game1", "=", 
    RowBox[{"MC", "[", 
     RowBox[{
      RowBox[{"TransitionMatrix", "[", 
       RowBox[{
        RowBox[{"Length", "@", "labelsGame1"}], ",", "edgeGame1"}], "]"}], 
      ",", "labelsGame1"}], "]"}]}], ")"}], "//", "PlotMC"}]], "Input",
 CellChangeTimes->{{3.558671668730261*^9, 3.558671692086938*^9}, {
  3.5586717735396957`*^9, 3.558671795650897*^9}, {3.55867211170418*^9, 
  3.558672140534251*^9}, {3.558674516388204*^9, 3.55867453156172*^9}, {
  3.55955722129506*^9, 3.5595572682328787`*^9}, {3.559557415900332*^9, 
  3.559557426034408*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 4, 9, 5, 8, 6, 7, 2, 
      3}, {{{1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {1, 8}, {1, 9}, {
       8, 8}, {9, 9}, {2, 2}, {2, 8}, {2, 9}, {4, 4}, {4, 8}, {4, 9}, {6, 
       6}, {6, 8}, {6, 9}, {7, 7}, {5, 5}, {3, 3}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[1, 4] -> Rational[1, 12], DirectedEdge[4, 3] -> 
         Rational[1, 6], DirectedEdge[1, 3] -> Rational[1, 9], 
         DirectedEdge[2, 2] -> 1, DirectedEdge[5, 5] -> Rational[13, 18], 
         DirectedEdge[6, 6] -> Rational[13, 18], DirectedEdge[6, 2] -> 
         Rational[1, 9], DirectedEdge[5, 2] -> Rational[1, 9], 
         DirectedEdge[3, 3] -> 1, DirectedEdge[1, 6] -> Rational[5, 36], 
         DirectedEdge[5, 3] -> Rational[1, 6], DirectedEdge[7, 7] -> 1, 
         DirectedEdge[9, 9] -> 1, DirectedEdge[8, 8] -> 1, DirectedEdge[4, 4] -> 
         Rational[3, 4], DirectedEdge[1, 5] -> Rational[1, 9], 
         DirectedEdge[1, 2] -> Rational[2, 9], DirectedEdge[4, 2] -> 
         Rational[1, 12], DirectedEdge[6, 3] -> Rational[1, 6], 
         DirectedEdge[1, 7] -> Rational[5, 36], DirectedEdge[1, 9] -> 
         Rational[1, 12], DirectedEdge[1, 8] -> Rational[1, 9]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, VertexStyle -> {1 -> Hue[
           Rational[1, 2]], 6 -> Hue[
           Rational[1, 5]], 5 -> Hue[
           Rational[1, 5]], 8 -> Hue[
           Rational[1, 5]], 2 -> Hue[
           Rational[1, 3]], 9 -> Hue[
           Rational[1, 5]], 4 -> Hue[
           Rational[1, 5]], 3 -> Hue[
           Rational[1, 4]], 7 -> Hue[
           Rational[1, 5]]}}]], Typeset`boxes = GraphicsGroupBox[{{
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.2601772196190895`, 1.0630446364311008`}, 
            0.02539646533048903], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.5871606967321028, 0.410903305733183}, 
            0.02539646533048903], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.0606194677203264`, 2.060099833704972}, 
            0.02539646533048903], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.6135865663395277, 1.9164525103944277`}, 
            0.02539646533048903], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.5245751919711887`, 1.011267806694702}, 
            0.02539646533048903], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.7129168785264788}, 0.02539646533048903], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1.9743584795954847`, 0.}, 0.02539646533048903], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.6048267188774163, 1.10712481794348}, 
            0.02539646533048903], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.13931930521778757`, 1.3103365999370833`}, 
            0.02539646533048903], 
           Hue[
            Rational[1, 4]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"]}, {
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       Arrowheads[{{0.031026067360623733`, 0.7}}], {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$6", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$7", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["2", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.031026067360623733`], 
           ArrowBox[{
             DynamicLocation["VertexID$2", Automatic, Center], {
             0.5910205453692073, 0.41017980067355686`}, {0.6580599208093656, 
             0.387413265773323}, {0.7160277618010693, 0.3467644972614652}, {
             0.7602743876304782, 0.2914939890904491}, {0.7872507152327084, 
             0.22603506517730176`}, {0.7947929360539746, 
             0.15563827635953453`}, {0.7822960781289211, 
             0.08595024644929028}, {0.7507625317188318, 
             0.022560748726301566`}, {
             0.7027216462021483, -0.029445657509305362`}, {
             0.6420268474619343, -0.06589746647203015}, {
             0.5735465492652851, -0.0838708281405681}, {
             0.50277365106051, -0.08192407431263027}, {
             0.435384944913962, -0.06021335680573309}, {
             0.3767857721655945, -0.020480122303908}, {0.3316764535227814, 
             0.03408857148979774}, {0.3036752698343472, 
             0.09911569416039287}, {0.2950282347784526, 
             0.16938533024534916`}, {0.30642893899852097`, 
             0.23926105502911493`}, {0.33696291623827335`, 
             0.3031380399665111}, {0.3841809939451417, 0.3558926237335944}, {
             0.4442957447886916, 0.3932932881900981}, {0.5124852814460095, 
             0.4123400743029937}, {0.5832800268540707, 0.41150521301042403`}, 
             
             DynamicLocation["VertexID$2", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$9"], 
         InsetBox[
          FormBox[
           FractionBox["3", "4"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$9", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.031026067360623733`], 
           ArrowBox[{
             DynamicLocation["VertexID$3", Automatic, Center], {
             2.0575961302740415`, 2.0626060902278667`}, {2.010037279068825, 
             2.1150536701797593`}, {1.9790901230479307`, 2.178731503881829}, {
             1.9672369764055189`, 2.248531904206208}, {1.9754285964304361`, 
             2.318856084486802}, {2.003007921948877, 2.3840632449426744`}, {
             2.0477627771100595`, 2.438923029031492}, {2.106103313071356, 
             2.479035057583021}, {2.17334995473986, 2.5011818892994966`}, {
             2.244108755963923, 2.503587096172852}, {2.3127040554155145`, 
             2.4860577532326125`}, {2.3736337292365834`, 2.449999913324651}, {
             2.422010524004893, 2.3983058256674057`}, {2.4539540700916374`, 
             2.3351219445411715`}, {2.46690213147715, 2.2655163364544157`}, {
             2.4598161262464275`, 2.195072163518393}, {2.433264432681217, 
             2.12943985029092}, {2.3893767988517904`, 2.073883855406261}, {
             2.3316735125781136`, 2.0328604020656638`}, {2.264783034274131, 
             2.0096600382100145`}, {2.1940707417353362`, 2.006143697117632}, {
             2.125208565763778, 2.0225934293717494`}, {2.063720036752348, 
             2.0576897791930717`}, 
             DynamicLocation["VertexID$3", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$12"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          DynamicLocation["EdgeLabelID$12", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {{
         TagBox[{
           Arrowheads[0.031026067360623733`], 
           ArrowBox[{
             DynamicLocation["VertexID$4", Automatic, Center], {
             0.6096605787210706, 1.9165447724795746`}, {0.5398292631153752, 
             1.9282144053597012`}, {0.47607030370378184`, 
             1.9589940750384027`}, {0.4234978948195424, 2.006414901632712}, {
             0.3863289421035654, 2.0666731950434665`}, {0.3675448186696406, 
             2.1349355541998736`}, {0.36865222504279926`, 
             2.205726560845519}, {0.38956233462595635`, 
             2.2733679704109586`}, {0.4285979186041382, 2.332434171865441}, {
             0.48262787878787056`, 2.378187383483026}, {0.5473183973302576, 
             2.406957676868674}, {0.6174805582515248, 2.416437346991488}, {
             0.6874865575676724, 2.4058660163975305`}, {0.7517211172330674, 
             2.3760916261372422`}, {0.8050318943601953, 2.329502421240819}, {
             0.8431427577699881, 2.2698353862806395`}, {0.8629967823889437, 
             2.201876496669279}, {0.8630014494379675, 2.1310768289511475`}, {
             0.843156384566601, 2.0631153224122953`}, {0.8050533878801911, 
             2.0034432635045065`}, {0.7517487534514748, 
             1.9568470306181445`}, {0.6875181197451828, 
             1.9270641720503818`}, {0.6175135147422204, 1.9164836120860715`}, 
             
             DynamicLocation["VertexID$4", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$13"], 
         InsetBox[
          FormBox[
           FractionBox["13", "18"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$13", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.031026067360623733`], 
           ArrowBox[{
             DynamicLocation["VertexID$5", Automatic, Center], {
             2.524797482342569, 1.0151885818812505`}, {2.5387744147461895`, 
             1.0845949096284717`}, {2.5716496976093057`, 
             1.1472990462339632`}, {2.620786359016532, 1.198271406160905}, {
             2.682243079384818, 1.2334234259086285`}, {2.751090330159302, 
             1.2499355133467844`}, {2.821805778117796, 1.2464832111005086`}, {
             2.8887172393576717`, 1.2233434331086028`}, {2.9464576530131215`, 
             1.1823722529734442`}, {2.99039558063155, 1.1268560257298015`}, {
             3.0170067002586043`, 1.0612477847614241`}, {3.024156497177385, 
             0.9908100578333761}, {3.011271476286603, 0.9211927524602567}, {
             2.979385162935974, 0.8579799690088408}, {2.9310552024282304`, 
             0.8062420922830804}, {2.8701582077513503`, 0.7701290889450294}, {
             2.80157881108821, 0.7525376329481618}, {2.7308178607122007`, 
             0.7548787593125454}, {2.663551190337803, 0.7769646830539731}, {
             2.605174352646871, 0.8170238616773129}, {2.5603698345442627`, 
             0.8718430930506468}, {2.5327314684058364`, 0.9370252507931486}, {
             2.5244761658121755`, 1.0073419838647093`}, 
             DynamicLocation["VertexID$5", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$16"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          DynamicLocation["EdgeLabelID$16", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {{
         TagBox[{
           Arrowheads[0.031026067360623733`], 
           ArrowBox[{
             DynamicLocation["VertexID$6", Automatic, Center], {
             0.002791373785524659, 0.7101546107150333}, {0.04555678753565151, 
             0.6537302156580145}, {0.07078780192305495, 0.5875789580452321}, {
             0.07646060238123192, 0.5170069217579619}, {0.062120165738151156`,
              0.4476747874502988}, {0.02891675825432291, 
             0.3851437815233755}, {-0.020486328825139205`, 
             0.33442960246278974`}, {-0.08212640554546455, 
             0.2996001047247738}, {-0.15105923608515423`, 
             0.28344901050312776`}, {-0.22175562275066807`, 
             0.28727182140745194`}, {-0.2885449105720565, 
             0.31076190448695157`}, {-0.34606983838241334`, 
             0.3520350876835902}, {-0.3897162521468633, 
             0.4077807918792725}, {-0.41598321264053645`, 
             0.47352757702648607`}, {-0.4227638106267043, 
             0.544001802539932}, {-0.40951416496118037`, 
             0.6135506333029874}, {-0.3772970480512553, 
             0.6765954613920725}, {-0.3286966394107577, 
             0.7280793739351835}, {-0.2676112450465099, 
             0.7638727750886697}, {-0.19894060894092852`, 
             0.781104626632392}, {-0.12819289780929588`, 
             0.7783927379169165}, {-0.061042883427986666`, 
             0.755954633287513}, {-0.0028767613402781445`, 
             0.7155901041555162}, 
             DynamicLocation["VertexID$6", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$17"], 
         InsetBox[
          FormBox[
           FractionBox["13", "18"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$17", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.031026067360623733`], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.031026067360623733`], 
           ArrowBox[{
             DynamicLocation["VertexID$7", Automatic, Center], {
             1.9776522139041501`, 0.002138505407189989}, {2.041894887551974, 
             0.03189538450008669}, {2.1119037659657063`, 
             0.042447631370839484`}, {2.1820633401633147`, 
             0.03294883570084359}, {2.2467460136454824`, 
             0.004160909030634208}, {
             2.300763499695567, -0.04160702921874479}, {
             2.3397829810341886`, -0.1006838694087468}, {
             2.3606746510868666`, -0.16833097646573847`}, {
             2.361762760098875, -0.23912228235528996`}, {
             2.3429600293411617`, -0.3073795185051883}, {
             2.3057746518579374`, -0.36762767758245973`}, {
             2.253189318216295, -0.4150341714052177}, {
             2.1894219707698124`, -0.4457964595257333}, {
             2.1195874766676233`, -0.4574470562598659}, {
             2.049287357284902, -0.4490514511271031}, {
             1.9841604824446837`, -0.42128306722892656`}, {
             1.9294307688690089`, -0.37636924505028435`}, {
             1.8894881625923228`, -0.31791258439817605`}, {
             1.8675365153173624`, -0.25060197488759633`}, {
             1.8653365990381368`, -0.17983649361929413`}, {
             1.8830648720825844`, -0.11129233773688796`}, {
             1.9192993251459902`, -0.050467528801997424`}, {
             1.9711335426244054`, -0.0022409088792784693`}, 
             DynamicLocation["VertexID$7", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$20"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          DynamicLocation["EdgeLabelID$20", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {{
         TagBox[{
           Arrowheads[0.031026067360623733`], 
           ArrowBox[{
             DynamicLocation["VertexID$8", Automatic, Center], {
             0.43223731604946247`, 1.0418275283683962`}, {0.3860364851931193, 
             1.0299795199725925`}, {0.33836171732820586`, 
             1.0285622748314502`}, {0.2915386730720369, 
             1.0376449287028862`}, {0.24785146443786643`, 
             1.0567844134534725`}, {0.20943123175738482`, 
             1.085047070716036}, {0.17815218283599243`, 
             1.1210541974180739`}, {0.15554016573716906`, 
             1.1630493013884893`}, {0.14269823517937275`, 
             1.2089837861936135`}, {0.14025284355002102`, 
             1.2566168853426567`}, {0.14832328143532947`, 
             1.303624970892941}, {0.16651585841172795`, 
             1.3477149041852616`}, {0.19394310797027903`, 
             1.3867358992573562`}, {0.22926707972346708`, 
             1.4187844420376987`}, {0.2707646070229238, 
             1.4422971471733126`}, {0.3164113661167277, 1.456127022769127}, {
             0.3639806262899372, 1.4595994227082134`}, {0.4111518737795259, 
             1.4525449570984432`}, {0.4556240105944772, 
             1.4353077554149996`}, {0.4952276061997248, 1.408728679247843}, {
             0.5280307262256208, 1.374104303566394}, {0.5524331756888269, 
             1.3331236674688522`}, {0.5672445593714074, 1.2877858798279576`}, 
             
             DynamicLocation["VertexID$8", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$21"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          DynamicLocation["EdgeLabelID$21", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {{
         TagBox[{
           Arrowheads[0.031026067360623733`], 
           ArrowBox[{
             DynamicLocation["VertexID$9", Automatic, Center], {
             0.11987918567791003`, 1.28109723641708}, {0.07509962455986885, 
             1.2303673594656608`}, {0.018305980878284153`, 
             1.1935813356685758`}, {-0.046299719812089926`, 
             1.1734608747460142`}, {-0.113937456584866, 
             1.1714946413704537`}, {-0.17960287543207795`, 
             1.1878281124360521`}, {-0.23843754942118703`, 
             1.2212528135719753`}, {-0.286088442057582, 
             1.2692957312642352`}, {-0.31902997802006017`, 
             1.3284022851974775`}, {-0.33482489202761145`, 
             1.3941993231317538`}, {-0.33230455625513994`, 
             1.46181867995378}, {-0.31165544430490055`, 
             1.5262573615440873`}, {-0.2744053344716678, 
             1.5827477043191374`}, {-0.22331027308897564`, 
             1.6271101232312009`}, {-0.16215066126747524`, 
             1.6560623492470687`}, {-0.09545155207883843, 
             1.6674622765658211`}, {-0.028147852726085408`, 
             1.6604664518921508`}, {0.03478079741079734, 
             1.6355924795238228`}, {0.08867845835578161, 
             1.5946807250504442`}, {0.129557371374773, 1.5407581511150665`}, {
             0.1543930036852043, 1.4778143597042246`}, {0.1613478263864472, 
             1.410506411060511}, {0.14990726881838945`, 1.3438142589587645`}, 
             
             DynamicLocation["VertexID$9", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$22"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          DynamicLocation["EdgeLabelID$22", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}}}]}, 
    DynamicBox[GraphComputation`NetworkGraphicsBox[
     1, Typeset`graph, Typeset`boxes], {
     CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
      SynchronousUpdating -> False, TrackedSymbols :> {}},
     ImageSizeCache->{{1.7606933090100947`, 
      287.2793021133532}, {-127.43871499653591`, 121.2393066909899}}]]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.558672613079369*^9, 3.5586745329923153`*^9, {3.559557410556624*^9, 
   3.559557426992676*^9}, 3.5595635031113377`*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"labelsGame2", "=", "labelsGame1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"edgeGame2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "12"}], ",", "4"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "12"}], ",", "9"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "9"}], ",", "5"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "9"}], ",", "8"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"5", "/", "36"}], ",", "6"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"5", "/", "36"}], ",", "7"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"2", "/", "9"}], ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"1", ",", 
       RowBox[{"1", "/", "9"}], ",", "lost"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"won", ",", "1", ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"lost", ",", "1", ",", "lost"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"3", "/", "4"}], ",", "4"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"1", "/", "12"}], ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"4", ",", 
       RowBox[{"1", "/", "6"}], ",", "lost"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"9", ",", 
       RowBox[{"3", "/", "4"}], ",", "9"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"9", ",", 
       RowBox[{"1", "/", "12"}], ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"9", ",", 
       RowBox[{"1", "/", "6"}], ",", "lost"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"13", "/", "18"}], ",", "5"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"1", "/", "9"}], ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"5", ",", 
       RowBox[{"1", "/", "6"}], ",", "lost"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Edge", "[", 
      RowBox[{"8", ",", 
       RowBox[{"13", "/", "18"}], ",", "8"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"8", ",", 
       RowBox[{"1", "/", "9"}], ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"8", ",", 
       RowBox[{"1", "/", "6"}], ",", "lost"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"25", "/", "36"}], ",", "6"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"5", "/", "36"}], ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"6", ",", 
       RowBox[{"1", "/", "6"}], ",", "lost"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"25", "/", "36"}], ",", "7"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"5", "/", "36"}], ",", "won"}], "]"}], ",", 
     RowBox[{"Edge", "[", 
      RowBox[{"7", ",", 
       RowBox[{"1", "/", "6"}], ",", "lost"}], "]"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.558672927762569*^9, 3.558673369832284*^9, {3.558673680998494*^9, 
   3.558673895423319*^9}, {3.559557498886681*^9, 3.559557517879985*^9}, {
   3.559557563112156*^9, 3.559557564054269*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"game2", "=", 
    RowBox[{"MC", "[", 
     RowBox[{
      RowBox[{"TransitionMatrix", "[", 
       RowBox[{
        RowBox[{"Length", "@", "labelsGame2"}], ",", "edgeGame2"}], "]"}], 
      ",", "labelsGame2"}], "]"}]}], ")"}], "//", "PlotMC"}]], "Input",
 CellChangeTimes->{{3.558671668730261*^9, 3.558671692086938*^9}, {
  3.5586717735396957`*^9, 3.558671795650897*^9}, {3.55867211170418*^9, 
  3.558672140534251*^9}, {3.55867454180235*^9, 3.558674547241844*^9}, {
  3.55955752614192*^9, 3.559557558456512*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 4, 9, 5, 8, 6, 7, 2, 
      3}, {{{1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {1, 8}, {1, 9}, {
       8, 8}, {9, 9}, {2, 2}, {2, 8}, {2, 9}, {4, 4}, {4, 8}, {4, 9}, {6, 
       6}, {6, 8}, {6, 9}, {7, 7}, {7, 8}, {7, 9}, {5, 5}, {5, 8}, {5, 9}, {3,
        3}, {3, 8}, {3, 9}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[1, 2] -> Rational[2, 9], DirectedEdge[5, 5] -> 
         Rational[13, 18], DirectedEdge[1, 8] -> Rational[1, 9], 
         DirectedEdge[4, 4] -> Rational[3, 4], DirectedEdge[9, 9] -> 
         Rational[3, 4], DirectedEdge[1, 7] -> Rational[5, 36], 
         DirectedEdge[9, 2] -> Rational[1, 12], DirectedEdge[4, 3] -> 
         Rational[1, 6], DirectedEdge[7, 7] -> Rational[25, 36], 
         DirectedEdge[5, 3] -> Rational[1, 6], DirectedEdge[6, 6] -> 
         Rational[25, 36], DirectedEdge[6, 3] -> Rational[1, 6], 
         DirectedEdge[1, 5] -> Rational[1, 9], DirectedEdge[8, 2] -> 
         Rational[1, 9], DirectedEdge[3, 3] -> 1, DirectedEdge[8, 3] -> 
         Rational[1, 6], DirectedEdge[1, 6] -> Rational[5, 36], 
         DirectedEdge[4, 2] -> Rational[1, 12], DirectedEdge[7, 3] -> 
         Rational[1, 6], DirectedEdge[6, 2] -> Rational[5, 36], 
         DirectedEdge[1, 4] -> Rational[1, 12], DirectedEdge[8, 8] -> 
         Rational[13, 18], DirectedEdge[2, 2] -> 1, DirectedEdge[1, 3] -> 
         Rational[1, 9], DirectedEdge[1, 9] -> Rational[1, 12], 
         DirectedEdge[5, 2] -> Rational[1, 9], DirectedEdge[9, 3] -> 
         Rational[1, 6], DirectedEdge[7, 2] -> Rational[5, 36]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, VertexStyle -> {5 -> Hue[
           Rational[1, 5]], 3 -> Hue[
           Rational[1, 4]], 8 -> Hue[
           Rational[1, 5]], 4 -> Hue[
           Rational[1, 5]], 2 -> Hue[
           Rational[1, 3]], 1 -> Hue[
           Rational[1, 2]], 7 -> Hue[
           Rational[1, 5]], 6 -> Hue[
           Rational[1, 5]], 9 -> Hue[
           Rational[1, 5]]}}]], Typeset`boxes = GraphicsGroupBox[{{
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.8100075407445243, 0.7732531766484123}, 
            0.02069034396772051], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.5148892838448214, 0.00007596113345142985}, 
            0.02069034396772051], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.8842136227473502}, 0.02069034396772051], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1.517723483326876, 0.}, 0.02069034396772051], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.49320548487329474`, 1.755894333980136}, 
            0.02069034396772051], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.5365671300036468`, 1.7561424533352517`}, 
            0.02069034396772051], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.030485589479236, 0.9051788305215672}, 
            0.02069034396772051], 
           Hue[
            Rational[1, 5]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.2227058100436097`, 0.7429831928595992}, 
            0.02069034396772051], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.012984725815939, 1.134165087895178}, 
            0.02069034396772051], 
           Hue[
            Rational[1, 4]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"]}, {
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       Arrowheads[{{0.03366378940986355, 0.7}}], {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$6", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$7", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["2", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03366378940986355], 
           ArrowBox[{
             DynamicLocation["VertexID$2", Automatic, Center], {
             0.5181770798815853, -0.0020716627380170105`}, {
             0.57137129565806, -0.04879390988748447}, {
             0.6093329724830351, -0.10855597196206661`}, {
             0.6290171517453492, -0.1765642512928889}, {
             0.6288449381969136, -0.24736370971782176`}, {
             0.6088301453246742, -0.3152754247385118}, {
             0.5705781873517151, -0.37485210374972433`}, {
             0.5171573067416286, -0.42131501891454093`}, {
             0.4528524662261584, -0.45093731553465466`}, {
             0.38282164601702495`, -0.46134294822114175`}, {
             0.3126821150780221, -0.45169726678193106`}, {
             0.24805986221096815`, -0.4227739646682962}, {
             0.19413832771138576`, -0.3768930199528653}, {
             0.15524263245205844`, -0.3177346066791509}, {
             0.13449265395481033`, -0.25004390301067214`}, {
             0.13355277669870239`, -0.17925047392637422`}, {
             0.15249838953859518`, -0.11103275830285782`}, {
             0.18980983866081386`, -0.050862593477006196`}, {
             0.24249432111770594`, -0.0035663116039087173`}, {
             0.30632594169206756`, 0.027062387121646048`}, {
             0.37618467779826764`, 0.03856673240568373}, {
             0.44646706357645566`, 0.030023944798816038`}, {
             0.5115356516405483, 0.00211925311237271}, 
             DynamicLocation["VertexID$2", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$9"], 
         InsetBox[
          FormBox[
           FractionBox["3", "4"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$9", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03366378940986355], 
           ArrowBox[{
             DynamicLocation["VertexID$3", Automatic, Center], {
             0.000145974222079015, 
             0.8802892651439773}, {-0.007267708446339477, 
             0.8098788235883241}, {-0.034124480717747124`, 
             0.7443707572611014}, {-0.07827012373682651, 
             0.689019558780833}, {-0.13616365440960182`, 
             0.6482650243458712}, {-0.2031613525557086, 
             0.6253761315396817}, {-0.2738892401277974, 
             0.6221888301168423}, {-0.3426741354246265, 
             0.6389587779335266}, {-0.40399870684312705`, 
             0.6743408342772059}, {-0.4529440256785031, 
             0.7254969554639558}, {-0.485584120200081, 
             0.7883238382482586}, {-0.49930088327468947`, 
             0.8577820514524948}, {-0.49299407436148357`, 
             0.9283002557128301}, {-0.46716957132770714`, 
             0.994222088316517}, {-0.42389879328517166`, 
             1.0502598678796269`}, {-0.3666525491978688, 
             1.0919187265853934`}, {-0.30002263949373986`, 
             1.1158571497496221`}, {-0.2293535414004352, 
             1.1201550033358845`}, {-0.16031372103377872`, 
             1.1044675505627326`}, {-0.09844095788933241, 
             1.07005310371782}, {-0.04869815188855314, 
             1.0196720931886643`}, {-0.015075242310829101`, 
             0.9573656495227136}, {-0.00026916924452985436`, 
             0.8881314587559729}, 
             DynamicLocation["VertexID$3", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$12"], 
         InsetBox[
          FormBox[
           FractionBox["3", "4"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$12", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$3", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["1", "12"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$3", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03366378940986355], 
           ArrowBox[{
             DynamicLocation["VertexID$4", Automatic, Center], {
             1.521083930142237, 0.002032065026959573}, {1.5862454757711346`, 
             0.0297189923036216}, {1.656556038095698, 0.03802668731329367}, {
             1.726375909650083, 0.026288778347074715`}, {
             1.7901047419539018`, -0.004553220679606507}, {
             1.8426307572108924`, -0.05202543036056051}, {
             1.8797407710771652`, -0.11232003908816651`}, {
             1.898458138005596, -0.18060073288983014`}, {
             1.8972815121028048`, -0.2513906228618802}, {
             1.8763052721601012`, -0.319011554004805}, {
             1.837211951400077, -0.37803955789045174`}, {
             1.7831372791593465`, -0.4237399166727155}, {
             1.7184186597007483`, -0.4524469413555907}, {
             1.6482472630174183`, -0.46185800177835074`}, {
             1.5782516339066082`, -0.4512182237660068}, {
             1.5140462186054346`, -0.4213810386311141}, {
             1.4607810222916424`, -0.37473972826762547`}, {
             1.422728520044209, -0.3150354566995109}, {
             1.4029409557070722`, -0.24705718613917887`}, {
             1.403005517188186, -0.176257547703766}, {
             1.422917025921841, -0.10831547833051491`}, {
             1.4610783522485842`, -0.048680705389269385`}, {
             1.5144285233945383`, -0.0021366165114381774`}, 
             DynamicLocation["VertexID$4", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$15"], 
         InsetBox[
          FormBox[
           FractionBox["13", "18"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$15", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$16"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$16", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03366378940986355], 
           ArrowBox[{
             DynamicLocation["VertexID$5", Automatic, Center], {
             0.4897375332713252, 1.7540517263824478`}, {0.42314104067054853`, 
             1.7300204937040193`}, {0.352477999192647, 1.7256241839034672`}, {
             0.28341638914394474`, 1.7412154310713834`}, {
             0.22149573780054274`, 1.775543639704793}, {0.17168278626258052`, 
             1.8258552967024184`}, {0.1379731002800174, 
             1.8881148344595127`}, {0.12307058039669413`, 
             1.9573283293279067`}, {0.12817057834736015`, 
             2.0279440711400074`}, {0.152864016241479, 2.094297873561115}, {
             0.19517019926671267`, 2.151067406310694}, {0.2516956899597479, 
             2.193699106636644}, {0.31790650051942826`, 2.2187734268826693`},
              {0.38849177024022574`, 2.224279121136103}, {0.4577897569960373, 
             2.209774570044758}, {0.5202419734081005, 2.176423203716062}, {
             0.5708390408067955, 2.126900181378749}, {0.6055224984242928, 
             2.0651778131605307`}, {0.6215103381468791, 
             1.9962069355977872`}, {0.617520153234156, 1.925519798188409}, {
             0.5938720019376637, 1.8587863140067158`}, {0.5524627351857815, 
             1.8013592681324804`}, {0.49661384754681825`, 1.75784496335508}, 
             DynamicLocation["VertexID$5", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$18"], 
         InsetBox[
          FormBox[
           FractionBox["13", "18"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$18", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["1", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03366378940986355], 
           ArrowBox[{
             DynamicLocation["VertexID$6", Automatic, Center], {
             1.5331509197450266`, 1.758079306076572}, {1.4771268050226338`, 
             1.8013677749839179`}, {1.4354860229680115`, 
             1.8586271693279859`}, {1.4115686383121593`, 
             1.9252646338805488`}, {1.4072930975636464`, 
             1.9959350854291125`}, {1.4230023477603388`, 
             2.0649699492953344`}, {1.4574363282130884`, 
             2.1268318435514084`}, {1.5078330417166717`, 2.17655874008445}, {
             1.570150098166339, 2.2101619757354856`}, {1.6393889602600238`, 
             2.2249461884890205`}, {1.7099958830899007`, 
             2.2197255161888423`}, {1.776307387704034, 2.1949187161819923`}, {
             1.833004536587497, 2.1525155762126866`}, {1.8755395729982203`, 
             2.0959173107948446`}, {1.9005007028262648`, 
             2.0296637450909705`}, {1.9058857593189689`, 1.959069169255851}, {
             1.8912627996458131`, 1.889796071871893}, {1.857804751630369, 
             1.8274009439069123`}, {1.8081953315870398`, 
             1.7768885848872171`}, {1.7464137797230515`, 
             1.7423106610043786`}, {1.6774156797768813`, 
             1.7264407153652668`}, {1.6067354647914514`, 
             1.7305516982627591`}, {1.540042492583881, 1.754313862071856}, 
             DynamicLocation["VertexID$6", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$21"], 
         InsetBox[
          FormBox[
           FractionBox["25", "36"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$21", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03366378940986355], 
           ArrowBox[{
             DynamicLocation["VertexID$7", Automatic, Center], {
             2.0305928223318324`, 0.909104437759688}, {2.0425286664632085`, 
             0.9788907444082101}, {2.0735512520002706`, 
             1.0425318644279407`}, {2.121172214443022, 1.0949230555462581`}, {
             2.1815718105190474`, 1.1318619478499408`}, {2.249905305075304, 
             1.1503856216891148`}, {2.320691573986555, 1.1490082675610287`}, {
             2.388252752703584, 1.1278403649456132`}, {2.4471696656229764`, 
             1.088579820593569}, {2.492716505658704, 1.0343757770771496`}, {
             2.521239897765786, 0.9695760157081776}, {2.530451941206423, 
             0.8993782149846657}, {2.519613725233065, 0.8294130376084529}, {
             2.4895945981416228`, 0.7652924872408999}, {2.442802435642068, 
             0.7121597619260309}, {2.3829905018168804`, 0.6742767110607502}, {
             2.3149563946170395`, 0.6546819865592274}, {2.244157223893776, 
             0.654947308379444}, {2.1762718890684956`, 0.6750513946911763}, {
             2.116745566754466, 0.7133816689210373}, {2.070352945608265, 
             0.7668636067501325}, {2.0408152419477292`, 0.8312073479627202}, {
             2.0305017158434744`, 0.9012517920683509}, 
             DynamicLocation["VertexID$7", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$24"], 
         InsetBox[
          FormBox[
           FractionBox["25", "36"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$24", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$25"], 
        InsetBox[
         FormBox[
          FractionBox["5", "36"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$25", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03366378940986355], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$26"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$26", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03366378940986355], 
           ArrowBox[{
             DynamicLocation["VertexID$8", Automatic, Center], {
             1.5000678162855068`, 0.7593831314570137}, {1.5334085699063742`, 
             0.7581279014710498}, {1.5658866310000545`, 0.750488725997204}, {
             1.596291229301055, 0.7367503907094097}, {1.6234888924801334`, 
             0.7174250557337245}, {1.6464657015791002`, 0.6932331625057303}, {
             1.6643650895395745`, 0.665076575976723}, {1.6765197737103361`, 
             0.6340049634174418}, {1.682476631901056, 0.6011766632052667}, {
             1.6820135946121948`, 0.567815502392217}, {1.6751479237049067`, 
             0.535165172879058}, {1.6621355688851562`, 0.5044428670350957}, {
             1.6434616259920805`, 0.47679390121083404`}, {1.6198222528021318`,
              0.4532490187623832}, {1.5920987165212162`, 
             0.4346859643152884}, {1.5613245404648555`, 
             0.42179676176520187`}, {1.5286469746861429`, 
             0.4150619158795893}, {1.495284226912425, 0.41473249925534805`}, {
             1.4624800482057818`, 0.42082079242401715`}, {1.431457366377309, 
             0.4330998260380434}, {1.403372695684598, 0.4511118422052309}, {
             1.3792730224022547`, 0.47418535953591456`}, {1.360056773555655, 
             0.501460205724126}, 
             DynamicLocation["VertexID$8", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$27"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          DynamicLocation["EdgeLabelID$27", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {{
         TagBox[{
           Arrowheads[0.03366378940986355], 
           ArrowBox[{
             DynamicLocation["VertexID$9", Automatic, Center], {
             0.8665197995761498, 1.3694923713585874`}, {0.8516640348544426, 
             1.399481611857244}, {0.8428543828644062, 1.4317684253105323`}, {
             0.8404198881740662, 1.4651468843336162`}, {0.8444514802837764, 
             1.498370288075766}, {0.8547985773674104, 1.530197727072563}, {
             0.8710747105730713, 1.5594404317871509`}, {0.8926719588130883, 
             1.5850061737011274`}, {0.9187836548972347, 
             1.6059400605538396`}, {0.9484345149246097, 
             1.6214602020090587`}, {0.98051706558749, 1.6309869136199295`}, {
             1.0138330088105414`, 1.6341643683106213`}, {1.0471379787370203`, 
             1.6308738866818453`}, {1.0791880193678753`, 
             1.6212383697411967`}, {1.1087860468924737`, 1.605617708493794}, {
             1.134826561321456, 1.5845953418471261`}, {1.156336937421597, 
             1.5589564648985645`}, {1.1725137527171912`, 
             1.5296587015360616`}, {1.1827527956903496`, 1.497796336743931}, {
             1.1866716333600755`, 1.4645594445536054`}, {1.184123895330619, 
             1.4311894382292691`}, {1.175204740793319, 1.398932702909452}, {
             1.1602473042868833`, 1.3689940425468219`}, 
             DynamicLocation["VertexID$9", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$28"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          DynamicLocation["EdgeLabelID$28", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}}}]}, 
    DynamicBox[GraphComputation`NetworkGraphicsBox[
     1, Typeset`graph, Typeset`boxes], {
     CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
      SynchronousUpdating -> False, TrackedSymbols :> {}},
     ImageSizeCache->{{0.6937067163994284, 
      341.10628870596395`}, {-157.13944617067082`, 153.75822339564738`}}]]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImageSize->{425., Automatic}]], "Output",
 CellChangeTimes->{
  3.558673928896667*^9, 3.558674548103462*^9, {3.559557560090495*^9, 
   3.5595575663787403`*^9}, 3.559563503343012*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComputeDistances", "[", 
  RowBox[{
   RowBox[{"JoinMC", "[", 
    RowBox[{"game1", ",", "game2"}], "]"}], ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "10"}], "}"}], "}"}], ",", 
   RowBox[{"Verbose", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.559558560737713*^9, 3.559558597818318*^9}, {
  3.559558653925254*^9, 3.559558659093215*^9}, {3.559558716337626*^9, 
  3.5595587325272503`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Pairs to compute: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "10"}], "}"}], "}"}]}],
  SequenceForm["Pairs to compute: ", {{1, 10}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503444935*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Picked pair: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "10"}], "}"}], "}"}]}],
  SequenceForm["Picked pair: ", {{1, 10}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503447845*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "10"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm[
  "Reachable states from ", {{1, 10}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503451239*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "10"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"13\"\>",
        HoldForm], 
       TagBox["\<\"14\"\>",
        HoldForm], 
       TagBox["\<\"15\"\>",
        HoldForm], 
       TagBox["\<\"16\"\>",
        HoldForm], 
       TagBox["\<\"17\"\>",
        HoldForm], 
       TagBox["\<\"18\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0", "0", "0", "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0", "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "12"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0", "0"},
      {
       TagBox["\<\"5\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", "0", 
       StyleBox[
        FractionBox["5", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"7\"\>",
        HoldForm], "0", "0", "0", "0", "0", 
       StyleBox[
        FractionBox["5", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"8\"\>",
        HoldForm], "0", "0", "0", "0", "0", "0", 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"9\"\>",
        HoldForm], "0", "0", "0", "0", "0", "0", "0", 
       StyleBox[
        FractionBox["1", "12"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "5", "6", "7", "8", "9"}, {
       "11", "12", "13", "14", "15", "16", "17", "18"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503455413*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"2", ",", "11"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox["1",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$, TableHeadings -> {{"2"}, {"11"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503460472*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "12"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"12\"\>",
        HoldForm]},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox["1",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$, TableHeadings -> {{"3"}, {"12"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.5595635034634666`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"4", ",", "13"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"13\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "12"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["3", "4"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4"}, {"11", "12", "13"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503467231*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"5", ",", "14"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"14\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"5\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["13", "18"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "5"}, {"11", "12", "14"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.5595635034706593`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"6", ",", "15"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"15\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["5", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["25", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "6"}, {"11", "12", "15"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503474375*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"7", ",", "16"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"16\"\>",
        HoldForm]},
      {
       TagBox["\<\"7\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["5", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["25", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"7"}, {"11", "12", "16"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503479412*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"8", ",", "17"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"17\"\>",
        HoldForm]},
      {
       TagBox["\<\"8\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["13", "18"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"8"}, {"11", "12", "17"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503483429*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"9", ",", "18"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"18\"\>",
        HoldForm]},
      {
       TagBox["\<\"9\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "12"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["3", "4"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"9"}, {"11", "12", "18"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.5595635034864283`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"\<\"d(2,11)\"\>", ",", "\<\"d(3,12)\"\>", ",", "\<\"d(4,13)\"\>",
      ",", "\<\"d(5,14)\"\>"}], "}"}]}],
  SequenceForm[
  "Variables detected to be zero:", {
   "d(2,11)", "d(3,12)", "d(4,13)", "d(5,14)"}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.5595635034891376`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["5", "36"]}], 
        RowBox[{"-", 
         FractionBox["5", "36"]}], 
        RowBox[{"-", 
         FractionBox["1", "9"]}], 
        RowBox[{"-", 
         FractionBox["1", "12"]}]},
       {"0", 
        FractionBox["11", "36"], "0", "0", "0"},
       {"0", "0", 
        FractionBox["11", "36"], "0", "0"},
       {"0", "0", "0", 
        FractionBox["5", "18"], "0"},
       {"0", "0", "0", "0", 
        FractionBox["1", "4"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {5, 5}, 0, {
       1, {{0, 5, 6, 7, 8, 9}, {{1}, {2}, {3}, {4}, {5}, {2}, {3}, {4}, {
         5}}}, {1, Rational[-5, 36], Rational[-5, 36], Rational[-1, 9], 
         Rational[-1, 12], Rational[11, 36], Rational[11, 36], Rational[
         5, 18], Rational[1, 4]}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,10)\"\>"},
        {"\<\"d(6,15)\"\>"},
        {"\<\"d(7,16)\"\>"},
        {"\<\"d(8,17)\"\>"},
        {"\<\"d(9,18)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["1", "18"]},
        {
         FractionBox["11", "36"]},
        {
         FractionBox["5", "18"]},
        {
         FractionBox["1", "4"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[
      Automatic, {5}, 0, {1, {{0, 5}, {{1}, {2}, {3}, {4}, {5}}}, {0, 
         Rational[1, 18], 
         Rational[11, 36], 
         Rational[5, 18], 
         Rational[1, 4]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,10)\"\>"},
        {"\<\"d(6,15)\"\>"},
        {"\<\"d(7,16)\"\>"},
        {"\<\"d(8,17)\"\>"},
        {"\<\"d(9,18)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["71", "198"]},
        {
         FractionBox["2", "11"]},
        {"1"},
        {"1"},
        {"1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {5, 5}, 0, {
     1, {{0, 5, 6, 7, 8, 9}, {{1}, {2}, {3}, {4}, {5}, {2}, {3}, {4}, {5}}}, {
      1, Rational[-5, 36], Rational[-5, 36], Rational[-1, 9], 
       Rational[-1, 12], Rational[11, 36], Rational[11, 36], Rational[5, 18], 
       Rational[1, 4]}}]], 
   MatrixForm[{"d(1,10)", "d(6,15)", "d(7,16)", "d(8,17)", "d(9,18)"}], "==", 
   
   MatrixForm[
    SparseArray[
    Automatic, {5}, 0, {1, {{0, 5}, {{1}, {2}, {3}, {4}, {5}}}, {0, 
       Rational[1, 18], 
       Rational[11, 36], 
       Rational[5, 18], 
       Rational[1, 4]}}]], ";  Solution:", 
   MatrixForm[{"d(1,10)", "d(6,15)", "d(7,16)", "d(8,17)", "d(9,18)"}], "=", 
   MatrixForm[{
     Rational[71, 198], 
     Rational[2, 11], 1, 1, 1}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.5595635034944143`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "10"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", 
    FractionBox["42", "11"]}], 
   "\[InvisibleSpace]", "\<\" for introducing \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"1", ",", "6"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm["Non optimal schedule for: ", {1, 10}, " reduced cost: ", 
   Rational[-42, 11], " for introducing ", {1, 6}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503501916*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "10"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm[
  "Reachable states from ", {{1, 10}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.5595635035046043`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "10"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"13\"\>",
        HoldForm], 
       TagBox["\<\"14\"\>",
        HoldForm], 
       TagBox["\<\"15\"\>",
        HoldForm], 
       TagBox["\<\"16\"\>",
        HoldForm], 
       TagBox["\<\"17\"\>",
        HoldForm], 
       TagBox["\<\"18\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0", "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "12"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"5\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", "0", 
       StyleBox[
        FractionBox["5", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"7\"\>",
        HoldForm], "0", "0", "0", "0", "0", 
       StyleBox[
        FractionBox["5", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"8\"\>",
        HoldForm], "0", "0", "0", "0", "0", "0", 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"9\"\>",
        HoldForm], "0", "0", "0", "0", "0", "0", "0", 
       StyleBox[
        FractionBox["1", "12"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "5", "6", "7", "8", "9"}, {
       "11", "12", "13", "14", "15", "16", "17", "18"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503509302*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"6", ",", "15"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"15\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["5", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["25", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "6"}, {"11", "12", "15"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503516588*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"7", ",", "16"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"16\"\>",
        HoldForm]},
      {
       TagBox["\<\"7\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["5", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["25", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"7"}, {"11", "12", "16"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.55956350352178*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"8", ",", "17"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"17\"\>",
        HoldForm]},
      {
       TagBox["\<\"8\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["13", "18"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"8"}, {"11", "12", "17"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.5595635035260477`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"9", ",", "18"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"18\"\>",
        HoldForm]},
      {
       TagBox["\<\"9\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "12"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["3", "4"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"9"}, {"11", "12", "18"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503530678*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503535433*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["5", "36"]}], 
        RowBox[{"-", 
         FractionBox["5", "36"]}], 
        RowBox[{"-", 
         FractionBox["1", "9"]}], 
        RowBox[{"-", 
         FractionBox["1", "12"]}]},
       {"0", 
        FractionBox["11", "36"], "0", "0", "0"},
       {"0", "0", 
        FractionBox["11", "36"], "0", "0"},
       {"0", "0", "0", 
        FractionBox["5", "18"], "0"},
       {"0", "0", "0", "0", 
        FractionBox["1", "4"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {5, 5}, 0, {
       1, {{0, 5, 6, 7, 8, 9}, {{1}, {2}, {3}, {4}, {5}, {2}, {3}, {4}, {
         5}}}, {1, Rational[-5, 36], Rational[-5, 36], Rational[-1, 9], 
         Rational[-1, 12], Rational[11, 36], Rational[11, 36], Rational[
         5, 18], Rational[1, 4]}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,10)\"\>"},
        {"\<\"d(6,15)\"\>"},
        {"\<\"d(7,16)\"\>"},
        {"\<\"d(8,17)\"\>"},
        {"\<\"d(9,18)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["1", "18"]},
        {
         FractionBox["11", "36"]},
        {
         FractionBox["5", "18"]},
        {
         FractionBox["1", "4"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[
      Automatic, {5}, 0, {1, {{0, 5}, {{1}, {2}, {3}, {4}, {5}}}, {0, 
         Rational[1, 18], 
         Rational[11, 36], 
         Rational[5, 18], 
         Rational[1, 4]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,10)\"\>"},
        {"\<\"d(6,15)\"\>"},
        {"\<\"d(7,16)\"\>"},
        {"\<\"d(8,17)\"\>"},
        {"\<\"d(9,18)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["71", "198"]},
        {
         FractionBox["2", "11"]},
        {"1"},
        {"1"},
        {"1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {5, 5}, 0, {
     1, {{0, 5, 6, 7, 8, 9}, {{1}, {2}, {3}, {4}, {5}, {2}, {3}, {4}, {5}}}, {
      1, Rational[-5, 36], Rational[-5, 36], Rational[-1, 9], 
       Rational[-1, 12], Rational[11, 36], Rational[11, 36], Rational[5, 18], 
       Rational[1, 4]}}]], 
   MatrixForm[{"d(1,10)", "d(6,15)", "d(7,16)", "d(8,17)", "d(9,18)"}], "==", 
   
   MatrixForm[
    SparseArray[
    Automatic, {5}, 0, {1, {{0, 5}, {{1}, {2}, {3}, {4}, {5}}}, {0, 
       Rational[1, 18], 
       Rational[11, 36], 
       Rational[5, 18], 
       Rational[1, 4]}}]], ";  Solution:", 
   MatrixForm[{"d(1,10)", "d(6,15)", "d(7,16)", "d(8,17)", "d(9,18)"}], "=", 
   MatrixForm[{
     Rational[71, 198], 
     Rational[2, 11], 1, 1, 1}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503541514*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Non optimal schedule for: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"6", ",", "15"}], "}"}], 
   "\[InvisibleSpace]", "\<\" reduced cost: \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1"}], "\[InvisibleSpace]", "\<\" for introducing \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], "\[InvisibleSpace]", "\<\" as basic\"\>"}],
  SequenceForm[
  "Non optimal schedule for: ", {6, 15}, " reduced cost: ", -1, 
   " for introducing ", {3, 1}, " as basic"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503546751*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reachable states from \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"1", ",", "10"}], "}"}], "}"}], 
   "\[InvisibleSpace]", "\<\" in the current coupling\"\>"}],
  SequenceForm[
  "Reachable states from ", {{1, 10}}, " in the current coupling"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503549169*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"1", ",", "10"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"13\"\>",
        HoldForm], 
       TagBox["\<\"14\"\>",
        HoldForm], 
       TagBox["\<\"15\"\>",
        HoldForm], 
       TagBox["\<\"16\"\>",
        HoldForm], 
       TagBox["\<\"17\"\>",
        HoldForm], 
       TagBox["\<\"18\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["2", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0", "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], "0", 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"4\"\>",
        HoldForm], "0", "0", 
       StyleBox[
        FractionBox["1", "12"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"5\"\>",
        HoldForm], "0", "0", "0", 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], "0", "0", "0", "0", 
       StyleBox[
        FractionBox["5", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"7\"\>",
        HoldForm], "0", "0", "0", "0", "0", 
       StyleBox[
        FractionBox["5", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"8\"\>",
        HoldForm], "0", "0", "0", "0", "0", "0", 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]},
      {
       TagBox["\<\"9\"\>",
        HoldForm], "0", "0", "0", "0", "0", "0", "0", 
       StyleBox[
        FractionBox["1", "12"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "4", "5", "6", "7", "8", "9"}, {
       "11", "12", "13", "14", "15", "16", "17", "18"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503552012*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"6", ",", "15"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"15\"\>",
        HoldForm]},
      {
       TagBox["\<\"2\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", "0"},
      {
       TagBox["\<\"3\"\>",
        HoldForm], 
       StyleBox["0",
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0"},
      {
       TagBox["\<\"6\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], "0", 
       StyleBox[
        FractionBox["25", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {{"2", "3", "6"}, {"11", "12", "15"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503556335*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"7", ",", "16"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"16\"\>",
        HoldForm]},
      {
       TagBox["\<\"7\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["5", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["25", "36"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"7"}, {"11", "12", "16"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503559176*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"8", ",", "17"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"17\"\>",
        HoldForm]},
      {
       TagBox["\<\"8\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "9"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["13", "18"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"8"}, {"11", "12", "17"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503561956*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"9", ",", "18"}], "}"}], "\[Rule]", 
  TagBox[
   TagBox[GridBox[{
      {
       StyleBox["\[Null]",
        ShowStringCharacters->False], 
       TagBox["\<\"11\"\>",
        HoldForm], 
       TagBox["\<\"12\"\>",
        HoldForm], 
       TagBox["\<\"18\"\>",
        HoldForm]},
      {
       TagBox["\<\"9\"\>",
        HoldForm], 
       StyleBox[
        FractionBox["1", "12"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["1", "6"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]], 
       StyleBox[
        FractionBox["3", "4"],
        StripOnInput->False,
        LineColor->RGBColor[1, 0, 0],
        FrontFaceColor->RGBColor[1, 0, 0],
        BackFaceColor->RGBColor[1, 0, 0],
        GraphicsColor->RGBColor[1, 0, 0],
        FontWeight->Bold,
        FontColor->RGBColor[1, 0, 0]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {False, True, {False}, False}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, TableHeadings -> {{"9"}, {"11", "12", "18"}}]]]}]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503564787*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Variables detected to be zero:\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["Variables detected to be zero:", {}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503567153*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Reduced Linear System: \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1", 
        RowBox[{"-", 
         FractionBox["5", "36"]}], 
        RowBox[{"-", 
         FractionBox["5", "36"]}], 
        RowBox[{"-", 
         FractionBox["1", "9"]}], 
        RowBox[{"-", 
         FractionBox["1", "12"]}]},
       {"0", 
        FractionBox["11", "36"], "0", "0", "0"},
       {"0", "0", 
        FractionBox["11", "36"], "0", "0"},
       {"0", "0", "0", 
        FractionBox["5", "18"], "0"},
       {"0", "0", "0", "0", 
        FractionBox["1", "4"]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
     SparseArray[
      Automatic, {5, 5}, 0, {
       1, {{0, 5, 6, 7, 8, 9}, {{1}, {2}, {3}, {4}, {5}, {2}, {3}, {4}, {
         5}}}, {1, Rational[-5, 36], Rational[-5, 36], Rational[-1, 9], 
         Rational[-1, 12], Rational[11, 36], Rational[11, 36], Rational[
         5, 18], Rational[1, 4]}}]]]], "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,10)\"\>"},
        {"\<\"d(6,15)\"\>"},
        {"\<\"d(7,16)\"\>"},
        {"\<\"d(8,17)\"\>"},
        {"\<\"d(9,18)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"==\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"0"},
        {
         FractionBox["1", "36"]},
        {
         FractionBox["11", "36"]},
        {
         FractionBox["5", "18"]},
        {
         FractionBox["1", "4"]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[
      SparseArray[
      Automatic, {5}, 0, {1, {{0, 5}, {{1}, {2}, {3}, {4}, {5}}}, {0, 
         Rational[1, 36], 
         Rational[11, 36], 
         Rational[5, 18], 
         Rational[1, 4]}}]]]], "\[InvisibleSpace]", "\<\";  Solution:\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {"\<\"d(1,10)\"\>"},
        {"\<\"d(6,15)\"\>"},
        {"\<\"d(7,16)\"\>"},
        {"\<\"d(8,17)\"\>"},
        {"\<\"d(9,18)\"\>"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"=\"\>", 
   "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", 
     TagBox[GridBox[{
        {
         FractionBox["137", "396"]},
        {
         FractionBox["1", "11"]},
        {"1"},
        {"1"},
        {"1"}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
         "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.5599999999999999]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      Column], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Reduced Linear System: ", 
   MatrixForm[
   SparseArray[
    Automatic, {5, 5}, 0, {
     1, {{0, 5, 6, 7, 8, 9}, {{1}, {2}, {3}, {4}, {5}, {2}, {3}, {4}, {5}}}, {
      1, Rational[-5, 36], Rational[-5, 36], Rational[-1, 9], 
       Rational[-1, 12], Rational[11, 36], Rational[11, 36], Rational[5, 18], 
       Rational[1, 4]}}]], 
   MatrixForm[{"d(1,10)", "d(6,15)", "d(7,16)", "d(8,17)", "d(9,18)"}], "==", 
   
   MatrixForm[
    SparseArray[
    Automatic, {5}, 0, {1, {{0, 5}, {{1}, {2}, {3}, {4}, {5}}}, {0, 
       Rational[1, 36], 
       Rational[11, 36], 
       Rational[5, 18], 
       Rational[1, 4]}}]], ";  Solution:", 
   MatrixForm[{"d(1,10)", "d(6,15)", "d(7,16)", "d(8,17)", "d(9,18)"}], "=", 
   MatrixForm[{
     Rational[137, 396], 
     Rational[1, 11], 1, 1, 1}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.5595635035702953`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total solved TPs: \"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["Total solved TPs: ", 2],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503574542*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Execution Time: \"\>", "\[InvisibleSpace]", 
   "0.1278519999999972`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Execution Time: ", 0.1278519999999972, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.559558660004817*^9, {3.559558717284645*^9, 3.55955873308181*^9}, 
   3.559563503576419*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "10"}], "}"}], "\[Rule]", 
   FractionBox["137", "396"]}], "}"}]], "Output",
 CellChangeTimes->{{3.559558593411542*^9, 3.559558599184648*^9}, 
   3.5595586601136227`*^9, {3.559558717404305*^9, 3.559558733204001*^9}, 
   3.559563503578313*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Bisimilarity Distance and Bisimilarity Quotient\
\>", "Subsection",
 CellChangeTimes->{{3.5578543051840076`*^9, 3.557854310966935*^9}, {
  3.559368474196784*^9, 3.559368474912208*^9}, {3.559368530169324*^9, 
  3.5593685783471603`*^9}, {3.559563479821954*^9, 3.559563482677684*^9}}],

Cell["\<\
Let \[ScriptCapitalM] be a (randomly generated) Markov chain with 50 states \
and outer-degree 2\
\>", "Text",
 CellChangeTimes->{{3.559368691084111*^9, 3.559368746400116*^9}, {
  3.559368786593587*^9, 3.559368822042343*^9}, {3.559370344410762*^9, 
  3.5593703445281143`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"numStates", "=", "50"}], ";", 
  RowBox[{"outerDegree", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mc", "=", 
   RowBox[{"RandomMarkovChain", "[", 
    RowBox[{"numStates", ",", "outerDegree"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"PlotMC", "@", "mc"}]}], "Input",
 CellChangeTimes->{{3.557854348409972*^9, 3.557854390563903*^9}, {
   3.557854817576297*^9, 3.557854818758997*^9}, {3.557854979732957*^9, 
   3.55785498203126*^9}, {3.557855117057027*^9, 3.5578551240410633`*^9}, {
   3.557855287685052*^9, 3.557855314685761*^9}, {3.557855427026854*^9, 
   3.557855447872963*^9}, {3.557855479723105*^9, 3.5578554798427067`*^9}, {
   3.5578556451605797`*^9, 3.5578556452953997`*^9}, {3.5578557153231916`*^9, 
   3.557855715450189*^9}, {3.5580621564486556`*^9, 3.558062156573456*^9}, {
   3.559303765859511*^9, 3.559303766145413*^9}, {3.5593143695437813`*^9, 
   3.5593143698771067`*^9}, {3.559314456250338*^9, 3.559314460351667*^9}, {
   3.559368752540123*^9, 3.559368775476655*^9}, {3.5593689659966183`*^9, 
   3.559368966077454*^9}, 3.559563551909025*^9}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 49, 2, 44, 50, 3, 4, 46, 5, 6, 7, 8, 9, 45, 10, 11, 37, 12, 13,
       48, 14, 43, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 41, 25, 26, 27, 28,
       29, 30, 31, 32, 47, 33, 34, 35, 36, 38, 39, 40, 
      42}, {{{1, 2}, {3, 4}, {3, 5}, {6, 2}, {6, 5}, {7, 8}, {7, 5}, {9, 5}, {
       10, 5}, {11, 5}, {12, 2}, {12, 5}, {13, 14}, {15, 2}, {15, 5}, {16, 
       17}, {18, 2}, {19, 20}, {19, 5}, {21, 22}, {21, 5}, {23, 14}, {23, 
       5}, {24, 14}, {24, 5}, {25, 4}, {26, 2}, {26, 5}, {27, 2}, {28, 22}, {
       28, 4}, {29, 1}, {29, 5}, {30, 2}, {31, 2}, {32, 33}, {34, 2}, {34, 
       5}, {35, 20}, {36, 5}, {37, 2}, {37, 5}, {38, 2}, {38, 5}, {39, 14}, {
       39, 2}, {40, 2}, {40, 5}, {41, 42}, {41, 5}, {43, 5}, {44, 5}, {45, 
       5}, {46, 47}, {17, 2}, {47, 20}, {47, 5}, {48, 2}, {49, 42}, {49, 
       20}, {33, 8}, {33, 5}, {50, 20}, {22, 2}, {4, 42}, {4, 5}, {14, 8}, {
       14, 5}, {8, 42}, {8, 20}, {42, 5}, {20, 42}, {20, 5}, {2, 2}, {2, 5}, {
       5, 42}, {5, 5}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[46, 47] -> Rational[154, 339], DirectedEdge[48, 50] -> 
         Rational[27, 37], DirectedEdge[44, 47] -> Rational[7, 9], 
         DirectedEdge[10, 49] -> Rational[1, 4], DirectedEdge[6, 50] -> 1, 
         DirectedEdge[4, 46] -> Rational[85, 117], DirectedEdge[38, 50] -> 
         Rational[21, 25], DirectedEdge[15, 50] -> Rational[121, 244], 
         DirectedEdge[19, 49] -> 1, DirectedEdge[11, 37] -> 1, 
         DirectedEdge[18, 50] -> Rational[423, 467], DirectedEdge[35, 50] -> 
         1, DirectedEdge[49, 50] -> Rational[124, 199], DirectedEdge[45, 50] -> 
         Rational[217, 698], DirectedEdge[23, 49] -> 1, DirectedEdge[28, 50] -> 
         Rational[1, 2], DirectedEdge[3, 50] -> Rational[551, 951], 
         DirectedEdge[38, 48] -> Rational[4, 25], DirectedEdge[2, 44] -> 
         Rational[135, 152], DirectedEdge[27, 50] -> 1, DirectedEdge[5, 50] -> 
         1, DirectedEdge[12, 49] -> 1, DirectedEdge[20, 44] -> 
         Rational[27, 139], DirectedEdge[39, 49] -> 1, DirectedEdge[32, 47] -> 
         Rational[5, 14], DirectedEdge[34, 50] -> 1, DirectedEdge[49, 49] -> 
         Rational[75, 199], DirectedEdge[30, 49] -> Rational[6, 19], 
         DirectedEdge[31, 49] -> Rational[286, 601], DirectedEdge[8, 50] -> 
         Rational[713, 1033], DirectedEdge[28, 49] -> Rational[1, 2], 
         DirectedEdge[16, 45] -> Rational[128, 657], DirectedEdge[13, 50] -> 
         Rational[40, 61], DirectedEdge[42, 48] -> 1, DirectedEdge[33, 50] -> 
         1, DirectedEdge[26, 48] -> 1, DirectedEdge[7, 50] -> 1, 
         DirectedEdge[29, 49] -> Rational[68, 237], DirectedEdge[48, 47] -> 
         Rational[10, 37], DirectedEdge[21, 50] -> Rational[30, 47], 
         DirectedEdge[14, 50] -> Rational[5, 7], DirectedEdge[3, 49] -> 
         Rational[400, 951], DirectedEdge[46, 48] -> Rational[185, 339], 
         DirectedEdge[30, 45] -> Rational[13, 19], DirectedEdge[50, 50] -> 
         Rational[410, 641], DirectedEdge[32, 50] -> Rational[9, 14], 
         DirectedEdge[41, 50] -> Rational[336, 743], DirectedEdge[44, 50] -> 
         Rational[2, 9], DirectedEdge[1, 49] -> 1, DirectedEdge[14, 43] -> 
         Rational[2, 7], DirectedEdge[9, 45] -> 1, DirectedEdge[25, 50] -> 
         Rational[22, 57], DirectedEdge[37, 49] -> 1, DirectedEdge[47, 50] -> 
         1, DirectedEdge[29, 50] -> Rational[169, 237], DirectedEdge[45, 46] -> 
         Rational[481, 698], DirectedEdge[13, 48] -> Rational[21, 61], 
         DirectedEdge[31, 50] -> Rational[315, 601], DirectedEdge[16, 50] -> 
         Rational[529, 657], DirectedEdge[15, 45] -> Rational[123, 244], 
         DirectedEdge[8, 49] -> Rational[320, 1033], DirectedEdge[25, 49] -> 
         Rational[35, 57], DirectedEdge[22, 49] -> 1, DirectedEdge[10, 50] -> 
         Rational[3, 4], DirectedEdge[24, 41] -> 1, DirectedEdge[40, 47] -> 
         Rational[19, 69], DirectedEdge[36, 38] -> 1, DirectedEdge[41, 46] -> 
         Rational[407, 743], DirectedEdge[2, 50] -> Rational[17, 152], 
         DirectedEdge[43, 49] -> 1, DirectedEdge[4, 50] -> Rational[32, 117], 
         DirectedEdge[17, 44] -> 1, DirectedEdge[50, 47] -> 
         Rational[231, 641], DirectedEdge[20, 43] -> Rational[112, 139], 
         DirectedEdge[21, 1] -> Rational[17, 47], DirectedEdge[18, 49] -> 
         Rational[44, 467], DirectedEdge[40, 48] -> Rational[50, 69]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, 
       VertexStyle -> {49 -> Hue[
           Rational[1, 2]], 31 -> Hue[
           Rational[1, 2]], 8 -> Hue[
           Rational[1, 2]], 22 -> Hue[
           Rational[1, 2]], 41 -> Hue[1], 47 -> Hue[1], 20 -> Hue[1], 10 -> 
         Hue[
           Rational[1, 2]], 46 -> Hue[1], 33 -> Hue[
           Rational[1, 2]], 48 -> Hue[1], 23 -> Hue[1], 19 -> Hue[
           Rational[1, 2]], 4 -> Hue[1], 6 -> Hue[1], 21 -> Hue[1], 26 -> 
         Hue[
           Rational[1, 2]], 43 -> Hue[1], 11 -> Hue[
           Rational[1, 2]], 50 -> Hue[1], 25 -> Hue[
           Rational[1, 2]], 27 -> Hue[1], 9 -> Hue[
           Rational[1, 2]], 30 -> Hue[1], 45 -> Hue[1], 7 -> Hue[
           Rational[1, 2]], 29 -> Hue[1], 34 -> Hue[1], 16 -> Hue[
           Rational[1, 2]], 1 -> Hue[1], 36 -> Hue[
           Rational[1, 2]], 24 -> Hue[
           Rational[1, 2]], 15 -> Hue[1], 2 -> Hue[1], 37 -> Hue[1], 42 -> Hue[
           Rational[1, 2]], 32 -> Hue[1], 39 -> Hue[
           Rational[1, 2]], 18 -> Hue[1], 38 -> Hue[1], 40 -> Hue[1], 35 -> 
         Hue[
           Rational[1, 2]], 13 -> Hue[1], 44 -> Hue[1], 3 -> Hue[1], 12 -> Hue[
           Rational[1, 2]], 17 -> Hue[
           Rational[1, 2]], 28 -> Hue[
           Rational[1, 2]], 5 -> Hue[
           Rational[1, 2]], 14 -> Hue[1]}}]], Typeset`boxes = 
    GraphicsGroupBox[{{
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.555693816990384, 1.4667685052475457`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{4.3181078039491005`, 2.295799709454606}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["49", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.2979630649362752`, 1.2697738610511513`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.163981005858982, 0.9823488629714492}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["44", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.6744342894359447`, 2.246311097781215}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["50", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.7703989814139205`, 2.4336780215012084`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.9260463482280772`, 2.9358487630695134`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.5485978179008069`, 2.9921212332959537`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["46", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.0622323161702907`, 2.5137836288699233`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.709352005976182, 1.1739325259858977`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$10"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.7639043227307445`, 1.526251627077532}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$11"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$11", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$11"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.5976852559364927`, 2.8402961467146497`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$12"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$12", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$12"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.5136109734298953`, 4.5707654894626355`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$13"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$13", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$13"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.593699000843167, 3.5141035975219523`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$14"], 
         InsetBox[
          FormBox["45", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$14", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$14"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.5127629662523843`, 1.9202007836923973`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$15"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$15", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$15"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{6.761671836609098, 2.430019018292614}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$16"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$16", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$16"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.789900671619046, 2.378909779358904}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$17"], 
         InsetBox[
          FormBox["37", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$17", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$17"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.217139518340124, 1.7080099303234704`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$18"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$18", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$18"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.5834851383239823`, 2.454019867354191}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$19"], 
         InsetBox[
          FormBox["13", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$19", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$19"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.073608554630302, 2.3554929514466774`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$20"], 
         InsetBox[
          FormBox["48", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$20", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$20"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.2699330630937036`, 1.2387588019654672`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$21"], 
         InsetBox[
          FormBox["14", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$21", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$21"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.893930029652238, 1.0387653536205983`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$22"], 
         InsetBox[
          FormBox["43", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$22", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$22"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.8573060418993514`, 3.3461247813852175`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$23"], 
         InsetBox[
          FormBox["15", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$23", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$23"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2.38325921427456, 3.2643640724847787`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$24"], 
         InsetBox[
          FormBox["16", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$24", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$24"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1.7468381673369753`, 0.}, 0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$25"], 
         InsetBox[
          FormBox["17", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$25", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$25"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.496584941607977, 2.5583908589353923`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$26"], 
         InsetBox[
          FormBox["18", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$26", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$26"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.244176179821115, 2.7814825214738237`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$27"], 
         InsetBox[
          FormBox["19", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$27", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$27"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.078922683749452, 0.40442961908342423`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$28"], 
         InsetBox[
          FormBox["20", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$28", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$28"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.7118221444149997`, 1.4952811902718834`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$29"], 
         InsetBox[
          FormBox["21", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$29", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$29"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.045844622442995, 3.0802774783142652`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$30"], 
         InsetBox[
          FormBox["22", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$30", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$30"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.3134403592362425`, 2.0510546145716346`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$31"], 
         InsetBox[
          FormBox["23", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$31", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$31"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.0991861899417084`, 4.271576231640855}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$32"], 
         InsetBox[
          FormBox["24", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$32", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$32"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.7144151250799442`, 3.4270813288456807`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$33"], 
         InsetBox[
          FormBox["41", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$33", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$33"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.7505382738277118`, 2.1593356187997035`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$34"], 
         InsetBox[
          FormBox["25", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$34", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$34"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.07835523495828545, 2.716629241764382}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$35"], 
         InsetBox[
          FormBox["26", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$35", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$35"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.2520499346282823`, 1.6976991705263655`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$36"], 
         InsetBox[
          FormBox["27", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$36", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$36"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.8063380864124494`, 2.71318898138719}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$37"], 
         InsetBox[
          FormBox["28", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$37", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$37"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.7828546202006885`, 1.8946489867794187`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$38"], 
         InsetBox[
          FormBox["29", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$38", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$38"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.7386580502360447`, 3.380136780025892}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$39"], 
         InsetBox[
          FormBox["30", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$39", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$39"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.462432928005076, 2.2500205187183604`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$40"], 
         InsetBox[
          FormBox["31", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$40", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$40"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.895294040598455, 1.9835480227801745`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$41"], 
         InsetBox[
          FormBox["32", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$41", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$41"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.5563144547039347`, 1.9994019882136003`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$42"], 
         InsetBox[
          FormBox["47", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$42", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$42"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.394173111352319, 2.9079106625844697`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$43"], 
         InsetBox[
          FormBox["33", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$43", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$43"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.896206030864388, 3.0061829873975676`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$44"], 
         InsetBox[
          FormBox["34", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$44", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$44"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.9167442537232535`, 1.477819920946112}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$45"], 
         InsetBox[
          FormBox["35", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$45", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$45"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.3681384074063945, 1.1671415587161917`}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$46"], 
         InsetBox[
          FormBox["36", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$46", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$46"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.2574453459178276`, 1.7292236837659871`}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$47"], 
         InsetBox[
          FormBox["38", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$47", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$47"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{5.294554921954494, 2.431159573732963}, 
            0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$48"], 
         InsetBox[
          FormBox["39", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$48", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$48"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.6279889495433295, 1.987517804793975}, 
            0.012215997210953608`], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$49"], 
         InsetBox[
          FormBox["40", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$49", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$49"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 2.2534178949733534`}, 0.012215997210953608`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$50"], 
         InsetBox[
          FormBox["42", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$50", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$50"]}, {
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       Arrowheads[{{0.019998728954394612`, 0.7}}], {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.019998728954394612`], 
           ArrowBox[{
             DynamicLocation["VertexID$2", Automatic, Center], {
             4.2111598509684915`, 2.5740865142296054`}, {4.203012212853365, 
             2.603187842877298}, {4.200442260388148, 2.6332987492110926`}, {
             4.203540407142119, 2.663359900596342}, {4.212197657128011, 
             2.69231371482863}, {4.226109439392871, 2.7191415669627688`}, {
             4.244786323137241, 2.7428996255853777`}, {4.267571236393756, 
             2.762752057774132}, {4.29366258249433, 2.7780004345590923`}, {
             4.322142441064869, 2.7881083023717523`}, {4.3520088614075245`, 
             2.7927200560329797`}, {4.382211112156116, 2.791673449308731}, {
             4.4116866470855935`, 2.7850053028993313`}, {4.439398486580387, 
             2.772950209049391}, {4.464371699643151, 2.7559322783515112`}, {
             4.485727702969347, 2.73455021909971}, {4.5027151704109585`, 
             2.709556274116249}, {4.514736465402633, 2.681829756075947}, {
             4.521368666430345, 2.6523461123824674`}, {4.52237844584496, 
             2.622142607926033}, {4.517730278568757, 2.5922818330384234`}, {
             4.507587691904183, 2.56381432047291}, {4.492307512475267, 
             2.537741586582192}, 
             DynamicLocation["VertexID$2", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$2"], 
         InsetBox[
          FormBox[
           FractionBox["75", "199"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$2", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["124", "199"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$3", Automatic, Center], 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["135", "152"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$3", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["17", "152"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$42", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["7", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["2", "9"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            2.5654719821808256`, 2.178902746299344}, {2.537513696103691, 
            2.1625228645958154`}, {2.508800231554916, 2.1475060993449775`}, {
            2.4793979975539107`, 2.133887181592724}, {2.449374996118513, 
            2.121697609418007}, {2.4188006649886957`, 2.1109655750835103`}, {
            2.387745717029706, 2.1017158998320777`}, {2.3562819766860743`, 
            2.0939699764796904`}, {1.909034042793271, 1.9952063326526446`}, {
            1.8772342799719386`, 1.9889820761107335`}, {1.8451720417387012`, 
            1.984293881952246}, {1.8129214822172293`, 1.9811525931173077`}, {
            1.7805571910840687`, 1.97956547483547}, {1.7481540210562916`, 
            1.9795361978225616`}, {1.7157869147707794`, 
            1.9810648297909863`}, {1.6835307314555399`, 1.9841478352931183`}, 
            
            DynamicLocation["VertexID$42", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["231", "641"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.019998728954394612`], 
           ArrowBox[{
             DynamicLocation["VertexID$5", Automatic, Center], {
             2.8046425932606676`, 2.5970390805221557`}, {2.8125428551679703`, 
             2.6138253941458935`}, {2.8231509933373764`, 
             2.6290458365789258`}, {2.836165446205294, 2.642267730536571}, {
             2.851216246988347, 2.6531152122289874`}, {2.867875540869322, 
             2.661279916183558}, {2.8856697477881874`, 2.6665297412670306`}, {
             2.90409302508192, 2.6687154487123883`}, {2.9226216472655704`, 
             2.6677749045858286`}, {2.9407288941750833`, 2.663734846091648}, {
             2.9579000242409976`, 2.656710121503601}, {2.9736469072420975`, 
             2.6469004253295023`}, {2.987521900568184, 2.634584621519782}, {
             2.9991305745261827`, 2.6201128160962925`}, {3.0081429249424962`, 
             2.603896404555756}, {3.0143027543166983`, 2.586396376974087}, {
             3.0174349548449606`, 2.5681102132668134`}, {3.01745048627595, 
             2.549557741139005}, {3.0143489070917915`, 2.531266358746117}, {
             3.008218387059267, 2.513756042146772}, {2.9992332007944422`, 
             2.497524563746304}, {2.987648773592115, 2.483033341931963}, {
             2.9737944203541713`, 2.470694324157572}, 
             DynamicLocation["VertexID$5", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$9"], 
         InsetBox[
          FormBox[
           FractionBox["410", "641"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$9", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["400", "951"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["551", "951"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox[
          FractionBox["85", "117"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["32", "117"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$8", Automatic, Center], 
            DynamicLocation["VertexID$42", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["154", "339"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$8", Automatic, Center], 
            DynamicLocation["VertexID$20", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["185", "339"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$9", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$16"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$16", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$10", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$11", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$12", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["320", "1033"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$12", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["713", "1033"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$13", Automatic, Center], 
            DynamicLocation["VertexID$14", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$14", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox[
          FractionBox["481", "698"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$14", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox[
          FractionBox["217", "698"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$15", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$24"], 
        InsetBox[
         FormBox[
          FractionBox["1", "4"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$24", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$15", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$25"], 
        InsetBox[
         FormBox[
          FractionBox["3", "4"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$25", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$16", Automatic, Center], 
            DynamicLocation["VertexID$17", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$26"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$26", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$17", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$27"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$27", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$18", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$28"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$28", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$19", Automatic, Center], 
            DynamicLocation["VertexID$20", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$29"], 
        InsetBox[
         FormBox[
          FractionBox["21", "61"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$29", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$19", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$30"], 
        InsetBox[
         FormBox[
          FractionBox["40", "61"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$30", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$20", Automatic, Center], 
            DynamicLocation["VertexID$42", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$31"], 
        InsetBox[
         FormBox[
          FractionBox["10", "37"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$31", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$20", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$32"], 
        InsetBox[
         FormBox[
          FractionBox["27", "37"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$32", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$21", Automatic, Center], 
            DynamicLocation["VertexID$22", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$33"], 
        InsetBox[
         FormBox[
          FractionBox["2", "7"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$33", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$21", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$34"], 
        InsetBox[
         FormBox[
          FractionBox["5", "7"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$34", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$22", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$35"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$35", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$23", Automatic, Center], 
            DynamicLocation["VertexID$14", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$36"], 
        InsetBox[
         FormBox[
          FractionBox["123", "244"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$36", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$23", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$37"], 
        InsetBox[
         FormBox[
          FractionBox["121", "244"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$37", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$24", Automatic, Center], 
            DynamicLocation["VertexID$14", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$38"], 
        InsetBox[
         FormBox[
          FractionBox["128", "657"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$38", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$24", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$39"], 
        InsetBox[
         FormBox[
          FractionBox["529", "657"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$39", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$25", Automatic, Center], 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$40"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$40", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$26", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$41"], 
        InsetBox[
         FormBox[
          FractionBox["44", "467"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$41", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$26", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$42"], 
        InsetBox[
         FormBox[
          FractionBox["423", "467"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$42", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$27", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$43"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$43", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$28", Automatic, Center], 
            DynamicLocation["VertexID$22", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$44"], 
        InsetBox[
         FormBox[
          FractionBox["112", "139"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$44", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$28", Automatic, Center], 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$45"], 
        InsetBox[
         FormBox[
          FractionBox["27", "139"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$45", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$29", Automatic, Center], 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$46"], 
        InsetBox[
         FormBox[
          FractionBox["17", "47"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$46", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$29", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$47"], 
        InsetBox[
         FormBox[
          FractionBox["30", "47"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$47", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$30", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$48"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$48", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$31", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$49"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$49", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$32", Automatic, Center], 
            DynamicLocation["VertexID$33", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$50"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$50", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$33", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$51"], 
        InsetBox[
         FormBox[
          FractionBox["407", "743"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$51", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$33", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$52"], 
        InsetBox[
         FormBox[
          FractionBox["336", "743"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$52", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$34", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$53"], 
        InsetBox[
         FormBox[
          FractionBox["35", "57"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$53", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$34", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$54"], 
        InsetBox[
         FormBox[
          FractionBox["22", "57"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$54", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$35", Automatic, Center], 
            DynamicLocation["VertexID$20", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$55"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$55", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$36", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$56"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$56", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$37", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$57"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$57", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$37", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$58"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$58", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$38", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$59"], 
        InsetBox[
         FormBox[
          FractionBox["68", "237"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$59", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$38", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$60"], 
        InsetBox[
         FormBox[
          FractionBox["169", "237"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$60", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$39", Automatic, Center], 
            DynamicLocation["VertexID$14", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$61"], 
        InsetBox[
         FormBox[
          FractionBox["13", "19"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$61", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$39", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$62"], 
        InsetBox[
         FormBox[
          FractionBox["6", "19"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$62", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$40", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$63"], 
        InsetBox[
         FormBox[
          FractionBox["286", "601"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$63", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$40", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$64"], 
        InsetBox[
         FormBox[
          FractionBox["315", "601"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$64", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$41", Automatic, Center], 
            DynamicLocation["VertexID$42", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$65"], 
        InsetBox[
         FormBox[
          FractionBox["5", "14"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$65", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$41", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$66"], 
        InsetBox[
         FormBox[
          FractionBox["9", "14"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$66", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$42", Automatic, Center], {
            1.6652767619590538`, 2.066810339695472}, {1.693235048036189, 
            2.0831902213990006`}, {1.7219485125849636`, 
            2.0982069866498385`}, {1.751350746585969, 2.1118259044020924`}, {
            1.7813737480213667`, 2.1240154765768096`}, {1.811948079151184, 
            2.134747510911306}, {1.8430030271101734`, 2.1439971861627387`}, {
            1.8744667674538051`, 2.1517431095151256`}, {2.321714701346609, 
            2.2505067533421714`}, {2.353514464167941, 2.2567310098840827`}, {
            2.3855767024011785`, 2.26141920404257}, {2.41782726192265, 
            2.264560492877509}, {2.450191553055811, 2.2661476111593464`}, {
            2.4825947230835883`, 2.2661768881722546`}, {2.5149618293691, 
            2.26464825620383}, {2.54721801268434, 2.2615652507016977`}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$67"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$67", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$43", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$68"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$68", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$44", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$69"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$69", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$45", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$70"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$70", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$46", Automatic, Center], 
            DynamicLocation["VertexID$47", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$71"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$71", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$47", Automatic, Center], 
            DynamicLocation["VertexID$20", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$72"], 
        InsetBox[
         FormBox[
          FractionBox["4", "25"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$72", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$47", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$73"], 
        InsetBox[
         FormBox[
          FractionBox["21", "25"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$73", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$48", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$74"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$74", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$49", Automatic, Center], 
            DynamicLocation["VertexID$42", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$75"], 
        InsetBox[
         FormBox[
          FractionBox["19", "69"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$75", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$49", Automatic, Center], 
            DynamicLocation["VertexID$20", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$76"], 
        InsetBox[
         FormBox[
          FractionBox["50", "69"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$76", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.019998728954394612`], 
          ArrowBox[{
            DynamicLocation["VertexID$50", Automatic, Center], 
            DynamicLocation["VertexID$20", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$77"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$77", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}}]}, 
    DynamicBox[GraphComputation`NetworkGraphicsBox[
     1, Typeset`graph, Typeset`boxes], {
     CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
      SynchronousUpdating -> False, TrackedSymbols :> {}},
     ImageSizeCache->{{7.063999999999998, 
      405.4390042168144}, {-141.94954149016368`, 131.25856000000002`}}]]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImageSize->{504., Automatic}]], "Output",
 CellChangeTimes->{
  3.5592998550233383`*^9, {3.559303748841342*^9, 3.559303767641418*^9}, 
   3.559314338419385*^9, 3.5593143708534403`*^9, 3.559314462115748*^9, 
   3.559368289672639*^9, {3.559368908691484*^9, 3.559368967183587*^9}, 
   3.559563503659679*^9, 3.559563559290922*^9}]
}, Open  ]],

Cell[TextData[{
 "the bisimilarity pseudometric can also be used in order to detect all the \
bisimilarity classes, i.e. the equivalence classes of the set of state w.r.t ",
 ButtonBox["probabilistic bisimilarity",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1016/0890-5401(91)90030-6"], None},
  ButtonNote->"http://dx.doi.org/10.1016/0890-5401(91)90030-6"]
}], "Text",
 CellChangeTimes->{{3.5593688323148117`*^9, 3.559368903269061*^9}, {
   3.559369027837755*^9, 3.559369120811987*^9}, 3.559369246265841*^9, {
   3.5593693356443243`*^9, 3.559369396188394*^9}, {3.559369484575027*^9, 
   3.5593694845764437`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BisimClasses", "[", "mc", "]"}]], "Input",
 CellChangeTimes->{{3.559364588622055*^9, 3.559364598948433*^9}, 
   3.559364880760984*^9, {3.559366404142303*^9, 3.559366404251511*^9}, {
   3.5593670672079487`*^9, 3.559367077440153*^9}, {3.559367681804838*^9, 
   3.5593676883066597`*^9}, {3.559368340873324*^9, 3.55936834095751*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "23", ",", "37", ",", "43"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2", ",", "4", ",", "6", ",", "13", ",", "15", ",", "27", ",", "32", ",", 
     "34", ",", "38", ",", "40", ",", "41", ",", "44", ",", "45", ",", "46", 
     ",", "47", ",", "48", ",", "50"}], "}"}], ",", 
   RowBox[{"{", "3", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "5", ",", "7", ",", "9", ",", "16", ",", "17", ",", "24", ",", "26", ",", 
     "33", ",", "35", ",", "36", ",", "42"}], "}"}], ",", 
   RowBox[{"{", "8", "}"}], ",", 
   RowBox[{"{", "10", "}"}], ",", 
   RowBox[{"{", "11", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"12", ",", "19", ",", "22", ",", "39"}], "}"}], ",", 
   RowBox[{"{", "14", "}"}], ",", 
   RowBox[{"{", "18", "}"}], ",", 
   RowBox[{"{", "20", "}"}], ",", 
   RowBox[{"{", "21", "}"}], ",", 
   RowBox[{"{", "25", "}"}], ",", 
   RowBox[{"{", "28", "}"}], ",", 
   RowBox[{"{", "29", "}"}], ",", 
   RowBox[{"{", "30", "}"}], ",", 
   RowBox[{"{", "31", "}"}], ",", 
   RowBox[{"{", "49", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.559364682707975*^9, 3.5593647421841717`*^9, 3.559364886233445*^9, {
   3.559366382202739*^9, 3.559366410472754*^9}, 3.5593671285539637`*^9, 
   3.559367690255427*^9, 3.5593682919665422`*^9, 3.5593683552627983`*^9, {
   3.559368929214074*^9, 3.559368975585587*^9}, 3.5595635038886642`*^9, 
   3.559563568292123*^9}]
}, Open  ]],

Cell["\<\
so that this can be used to construct an MC \[ScriptCapitalM]\
\[CloseCurlyQuote] bisimilar to \[ScriptCapitalM] with all the states that \
are bisimilar in \[ScriptCapitalM] lumped together. \[ScriptCapitalM]\
\[CloseCurlyQuote] is also known as the bisimilar quotient of \
\[ScriptCapitalM].\
\>", "Text",
 CellChangeTimes->{{3.559369514578313*^9, 3.559369714919273*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BisimQuotient", "[", "mc", "]"}], "//", "PlotMC"}]], "Input",
 CellChangeTimes->{{3.559367701452523*^9, 3.559367763756866*^9}, {
  3.5593683634098177`*^9, 3.5593683871031218`*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 18, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 
      17}, {{{1, 2}, {3, 3}, {4, 3}, {4, 2}, {5, 3}, {6, 3}, {6, 2}, {7, 3}, {
       7, 2}, {8, 1}, {9, 2}, {10, 1}, {10, 3}, {11, 3}, {11, 2}, {12, 1}, {
       12, 3}, {13, 1}, {13, 3}, {14, 3}, {14, 2}, {15, 3}, {15, 2}, {16, 
       3}, {16, 2}, {17, 3}, {17, 2}, {18, 3}, {18, 2}, {2, 3}, {2, 2}}, 
       Null}, {EdgeLabels -> {
        DirectedEdge[16, 18] -> Rational[6, 19], DirectedEdge[5, 18] -> 
         Rational[320, 1033], DirectedEdge[17, 18] -> Rational[286, 601], 
         DirectedEdge[18, 2] -> Rational[124, 199], DirectedEdge[16, 2] -> 
         Rational[13, 19], DirectedEdge[1, 18] -> 1, DirectedEdge[15, 18] -> 
         Rational[68, 237], DirectedEdge[14, 18] -> Rational[1, 2], 
         DirectedEdge[13, 18] -> Rational[35, 57], DirectedEdge[9, 2] -> 
         Rational[5, 7], DirectedEdge[7, 1] -> 1, DirectedEdge[15, 2] -> 
         Rational[169, 237], DirectedEdge[4, 2] -> 1, DirectedEdge[12, 1] -> 
         Rational[17, 47], DirectedEdge[11, 2] -> Rational[27, 139], 
         DirectedEdge[6, 2] -> Rational[3, 4], DirectedEdge[11, 1] -> 
         Rational[112, 139], DirectedEdge[8, 18] -> 1, DirectedEdge[9, 1] -> 
         Rational[2, 7], DirectedEdge[10, 2] -> Rational[423, 467], 
         DirectedEdge[6, 18] -> Rational[1, 4], DirectedEdge[10, 18] -> 
         Rational[44, 467], DirectedEdge[2, 2] -> 1, DirectedEdge[12, 2] -> 
         Rational[30, 47], DirectedEdge[5, 2] -> Rational[713, 1033], 
         DirectedEdge[17, 2] -> Rational[315, 601], DirectedEdge[13, 2] -> 
         Rational[22, 57], DirectedEdge[18, 18] -> Rational[75, 199], 
         DirectedEdge[14, 2] -> Rational[1, 2], DirectedEdge[3, 18] -> 
         Rational[400, 951], DirectedEdge[3, 2] -> Rational[551, 951]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, 
       VertexStyle -> {13 -> Hue[
           Rational[1, 2]], 12 -> Hue[1], 5 -> Hue[
           Rational[1, 2]], 10 -> Hue[1], 3 -> Hue[1], 8 -> Hue[
           Rational[1, 2]], 18 -> Hue[
           Rational[1, 2]], 4 -> Hue[
           Rational[1, 2]], 2 -> Hue[1], 1 -> Hue[1], 11 -> Hue[1], 7 -> Hue[
           Rational[1, 2]], 6 -> Hue[
           Rational[1, 2]], 16 -> Hue[1], 14 -> Hue[
           Rational[1, 2]], 17 -> Hue[
           Rational[1, 2]], 15 -> Hue[1], 9 -> Hue[1]}}]], Typeset`boxes = 
    GraphicsGroupBox[{{
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.1698069953676034`, 1.6864690032189007`}, 
            0.02016991338084745], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.7849165462792778`, 1.5636786428016674`}, 
            0.02016991338084745], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["18", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.416596118837386, 1.3258876250533185`}, 
            0.02016991338084745], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.1450182670546933`, 2.0193487663005243`}, 
            0.02016991338084745], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{2.09289936832747, 0.}, 0.02016991338084745], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.470062381098742, 2.3883916729604087`}, 
            0.02016991338084745], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.520208981584999, 1.457234890691173}, 
            0.02016991338084745], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 1.9831921410162865`}, 0.02016991338084745], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.9942479894569036`, 2.2496469954087335`}, 
            0.02016991338084745], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.215761779971336, 1.2316233210597134`}, 
            0.02016991338084745], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$10"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.7632016122850382`, 0.5619841855864257}, 
            0.02016991338084745], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$11"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$11", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$11"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.4536967814616166`, 2.1560117010016904`}, 
            0.02016991338084745], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$12"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$12", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$12"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.3195556396897445`, 0.8418067013510215}, 
            0.02016991338084745], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$13"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$13", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$13"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.299879008250801, 1.9462324975863274`}, 
            0.02016991338084745], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$14"], 
         InsetBox[
          FormBox["13", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$14", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$14"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.2528955087503686`, 0.7549417807780071}, 
            0.02016991338084745], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$15"], 
         InsetBox[
          FormBox["14", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$15", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$15"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.9417757375221405`, 2.3169681443705383`}, 
            0.02016991338084745], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$16"], 
         InsetBox[
          FormBox["15", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$16", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$16"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.185675871680265, 0.6784503208037327}, 
            0.02016991338084745], 
           Hue[1], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$17"], 
         InsetBox[
          FormBox["16", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$17", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$17"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{3.4566809674001737`, 1.014309676856289}, 
            0.02016991338084745], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$18"], 
         InsetBox[
          FormBox["17", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$18", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$18"]}, {
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       Arrowheads[{{0.025563644246897436`, 0.7}}], {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["124", "199"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.025563644246897436`], 
           ArrowBox[{
             DynamicLocation["VertexID$2", Automatic, Center], {
             2.8870822648520194`, 1.921724931896754}, {2.8937582163039406`, 
             1.9393240209268985`}, {2.903302743155551, 1.9555474074309007`}, {
             2.915443184189183, 1.9699316333046926`}, {2.9298327199671923`, 
             1.9820657802698793`}, {2.9460602805216376`, 
             1.9916032086932627`}, {2.9636622885071624`, 1.998271460139997}, {
             2.982135902347087, 2.001880040771314}, {3.0009533810519793`, 
             2.0023258632362873`}, {3.0195771603468495`, 
             1.9995961915975506`}, {3.037475209422935, 1.9937690051624526`}, {
             3.0541362296133836`, 1.9850107708259657`}, {3.069084260807931, 
             1.9735716875634746`}, {3.081892278340964, 1.9597785389253686`}, {
             3.092194391926797, 1.9440253577182616`}, {3.0996962981517004`, 
             1.9267621695575505`}, {3.1041836879233626`, 
             1.9084821368574556`}, {3.105528368699784, 1.8897074705198378`}, {
             3.1036919266021448`, 1.870974511786595}, {3.0987268237950234`, 
             1.8528184104266094`}, {3.090774899784797, 1.8357578369598426`}, {
             3.080063319450055, 1.8202801656488308`}, {3.0668980835577933`, 
             1.8068275515392807`}, 
             DynamicLocation["VertexID$2", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$3"], 
         InsetBox[
          FormBox[
           FractionBox["75", "199"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$3", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {{
         TagBox[{
           Arrowheads[0.025563644246897436`], 
           ArrowBox[{
             DynamicLocation["VertexID$3", Automatic, Center], {
             2.29120764331501, 0.9995410154191144}, {2.2814297204382243`, 
             0.9795121068099544}, {2.268320172446524, 0.9614869935700392}, {
             2.252277879716303, 0.9460141205395908}, {2.2337909563889893`, 
             0.9335642762936383}, {2.213421898665049, 0.9245162685959596}, {
             2.1917904698968775`, 0.9191453985262226}, {2.169554843230831, 
             0.9176150839746807}, {2.147391575565708, 0.919971887373899}, {
             2.1259750221541824`, 0.9261440989572581}, {2.1059568181930803`, 
             0.935943918651017}, {2.0879460517101354`, 0.9490731702121412}, {
             2.0724907310209972`, 0.9651323737495016}, {2.0600611106407483`, 
             0.9836329005814963}, {2.0510353829875285`, 
             1.0040118405978067`}, {2.0456881712326207`, 
             1.0256491297604222`}, {2.044182173421663, 1.0478864166104822`}, {
             2.046563212108878, 1.0700470937352555`}, {2.0527588401276384`, 
             1.0914568847036796`}, {2.0625805449191823`, 
             1.1114643600778047`}, {2.075729484349017, 1.1294607582654703`}, {
             2.091805579488998, 1.1448985081309373`}, {2.1103196877016805`, 
             1.1573078897814286`}, 
             DynamicLocation["VertexID$3", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$4"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          DynamicLocation["EdgeLabelID$4", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["551", "951"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["400", "951"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["713", "1033"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$9"], 
        InsetBox[
         FormBox[
          FractionBox["320", "1033"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$9", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["3", "4"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["1", "4"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$8", Automatic, Center], 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$9", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox["1", TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$10", Automatic, Center], 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["2", "7"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$10", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["5", "7"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$11", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$16"], 
        InsetBox[
         FormBox[
          FractionBox["423", "467"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$16", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$11", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox[
          FractionBox["44", "467"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$12", Automatic, Center], 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["112", "139"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$12", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["27", "139"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$13", Automatic, Center], 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["17", "47"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$13", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox[
          FractionBox["30", "47"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$14", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox[
          FractionBox["22", "57"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$14", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox[
          FractionBox["35", "57"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$15", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$24"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$24", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$15", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$25"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$25", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$16", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$26"], 
        InsetBox[
         FormBox[
          FractionBox["169", "237"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$26", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$16", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$27"], 
        InsetBox[
         FormBox[
          FractionBox["68", "237"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$27", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$17", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$28"], 
        InsetBox[
         FormBox[
          FractionBox["13", "19"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$28", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$17", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$29"], 
        InsetBox[
         FormBox[
          FractionBox["6", "19"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$29", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$18", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$30"], 
        InsetBox[
         FormBox[
          FractionBox["315", "601"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$30", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.025563644246897436`], 
          ArrowBox[{
            DynamicLocation["VertexID$18", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$31"], 
        InsetBox[
         FormBox[
          FractionBox["286", "601"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$31", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}}]}, 
    DynamicBox[GraphComputation`NetworkGraphicsBox[
     1, Typeset`graph, Typeset`boxes], {
     CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
      SynchronousUpdating -> False, TrackedSymbols :> {}},
     ImageSizeCache->{{7.32, 414.00233616698745`}, {-131.11532056154908`, 
      120.0128}}]]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None,
  ImageSize->{520., Automatic}]], "Output",
 CellChangeTimes->{{3.559367712376761*^9, 3.559367734772703*^9}, 
   3.559367767804834*^9, 3.55936829290627*^9, {3.559368374194358*^9, 
   3.559368392442828*^9}, 3.5593689916717*^9, 3.559563503960229*^9, 
   3.559563575763114*^9}]
}, Open  ]],

Cell["\<\
Obvousy, for any MC \[ScriptCapitalM], the bisimilarity quotient of two \
copies of \[ScriptCapitalM] joined together correspons to \[ScriptCapitalM] \
itselfs\
\>", "Text",
 CellChangeTimes->{{3.559369827658413*^9, 3.559370018077299*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"JoinMC", "[", 
   RowBox[{"mcPaper", ",", "mcPaper"}], "]"}], " ", "//", "PlotMC"}]], "Input",\

 CellChangeTimes->{{3.559370027319148*^9, 3.559370063665084*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 6, 5, 7, 8, 9, 10, 11, 13, 12, 
      14}, {{{1, 2}, {1, 3}, {1, 4}, {1, 5}, {2, 3}, {2, 4}, {2, 5}, {3, 2}, {
       3, 3}, {4, 1}, {4, 2}, {4, 3}, {6, 1}, {6, 2}, {6, 3}, {5, 1}, {5, 
       2}, {5, 4}, {5, 5}, {7, 2}, {7, 3}, {7, 6}, {7, 5}, {7, 7}, {8, 9}, {8,
        10}, {8, 11}, {8, 12}, {9, 10}, {9, 11}, {9, 12}, {10, 9}, {10, 10}, {
       11, 8}, {11, 9}, {11, 10}, {13, 8}, {13, 9}, {13, 10}, {12, 8}, {12, 
       9}, {12, 11}, {12, 12}, {14, 9}, {14, 10}, {14, 13}, {14, 12}, {14, 
       14}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[7, 5] -> Rational[1, 10], DirectedEdge[7, 6] -> 
         Rational[1, 5], DirectedEdge[5, 1] -> Rational[2, 5], 
         DirectedEdge[14, 12] -> Rational[1, 10], DirectedEdge[9, 13] -> 
         Rational[1, 5], DirectedEdge[14, 10] -> Rational[1, 3], 
         DirectedEdge[3, 2] -> Rational[1, 2], DirectedEdge[6, 2] -> 
         Rational[1, 10], DirectedEdge[13, 13] -> Rational[1, 5], 
         DirectedEdge[12, 10] -> Rational[1, 5], DirectedEdge[13, 11] -> 
         Rational[1, 5], DirectedEdge[2, 3] -> Rational[2, 5], 
         DirectedEdge[10, 9] -> Rational[1, 2], DirectedEdge[8, 10] -> 
         Rational[1, 3], DirectedEdge[11, 10] -> Rational[1, 3], 
         DirectedEdge[10, 10] -> Rational[1, 2], DirectedEdge[2, 6] -> 
         Rational[1, 5], DirectedEdge[3, 3] -> Rational[1, 2], 
         DirectedEdge[6, 6] -> Rational[1, 5], DirectedEdge[14, 9] -> 
         Rational[1, 5], DirectedEdge[11, 9] -> Rational[1, 3], 
         DirectedEdge[9, 10] -> Rational[2, 5], DirectedEdge[8, 9] -> 
         Rational[1, 3], DirectedEdge[1, 4] -> Rational[1, 6], 
         DirectedEdge[5, 3] -> Rational[1, 5], DirectedEdge[5, 2] -> 
         Rational[2, 5], DirectedEdge[4, 2] -> Rational[1, 3], 
         DirectedEdge[7, 7] -> Rational[1, 6], DirectedEdge[8, 13] -> 
         Rational[1, 6], DirectedEdge[9, 11] -> Rational[2, 5], 
         DirectedEdge[6, 4] -> Rational[1, 5], DirectedEdge[12, 9] -> 
         Rational[2, 5], DirectedEdge[1, 3] -> Rational[1, 3], 
         DirectedEdge[2, 4] -> Rational[2, 5], DirectedEdge[1, 6] -> 
         Rational[1, 6], DirectedEdge[13, 8] -> Rational[1, 2], 
         DirectedEdge[7, 2] -> Rational[1, 5], DirectedEdge[4, 1] -> 
         Rational[1, 3], DirectedEdge[14, 13] -> Rational[1, 5], 
         DirectedEdge[8, 11] -> Rational[1, 6], DirectedEdge[1, 2] -> 
         Rational[1, 3], DirectedEdge[6, 1] -> Rational[1, 2], 
         DirectedEdge[11, 8] -> Rational[1, 3], DirectedEdge[7, 3] -> 
         Rational[1, 3], DirectedEdge[4, 3] -> Rational[1, 3], 
         DirectedEdge[12, 8] -> Rational[2, 5], DirectedEdge[13, 9] -> 
         Rational[1, 10], DirectedEdge[14, 14] -> Rational[1, 6]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, VertexStyle -> {8 -> Hue[
           Rational[1, 2]], 10 -> Hue[
           Rational[1, 2]], 4 -> Hue[
           Rational[1, 2]], 6 -> Hue[
           Rational[1, 3]], 11 -> Hue[
           Rational[1, 2]], 9 -> Hue[
           Rational[1, 3]], 7 -> Hue[
           Rational[1, 2]], 1 -> Hue[
           Rational[1, 2]], 2 -> Hue[
           Rational[1, 3]], 13 -> Hue[
           Rational[1, 3]], 3 -> Hue[
           Rational[1, 2]], 12 -> Hue[
           Rational[1, 2]], 5 -> Hue[
           Rational[1, 2]], 14 -> Hue[
           Rational[1, 2]]}}]], Typeset`boxes = GraphicsGroupBox[{{
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.3705915940107731`, -2.27598573457563}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.6886906321648238`, -1.545819881537877}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.0058713682085103`, -2.27623991624063}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.7102098332237241, -1.9749748498550366`}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.0597386354280292`, -1.0597386354280292`}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.668736502606012, -1.9766971381429963`}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.321066438039663, -1.0608128823315153`}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.3705915940107731`, -5.611964286244289}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$8"], 
         InsetBox[
          FormBox["8", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$8", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$8"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.6886906321648238`, -4.881798433206535}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$9"], 
         InsetBox[
          FormBox["9", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$9", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$9"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.0058713682085103`, -5.612218467909289}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$10"], 
         InsetBox[
          FormBox["10", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$10", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$10"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.7102098332237241, -5.310953401523696}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$11"], 
         InsetBox[
          FormBox["11", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$11", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$11"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.0597386354280292`, -4.395717187096688}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$12"], 
         InsetBox[
          FormBox["13", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$12", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$12"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.668736502606012, -5.3126756898116545`}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$13"], 
         InsetBox[
          FormBox["12", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$13", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$13"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{2.321066438039663, -4.396791434000174}, 
            0.031763991252401154`], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$14"], 
         InsetBox[
          FormBox["14", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$14", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$14"]}, {
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       Arrowheads[{{0.024087980722274326`, 0.7}}], {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            1.2897190716155011`, -2.2686057052608013`}, {
            1.2693173772702244`, -2.2662480532372284`}, {
            1.2490526264963013`, -2.262912257785895}, {
            1.2289716879753285`, -2.258606033994769}, {
            1.2091210052646038`, -2.2533393413760106`}, {
            1.1895464893816285`, -2.2471243608314317`}, {
            1.1702934126202766`, -2.2399754664802853`}, {
            1.1514063038442168`, -2.2319091924145456`}, {
            0.8872535995293972, -2.1115048385263084`}, {
            0.8687761411849309, -2.102539840570321}, {
            0.850751068271443, -2.0926968531332775`}, {
            0.8332200695031233, -2.0819986412542986`}, {
            0.8162236908905545, -2.0704699479510413`}, {
            0.7998012419651674, -2.0581374369936003`}, {
            0.7839907048634469, -2.0450296312360576`}, {
            0.7688286464811591, -2.031176846648313}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            1.2928025961876084`, -2.1590234799509616`}, {
            1.273846879300969, -2.128979483069872}, {
            1.2563575341015305`, -2.0980588790044234`}, {
            1.24037501026275, -2.0663331814861627`}, {
            1.225936272454426, -2.0338757662813163`}, {
            1.2130747148501424`, -2.0007617014859904`}, {
            1.2018200838926227`, -1.967067573907325}, {
            1.1921984094956182`, -1.9328713119321415`}, {
            1.0678572260625203`, -1.4463724722731017`}, {
            1.0598907614083548`, -1.4117531656337237`}, {
            1.0535979314803656`, -1.3767908824878143`}, {
            1.0489932904492663`, -1.3415664842352952`}, {
            1.0460874880119992`, -1.3061614385006417`}, {
            1.0448872447609232`, -1.2706576307130877`}, {
            1.0453953366403077`, -1.2351371747205269`}, {
            1.0476105885260774`, -1.1996822228751223`}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            1.749189356114041, -1.6112380107009951`}, {
            1.764087111898202, -1.6281452333256707`}, {
            1.7781547766730572`, -1.6457491565266835`}, {
            1.7913598144894352`, -1.6640090656325055`}, {
            1.803671684497375, -1.68288272879556}, {
            1.815061911581555, -1.7023264946668017`}, {
            1.825504152219053, -1.7222953933533451`}, {
            1.8349742554071227`, -1.742743240425645}, {
            1.9618465498245972`, -2.034911254306746}, {
            1.9703226129375437`, -2.05579075761478}, {
            1.9777850323835107`, -2.0770536266661876`}, {
            1.9842165489440236`, -2.0986506843133927`}, {
            1.9896022876914197`, -2.1205319804914}, {
            1.9939297923918506`, -2.1426469077432038`}, {
            1.9971890543142858`, -2.164944318265635}, {
            1.9993725353788845`, -2.187372642204917}, 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            1.6012128954154556`, -1.6273142260731226`}, {
            1.5786007809506055`, -1.6473860460752126`}, {
            1.5550498051543007`, -1.666347512732875}, {
            1.5306144371487225`, -1.6841547716235568`}, {
            1.505351191494328, -1.700766637797274}, {
            1.4793184974819515`, -1.7161446910299094`}, {
            1.452576563996488, -1.7302533646821998`}, {
            1.425187240264695, -1.7430600279589021`}, {
            1.0337949206882553`, -1.914722015285766}, {
            1.005821553232745, -1.9261970487047493`}, {
            0.9773288393630022, -1.936313912601469}, {
            0.9483826775422786, -1.9450492085103819`}, {
            0.9190500149764366, -1.9523827332813393`}, {
            0.889398692777243, -1.958297525805798}, {
            0.8594972890582196, -1.9627799062447797`}, {
            0.8294149603259444, -1.9658195076678475`}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            1.604296419987563, -1.5177320007632826`}, {
            1.5831302829813498`, -1.5101174759078557`}, {
            1.5623547127595296`, -1.5014941339514034`}, {
            1.542017759436144, -1.4918819191149506`}, {
            1.52216645868415, -1.4813030627025796`}, {
            1.5028467229504654`, -1.4697820316844683`}, {
            1.4841032352688337`, -1.4573454721092394`}, {
            1.465979345916096, -1.444022147476498}, {
            1.2143985472213783`, -1.2495896490325593`}, {
            1.1969361734561692`, -1.2354103737681523`}, {
            1.180175702571925, -1.220407941956006}, {
            1.1641558984884217`, -1.2046170514913785`}, {
            1.1489138120978817`, -1.1880742238309392`}, {
            1.134484695572999, -1.1708177195252853`}, {
            1.1209019208350808`, -1.1528874497292487`}, {
            1.1081969023708627`, -1.1343248838946565`}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            1.9453726442592933`, -2.210821787077512}, {
            1.9304748884751324`, -2.193914564452837}, {
            1.9164072237002774`, -2.1763106412518236`}, {
            1.9032021858838992`, -2.158050732146002}, {
            1.8908903158759593`, -2.139177068982947}, {
            1.8795000887917792`, -2.1197333031117056`}, {
            1.8690578481542812`, -2.099764404425162}, {
            1.8595877449662117`, -2.079316557352862}, {
            1.7327154505487372`, -1.7871485434717609`}, {
            1.7242393874357909`, -1.7662690401637269`}, {
            1.7167769679898235`, -1.7450061711123195`}, {
            1.710345451429311, -1.7234091134651144`}, {
            1.704959712681915, -1.7015278172871078`}, {
            1.7006322079814837`, -1.6794128900353034`}, {
            1.6973729460590485`, -1.6571154795128724`}, {
            1.6951894649944501`, -1.63468715557359}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.024087980722274326`], 
           ArrowBox[{
             DynamicLocation["VertexID$3", Automatic, Center], {
             2.0419083268713836`, -2.2737934554406576`}, {
             2.109307018325089, -2.2784148090226486`}, {
             2.172975258220458, -2.3010045356085818`}, {
             2.22821489004121, -2.339895711920302}, {
             2.2709497144668953`, -2.39221851096534}, {
             2.2980262770565303`, -2.454111970045691}, {
             2.30744656547024, -2.5210088958704557`}, {
             2.298515445219168, -2.5879728832790803`}, {
             2.271891954481127, -2.650062578555535}, {
             2.2295406728754488`, -2.702696307902391}, {
             2.174586752754006, -2.7419901646981755`}, {
             2.1110853104249934`, -2.7650446076699025`}, {
             2.0437221942103, -2.770158421554596}, {
             1.9774682100238519`, -2.756954251833504}, {
             1.917212319584187, -2.7264064501789718`}, {
             1.867400878009316, -2.6807691758647145`}, {
             1.831709531888574, -2.623410058623504}, {
             1.812771988870038, -2.5585616971714007`}, {
             1.8119856731840793`, -2.4910093306233403`}, {
             1.8294086080172969`, -2.425737729904505}, {
             1.8637551339113174`, -2.3675633654678143`}, {
             1.9124907791310055`, -2.3207789941070467`}, {
             1.9720192814027324`, -2.2888368912350288`}, 
             DynamicLocation["VertexID$3", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$9"], 
         InsetBox[
          FormBox[
           FractionBox["1", "2"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$9", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.7910823556189963, -1.9823548791698657`}, {
            0.8114840499642729, -1.9847125311934384`}, {
            0.831748800738196, -1.988048326644772}, {
            0.8518297392591688, -1.992354550435898}, {
            0.8716804219698936, -1.9976212430546563`}, {
            0.8912549378528689, -2.0038362235992353`}, {
            0.9105080146142206, -2.0109851179503817`}, {
            0.9293951233902806, -2.0190513920161215`}, {
            1.1935478277051002`, -2.1394557459043586`}, {
            1.2120252860495666`, -2.148420743860346}, {
            1.2300503589630545`, -2.1582637312973896`}, {
            1.2475813577313741`, -2.1689619431763685`}, {
            1.2645777363439428`, -2.1804906364796253`}, {
            1.28100018526933, -2.1928231474370667`}, {
            1.2968107223710506`, -2.2059309531946094`}, {
            1.3119727807533383`, -2.2197837377823535`}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.7976875699730926, -1.8934805053197914`}, {
            0.8202996844379429, -1.8734086853177012`}, {
            0.8438506602342477, -1.854447218660039}, {
            0.8682860282398258, -1.8366399597693572`}, {
            0.8935492738942205, -1.82002809359564}, {
            0.9195819679065969, -1.8046500403630046`}, {
            0.9463239013920604, -1.7905413667107142`}, {
            0.9737132251238533, -1.777734703434012}, {
            1.3651055447002927`, -1.606072716107148}, {
            1.393078912155803, -1.5945976826881647`}, {
            1.4215716260255458`, -1.584480818791445}, {
            1.4505177878462696`, -1.5757455228825321`}, {
            1.4798504504121115`, -1.568411998111575}, {
            1.509501772611305, -1.5624972055871158`}, {
            1.5394031763303282`, -1.558014825148134}, {
            1.5694855050626035`, -1.5549752237250667`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            1.1375276332511943`, -1.1767008900526983`}, {
            1.1564833501378335`, -1.2067448869337876`}, {
            1.173972695337272, -1.2376654909992362`}, {
            1.1899552191760525`, -1.2693911885174967`}, {
            1.2043939569843767`, -1.3018486037223433`}, {
            1.2172555145886603`, -1.3349626685176692`}, {
            1.22851014554618, -1.3686567960963347`}, {
            1.2381318199431846`, -1.4028530580715182`}, {
            1.3624730033762822`, -1.889351897730558}, {
            1.3704394680304475`, -1.923971204369936}, {
            1.3767322979584367`, -1.9589334875158455`}, {
            1.381336938989536, -1.9941578857683642`}, {
            1.384242741426803, -2.029562931503018}, {
            1.385442984677879, -2.065066739290572}, {
            1.3849348927984946`, -2.1005871952831328`}, {
            1.382719640912725, -2.136042147128537}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            1.1441328476052903`, -1.0878265162026237`}, {
            1.1652989846115034`, -1.0954410410580506`}, {
            1.1860745548333234`, -1.104064383014503}, {
            1.206411508156709, -1.1136765978509557`}, {
            1.2262628089087033`, -1.1242554542633267`}, {
            1.2455825446423878`, -1.135776485281438}, {
            1.2643260323240193`, -1.148213044856667}, {
            1.2824499216767573`, -1.1615363694894083`}, {
            1.534030720371475, -1.355968867933347}, {
            1.551493094136684, -1.370148143197754}, {
            1.5682535650209282`, -1.3851505750099002`}, {
            1.5842733691044315`, -1.4009414654745278`}, {
            1.5995154554949718`, -1.4174842931349672`}, {
            1.6139445720198542`, -1.434740797440621}, {
            1.6275273467577724`, -1.4526710672366576`}, {
            1.6402323652219906`, -1.4712336330712497`}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.024087980722274326`], 
           ArrowBox[{
             DynamicLocation["VertexID$5", Automatic, Center], {
             1.0564686301465938`, -1.061913251838352}, {
             0.9925572556884626, -1.0923751819420509`}, {
             0.922668719887086, -1.103697087007443}, {
             0.8524088788770869, -1.0949708213674507`}, {
             0.7874133716975051, -1.0668963308602484`}, {
             0.7328955778886004, -1.021725509205337}, {
             0.6932284451071721, -0.9630815704932194}, {
             0.6715937289458352, -0.8956684261711478}, {
             0.6697267799155596, -0.8248933777989396}, {
             0.687777348580646, -0.7564333899108522}, {
             0.7242975738588104, -0.6957797328372496}, {
             0.7763581179614454, -0.6477975203152362}, {
             0.8397831326298467, -0.6163354719858096}, {
             0.9094852097005646, -0.6039172022674575}, {
             0.9798734491516939, -0.6115387977526914}, {
             1.0453019129276162`, -0.6385889197245587}, {
             1.1005224934405626`, -0.6828978404808043}, {
             1.1411058715400262`, -0.7409114801942893}, {
             1.1637967983289748`, -0.8079764845723452}, {
             1.1667752031809233`, -0.8787134768416518}, {
             1.1498021841226194`, -0.9474485450006092}, {
             1.114239170491794, -1.0086683541498038`}, {
             1.062938720806695, -1.05746237871098}, 
             DynamicLocation["VertexID$5", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$16"], 
         InsetBox[
          FormBox[
           FractionBox["1", "5"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$16", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$6", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.024087980722274326`], 
           ArrowBox[{
             DynamicLocation["VertexID$7", Automatic, Center], {
             2.317870582729513, -1.0585306904225709`}, {
             2.2666607793489097`, -1.0096415402101773`}, {
             2.231211446218826, -0.9483558342796554}, {
             2.214366023387289, -0.8795893838812466}, {
             2.217475705522175, -0.8088580411272028}, {
             2.2402910607177695`, -0.7418352648636897}, {
             2.2809820377729655`, -0.6838970446885447}, {
             2.336284757129649, -0.6396906853889375}, {
             2.401763311167032, -0.6127620401956946}, {
             2.472165574488184, -0.6052710929906169}, {
             2.541844484163472, -0.6178187030113778}, {
             2.605210998459826, -0.6493984091008906}, {
             2.6571824016095635`, -0.6974771593489737}, {
             2.6935899954731215`, -0.7581984906900787}, {
             2.711513476583464, -0.82669186114049}, {
             2.7095151777268742`, -0.8974633227083411}, {
             2.687755385218921, -0.9648361985619135}, {
             2.647979482117356, -1.0234064171309523`}, {
             2.5933779486326363`, -1.06847598016286}, {
             2.528330449296797, -1.0964297956613576`}, {
             2.4580545340128728`, -1.1050256494163242`}, {
             2.3881871311596505`, -1.093574056107284}, {
             2.3243324017687494`, -1.062993563874738}, 
             DynamicLocation["VertexID$7", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$24"], 
         InsetBox[
          FormBox[
           FractionBox["1", "6"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$24", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$8", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$25"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$25", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$8", Automatic, Center], 
            DynamicLocation["VertexID$10", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$26"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$26", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$8", Automatic, Center], {
            1.2897190716155011`, -5.60458425692946}, {
            1.2693173772702244`, -5.602226604905888}, {
            1.2490526264963013`, -5.598890809454554}, {
            1.2289716879753285`, -5.594584585663428}, {
            1.2091210052646038`, -5.5893178930446705`}, {
            1.1895464893816285`, -5.583102912500091}, {
            1.1702934126202766`, -5.575954018148945}, {
            1.1514063038442168`, -5.567887744083205}, {
            0.8872535995293972, -5.447483390194967}, {
            0.8687761411849309, -5.43851839223898}, {
            0.850751068271443, -5.428675404801936}, {
            0.8332200695031233, -5.417977192922957}, {
            0.8162236908905545, -5.4064484996197}, {
            0.7998012419651674, -5.394115988662259}, {
            0.7839907048634469, -5.381008182904717}, {
            0.7688286464811591, -5.367155398316972}, 
            DynamicLocation["VertexID$11", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$27"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$27", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$8", Automatic, Center], {
            1.2928025961876082`, -5.495002031619621}, {
            1.2738468793009687`, -5.464958034738532}, {
            1.2563575341015305`, -5.434037430673084}, {
            1.2403750102627498`, -5.402311733154823}, {
            1.2259362724544256`, -5.369854317949976}, {
            1.2130747148501424`, -5.336740253154651}, {
            1.2018200838926223`, -5.303046125575985}, {
            1.1921984094956177`, -5.268849863600802}, {
            1.0678572260625203`, -4.782351023941761}, {
            1.0598907614083553`, -4.747731717302384}, {
            1.053597931480366, -4.712769434156474}, {
            1.0489932904492667`, -4.677545035903954}, {
            1.0460874880119992`, -4.642139990169301}, {
            1.0448872447609234`, -4.606636182381747}, {
            1.045395336640308, -4.571115726389186}, {
            1.0476105885260774`, -4.535660774543781}, 
            DynamicLocation["VertexID$12", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$28"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$28", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$9", Automatic, Center], {
            1.7491893561140408`, -4.947216562369654}, {
            1.764087111898202, -4.96412378499433}, {
            1.778154776673057, -4.981727708195343}, {
            1.7913598144894352`, -4.999987617301164}, {
            1.803671684497375, -5.018861280464219}, {
            1.815061911581555, -5.03830504633546}, {
            1.825504152219053, -5.0582739450220044`}, {
            1.8349742554071224`, -5.078721792094304}, {
            1.961846549824597, -5.370889805975405}, {
            1.9703226129375435`, -5.391769309283439}, {
            1.9777850323835107`, -5.413032178334846}, {
            1.9842165489440236`, -5.434629235982052}, {
            1.9896022876914194`, -5.456510532160058}, {
            1.9939297923918506`, -5.478625459411862}, {
            1.9971890543142856`, -5.500922869934294}, {
            1.9993725353788843`, -5.523351193873577}, 
            DynamicLocation["VertexID$10", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$29"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$29", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$9", Automatic, Center], {
            1.6012128954154556`, -4.963292777741781}, {
            1.5786007809506055`, -4.983364597743871}, {
            1.5550498051543007`, -5.002326064401533}, {
            1.5306144371487225`, -5.020133323292216}, {
            1.5053511914943278`, -5.036745189465933}, {
            1.4793184974819515`, -5.052123242698569}, {
            1.4525765639964878`, -5.066231916350859}, {
            1.425187240264695, -5.079038579627561}, {
            1.0337949206882553`, -5.250700566954425}, {
            1.005821553232745, -5.262175600373409}, {
            0.9773288393630022, -5.272292464270128}, {
            0.9483826775422786, -5.281027760179041}, {
            0.9190500149764367, -5.288361284949998}, {
            0.8893986927772431, -5.294276077474457}, {
            0.8594972890582198, -5.298758457913439}, {
            0.8294149603259446, -5.301798059336507}, 
            DynamicLocation["VertexID$11", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$30"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$30", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$9", Automatic, Center], {
            1.6042964199875627`, -4.8537105524319415`}, {
            1.5831302829813496`, -4.846096027576515}, {
            1.5623547127595296`, -4.837472685620062}, {
            1.542017759436144, -4.827860470783609}, {
            1.52216645868415, -4.817281614371238}, {
            1.5028467229504652`, -4.805760583353127}, {
            1.4841032352688337`, -4.793324023777898}, {
            1.465979345916096, -4.780000699145157}, {
            1.2143985472213783`, -4.585568200701219}, {
            1.1969361734561692`, -4.571388925436811}, {
            1.1801757025719248`, -4.556386493624665}, {
            1.1641558984884217`, -4.540595603160037}, {
            1.1489138120978815`, -4.524052775499598}, {
            1.1344846955729988`, -4.506796271193944}, {
            1.1209019208350808`, -4.488866001397908}, {
            1.1081969023708624`, -4.4703034355633156`}, 
            DynamicLocation["VertexID$12", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$31"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$31", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$10", Automatic, Center], {
            1.9453726442592933`, -5.546800338746172}, {
            1.9304748884751322`, -5.529893116121496}, {
            1.9164072237002772`, -5.512289192920483}, {
            1.903202185883899, -5.494029283814662}, {
            1.8908903158759591`, -5.4751556206516065`}, {
            1.879500088791779, -5.455711854780366}, {
            1.8690578481542812`, -5.435742956093821}, {
            1.8595877449662117`, -5.415295109021522}, {
            1.7327154505487372`, -5.123127095140421}, {
            1.7242393874357909`, -5.102247591832387}, {
            1.7167769679898233`, -5.08098472278098}, {
            1.7103454514293108`, -5.059387665133774}, {
            1.704959712681915, -5.037506368955768}, {
            1.7006322079814835`, -5.015391441703963}, {
            1.6973729460590485`, -4.993094031181532}, {
            1.6951894649944501`, -4.970665707242249}, 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$32"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$32", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.024087980722274326`], 
           ArrowBox[{
             DynamicLocation["VertexID$10", Automatic, Center], {
             2.041908326871383, -5.609772007109316}, {
             2.1093070183250884`, -5.614393360691308}, {
             2.172975258220458, -5.636983087277241}, {
             2.22821489004121, -5.675874263588962}, {
             2.2709497144668953`, -5.728197062633999}, {
             2.29802627705653, -5.79009052171435}, {
             2.30744656547024, -5.856987447539114}, {
             2.298515445219168, -5.92395143494774}, {
             2.271891954481127, -5.986041130224194}, {
             2.229540672875449, -6.03867485957105}, {
             2.174586752754006, -6.077968716366835}, {
             2.1110853104249934`, -6.1010231593385615`}, {
             2.0437221942103005`, -6.106136973223255}, {
             1.9774682100238519`, -6.092932803502164}, {
             1.917212319584187, -6.062385001847631}, {
             1.867400878009316, -6.016747727533374}, {
             1.831709531888574, -5.959388610292163}, {
             1.812771988870038, -5.89454024884006}, {
             1.8119856731840793`, -5.826987882291999}, {
             1.8294086080172969`, -5.761716281573165}, {
             1.8637551339113174`, -5.703541917136474}, {
             1.9124907791310055`, -5.656757545775706}, {
             1.9720192814027324`, -5.624815442903688}, 
             DynamicLocation["VertexID$10", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$33"], 
         InsetBox[
          FormBox[
           FractionBox["1", "2"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$33", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$11", Automatic, Center], {
            0.7910823556189963, -5.318333430838525}, {
            0.8114840499642729, -5.320691082862098}, {
            0.831748800738196, -5.324026878313432}, {
            0.8518297392591688, -5.3283331021045575`}, {
            0.8716804219698936, -5.333599794723315}, {
            0.8912549378528689, -5.339814775267895}, {
            0.9105080146142206, -5.346963669619041}, {
            0.9293951233902806, -5.355029943684781}, {
            1.1935478277051002`, -5.475434297573019}, {
            1.2120252860495666`, -5.4843992955290055`}, {
            1.2300503589630545`, -5.4942422829660496`}, {
            1.2475813577313741`, -5.5049404948450285`}, {
            1.2645777363439428`, -5.516469188148285}, {
            1.28100018526933, -5.528801699105727}, {
            1.2968107223710506`, -5.541909504863269}, {
            1.3119727807533383`, -5.555762289451014}, 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$34"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$34", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$11", Automatic, Center], {
            0.7976875699730925, -5.22945905698845}, {
            0.8202996844379428, -5.20938723698636}, {
            0.8438506602342476, -5.190425770328698}, {
            0.8682860282398257, -5.172618511438015}, {
            0.8935492738942203, -5.156006645264298}, {
            0.9195819679065966, -5.140628592031662}, {
            0.9463239013920602, -5.126519918379372}, {
            0.9737132251238532, -5.11371325510267}, {
            1.3651055447002929`, -4.942051267775806}, {
            1.393078912155803, -4.930576234356822}, {
            1.4215716260255458`, -4.920459370460103}, {
            1.4505177878462696`, -4.91172407455119}, {
            1.4798504504121115`, -4.904390549780233}, {
            1.5095017726113051`, -4.898475757255774}, {
            1.5394031763303284`, -4.893993376816792}, {
            1.5694855050626035`, -4.890953775393724}, 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$35"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$35", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$11", Automatic, Center], 
            DynamicLocation["VertexID$10", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$36"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$36", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$12", Automatic, Center], {
            1.1375276332511943`, -4.512679441721357}, {
            1.1564833501378338`, -4.5427234386024455`}, {
            1.173972695337272, -4.573644042667894}, {
            1.1899552191760525`, -4.605369740186155}, {
            1.2043939569843767`, -4.637827155391002}, {
            1.2172555145886603`, -4.670941220186327}, {
            1.22851014554618, -4.7046353477649925`}, {
            1.2381318199431848`, -4.738831609740176}, {
            1.3624730033762824`, -5.225330449399217}, {
            1.3704394680304475`, -5.259949756038594}, {
            1.3767322979584367`, -5.294912039184504}, {
            1.381336938989536, -5.330136437437024}, {
            1.3842427414268033`, -5.365541483171677}, {
            1.385442984677879, -5.401045290959231}, {
            1.3849348927984946`, -5.436565746951792}, {
            1.3827196409127251`, -5.472020698797197}, 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$37"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$37", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$12", Automatic, Center], {
            1.1441328476052905`, -4.423805067871283}, {
            1.1652989846115034`, -4.4314195927267095`}, {
            1.1860745548333236`, -4.440042934683161}, {
            1.2064115081567093`, -4.449655149519615}, {
            1.2262628089087035`, -4.460234005931986}, {
            1.245582544642388, -4.471755036950097}, {
            1.2643260323240195`, -4.484191596525326}, {
            1.2824499216767573`, -4.497514921158067}, {
            1.534030720371475, -4.6919474196020055`}, {
            1.551493094136684, -4.706126694866413}, {
            1.5682535650209284`, -4.721129126678559}, {
            1.5842733691044315`, -4.736920017143187}, {
            1.5995154554949718`, -4.753462844803626}, {
            1.6139445720198544`, -4.77071934910928}, {
            1.6275273467577724`, -4.788649618905316}, {
            1.6402323652219906`, -4.8072121847399085`}, 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$38"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$38", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$12", Automatic, Center], 
            DynamicLocation["VertexID$11", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$39"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$39", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.024087980722274326`], 
           ArrowBox[{
             DynamicLocation["VertexID$12", Automatic, Center], {
             1.0564686301465938`, -4.397891803507011}, {
             0.9925572556884626, -4.4283537336107095`}, {
             0.922668719887086, -4.439675638676102}, {
             0.8524088788770869, -4.43094937303611}, {
             0.7874133716975051, -4.4028748825289075`}, {
             0.7328955778886004, -4.357704060873996}, {
             0.6932284451071721, -4.299060122161878}, {
             0.6715937289458352, -4.231646977839806}, {
             0.6697267799155596, -4.160871929467598}, {
             0.687777348580646, -4.092411941579511}, {
             0.7242975738588104, -4.031758284505909}, {
             0.7763581179614454, -3.983776071983895}, {
             0.8397831326298467, -3.952314023654468}, {
             0.9094852097005646, -3.939895753936116}, {
             0.9798734491516939, -3.94751734942135}, {
             1.0453019129276162`, -3.9745674713932173`}, {
             1.1005224934405626`, -4.018876392149463}, {
             1.1411058715400262`, -4.076890031862948}, {
             1.1637967983289748`, -4.143955036241004}, {
             1.1667752031809233`, -4.214692028510311}, {
             1.1498021841226194`, -4.283427096669268}, {
             1.114239170491794, -4.344646905818463}, {
             1.062938720806695, -4.393440930379638}, 
             DynamicLocation["VertexID$12", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$40"], 
         InsetBox[
          FormBox[
           FractionBox["1", "5"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$40", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$13", Automatic, Center], 
            DynamicLocation["VertexID$8", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$41"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$41", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$13", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$42"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$42", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$13", Automatic, Center], 
            DynamicLocation["VertexID$10", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$43"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$43", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$14", Automatic, Center], 
            DynamicLocation["VertexID$9", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$44"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$44", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$14", Automatic, Center], 
            DynamicLocation["VertexID$10", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$45"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$45", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$14", Automatic, Center], 
            DynamicLocation["VertexID$13", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$46"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$46", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.024087980722274326`], 
          ArrowBox[{
            DynamicLocation["VertexID$14", Automatic, Center], 
            DynamicLocation["VertexID$12", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$47"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$47", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.024087980722274326`], 
           ArrowBox[{
             DynamicLocation["VertexID$14", Automatic, Center], {
             2.317870582729513, -4.394509242091229}, {
             2.2666607793489097`, -4.3456200918788355`}, {
             2.231211446218826, -4.284334385948314}, {
             2.214366023387289, -4.215567935549905}, {
             2.217475705522175, -4.144836592795861}, {
             2.2402910607177695`, -4.077813816532348}, {
             2.2809820377729655`, -4.0198755963572035`}, {
             2.336284757129649, -3.9756692370575957`}, {
             2.401763311167032, -3.948740591864353}, {
             2.472165574488184, -3.9412496446592753`}, {
             2.541844484163472, -3.9537972546800364`}, {
             2.605210998459826, -3.9853769607695493`}, {
             2.6571824016095635`, -4.033455711017632}, {
             2.6935899954731215`, -4.094177042358737}, {
             2.711513476583464, -4.162670412809148}, {
             2.7095151777268742`, -4.233441874376999}, {
             2.687755385218921, -4.300814750230572}, {
             2.647979482117356, -4.359384968799611}, {
             2.5933779486326363`, -4.404454531831519}, {
             2.528330449296797, -4.432408347330016}, {
             2.4580545340128728`, -4.441004201084983}, {
             2.3881871311596505`, -4.429552607775943}, {
             2.3243324017687494`, -4.398972115543397}, 
             DynamicLocation["VertexID$14", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$48"], 
         InsetBox[
          FormBox[
           FractionBox["1", "6"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$48", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}}}]}, 
    DynamicBox[GraphComputation`NetworkGraphicsBox[
     1, Typeset`graph, Typeset`boxes], {
     CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
      SynchronousUpdating -> False, TrackedSymbols :> {}},
     ImageSizeCache->{{-1.2393066909899018`, 
      140.4926126801138}, {-182.74947094076546`, 183.548819936966}}]]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.559370042024219*^9, 3.5593700645547132`*^9}, 
   3.559563504201912*^9, 3.559563588062395*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BisimQuotient", "[", 
   RowBox[{"JoinMC", "[", 
    RowBox[{"mcPaper", ",", "mcPaper"}], "]"}], "]"}], "//", 
  "PlotMC"}]], "Input",
 CellChangeTimes->{{3.559370046825369*^9, 3.559370089401692*^9}}],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 6, 5, 
      7}, {{{1, 2}, {1, 3}, {1, 4}, {1, 5}, {2, 3}, {2, 4}, {2, 5}, {3, 2}, {
       3, 3}, {4, 1}, {4, 2}, {4, 3}, {6, 1}, {6, 2}, {6, 3}, {5, 1}, {5, 
       2}, {5, 4}, {5, 5}, {7, 2}, {7, 3}, {7, 6}, {7, 5}, {7, 7}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[1, 4] -> Rational[1, 6], DirectedEdge[4, 3] -> 
         Rational[1, 3], DirectedEdge[4, 1] -> Rational[1, 3], 
         DirectedEdge[3, 2] -> Rational[1, 2], DirectedEdge[1, 3] -> 
         Rational[1, 3], DirectedEdge[6, 6] -> Rational[1, 5], 
         DirectedEdge[7, 2] -> Rational[1, 5], DirectedEdge[6, 2] -> 
         Rational[1, 10], DirectedEdge[5, 2] -> Rational[2, 5], 
         DirectedEdge[3, 3] -> Rational[1, 2], DirectedEdge[2, 3] -> 
         Rational[2, 5], DirectedEdge[1, 6] -> Rational[1, 6], 
         DirectedEdge[5, 3] -> Rational[1, 5], DirectedEdge[7, 7] -> 
         Rational[1, 6], DirectedEdge[7, 5] -> Rational[1, 10], 
         DirectedEdge[6, 1] -> Rational[1, 2], DirectedEdge[2, 4] -> 
         Rational[2, 5], DirectedEdge[7, 3] -> Rational[1, 3], 
         DirectedEdge[1, 2] -> Rational[1, 3], DirectedEdge[4, 2] -> 
         Rational[1, 3], DirectedEdge[6, 4] -> Rational[1, 5], 
         DirectedEdge[7, 6] -> Rational[1, 5], DirectedEdge[2, 6] -> 
         Rational[1, 5], DirectedEdge[5, 1] -> Rational[2, 5]}, 
       VertexLabels -> {"Name"}, VertexSize -> {0.1}, VertexStyle -> {1 -> Hue[
           Rational[1, 2]], 6 -> Hue[
           Rational[1, 3]], 5 -> Hue[
           Rational[1, 2]], 2 -> Hue[
           Rational[1, 3]], 4 -> Hue[
           Rational[1, 2]], 3 -> Hue[
           Rational[1, 2]], 7 -> Hue[
           Rational[1, 2]]}}]], Typeset`boxes = GraphicsGroupBox[{{
       Directive[
        Hue[0.6, 0.2, 0.8], 
        EdgeForm[
         Directive[
          GrayLevel[0], 
          Opacity[0.7]]]], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.6603817607870491, 0.0002541816649996864}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$1"], 
         InsetBox[
          FormBox["1", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$1", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$1"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.9784807989410997, 0.730420034702753}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$2"], 
         InsetBox[
          FormBox["2", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$2", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$2"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{1.2956615349847862`, 0.}, 0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$3"], 
         InsetBox[
          FormBox["3", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$3", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$3"], 
       TagBox[{
         TagBox[
          StyleBox[
           DiskBox[{0., 0.30126506638559325`}, 0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$4"], 
         InsetBox[
          FormBox["4", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$4", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$4"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{0.34952880220430516`, 1.2165012808126008`}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 3]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$5"], 
         InsetBox[
          FormBox["6", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$5", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$5"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.9585266693822878`, 0.29954277809763374`}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$6"], 
         InsetBox[
          FormBox["5", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$6", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$6"], 
       TagBox[{
         TagBox[
          StyleBox[
           
           DiskBox[{1.6108566048159387`, 1.2154270339091147`}, 
            0.03176399125240115], 
           Hue[
            Rational[1, 2]], StripOnInput -> False], "DynamicName", BoxID -> 
          "VertexID$7"], 
         InsetBox[
          FormBox["7", TraditionalForm], 
          Offset[{2, 2}, 
           DynamicLocation["VertexID$7", Automatic, {Right, Top}]], 
          ImageScaled[{0, 0}], BaseStyle -> "Graphics"]}, "DynamicName", 
        BoxID -> "VertexLabelID$7"]}, {
       Directive[
        Opacity[0.7], 
        Hue[0.6, 0.7, 0.5]], 
       Arrowheads[{{0.03409704806107404, 0.7}}], {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$1"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$1", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$2"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$2", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            0.5795092383917769, 0.007634210979828526}, {0.5591075440465004, 
            0.009991863003401324}, {0.5388427932725773, 
            0.013327658454734825`}, {0.5187618547516044, 
            0.01763388224586071}, {0.49891117204087976`, 
            0.022900574864619105`}, {0.47933665615790433`, 
            0.02911555540919819}, {0.46008357939655264`, 
            0.036264449760344375`}, {0.44119647062049266`, 
            0.044330723826084384`}, {0.1770437663056732, 
            0.16473507771432172`}, {0.15856630796120683`, 
            0.17370007567030932`}, {0.14054123504771898`, 
            0.1835430631073529}, {0.12301023627939925`, 0.1942412749863316}, {
            0.10601385766683047`, 0.20576996828958866`}, {0.0895914087414435, 
            0.2181024792470299}, {0.0737808716397228, 0.2312102850045724}, {
            0.058618813257435176`, 0.24506306959231688`}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$3"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$3", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$1", Automatic, Center], {
            0.5825927629638842, 0.11721643628966855`}, {0.5636370460772446, 
            0.14726043317075801`}, {0.5461477008778064, 0.1781810372362065}, {
            0.5301651770390258, 0.20990673475446703`}, {0.5157264392307017, 
            0.24236414995931366`}, {0.5028648816264183, 0.2754782147546395}, {
            0.4916102506688984, 0.30917234233330504`}, {0.48198857627189373`, 
            0.34336860430848826`}, {0.3576473928387963, 0.8298674439675283}, {
            0.34968092818463115`, 0.8644867506069065}, {0.34338809825664196`, 
            0.8994490337528158}, {0.3387834572255426, 0.9346734320053349}, {
            0.33587765478827536`, 0.9700784777399886}, {0.33467741153719943`, 
            1.0055822855275427`}, {0.33518550341658404`, 
            1.0411027415201035`}, {0.3374007553023536, 1.0765576933655079`}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$4"], 
        InsetBox[
         FormBox[
          FractionBox["1", "6"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$4", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            1.038979522890317, 0.665001905539635}, {1.0538772786744781`, 
            0.6480946829149593}, {1.067944943449333, 0.6304907597139465}, {
            1.081149981265711, 0.6122308506081247}, {1.093461851273651, 
            0.5933571874450702}, {1.1048520783578308`, 0.5739134215738284}, {
            1.1152943189953288`, 0.5539445228872849}, {1.1247644221833988`, 
            0.533496675814985}, {1.2516367166008733`, 0.24132866193388397`}, {
            1.2601127797138196`, 0.22044915862585002`}, {1.267575199159787, 
            0.1991862895744425}, {1.2740067157202997`, 
            0.17758923192723736`}, {1.2793924544676956`, 
            0.15570793574923072`}, {1.2837199591681268`, 
            0.1335930084974264}, {1.286979221090562, 0.11129559797499539`}, {
            1.2891627021551604`, 0.0888672740357129}, 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$5"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$5", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.8910030621917313, 0.6489256901675073}, {0.8683909477268812, 
            0.6288538701654175}, {0.8448399719305763, 0.6098924035077549}, {
            0.8204046039249983, 0.5920851446170732}, {0.7951413582706036, 
            0.5754732784433558}, {0.7691086642582272, 0.5600952252107205}, {
            0.7423667307727637, 0.5459865515584301}, {0.7149774070409708, 
            0.5331798882817278}, {0.32358508746453113`, 
            0.36151790095486414`}, {0.2956117200090208, 
            0.35004286753588076`}, {0.267119006139278, 
            0.33992600363916103`}, {0.2381728443185544, 0.3311907077302483}, {
            0.2088401817527125, 0.323857182959291}, {0.1791888595535189, 
            0.31794239043483197`}, {0.14928745583449557`, 
            0.31346000999585033`}, {0.11920512710222034`, 0.3104204085727825}, 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$6"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$6", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$2", Automatic, Center], {
            0.8940865867638388, 0.7585079154773475}, {0.8729204497576257, 
            0.7661224403327744}, {0.8521448795358056, 0.7747457822892267}, {
            0.8318079262124198, 0.7843579971256796}, {0.8119566254604258, 
            0.7949368535380505}, {0.7926368897267413, 0.8064578845561621}, {
            0.7738934020451096, 0.8188944441313909}, {0.7557695126923718, 
            0.8322177687641322}, {0.5041887139976542, 1.0266502672080708`}, {
            0.48672634023244515`, 1.040829542472478}, {0.4699658693482009, 
            1.0558319742846243`}, {0.4539460652646978, 1.0716228647492516`}, {
            0.43870397887415746`, 1.088165692409691}, {0.424274862349275, 
            1.105422196715345}, {0.4106920876113567, 1.1233524665113817`}, {
            0.39798706914713866`, 1.141915032345974}, 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$7"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$7", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$3", Automatic, Center], {
            1.2351628110355692`, 0.06541812916311807}, {1.2202650552514083`, 
            0.08232535178779374}, {1.2061973904765533`, 
            0.09992927498880652}, {1.1929923526601751`, 
            0.11818918409462845`}, {1.1806804826522352`, 
            0.13706284725768295`}, {1.1692902555680553`, 
            0.15650661312892467`}, {1.1588480149305571`, 
            0.17647551181546817`}, {1.1493779117424876`, 
            0.19692335888776805`}, {1.0225056173250129`, 
            0.48909137276886905`}, {1.0140295542120663`, 
            0.5099708760769031}, {1.0065671347660994`, 0.5312337451283105}, {
            1.0001356182055865`, 0.5528308027755157}, {0.9947498794581904, 
            0.5747120989535224}, {0.9904223747577594, 0.5968270262053267}, {
            0.9871631128353242, 0.6191244367277576}, {0.9849796317707257, 
            0.6415527606670401}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$8"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$8", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03409704806107404], 
           ArrowBox[{
             DynamicLocation["VertexID$3", Automatic, Center], {
             1.3316984936476595`, 0.0024464607999724053`}, {
             1.3990971851013647`, -0.0021748927820189057`}, {
             1.4627654249967341`, -0.024764619367952018`}, {
             1.518005056817486, -0.06365579567967233}, {
             1.5607398812431714`, -0.1159785947247099}, {
             1.5878164438328062`, -0.17787205380506133`}, {
             1.5972367322465162`, -0.24476897962982594`}, {
             1.5883056119954437`, -0.31173296703845055`}, {
             1.5616821212574032`, -0.37382266231490535`}, {
             1.519330839651725, -0.4264563916617613}, {
             1.4643769195302823`, -0.46575024845754565`}, {
             1.4008754772012695`, -0.48880469142927285`}, {
             1.3335123609865764`, -0.4939185053139661}, {
             1.267258376800128, -0.4807143355928746}, {
             1.2070024863604631`, -0.45016653393834216`}, {
             1.1571910447855922`, -0.4045292596240849}, {
             1.1214996986648502`, -0.34717014238287447`}, {
             1.102562155646314, -0.28232178093077115`}, {
             1.1017758399603554`, -0.21476941438271044`}, {
             1.119198774793573, -0.1494978136638756}, {
             1.1535453006875935`, -0.0913234492271848}, {
             1.2022809459072816`, -0.044539077866417004`}, {
             1.2618094481790085`, -0.012596974994399018`}, 
             DynamicLocation["VertexID$3", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$9"], 
         InsetBox[
          FormBox[
           FractionBox["1", "2"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$9", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.08087252239527226, 0.2938850370707644}, {0.10127421674054889`, 
            0.29152738504719167`}, {0.12153896751447191`, 
            0.2881915895958581}, {0.14161990603544478`, 0.2838853658047322}, {
            0.1614705887461695, 0.27861867318597383`}, {0.18104510462914486`, 
            0.27240369264139475`}, {0.20029818139049657`, 
            0.26525479829024856`}, {0.21918529016655655`, 
            0.2571885242245086}, {0.483337994481376, 0.13678417033627122`}, {
            0.5018154528258424, 0.12781917238028362`}, {0.5198405257393302, 
            0.11797618494324008`}, {0.5373715245076499, 
            0.10727797306426134`}, {0.5543679031202187, 
            0.09574927976100422}, {0.5707903520456057, 0.08341676880356308}, {
            0.5866008891473264, 0.07030896304602052}, {0.601762947529614, 
            0.056456178458275996`}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$10"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$10", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], {
            0.0874777367493684, 0.382759410920839}, {0.11008985121421863`, 
            0.40283123092292883`}, {0.13364082701052352`, 
            0.42179269758059146`}, {0.15807619501610146`, 
            0.43959995647127315`}, {0.1833394406704962, 
            0.45621182264499044`}, {0.20937213468287258`, 
            0.47158987587762585`}, {0.23611406816833613`, 
            0.48569854952991626`}, {0.26350339190012906`, 
            0.4985052128066184}, {0.6548957114765686, 0.6701672001334822}, {
            0.6828690789320789, 0.6816422335524656}, {0.7113617928018217, 
            0.6917590974491853}, {0.7403079546225453, 0.700494393358098}, {
            0.7696406171883873, 0.7078279181290553}, {0.7992919393875808, 
            0.7137427106535144}, {0.8291933431066041, 0.718225091092496}, {
            0.8592756718388793, 0.7212646925155637}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$11"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$11", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$4", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$12"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$12", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            0.4273178000274703, 1.099539026187932}, {0.4462735169141097, 
            1.0694950293068426`}, {0.46376286211354795`, 1.038574425241394}, {
            0.4797453859523285, 1.0068487277231335`}, {0.4941841237606527, 
            0.9743913125182869}, {0.5070456813649362, 0.941277247722961}, {
            0.5183003123224559, 0.9075831201442955}, {0.5279219867194608, 
            0.8733868581691123}, {0.6522631701525582, 0.38688801851007215`}, {
            0.6602296348067234, 0.35226871187069414`}, {0.6665224647347125, 
            0.31730642872478465`}, {0.6711271057658118, 
            0.28208203047226565`}, {0.6740329082030792, 
            0.24667698473761202`}, {0.675233151454155, 
            0.21117317695005786`}, {0.6747250595747704, 
            0.17565272095749704`}, {0.6725098076890009, 0.1401977691120927}, 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$13"], 
        InsetBox[
         FormBox[
          FractionBox["1", "2"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$13", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], {
            0.4339230143815664, 1.1884134000380067`}, {0.45508915138777933`, 
            1.18079887518258}, {0.4758647216095995, 1.1721755332261274`}, {
            0.4962016749329851, 1.1625633183896746`}, {0.5160529756849793, 
            1.1519844619773036`}, {0.5353727114186639, 1.1404634309591923`}, {
            0.5541161991002954, 1.1280268713839634`}, {0.5722400884530332, 
            1.114703546751222}, {0.8238208871477508, 0.9202710483072831}, {
            0.8412832609129599, 0.906091773042876}, {0.8580437317972041, 
            0.8910893412307299}, {0.8740635358807072, 0.8752984507661024}, {
            0.8893056222712475, 0.8587556231056631}, {0.9037347387961301, 
            0.8414991188000092}, {0.9173175135340483, 0.8235688490039725}, {
            0.9300225319982663, 0.8050062831693804}, 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$14"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$14", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$5", Automatic, Center], 
            DynamicLocation["VertexID$4", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$15"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$15", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03409704806107404], 
           ArrowBox[{
             DynamicLocation["VertexID$5", Automatic, Center], {
             0.34625879692286965`, 1.2143266644022779`}, {0.2823474224647387, 
             1.183864734298579}, {0.21245888666336202`, 1.172542829233187}, {
             0.14219904565336292`, 1.1812690948731792`}, {0.07720353847378109,
              1.2093435853803816`}, {0.02268574466487633, 
             1.254514407035293}, {-0.016981388116551893`, 
             1.3131583457474105`}, {-0.03861610427788875, 
             1.380571490069482}, {-0.040483053308164346`, 
             1.4513465384416904`}, {-0.022432484643077982`, 
             1.5198065263297778`}, {0.014087740635086443`, 
             1.5804601834033802`}, {0.06614828473772144, 
             1.6284423959253937`}, {0.12957329940612272`, 
             1.6599044442548203`}, {0.19927537647684057`, 
             1.6723227139731724`}, {0.26966361592796995`, 
             1.6647011184879386`}, {0.33509207970389215`, 
             1.6376509965160713`}, {0.39031266021683875`, 
             1.5933420757598258`}, {0.43089603831630224`, 
             1.5353284360463406`}, {0.45358696510525065`, 
             1.4682634316682848`}, {0.45656536995719926`, 
             1.3975264393989781`}, {0.4395923508988953, 
             1.3287913712400208`}, {0.40402933726806994`, 
             1.267571562090826}, {0.35272888758297094`, 1.21877753752965}, 
             DynamicLocation["VertexID$5", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$16"], 
         InsetBox[
          FormBox[
           FractionBox["1", "5"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$16", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$1", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$17"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$17", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$18"], 
        InsetBox[
         FormBox[
          FractionBox["2", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$18", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$6", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$19"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$19", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$2", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$20"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$20", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$3", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$21"], 
        InsetBox[
         FormBox[
          FractionBox["1", "3"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$21", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$6", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$22"], 
        InsetBox[
         FormBox[
          FractionBox["1", "10"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$22", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {
        TagBox[{
          Arrowheads[0.03409704806107404], 
          ArrowBox[{
            DynamicLocation["VertexID$7", Automatic, Center], 
            DynamicLocation["VertexID$5", Automatic, Center]}]}, 
         "DynamicName", BoxID -> "EdgeLabelID$23"], 
        InsetBox[
         FormBox[
          FractionBox["1", "5"], TraditionalForm], 
         DynamicLocation["EdgeLabelID$23", Automatic, 
          Scaled[0.5]], 
         ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}, {{
         TagBox[{
           Arrowheads[0.03409704806107404], 
           ArrowBox[{
             DynamicLocation["VertexID$7", Automatic, Center], {
             1.607660749505789, 1.217709225818059}, {1.5564509461251854`, 
             1.2665983760304527`}, {1.5210016129951018`, 
             1.3278840819609745`}, {1.504156190163565, 1.3966505323593832`}, {
             1.5072658722984513`, 1.467381875113427}, {1.5300812274940454`, 
             1.5344046513769403`}, {1.5707722045492414`, 1.592342871552085}, {
             1.6260749239059247`, 1.6365492308516925`}, {1.691553477943308, 
             1.6634778760449354`}, {1.7619557412644598`, 1.670968823250013}, {
             1.8316346509397479`, 1.6584212132292522`}, {1.8950011652361018`, 
             1.6268415071397393`}, {1.9469725683858392`, 
             1.5787627568916562`}, {1.9833801622493974`, 
             1.5180414255505512`}, {2.0013036433597398`, 
             1.4495480551001398`}, {1.9993053445031501`, 
             1.3787765935322889`}, {1.9775455519951968`, 
             1.3114037176787166`}, {1.9377696488936318`, 
             1.2528334991096777`}, {1.8831681154089122`, 
             1.2077639360777699`}, {1.818120616073073, 1.1798101205792724`}, {
             1.7478447007891487`, 1.1712142668243057`}, {1.6779772979359264`, 
             1.182665860133346}, {1.6141225685450251`, 1.2132463523658918`}, 
             DynamicLocation["VertexID$7", Automatic, Center]}]}, 
          "DynamicName", BoxID -> "EdgeLabelID$24"], 
         InsetBox[
          FormBox[
           FractionBox["1", "6"], TraditionalForm], 
          DynamicLocation["EdgeLabelID$24", Automatic, 
           Scaled[0.5]], 
          ImageScaled[{0.5, 0.5}], BaseStyle -> "Graphics"]}}}}]}, 
    DynamicBox[GraphComputation`NetworkGraphicsBox[
     1, Typeset`graph, Typeset`boxes], {
     CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
      SynchronousUpdating -> False, TrackedSymbols :> {}},
     ImageSizeCache->{{1.7606933090100982`, 
      288.6353385756221}, {-156.31296287425948`, 159.17067848673815`}}]]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.5593700911255007`*^9, 3.559563505550665*^9, 
  3.5595635915844593`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation", "Section",
 InitializationGroup->True,
 CellChangeTimes->{{3.5487310498981857`*^9, 3.5487310576573887`*^9}}],

Cell[CellGroupData[{

Cell["Utilities", "Subsection",
 InitializationGroup->True,
 CellChangeTimes->{{3.555851520770937*^9, 3.555851522416521*^9}, {
  3.555910513255423*^9, 3.555910514367128*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DiffDist", "[", 
    RowBox[{"d1_", ",", "d2_"}], "]"}], ":=", 
   RowBox[{"Max", "[", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Abs", "[", 
      RowBox[{"d1", "-", "d2"}], "]"}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.558794994884231*^9, 3.5587950399411917`*^9}, {
  3.558795187410437*^9, 3.55879519262022*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ZeroMatrix", "[", "n_", "]"}], ":=", 
   RowBox[{"SparseArray", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "n"}], "}"}]}], "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.5485845084613237`*^9, 3.548584528110305*^9}, 
   3.548584584233588*^9, {3.548585286573312*^9, 3.548585318725881*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TestAll", "[", 
    RowBox[{"list_", ",", "test_"}], "]"}], ":=", 
   RowBox[{"And", "@@", 
    RowBox[{"(", 
     RowBox[{"test", "/@", "list"}], ")"}]}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.5559247072761097`*^9, 3.555924876850914*^9}, {
  3.557813596552372*^9, 3.557813632758194*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DebugPrint", "[", "s___", "]"}], ":=", 
   RowBox[{
    RowBox[{"Print", "[", "s", "]"}], "/;", 
    RowBox[{"OptionValue", "[", 
     RowBox[{"ComputeDistances", ",", "Verbose"}], "]"}]}]}], ";"}]], "Input",\

 InitializationGroup->True,
 CellChangeTimes->{{3.555851529167551*^9, 3.55585158636123*^9}, {
   3.55585162482337*^9, 3.5558516354861307`*^9}, 3.5578354385955553`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PrintActiveProblems", "[", 
    RowBox[{"dist_", ",", "problems_", ",", "queryLst_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ActivePrint", ",", 
        RowBox[{"active", " ", "=", " ", 
         RowBox[{"ReachableProblems", "[", 
          RowBox[{"dist", ",", "problems", ",", "queryLst"}], "]"}]}]}], 
       "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"ActivePrint", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"u_", ",", "v_"}], "}"}], "\[Rule]", "actv_"}], "]"}], ":=", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"u", ",", "v"}], "}"}], "\[Rule]", 
           RowBox[{"PrPrint", "[", 
            RowBox[{"problems", "\[LeftDoubleBracket]", 
             RowBox[{"u", ",", "v"}], "\[RightDoubleBracket]"}], "]"}]}], 
          "]"}], "/;", "actv"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Reachable states from \>\"", ",", "queryLst", ",", " ", 
         "\"\< in the current coupling\>\""}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Scan", "[", 
        RowBox[{"ActivePrint", ",", 
         RowBox[{"ArrayRules", "[", "active", "]"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{"DebugPrint", "[", 
       RowBox[{"MatrixForm", "@", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{"ActivePrint", ",", "problems", ",", 
          RowBox[{"{", "2", "}"}]}], "]"}]}], "]"}], "*)"}], 
     "\[IndentingNewLine]", "]"}], "/;", 
    RowBox[{"OptionValue", "[", 
     RowBox[{"ComputeDistances", ",", "Verbose"}], "]"}]}]}], ";"}]], "Input",\

 InitializationGroup->True,
 CellChangeTimes->{{3.556611782286076*^9, 3.556611865868935*^9}, {
   3.556611901357718*^9, 3.55661214236788*^9}, {3.55661279309053*^9, 
   3.556612801897019*^9}, {3.556612848028675*^9, 3.556612902883781*^9}, {
   3.556612994864668*^9, 3.556613086268167*^9}, {3.556613140454073*^9, 
   3.556613193949904*^9}, {3.55661667197159*^9, 3.5566167547243023`*^9}, {
   3.556616880907802*^9, 3.556616888144506*^9}, {3.556616924147477*^9, 
   3.556616955259095*^9}, {3.556618908166027*^9, 3.556618911042738*^9}, {
   3.55775302866061*^9, 3.55775304337646*^9}, {3.5577530775781813`*^9, 
   3.557753099399701*^9}, 3.559282348011224*^9, {3.5592823868864717`*^9, 
   3.559282486317315*^9}, {3.559282537019038*^9, 3.559282587952642*^9}, {
   3.559282630424438*^9, 3.5592826326643*^9}, {3.5592826627068644`*^9, 
   3.559282754155686*^9}, {3.5592827842962217`*^9, 3.559282854169532*^9}, {
   3.5592829492054033`*^9, 3.559282992341757*^9}, {3.559283093385558*^9, 
   3.559283129070178*^9}, {3.559283290295751*^9, 3.559283413947928*^9}, 
   3.559283506282708*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"PrintProblems", "[", "problems_", "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"DebugPrint", "[", 
    RowBox[{"MatrixForm", "@", 
     RowBox[{"Map", "[", 
      RowBox[{"PrPrint", ",", "problems", ",", 
       RowBox[{"{", "2", "}"}]}], "]"}]}], "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.548647915654541*^9, 3.548647985790598*^9}, {
   3.548648446808104*^9, 3.548648485047453*^9}, 3.548648519546731*^9, {
   3.548671912571375*^9, 3.548671951265956*^9}, 3.548989789624279*^9, {
   3.555852044438796*^9, 3.555852055392061*^9}, {3.556611617997498*^9, 
   3.556611647955921*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Labelled Markov Chains (LMCs)", "Subsection",
 InitializationGroup->True,
 CellChangeTimes->{
  3.546630482482202*^9, {3.546630515883642*^9, 3.54663055099403*^9}, {
   3.556382967271118*^9, 3.5563829967091312`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"AllPairs", "[", 
    RowBox[{"MC", "[", 
     RowBox[{"_", ",", "labels_"}], "]"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"size", "=", 
       RowBox[{"Length", "@", "labels"}]}], "}"}], ",", 
     RowBox[{"Join", "@@", 
      RowBox[{"(", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"i", ",", "j"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "size"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"j", ",", "size"}], "}"}]}], "]"}], ")"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.558164962049395*^9, 3.5581650120911818`*^9}, {
  3.5587923699930487`*^9, 3.558792422411406*^9}, {3.558792460108384*^9, 
  3.558792468605187*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SameLabelsPairs", "[", 
    RowBox[{"mc", ":", 
     RowBox[{"MC", "[", 
      RowBox[{"_", ",", "labels_"}], "]"}]}], "]"}], ":=", 
   RowBox[{"Select", "[", 
    RowBox[{
     RowBox[{"AllPairs", "@", "mc"}], ",", 
     RowBox[{
      RowBox[{"Equal", "@@", 
       RowBox[{"(", 
        RowBox[{
        "labels", "\[LeftDoubleBracket]", "#", "\[RightDoubleBracket]"}], 
        ")"}]}], "&"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5587916610981216`*^9, 3.5587917042437477`*^9}, {
  3.558792455111663*^9, 3.5587924889896708`*^9}, {3.558792593702345*^9, 
  3.558792636960565*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MarkovChainQ", "[", 
    RowBox[{"MC", "[", 
     RowBox[{"TM_", ",", "labels_"}], "]"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"size", ",", "a", ",", "b"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"size", "=", 
        RowBox[{"Length", "@", "labels"}]}], ";", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"a", ",", "b"}], "}"}], "=", 
        RowBox[{"Dimensions", "[", "TM", "]"}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{
         "check", " ", "if", " ", "the", " ", "sizes", " ", "are", " ", 
          "consistent"}], ",", " ", 
         RowBox[{
         "and", " ", "if", " ", "TM", " ", "is", " ", "a", " ", "probability",
           " ", "distribution", " ", "matrix"}]}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"size", "\[Equal]", "a"}], "\[And]", 
        RowBox[{"a", "\[Equal]", "b"}], "\[And]", " ", 
        RowBox[{"TestAll", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Plus", "@@", "#"}], "&"}], ")"}], "/@", "TM"}], ",", 
          RowBox[{
           RowBox[{"#", "\[Equal]", "1"}], "&"}]}], "]"}]}]}]}], 
     "\[IndentingNewLine]", "]"}], "/;", 
    RowBox[{
     RowBox[{"MatchQ", "[", 
      RowBox[{"labels", ",", 
       RowBox[{"{", "__Integer", "}"}]}], "]"}], "\[And]", " ", 
     RowBox[{"(*", " ", 
      RowBox[{
      "labels", " ", "is", " ", "a", " ", "list", " ", "of", " ", 
       "integers"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"MatrixQ", "[", 
      RowBox[{"TM", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"MatchQ", "[", 
          RowBox[{"#", ",", "_Rational"}], "]"}], "\[Or]", " ", 
         RowBox[{"IntegerQ", "[", "#", "]"}]}], "&"}]}], "]"}]}]}]}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "TM", " ", "is", " ", "a", " ", "matrix", " ", "of", " ", "rationals"}], 
   " ", "*)"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MarkovChainQ", "[", "_", "]"}], ":=", "False"}], ";"}]}], "Input",\

 InitializationGroup->True,
 CellChangeTimes->{{3.55592313274506*^9, 3.555923247284629*^9}, {
  3.555923288830842*^9, 3.555923297814624*^9}, {3.555923808088561*^9, 
  3.555924207973626*^9}, {3.555924317970128*^9, 3.5559244305149937`*^9}, {
  3.555926383189827*^9, 3.55592648427955*^9}, {3.555926549240624*^9, 
  3.5559265822653303`*^9}, {3.555926621357379*^9, 3.555926674749872*^9}, {
  3.557813463929879*^9, 3.557813510602339*^9}, {3.5578135550758133`*^9, 
  3.557813591180455*^9}}],

Cell[TextData[{
 "Given a list of edges of the form ",
 StyleBox["Edge[s,p,t]", "Program"],
 " indicating that there exists a transition from the state ",
 StyleBox["s", "Program"],
 " to ",
 StyleBox["t", "Program"],
 " with probability p, \n",
 StyleBox["TransitionMatrix[|S|,edgeList]", "Program"],
 " returns the transition matrix \[Pi] induced by them."
}], "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.546630648599251*^9, 3.546630738423296*^9}, {
  3.546630798931601*^9, 3.54663079924125*^9}, {3.546630842346266*^9, 
  3.5466308831228933`*^9}, {3.54663092411639*^9, 3.5466310360882273`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TransitionMatrix", "[", 
    RowBox[{"numStates_", ",", "edgeList_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "f", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"Edge", "[", 
         RowBox[{"x_", ",", "p_", ",", "y_"}], "]"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], "\[Rule]", "p"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"SparseArray", "[", 
       RowBox[{
        RowBox[{"f", "/@", "edgeList"}], ",", 
        RowBox[{"{", 
         RowBox[{"numStates", ",", "numStates"}], "}"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.546536284893381*^9, 3.546536307308885*^9}, {
   3.546536372881762*^9, 3.5465365004587717`*^9}, {3.54653665511798*^9, 
   3.546536777728964*^9}, {3.546536815108964*^9, 3.546536836219952*^9}, 
   3.5465369469433937`*^9, {3.546620236242071*^9, 3.546620268901168*^9}, {
   3.546620468993621*^9, 3.546620474801612*^9}}],

Cell[TextData[{
 StyleBox["JoinMC", "Program"],
 " returns a graphical representation of a given Markov chain "
}], "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.5466310607922363`*^9, 3.546631119217248*^9}, {
  3.559302872398575*^9, 3.559302874684082*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"JoinMC", "[", "seq__MC", "]"}], ":=", 
   RowBox[{"Fold", "[", 
    RowBox[{"JoinMCAux", ",", 
     RowBox[{"First", "@", 
      RowBox[{"{", "seq", "}"}]}], ",", 
     RowBox[{"Rest", "@", 
      RowBox[{"{", "seq", "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"JoinMCAux", "[", 
    RowBox[{
     RowBox[{"MC", "[", 
      RowBox[{"tm1_", ",", "l1_"}], "]"}], ",", 
     RowBox[{"MC", "[", 
      RowBox[{"tm2_", ",", "l2_"}], "]"}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"n", " ", "=", " ", 
        RowBox[{"Length", "@", "l1"}]}], ",", " ", 
       RowBox[{"m", "=", 
        RowBox[{"Length", "@", "l2"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
     
     RowBox[{"MC", "[", 
      RowBox[{
       RowBox[{"ArrayFlatten", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"tm1", ",", 
            RowBox[{"SparseArray", "[", 
             RowBox[{
              RowBox[{"{", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"n", ",", "m"}], "}"}]}], "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"SparseArray", "[", 
             RowBox[{
              RowBox[{"{", "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"m", ",", "n"}], "}"}]}], "]"}], ",", "tm2"}], "}"}]}],
          "}"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Join", "[", 
        RowBox[{"l1", ",", "l2"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.55930296555204*^9, 3.5593030996496058`*^9}, {
  3.559303135966292*^9, 3.5593031488196077`*^9}}],

Cell[TextData[{
 StyleBox["PlotMC", "Program"],
 " returns a graphical representation of a given Markov chain "
}], "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.5466310607922363`*^9, 3.546631119217248*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PlotMC", "[", 
    RowBox[{"edgeList", ":", 
     RowBox[{"{", "___Edge", "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "f", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"Edge", "[", 
         RowBox[{"x_", ",", "p_", ",", "y_"}], "]"}], "]"}], ":=", 
       RowBox[{"Labeled", "[", 
        RowBox[{
         RowBox[{"x", "\[Rule]", "y"}], ",", "p"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Graph", "[", 
       RowBox[{
        RowBox[{"f", "/@", "edgeList"}], ",", 
        RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
        RowBox[{"VertexSize", "\[Rule]", "0.1"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PlotMC", "[", 
    RowBox[{"MC", "[", 
     RowBox[{"tm_", ",", "labels_"}], "]"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f", ",", "g", ",", "edgelist"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"Edge", "[", 
         RowBox[{"x_", ",", "p_", ",", "y_"}], "]"}], "]"}], ":=", 
       RowBox[{"Labeled", "[", 
        RowBox[{
         RowBox[{"x", "\[Rule]", "y"}], ",", "p"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"g", "[", 
        RowBox[{"lbl_", ",", 
         RowBox[{"{", "vertex_", "}"}]}], "]"}], ":=", 
       RowBox[{"vertex", "\[Rule]", 
        RowBox[{"Hue", "[", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"lbl", "+", "1"}], ")"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"edgelist", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"Edge", "[", 
          RowBox[{
           RowBox[{"#", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
           RowBox[{
           "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
           RowBox[{"#", "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}], "]"}], 
         "&"}], "/@", 
        RowBox[{"Most", "@", 
         RowBox[{"ArrayRules", "[", "tm", "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Graph", "[", 
       RowBox[{
        RowBox[{"f", "/@", "edgelist"}], ",", 
        RowBox[{"VertexLabels", "\[Rule]", "\"\<Name\>\""}], ",", 
        RowBox[{"VertexSize", "\[Rule]", "0.1"}], ",", 
        RowBox[{"VertexStyle", "\[Rule]", 
         RowBox[{"MapIndexed", "[", 
          RowBox[{"g", ",", "labels"}], "]"}]}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.546536972510084*^9, 3.546537026167132*^9}, {
   3.546537077445257*^9, 3.546537171166202*^9}, {3.549005317031501*^9, 
   3.549005319141273*^9}, {3.54900559243217*^9, 3.549005619638619*^9}, {
   3.5490056850107403`*^9, 3.549005688631926*^9}, {3.5570283108494673`*^9, 
   3.557028317646907*^9}, {3.557028472283875*^9, 3.5570284730677977`*^9}, 
   3.557854424571269*^9, {3.5578545743978786`*^9, 3.557854576020135*^9}, {
   3.557854606284895*^9, 3.557854782670001*^9}, {3.557854854978002*^9, 
   3.557854968188546*^9}, {3.557855058743423*^9, 3.557855059240388*^9}, {
   3.557855090833508*^9, 3.557855095029398*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Random generation of LMCs", "Subsection",
 InitializationGroup->True,
 CellChangeTimes->{{3.555147361455165*^9, 3.555147379548951*^9}, {
  3.556382943186984*^9, 3.5563829621908417`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomRational", "[", 
   RowBox[{"rmax_", ",", "n_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"RandomInteger", "[", 
       RowBox[{"{", 
        RowBox[{"1", ",", "#"}], "}"}], "]"}], "/", "#"}], ")"}], "&"}], "/@", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "rmax"}], "}"}], ",", "n"}], "]"}]}]}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.5550674770561657`*^9, 3.555067478180808*^9}, {
   3.555067690312152*^9, 3.555067704077372*^9}, {3.555067738608564*^9, 
   3.555068024102656*^9}, 3.555069263361195*^9, {3.5550706616946993`*^9, 
   3.555070664662917*^9}}],

Cell[TextData[{
 StyleBox["RandomProbDistr", "Program"],
 " gives a pseudorandom list of rationals ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     SubscriptBox["r", "1"], ",", "...", ",", " ", 
     SubscriptBox["r", "n"], " "}], "Program"], TraditionalForm]],
  CellChangeTimes->{{3.5550687127777033`*^9, 3.5550688041103153`*^9}, {
   3.5550688393874826`*^9, 3.5550690137598677`*^9}, {3.555069061826*^9, 
   3.5550690814669857`*^9}}],
 "such that ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "n"], 
     SubscriptBox["r", "i"]}], "=", " ", "1"}], "Program"]],
  CellChangeTimes->{{3.5550687127777033`*^9, 3.5550688041103153`*^9}, {
   3.5550688393874826`*^9, 3.5550690137598677`*^9}, {3.555069061826*^9, 
   3.5550690814669857`*^9}}]
}], "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.555069113938957*^9, 3.5550691825673523`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RandomProbDistr", "[", 
   RowBox[{"rmax_", ",", "n_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"rnd", "=", 
       RowBox[{"RandomRational", "[", 
        RowBox[{"rmax", ",", "n"}], "]"}]}], ",", "total"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"total", "=", 
      RowBox[{"Plus", "@@", "rnd"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"#", "/", "total"}], ")"}], "&"}], "/@", "rnd"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.555068296509959*^9, 3.555068573192752*^9}, {
   3.555068663814169*^9, 3.555068664741972*^9}, 3.5550687018888903`*^9, {
   3.5550693073416977`*^9, 3.5550693182674923`*^9}, {3.555069349365365*^9, 
   3.5550693553878107`*^9}, {3.555070432148758*^9, 3.555070441857491*^9}, 
   3.5550706394629927`*^9, {3.555070673298918*^9, 3.555070675451572*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"RandomTransitionMatrix", "[", 
    RowBox[{"numStates_", ",", "maxDegree_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "MakeRow", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"MakeRow", "[", "degree_", "]"}], ":=", 
        RowBox[{"Shuffle", "@", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{"0", ",", 
             RowBox[{"{", 
              RowBox[{"numStates", "-", "degree"}], "}"}]}], "]"}], ",", 
           RowBox[{"RandomProbDistr", "[", 
            RowBox[{"numStates", ",", "degree"}], "]"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"SparseArray", "@", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"MakeRow", "[", 
           RowBox[{"RandomInteger", "[", 
            RowBox[{"{", 
             RowBox[{"1", ",", "maxDegree"}], "}"}], "]"}], "]"}], ",", 
          RowBox[{"{", "numStates", "}"}]}], "]"}]}]}]}], 
     "\[IndentingNewLine]", "]"}], "/;", 
    RowBox[{"numStates", "\[GreaterEqual]", " ", "maxDegree"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RandomTransitionMatrix", "[", 
    RowBox[{"numStates_", ",", "maxDegree_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"Message", "[", 
      RowBox[{
       RowBox[{"RandomTransitionMatrix", "::", "nnarg"}], ",", "numStates", 
       ",", "maxDegree"}], "]"}], ";", 
     RowBox[{"Abort", "[", "]"}]}], ")"}]}], ";"}]}], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.555071135584466*^9, 3.555071396900217*^9}, 
   3.555071437283958*^9, {3.555071644061367*^9, 3.555071717801826*^9}, {
   3.555071865685264*^9, 3.555071928497099*^9}, 3.555071965454878*^9, {
   3.555072009657434*^9, 3.5550721578902082`*^9}, 3.555072188168577*^9, {
   3.5550722507698793`*^9, 3.555072268234144*^9}, {3.555073016237858*^9, 
   3.555073081310876*^9}, {3.555073231761182*^9, 3.555073297706122*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RandomTransitionMatrix", "::", "nnarg"}], "=", 
   "\"\<The argument `1` is not greater than or equal to `2`.\>\""}], 
  ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.555071827544783*^9, 3.555071876453291*^9}, 
   3.555071959072475*^9},
 CellID->390751893],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RandomMarkovChain", "[", 
    RowBox[{"numStates_", ",", "maxDegree_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"MC", "[", 
    RowBox[{
     RowBox[{"RandomTransitionMatrix", "[", 
      RowBox[{"numStates", ",", "maxDegree"}], "]"}], ",", 
     RowBox[{"RandomInteger", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], ",", "numStates"}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.5559267144855337`*^9, 3.555926783805952*^9}, {
  3.555926829731502*^9, 3.555926838501313*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Shuffle", "[", 
    RowBox[{"{", "}"}], "]"}], ":=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Shuffle", "[", "lst_", "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"left", ",", "right", ",", 
       RowBox[{"pick", "=", 
        RowBox[{"RandomInteger", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"Length", "@", "lst"}]}], "}"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"left", "=", 
       RowBox[{"Take", "[", 
        RowBox[{"lst", ",", "pick"}], "]"}]}], ";", 
      RowBox[{"right", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{"lst", ",", "pick"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "lst", "\[LeftDoubleBracket]", "pick", "\[RightDoubleBracket]"}], 
         "}"}], ",", 
        RowBox[{"Shuffle", "[", 
         RowBox[{"Most", "@", "left"}], "]"}], ",", 
        RowBox[{"Shuffle", "[", "right", "]"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 InitializationCell->True,
 InitializationGroup->True,
 CellChangeTimes->{{3.5550722719052877`*^9, 3.555072387330556*^9}, {
   3.555072462629727*^9, 3.5550725613289223`*^9}, {3.555072594959363*^9, 
   3.5550726829665527`*^9}, {3.55507271824862*^9, 3.555072728036368*^9}, {
   3.5550728460163383`*^9, 3.555072914696854*^9}, 3.555147430149253*^9, {
   3.558796706482699*^9, 3.558796707590095*^9}, {3.558796744707912*^9, 
   3.55879691926372*^9}, {3.558797021290193*^9, 3.558797148969084*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Transportation Problem", "Subsection",
 InitializationGroup->True,
 CellChangeTimes->{{3.548585757915329*^9, 3.548585770849608*^9}}],

Cell[TextData[{
 "Given two \[Epsilon]-numbers ",
 StyleBox["x", "Program"],
 " and ",
 StyleBox["y", "Program"],
 ", ",
 StyleBox["EpsilonLeq[x,y]", "Program"],
 " determines if ",
 StyleBox["x \[LessEqual] y", "Program"],
 " provided that ",
 StyleBox["\[Epsilon] \[Rule] +0", "Program"],
 "."
}], "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.555300058117783*^9, 3.555300178681591*^9}, {
  3.555300225154306*^9, 3.555300295298058*^9}, {3.5553003586605597`*^9, 
  3.5553003600929193`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"EpsilonLeq", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"EpsilonRemoval", "[", 
       RowBox[{"x", "-", "y"}], "]"}], "\[Equal]", "0"}], ",", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"check", " ", "if", " ", "x"}], "-", 
       RowBox[{
       "y", " ", "depends", " ", "only", " ", "on", " ", "\[Epsilon]"}]}], 
      "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"EpsilonFix", "[", 
       RowBox[{
        RowBox[{"x", "-", "y"}], ",", "1"}], "]"}], "\[LessEqual]", " ", 
      "0"}], ",", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"set", " ", "\[Epsilon]"}], " ", ">", " ", 
       RowBox[{"0", " ", "and", " ", "check", " ", "again"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"EpsilonRemoval", "[", 
       RowBox[{"x", "-", "y"}], "]"}], "\[LessEqual]", " ", "0"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"set", " ", 
       RowBox[{"e", "[", "]"}]}], "=", " ", 
      RowBox[{"0", " ", "and", " ", "check", " ", "again"}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.5552391776453123`*^9, 3.555239258119031*^9}, {
  3.555240361713274*^9, 3.555240521981283*^9}, {3.5552405557594233`*^9, 
  3.5552405679030113`*^9}, {3.555241037950642*^9, 3.555241043286358*^9}, {
  3.555241120281152*^9, 3.5552411204885387`*^9}, {3.5552414611259317`*^9, 
  3.555241498540557*^9}, {3.555241559359236*^9, 3.555241649105546*^9}, {
  3.5552417087154284`*^9, 3.555241840200774*^9}, {3.555241874321967*^9, 
  3.555242022671514*^9}, {3.555320508268059*^9, 3.555320663150226*^9}, {
  3.557804029272852*^9, 3.5578040376442537`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"EpsilonMin", "[", 
    RowBox[{"x_", ",", "y_"}], "]"}], ":=", " ", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"EpsilonLeq", "[", 
      RowBox[{"x", ",", "y"}], "]"}], ",", "x", ",", "y"}], "]"}]}], 
  ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.555320704620981*^9, 3.5553207851904573`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"EpsilonPerturbation", "[", 
    RowBox[{"\[Pi]s_", ",", "\[Pi]t_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "AddEpsilon", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"AddEpsilon", "[", "k_", "]"}], "[", 
        RowBox[{"{", 
         RowBox[{"a_", ",", "id_"}], "}"}], "]"}], ":=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", "+", " ", 
          RowBox[{"k", " ", 
           RowBox[{"e", "[", "]"}]}]}], ",", "id"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"AddEpsilon", "[", "1", "]"}], "/@", "\[Pi]s"}], ",", " ", 
        RowBox[{"Append", "[", 
         RowBox[{
          RowBox[{"Most", "[", "\[Pi]t", "]"}], ",", 
          RowBox[{
           RowBox[{"AddEpsilon", "[", 
            RowBox[{"Length", "@", "\[Pi]s"}], "]"}], "[", 
           RowBox[{"Last", "@", "\[Pi]t"}], "]"}]}], "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.555320015138637*^9, 3.5553201839210443`*^9}, {
  3.555322213163025*^9, 3.555322270866029*^9}, {3.555322554285261*^9, 
  3.5553227029871473`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"EpsilonFix", "[", 
    RowBox[{"x_", ",", "\[Epsilon]value_"}], "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{
     RowBox[{"e", "[", "]"}], "\[Rule]", "\[Epsilon]value"}]}]}], 
  ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.555320380338091*^9, 3.555320427391011*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"EpsilonRemoval", "[", "x_", "]"}], ":=", 
   RowBox[{"EpsilonFix", "[", 
    RowBox[{"x", ",", "0"}], "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.555320209314296*^9, 3.555320305713208*^9}, {
  3.555320433190873*^9, 3.555320449012827*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"indexed", "[", "lst_", "]"}], ":=", 
   RowBox[{"Thread", "[", 
    RowBox[{"{", 
     RowBox[{"lst", ",", 
      RowBox[{"Table", "[", 
       RowBox[{"i", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", 
          RowBox[{"Length", "@", "lst"}]}], "}"}]}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{3.547786231509747*^9, 3.547813465079526*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GuessVertexAux", "[", "_", "]"}], "[", 
    RowBox[{"\[Pi]s_", ",", "\[Pi]t_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"{", "}"}], "/;", 
    RowBox[{
     RowBox[{"\[Pi]s", "\[Equal]", 
      RowBox[{"{", "}"}]}], "||", 
     RowBox[{"\[Pi]t", "\[Equal]", 
      RowBox[{"{", "}"}]}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GuessVertexAux", "[", "strategy_", "]"}], "[", 
    RowBox[{"\[Pi]s_", ",", "\[Pi]t_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "G", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"G", "[", 
        RowBox[{"{", 
         RowBox[{"i_", ",", "j_"}], "}"}], "]"}], ":=", "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", "rec", "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"rec", "=", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"EpsilonLeq", "[", 
              RowBox[{
               RowBox[{"\[Pi]s", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
               RowBox[{"\[Pi]t", "\[LeftDoubleBracket]", 
                RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}], 
             ",", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"\[Pi]s", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], " ", 
               "\[LessEqual]", " ", 
               RowBox[{"\[Pi]t", "\[LeftDoubleBracket]", 
                RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}]}], "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"GuessVertexAux", "[", "strategy", "]"}], "[", 
              RowBox[{
               RowBox[{"Drop", "[", 
                RowBox[{"\[Pi]s", ",", 
                 RowBox[{"{", "i", "}"}]}], "]"}], ",", 
               RowBox[{"ReplacePart", "[", 
                RowBox[{"\[Pi]t", ",", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"j", ",", "1"}], "}"}], "\[Rule]", 
                  RowBox[{
                   RowBox[{"\[Pi]t", "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
                   " ", 
                   RowBox[{"\[Pi]s", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], 
                "]"}]}], "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"GuessVertexAux", "[", "strategy", "]"}], "[", 
              RowBox[{
               RowBox[{"ReplacePart", "[", 
                RowBox[{"\[Pi]s", ",", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"i", ",", "1"}], "}"}], "\[Rule]", 
                  RowBox[{
                   RowBox[{"\[Pi]s", "\[LeftDoubleBracket]", 
                    RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], "-", 
                   " ", 
                   RowBox[{"\[Pi]t", "\[LeftDoubleBracket]", 
                    RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}]}]}]}], 
                "]"}], ",", 
               RowBox[{"Drop", "[", 
                RowBox[{"\[Pi]t", ",", 
                 RowBox[{"{", "j", "}"}]}], "]"}]}], "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Prepend", "[", 
           RowBox[{"rec", ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"\[Pi]s", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
               RowBox[{"\[Pi]t", "\[LeftDoubleBracket]", 
                RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}]}], "}"}], 
             "\[Rule]", 
             RowBox[{"EpsilonMin", "[", 
              RowBox[{
               RowBox[{"\[Pi]s", "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
               RowBox[{"\[Pi]t", "\[LeftDoubleBracket]", 
                RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}]}], 
              "]"}]}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"G", "[", 
       RowBox[{"strategy", "[", 
        RowBox[{"\[Pi]s", ",", "\[Pi]t"}], "]"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.548131218865636*^9, 3.548131286438932*^9}, {
   3.548131320488125*^9, 3.548131374084268*^9}, {3.548131420812168*^9, 
   3.548131427296465*^9}, {3.548131461785132*^9, 3.548131566852249*^9}, {
   3.548131621638867*^9, 3.5481316267825937`*^9}, {3.548132359099801*^9, 
   3.548132371795329*^9}, {3.548132435726316*^9, 3.548132438581335*^9}, {
   3.5481325435682297`*^9, 3.548132546327661*^9}, {3.5481500728110323`*^9, 
   3.548150093395088*^9}, {3.5481502078997927`*^9, 3.548150213417972*^9}, {
   3.548952710294055*^9, 3.5489529556110086`*^9}, {3.548953073440531*^9, 
   3.548953079940089*^9}, {3.548953160666275*^9, 3.548953229194326*^9}, {
   3.548953267086298*^9, 3.548953289883986*^9}, {3.548953476211179*^9, 
   3.548953506514772*^9}, {3.548953561220085*^9, 3.5489536643434277`*^9}, {
   3.5489539143293667`*^9, 3.548953947320661*^9}, 3.548954026124935*^9, {
   3.548954261787787*^9, 3.548954329580962*^9}, {3.548954400224236*^9, 
   3.54895442723903*^9}, {3.548954550980218*^9, 3.548954560827902*^9}, {
   3.5489546812249203`*^9, 3.548954689503399*^9}, {3.548954785060334*^9, 
   3.5489548055639057`*^9}, {3.5489548687419987`*^9, 3.548955257262054*^9}, {
   3.548955440731992*^9, 3.5489554556903048`*^9}, {3.548956074133008*^9, 
   3.5489560743567*^9}, {3.5553210649566393`*^9, 3.5553211322481527`*^9}, {
   3.557724031309492*^9, 3.557724031402817*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"NorthWestStrategy", "[", 
    RowBox[{"_", ",", "_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "1"}], "}"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.548131670770192*^9, 3.548131725969268*^9}, {
  3.5481318869194736`*^9, 3.5481319234820433`*^9}, {3.54813223117575*^9, 
  3.548132233391478*^9}, {3.5481325197313833`*^9, 3.548132531832287*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ToMatrix", "[", 
    RowBox[{"\[Pi]s_", ",", "\[Pi]t_", ",", "vertex_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "mapS", ",", "revmapS", ",", "mapT", ",", "revmapT", ",", "toMap", ",", 
       "mapIndex", ",", "mappedvertex"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"toMap", "[", "indexlst_", "]"}], ":=", "\[IndentingNewLine]", 
       
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"index", "=", 
           RowBox[{"Table", "[", 
            RowBox[{"i", ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"Length", "@", "indexlst"}]}], "}"}]}], "]"}]}], " ", 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Thread", "[", 
            RowBox[{"Rule", "[", 
             RowBox[{"index", ",", "indexlst"}], "]"}], "]"}], ",", 
           RowBox[{"Thread", "[", 
            RowBox[{"Rule", "[", 
             RowBox[{"indexlst", ",", "index"}], "]"}], "]"}]}], "}"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"mapIndex", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"s_", ",", "t_"}], "}"}], "\[Rule]", "val_"}], "]"}], ":=", 
       
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"s", "/.", "revmapS"}], ",", 
          RowBox[{"t", "/.", "revmapT"}]}], "}"}], "\[Rule]", "val"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"mapS", ",", "revmapS"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"mapT", ",", "revmapT"}], "}"}]}], "}"}], " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"toMap", "[", 
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"All", ",", "2"}], "\[RightDoubleBracket]"}], "]"}], "&"}],
         "/@", 
        RowBox[{"{", 
         RowBox[{"\[Pi]s", ",", "\[Pi]t"}], "}"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"mappedvertex", "=", " ", 
       RowBox[{"mapIndex", "/@", "vertex"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"IndexedVertex", "[", 
       RowBox[{"mapS", ",", "mapT", ",", 
        RowBox[{"mappedvertex", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
        RowBox[{"SparseArray", "[", 
         RowBox[{"mappedvertex", ",", 
          RowBox[{"Length", "/@", 
           RowBox[{"{", 
            RowBox[{"\[Pi]s", ",", "\[Pi]t"}], "}"}]}]}], "]"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.5481481652638483`*^9, 3.548148198730831*^9}, {
   3.5481482467546453`*^9, 3.5481483028861637`*^9}, {3.548148341523921*^9, 
   3.5481485784514217`*^9}, {3.548148817939415*^9, 3.548149060660253*^9}, 
   3.54814997977735*^9, {3.5481507884573812`*^9, 3.5481509028923693`*^9}, {
   3.548150992832233*^9, 3.548151028481781*^9}, {3.548151076086603*^9, 
   3.548151080930163*^9}, {3.548151342562739*^9, 3.5481513446267843`*^9}, {
   3.548151383660878*^9, 3.548151810829205*^9}, 3.548153625782971*^9, 
   3.5481537132581244`*^9, {3.548153747337707*^9, 3.5481539235703697`*^9}, 
   3.5483860336099577`*^9, {3.548590384052356*^9, 3.5485904054028893`*^9}, 
   3.5553010410186*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GuessVertex", "[", 
    RowBox[{"\[Pi]s_", ",", "\[Pi]t_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Epsilon]\[Pi]s", ",", "\[Epsilon]\[Pi]t"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Epsilon]\[Pi]s", ",", "\[Epsilon]\[Pi]t"}], "}"}], "=", 
       RowBox[{"EpsilonPerturbation", "[", 
        RowBox[{"\[Pi]s", ",", " ", "\[Pi]t"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ToMatrix", "[", 
       RowBox[{"\[Epsilon]\[Pi]s", ",", "\[Epsilon]\[Pi]t", ",", 
        RowBox[{
         RowBox[{"GuessVertexAux", "[", "NorthWestStrategy", "]"}], "[", 
         RowBox[{"\[Epsilon]\[Pi]s", ",", "\[Epsilon]\[Pi]t"}], "]"}]}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.5484123969997463`*^9, 3.548412440076868*^9}, {
   3.548586963635112*^9, 3.5485870237574377`*^9}, {3.557723788473445*^9, 
   3.5577239576183367`*^9}, 3.557724031434331*^9, 3.5577240619045486`*^9}],

Cell[TextData[{
 StyleBox["AddtoBase[d, vertex] == {reducedcost, non-basic cell} ", "Program"],
 "\nreturns the non-basic cell which has the minimal reduced cost, if the \
vertex has no non-basic cells, then it returns {\[Infinity], {0,0}}."
}], "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.548386280420702*^9, 3.548386413333639*^9}, {
  3.548585869325411*^9, 3.54858588224545*^9}, {3.5485859253024673`*^9, 
  3.548586325162806*^9}, {3.5485863664761677`*^9, 3.548586367740019*^9}, {
  3.548587052410557*^9, 3.54858709392903*^9}, {3.557025952074607*^9, 
  3.5570259526571827`*^9}, {3.557807602466217*^9, 3.5578076034575653`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"AddtoBase", "[", 
    RowBox[{"dist_", ",", 
     RowBox[{"IndexedVertex", "[", 
      RowBox[{"mapS_", ",", "mapT_", ",", "basicCells_", ",", "V_"}], "]"}]}],
     "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"sizeS", "=", 
        RowBox[{"Length", "@", "mapS"}]}], ",", " ", 
       RowBox[{"sizeT", "=", 
        RowBox[{"Length", "@", "mapT"}]}], ",", " ", "\[IndentingNewLine]", 
       "t", ",", "getCost", ",", "ReducedCost", ",", "uv", ",", "makeRow", 
       ",", "base"}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"makeRow", "[", 
        RowBox[{"{", 
         RowBox[{"1", ",", "j_"}], "}"}], "]"}], ":=", 
       RowBox[{"{", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"sizeS", "+", "j"}]}], "}"}], "\[Rule]", "1"}], "}"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"sizeS", "+", "sizeT"}]}], "}"}]}], "]"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"makeRow", "[", 
        RowBox[{"{", 
         RowBox[{"i_", ",", "j_"}], "}"}], "]"}], ":=", 
       RowBox[{"{", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"1", ",", "i"}], "}"}], "\[Rule]", "1"}], ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"sizeS", "+", "j"}]}], "}"}], "\[Rule]", "1"}]}], 
           "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"sizeS", "+", "sizeT"}]}], "}"}]}], "]"}], "}"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"getCost", "[", 
        RowBox[{"{", 
         RowBox[{"i_", ",", "j_"}], "}"}], "]"}], ":=", 
       RowBox[{"getDistValue", "[", 
        RowBox[{"dist", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"i", "/.", "mapS"}], ",", 
           RowBox[{"j", "/.", "mapT"}]}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ReducedCost", "[", 
        RowBox[{"_", ",", 
         RowBox[{"{", 
          RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", 
       "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"reducedcost", "=", 
           RowBox[{
            RowBox[{"getCost", "[", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "]"}], "-", 
            RowBox[{
            "uv", "\[LeftDoubleBracket]", "i", "\[RightDoubleBracket]"}], "-", 
            RowBox[{"uv", "\[LeftDoubleBracket]", 
             RowBox[{"sizeS", "+", "j"}], "\[RightDoubleBracket]"}]}]}], 
          "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
             "base", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
             ">", "reducedcost"}], ",", "\[IndentingNewLine]", 
            RowBox[{"base", "=", 
             RowBox[{"{", 
              RowBox[{"reducedcost", ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}]}], "}"}]}]}], " ", 
           RowBox[{"(*", " ", 
            RowBox[{
            "update", " ", "the", " ", "current", " ", "least", " ", 
             "reduced", " ", "cost"}], " ", "*)"}], "\[IndentingNewLine]", 
           "]"}], ";", "reducedcost"}]}], "]"}]}], ";", "\[IndentingNewLine]",
       "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"u", "-", 
        RowBox[{"v", " ", "modifiers", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["u", "1"], ",", "...", ",", 
           SubscriptBox["u", "sizeS"], ",", 
           SubscriptBox["v", "1"], ",", "...", ",", 
           SubscriptBox["v", "sizeT"]}], ")"}]}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"uv", "=", 
       RowBox[{"LinearSolve", "[", 
        RowBox[{
         RowBox[{"Normal", "@", 
          RowBox[{"ArrayFlatten", "[", 
           RowBox[{"makeRow", "/@", "basicCells"}], "]"}]}], ",", 
         RowBox[{"getCost", "/@", "basicCells"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"DebugPrint", "[", 
         RowBox[{"\"\<u-v Problem:\>\"", ",", 
          RowBox[{"MatrixForm", "@", 
           RowBox[{"ArrayFlatten", "[", 
            RowBox[{"makeRow", "/@", "basicCells"}], "]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"MatrixForm", "@", "uv"}], ",", 
          RowBox[{"MatrixForm", "[", 
           RowBox[{"getCost", "/@", "basicCells"}], "]"}]}], "]"}], ";"}], 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"base", "=", 
       RowBox[{"{", 
        RowBox[{"\[Infinity]", ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "}"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"init", " ", "cell"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "scan", " ", "the", " ", "cells", " ", "computing", " ", "their", " ", 
        "reduced", " ", "cost"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"MapIndexed", "[", 
       RowBox[{"ReducedCost", ",", "V", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}], ";", "\[IndentingNewLine]", 
      "base"}]}], " ", 
    RowBox[{"(*", " ", 
     RowBox[{
     "return", " ", "the", " ", "cell", " ", "with", " ", "the", " ", "least",
       " ", "reduced", " ", "cost"}], " ", "*)"}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.548386139551592*^9, 3.5483862728994713`*^9}, 
   3.5483867572054253`*^9, {3.54838679708383*^9, 3.548386872703958*^9}, 
   3.548386934481659*^9, {3.548388056390139*^9, 3.548388116037249*^9}, {
   3.548389076416947*^9, 3.548389077459724*^9}, {3.548389625707814*^9, 
   3.5483898906513023`*^9}, {3.548390178077282*^9, 3.54839023588465*^9}, {
   3.548390345119684*^9, 3.548390443746436*^9}, {3.548390494613011*^9, 
   3.548390514158641*^9}, {3.5483905521374397`*^9, 3.548390558480564*^9}, {
   3.548390616680497*^9, 3.548390755020664*^9}, {3.548390824004253*^9, 
   3.5483908805682907`*^9}, {3.548390915426342*^9, 3.5483911225649*^9}, {
   3.548391166584516*^9, 3.5483912145282707`*^9}, {3.548391269071343*^9, 
   3.54839127693517*^9}, {3.548391308453348*^9, 3.54839134942437*^9}, 
   3.548393501365363*^9, {3.5483936392744102`*^9, 3.548393722338434*^9}, {
   3.548393770327199*^9, 3.548393834394479*^9}, {3.5483951194698143`*^9, 
   3.54839513899126*^9}, {3.548395195939427*^9, 3.548395232786942*^9}, {
   3.5483952737437563`*^9, 3.5483952797380123`*^9}, {3.548395617684816*^9, 
   3.548395647189088*^9}, {3.548395761048008*^9, 3.5483959056473494`*^9}, 
   3.548395939724478*^9, 3.548396063962823*^9, {3.5483960948022833`*^9, 
   3.5483961045258493`*^9}, {3.54839668723944*^9, 3.5483970076653976`*^9}, 
   3.548397042043432*^9, {3.548397197613398*^9, 3.5483972271926107`*^9}, {
   3.548401856975375*^9, 3.548401955052353*^9}, {3.548402012428774*^9, 
   3.548402352655272*^9}, {3.548402401041525*^9, 3.5484024571189537`*^9}, {
   3.548402504892755*^9, 3.5484025518049803`*^9}, {3.548402602494176*^9, 
   3.548402744328103*^9}, {3.5484027761991796`*^9, 3.54840282491529*^9}, {
   3.548585623140621*^9, 3.548585634363937*^9}, {3.5486675235788593`*^9, 
   3.548667548220398*^9}, {3.548667661422269*^9, 3.5486677006873903`*^9}, 
   3.548667949986187*^9, {3.548668019052346*^9, 3.548668043924571*^9}, {
   3.548668126616067*^9, 3.548668137391985*^9}, 3.548668206131485*^9, {
   3.548668442071272*^9, 3.548668459185173*^9}, {3.548668682590955*^9, 
   3.548668683405202*^9}, {3.552628571233499*^9, 3.552628647474601*^9}, {
   3.552634369074905*^9, 3.552634382800186*^9}, {3.5553016642520723`*^9, 
   3.555301668019259*^9}, {3.5553018088355703`*^9, 3.5553018214542294`*^9}, {
   3.555412562441922*^9, 3.555412574058609*^9}, {3.555412759006909*^9, 
   3.55541277111876*^9}, 3.555732822413816*^9, 3.5557344946587887`*^9, {
   3.555734591931677*^9, 3.555734611169198*^9}, {3.5557347693382807`*^9, 
   3.5557348397077303`*^9}, {3.5557348762207117`*^9, 3.555734982361409*^9}, 
   3.5557350315549*^9, {3.555735166154598*^9, 3.55573519744963*^9}, {
   3.5557352912018843`*^9, 3.555735297945339*^9}, {3.555735547402904*^9, 
   3.555735551737728*^9}, 3.5557363277518063`*^9, 3.555737695664805*^9, {
   3.5558516816621447`*^9, 3.5558517350321293`*^9}, 3.557721814116682*^9, {
   3.557722525367936*^9, 3.55772253983703*^9}, {3.557730425526194*^9, 
   3.557730430557626*^9}, {3.557807501497053*^9, 3.557807519698007*^9}, {
   3.557814410598777*^9, 3.557814414578095*^9}, {3.5592807272407007`*^9, 
   3.559280733540905*^9}}],

Cell[TextData[{
 StyleBox["SteppingStone[non-basic cell, vertex]", "Program"],
 " returns the vertex obtained by inserting the given non-basic cell into the \
base "
}], "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.548586404047098*^9, 3.548586592506564*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SteppingStone", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s_", ",", "t_"}], "}"}], ",", 
     RowBox[{"vertex", ":", 
      RowBox[{"IndexedVertex", "[", 
       RowBox[{"mapS_", ",", "mapT_", ",", "basicCells_", ",", "V_"}], 
       "]"}]}]}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"M", ",", "d", ",", "oldBasicCell", ",", "newBasicCells"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"oldBasicCell", ",", "M"}], "}"}], "=", 
       RowBox[{"SteppingStonePath", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"s", ",", "t"}], "}"}], ",", "vertex"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"DebugPrint", "[", 
         RowBox[{"MatrixForm", "@", "M"}], "]"}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"DebugPrint", "[", 
         RowBox[{
         "\"\<old basic cell: \>\"", ",", "oldBasicCell", ",", " ", 
          "\"\<, new basic cell: \>\"", ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "t"}], "}"}]}], "]"}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"d", "=", " ", 
       RowBox[{"Extract", "[", 
        RowBox[{"V", ",", "oldBasicCell"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"DebugPrint", "[", 
         RowBox[{"\"\<ammount moved: \>\"", ",", "d"}], "]"}], ";"}], "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"newBasicCells", " ", "=", " ", 
       RowBox[{"basicCells", "/.", 
        RowBox[{"oldBasicCell", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"s", ",", "t"}], "}"}]}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"DebugPrint", "[", 
         RowBox[{
         "\"\<Old basic cells:\>\"", ",", "basicCells", ",", 
          "\"\<, new basic cells\>\"", ",", "newBasicCells"}], "]"}], ";"}], 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"IndexedVertex", "[", 
       RowBox[{"mapS", ",", "mapT", ",", "newBasicCells", ",", 
        RowBox[{"SparseArray", "[", 
         RowBox[{"V", "+", 
          RowBox[{"d", " ", "M"}]}], "]"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.548137538880097*^9, 3.5481376005751047`*^9}, {
   3.548137631730999*^9, 3.5481379545516768`*^9}, {3.548138020524569*^9, 
   3.548138205492584*^9}, {3.5481382493055058`*^9, 3.548138363475841*^9}, {
   3.548138440692135*^9, 3.54813846781196*^9}, {3.54813851176003*^9, 
   3.548138523192007*^9}, {3.548138568578589*^9, 3.548138572400124*^9}, {
   3.548138852609199*^9, 3.54813885539465*^9}, {3.548138957173501*^9, 
   3.548138983959838*^9}, {3.54813956162858*^9, 3.548139563589115*^9}, {
   3.5481397495289593`*^9, 3.548139773489259*^9}, {3.5481413696829643`*^9, 
   3.548141370020276*^9}, {3.548141501398492*^9, 3.5481415489051247`*^9}, {
   3.548141578995389*^9, 3.548141606735962*^9}, {3.5481416423259163`*^9, 
   3.548141688288151*^9}, {3.548141726673963*^9, 3.5481418859781*^9}, {
   3.548145315788307*^9, 3.5481454538808603`*^9}, {3.548145495577098*^9, 
   3.5481455436349163`*^9}, {3.548145592859674*^9, 3.5481457390467863`*^9}, {
   3.5481458199721746`*^9, 3.548145835979721*^9}, {3.548145867222363*^9, 
   3.548145902681896*^9}, 3.548146285516266*^9, {3.548146617595216*^9, 
   3.548146640266789*^9}, {3.548147122145927*^9, 3.548147278351186*^9}, {
   3.5481474731647577`*^9, 3.548147501611491*^9}, {3.5481478335821447`*^9, 
   3.54814793337633*^9}, {3.548147984069861*^9, 3.548148097825705*^9}, {
   3.548148136010262*^9, 3.5481481428705473`*^9}, {3.548153139626153*^9, 
   3.548153245449089*^9}, 3.548153314739678*^9, {3.548153367044463*^9, 
   3.548153457485449*^9}, 3.548153493563714*^9, {3.548153528184454*^9, 
   3.548153577454949*^9}, {3.548153983206641*^9, 3.548154086094323*^9}, {
   3.5481546439372187`*^9, 3.5481546677292557`*^9}, {3.5481547008883247`*^9, 
   3.548154923203882*^9}, {3.548154987284655*^9, 3.5481550144506598`*^9}, {
   3.548155093216428*^9, 3.548155423774024*^9}, 3.548155465486772*^9, {
   3.548155512247196*^9, 3.548155524184546*^9}, {3.548155585829397*^9, 
   3.5481557657187366`*^9}, {3.548155796756339*^9, 3.548155874955227*^9}, {
   3.548157045818822*^9, 3.548157048496249*^9}, {3.548408093636201*^9, 
   3.5484081018557377`*^9}, {3.5486651361225758`*^9, 3.548665147578492*^9}, {
   3.548928095341902*^9, 3.548928151816571*^9}, {3.5489282240214252`*^9, 
   3.548928236885009*^9}, {3.548928323261517*^9, 3.548928325556121*^9}, {
   3.548928371197403*^9, 3.548928371900125*^9}, {3.548941499709901*^9, 
   3.548941540695582*^9}, {3.548941589362185*^9, 3.548941645339672*^9}, {
   3.548941762194975*^9, 3.548941777697435*^9}, {3.5489478452900963`*^9, 
   3.548948171182888*^9}, {3.548948245521665*^9, 3.548948245690143*^9}, {
   3.5489482859295483`*^9, 3.548948432792769*^9}, {3.555147551008073*^9, 
   3.5551477115767803`*^9}, {3.5551477455320377`*^9, 
   3.5551479725943947`*^9}, {3.555148252599065*^9, 3.5551482568570337`*^9}, {
   3.555148311789955*^9, 3.555148330521223*^9}, {3.555148437229155*^9, 
   3.5551484395738163`*^9}, {3.5551485273061037`*^9, 3.555148586294837*^9}, {
   3.555148651848383*^9, 3.555148678069928*^9}, {3.5551488431767406`*^9, 
   3.555148923711686*^9}, {3.555148959154756*^9, 3.555148985158228*^9}, {
   3.555149682341179*^9, 3.555149693169526*^9}, {3.555149762744796*^9, 
   3.555149848684452*^9}, {3.555150131025154*^9, 3.555150131808667*^9}, {
   3.5551505065404453`*^9, 3.555150614161035*^9}, 3.5551506585754147`*^9, {
   3.5553212488931437`*^9, 3.5553212591645823`*^9}, {3.555405492847652*^9, 
   3.5554055317657146`*^9}, {3.555738368231731*^9, 3.555738370836782*^9}, {
   3.5558430209865227`*^9, 3.555843075873673*^9}, {3.555843179724825*^9, 
   3.555843203126343*^9}, {3.555843255813985*^9, 3.555843320155211*^9}, {
   3.555844492209469*^9, 3.555844514601181*^9}, {3.555851750930509*^9, 
   3.555851784386599*^9}, 3.5592807521166267`*^9, {3.559281281611465*^9, 
   3.559281292619502*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SteppingStonePath", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"s_", ",", "t_"}], "}"}], ",", 
     RowBox[{"vertex", ":", 
      RowBox[{"IndexedVertex", "[", 
       RowBox[{"mapS_", ",", "mapT_", ",", "basicCells_", ",", "V_"}], 
       "]"}]}]}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "neighbors", ",", "visit", ",", "parent", ",", "cell", ",", "path", ",",
        "getMatrix", ",", "visited", ",", "f"}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"visited", "[", "_", "]"}], ":=", "False"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"neighbors", "[", 
        RowBox[{"{", 
         RowBox[{"u_", ",", "True"}], "}"}], "]"}], ":=", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], ",", 
           "False"}], "}"}], "&"}], "/@", 
        RowBox[{"(", 
         RowBox[{"Select", "[", 
          RowBox[{"basicCells", ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
              "\[Equal]", "u"}], " ", "\[And]", " ", 
             RowBox[{"Not", "[", 
              RowBox[{"visited", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                 ",", "False"}], "}"}], "]"}], "]"}]}], "&"}]}], "]"}], 
         ")"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"neighbors", "[", 
        RowBox[{"{", 
         RowBox[{"v_", ",", "False"}], "}"}], "]"}], ":=", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
           "True"}], "}"}], "&"}], "/@", 
        RowBox[{"(", 
         RowBox[{"Select", "[", 
          RowBox[{"basicCells", ",", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
              "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "\[Equal]", "v"}], " ", "\[And]", " ", 
             RowBox[{"Not", "[", 
              RowBox[{"visited", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{
                 "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                 ",", "True"}], "}"}], "]"}], "]"}]}], "&"}]}], "]"}], 
         ")"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"a_", ",", "True"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"b_", ",", "False"}], "}"}]}], "}"}], "]"}], ":=", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"a_", ",", "False"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"b_", ",", "True"}], "}"}]}], "}"}], "]"}], ":=", 
       RowBox[{"{", 
        RowBox[{"b", ",", "a"}], "}"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"visit", "[", "node_", "]"}], ":=", "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"visited", "[", "node", "]"}], "=", "True"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"Scan", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"parent", "[", "#", "]"}], "=", "node"}], ";", " ", 
              RowBox[{"visit", "@", "#"}]}], ")"}], "&"}], ",", 
           RowBox[{"neighbors", "[", "node", "]"}]}], "]"}]}], 
        "\[IndentingNewLine]", ")"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"getMatrix", "[", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "sign_"}], "]"}], ":=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"getMatrix", "[", 
        RowBox[{"lst_", ",", "sign_"}], "]"}], ":=", "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"sign", "<", "0"}], "\[And]", " ", 
            RowBox[{"EpsilonLeq", "[", 
             RowBox[{
              RowBox[{"Extract", "[", 
               RowBox[{"V", ",", 
                RowBox[{"First", "@", "lst"}]}], "]"}], " ", ",", 
              RowBox[{"Extract", "[", 
               RowBox[{"V", ",", "cell"}], "]"}]}], "]"}]}], ",", 
           RowBox[{"cell", "=", 
            RowBox[{"First", "@", "lst"}]}]}], "]"}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{"update", " ", "cell"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"getMatrix", "[", 
            RowBox[{
             RowBox[{"Rest", "@", "lst"}], ",", 
             RowBox[{"-", " ", "sign"}]}], "]"}], ",", " ", 
           RowBox[{
            RowBox[{"First", "@", "lst"}], " ", "\[Rule]", " ", "sign"}]}], 
          "]"}]}], ")"}]}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{"compute", " ", "arrayrules"}], " ", "*)"}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"DebugPrint", "[", 
         RowBox[{"PrPrint", "@", "vertex"}], "]"}], ";"}], "*)"}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "search", " ", "for", " ", "an", " ", "alternating", " ", "path", " ", 
        "from", " ", "s", " ", "to", " ", "t"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"parent", "[", 
        RowBox[{"{", 
         RowBox[{"s", ",", "True"}], "}"}], "]"}], "=", 
       RowBox[{"{", "}"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"s", ",", "True"}], "}"}], " ", "is", " ", "the", " ", 
        "root", " ", "of", " ", "the", " ", "tree"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"visit", "[", 
       RowBox[{"{", 
        RowBox[{"s", ",", "True"}], "}"}], "]"}], ";", " ", 
      RowBox[{"(*", " ", 
       RowBox[{
       "compute", " ", "the", " ", "spanning", " ", "tree", " ", "rooted", 
        " ", "in", " ", 
        RowBox[{"{", 
         RowBox[{"s", ",", "True"}], "}"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "get", " ", "the", " ", "alternating", " ", "path", " ", "from", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "False"}], "}"}], " ", "to", " ", 
        RowBox[{"{", 
         RowBox[{"s", ",", "True"}], "}"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"path", "=", 
       RowBox[{"Append", "[", 
        RowBox[{
         RowBox[{"f", "/@", 
          RowBox[{"Partition", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"Most", "@", 
              RowBox[{"NestWhileList", "[", 
               RowBox[{"parent", ",", 
                RowBox[{"{", 
                 RowBox[{"t", ",", "False"}], "}"}], ",", 
                RowBox[{
                 RowBox[{"#", "!=", 
                  RowBox[{"{", "}"}]}], "&"}]}], "]"}]}], ")"}], ",", "2", 
            ",", "1"}], "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"s", ",", "t"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cell", "=", 
       RowBox[{"First", "@", "path"}]}], ";", " ", 
      RowBox[{"path", "=", 
       RowBox[{"getMatrix", "[", 
        RowBox[{"path", ",", 
         RowBox[{"-", "1"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"cell", ",", 
        RowBox[{"SparseArray", "[", 
         RowBox[{"path", ",", 
          RowBox[{"Dimensions", "@", "V"}]}], "]"}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.555740414131527*^9, 3.555740443243576*^9}, 
   3.555740827225692*^9, {3.555740924937602*^9, 3.555740943874548*^9}, {
   3.55574173606774*^9, 3.555741743057189*^9}, {3.555741779194734*^9, 
   3.555741908632369*^9}, {3.555741973980646*^9, 3.55574198563443*^9}, {
   3.555742055397132*^9, 3.555742074813736*^9}, {3.555742153135963*^9, 
   3.5557421559359922`*^9}, {3.5557422256584473`*^9, 3.555742332039188*^9}, {
   3.55574272591928*^9, 3.555742865181357*^9}, {3.555742905342469*^9, 
   3.555742910927609*^9}, {3.5557429576714077`*^9, 3.555743014735434*^9}, 
   3.555743369227522*^9, {3.555753274403759*^9, 3.5557533961509523`*^9}, {
   3.555753509425785*^9, 3.555753574531227*^9}, {3.555753612564671*^9, 
   3.555753651590124*^9}, {3.555753685143073*^9, 3.555753703159849*^9}, {
   3.555753739303714*^9, 3.5557538142095947`*^9}, {3.55575393740501*^9, 
   3.555754105707037*^9}, {3.555754152236623*^9, 3.55575417182999*^9}, {
   3.555754302385285*^9, 3.555754379067687*^9}, {3.555754423204376*^9, 
   3.5557545463046713`*^9}, 3.5557549132852716`*^9, {3.55575494511185*^9, 
   3.5557550527043753`*^9}, {3.55575508375919*^9, 3.555755138300686*^9}, {
   3.555755175442803*^9, 3.555755193140772*^9}, {3.5557552275013733`*^9, 
   3.555755262663083*^9}, {3.555755309306007*^9, 3.5557553837607517`*^9}, {
   3.555755422156499*^9, 3.5557555779827642`*^9}, {3.555762907099041*^9, 
   3.555762911407132*^9}, {3.555839464208437*^9, 3.55583949195014*^9}, {
   3.555839592513259*^9, 3.555839659987204*^9}, {3.5558397259658527`*^9, 
   3.555839814007967*^9}, {3.555839870433504*^9, 3.555840083584084*^9}, {
   3.555840169970216*^9, 3.555840247596952*^9}, {3.555840283414832*^9, 
   3.5558402860145807`*^9}, {3.555840632610592*^9, 3.555840753300899*^9}, {
   3.5558408539996977`*^9, 3.555840936129662*^9}, {3.555841103924099*^9, 
   3.55584112775098*^9}, {3.555841225549777*^9, 3.555841309612764*^9}, {
   3.5558416040942183`*^9, 3.55584165391105*^9}, 3.555841719472937*^9, {
   3.555841857764875*^9, 3.555841862748608*^9}, {3.555841909687295*^9, 
   3.5558420549958076`*^9}, {3.555842093079075*^9, 3.555842490602556*^9}, {
   3.555842526148306*^9, 3.55584255138962*^9}, {3.5558426934812*^9, 
   3.555842712562031*^9}, {3.5558428224304132`*^9, 3.555842878439391*^9}, {
   3.5558434532010927`*^9, 3.5558434586471863`*^9}, {3.5558435265470457`*^9, 
   3.555843537882163*^9}, {3.555843808356636*^9, 3.555843822946643*^9}, {
   3.55584391243111*^9, 3.555843949478593*^9}, {3.555844423896411*^9, 
   3.555844427216786*^9}, {3.5558445870547256`*^9, 3.555844588006139*^9}, 
   3.555847494461244*^9, {3.555847526183155*^9, 3.555847559311215*^9}, {
   3.555847606165979*^9, 3.555847613220649*^9}, {3.555847659895918*^9, 
   3.5558476801585503`*^9}, {3.555847794639955*^9, 3.555847874591825*^9}, {
   3.555847916482574*^9, 3.555848018061522*^9}, {3.55584817760931*^9, 
   3.5558483110690327`*^9}, {3.555848363662404*^9, 3.555848397064056*^9}, {
   3.555848436680224*^9, 3.555848446455861*^9}, {3.555848519173877*^9, 
   3.555848534621789*^9}, {3.555848592720055*^9, 3.555848635563038*^9}, {
   3.555848898925641*^9, 3.5558489401129847`*^9}, {3.555849294075535*^9, 
   3.555849425103136*^9}, {3.5558494752237673`*^9, 3.555849478822145*^9}, {
   3.555849556966673*^9, 3.555849569508595*^9}, {3.555849599550769*^9, 
   3.555849638447921*^9}, {3.5558497163378763`*^9, 3.555849722255138*^9}, {
   3.555851815676745*^9, 3.555851882523493*^9}, 3.557721579733676*^9, {
   3.559281425327317*^9, 3.5592814285249453`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BestVertex", "[", 
    RowBox[{"dist_", ",", 
     RowBox[{"{", 
      RowBox[{"redCost_", ",", "nbCell_"}], "}"}], ",", "vertex_"}], "]"}], ":=",
    "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"currVertex", "=", "vertex"}], ",", " ", 
       RowBox[{"currRedCost", "=", "redCost"}], ",", 
       RowBox[{"currNbCell", "=", " ", "nbCell"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{"currRedCost", "<", "0"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"currVertex", "=", " ", 
          RowBox[{"SteppingStone", "[", 
           RowBox[{"currNbCell", ",", "currVertex"}], "]"}]}], ";", 
         RowBox[{"(*", " ", 
          RowBox[{"move", " ", "to", " ", "a", " ", "better", " ", "vertex"}],
           " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"DebugPrint", "[", 
            RowBox[{"PrPrint", "@", "currVertex"}], "]"}], ";"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "update", " ", "the", " ", "current", " ", "least", " ", "reduced", 
           " ", "cost"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"currRedCost", ",", "currNbCell"}], "}"}], "=", " ", 
          RowBox[{"AddtoBase", "[", 
           RowBox[{"dist", ",", "currVertex"}], "]"}]}], ";"}]}], 
       "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
      "currVertex"}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.555387114054696*^9, 3.5553872784245462`*^9}, {
   3.5553873731314907`*^9, 3.555387386158148*^9}, {3.555387495616723*^9, 
   3.5553877222261257`*^9}, {3.555387815013094*^9, 3.5553878359628763`*^9}, {
   3.555387873300782*^9, 3.5553879151099033`*^9}, {3.555387959646975*^9, 
   3.555387996608547*^9}, {3.555395830842382*^9, 3.555395830901766*^9}, {
   3.555737768939487*^9, 3.5557377858839006`*^9}, {3.555737868264433*^9, 
   3.555737870070261*^9}, 3.555737967339692*^9, {3.555844332593791*^9, 
   3.5558443551852903`*^9}, {3.555851905666891*^9, 3.5558519133704042`*^9}, 
   3.557807533743359*^9, 3.557807646922876*^9, {3.5592815809118843`*^9, 
   3.559281583656138*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PrPrint", "[", 
    RowBox[{"IndexedVertex", "[", 
     RowBox[{"mapS_", ",", "mapT_", ",", "basicCells_", ",", "V_"}], "]"}], 
    "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "basic", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"basic", "[", 
        RowBox[{"value_", ",", "index_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"Style", "[", 
         RowBox[{
          RowBox[{"EpsilonRemoval", "@", "value"}], ",", "Red", ",", "Bold"}],
          "]"}], "/;", 
        RowBox[{"MemberQ", "[", 
         RowBox[{"basicCells", ",", "index"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"basic", "[", 
        RowBox[{"value_", ",", "_"}], "]"}], ":=", "value"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"TableForm", "[", 
       RowBox[{
        RowBox[{"MapIndexed", "[", 
         RowBox[{"basic", ",", "V", ",", 
          RowBox[{"{", "2", "}"}]}], "]"}], ",", 
        RowBox[{"TableHeadings", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"ToString", "[", 
              RowBox[{
              "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "]"}], "&"}], "/@", "mapS"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"ToString", "[", 
              RowBox[{
              "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
              "]"}], "&"}], "/@", "mapT"}]}], "}"}]}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PrPrint", "[", "x_", "]"}], ":=", "x"}], ";"}]}], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.548156042016614*^9, 3.548156102835227*^9}, {
  3.548650498455522*^9, 3.5486505167568903`*^9}, {3.5486506722920103`*^9, 
  3.5486506731622257`*^9}, {3.54867138230835*^9, 3.548671524680398*^9}, {
  3.548671587921565*^9, 3.54867162443093*^9}, {3.5486717096011257`*^9, 
  3.5486717100149803`*^9}, {3.5490090552538843`*^9, 3.549009248996804*^9}, {
  3.549009285696327*^9, 3.54900928838211*^9}, {3.559280486562422*^9, 
  3.55928048872287*^9}, {3.559280529246214*^9, 3.5592805390564947`*^9}, {
  3.559280576318441*^9, 3.559280577528891*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Iterative Algorithm", "Subsection",
 InitializationGroup->True,
 CellChangeTimes->{{3.5471403852001553`*^9, 3.5471405478851833`*^9}, {
  3.558792299797785*^9, 3.558792306858425*^9}}],

Cell[TextData[{
 "Given the numer of states ",
 StyleBox["|S|", "Program"],
 ", ",
 StyleBox["BottomDist[|S|]", "Program"],
 " returns the bottom distance"
}], "Text",
 CellChangeTimes->{{3.547801316477981*^9, 3.5478014594882793`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BottomDist", "[", "size_", "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "size", "}"}], ",", 
     RowBox[{"{", "size", "}"}]}], "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.5471402109802847`*^9, 3.547140234441064*^9}, {
  3.547140556511156*^9, 3.547140568056047*^9}, {3.547140820589411*^9, 
  3.547140820981187*^9}, {3.5471417734744062`*^9, 3.5471417938268642`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"TopDist", "[", "size_", "]"}], ":=", 
   RowBox[{"Table", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", "size", "}"}], ",", 
     RowBox[{"{", "size", "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.558790980910681*^9, 3.5587909864945707`*^9}}],

Cell["\<\
The funtion \[CapitalDelta] implements the distance transformer\
\>", "Text",
 CellChangeTimes->{{3.547801514567346*^9, 3.547801735267733*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[CapitalDelta]", "[", 
     RowBox[{
      RowBox[{"MC", "[", 
       RowBox[{"TM_", ",", "labels_"}], "]"}], ",", "\[Lambda]_"}], "]"}], 
    "[", "dist_", "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"size", "=", 
        RowBox[{"Length", "@", "labels"}]}], ",", "Marginal", ",", "TP", ",", 
       "NewValue"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Marginal", "[", "state_", "]"}], ":=", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"indexed", "[", 
          RowBox[{"TM", "\[LeftDoubleBracket]", 
           RowBox[{"state", ",", "All"}], "\[RightDoubleBracket]"}], "]"}], 
         ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ">", 
           "0"}], "&"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"TP", "[", 
        RowBox[{"s_", ",", "t_"}], "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"vertex", "=", 
           RowBox[{"GuessVertex", "[", 
            RowBox[{
             RowBox[{"Marginal", "[", "s", "]"}], ",", 
             RowBox[{"Marginal", "[", "t", "]"}]}], "]"}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"BestVertex", "[", 
          RowBox[{"dist", ",", 
           RowBox[{"AddtoBase", "[", 
            RowBox[{"dist", ",", "vertex"}], "]"}], ",", "vertex"}], "]"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"NewValue", "[", 
        RowBox[{"s_", ",", "t_"}], "]"}], ":=", 
       RowBox[{"1", "/;", 
        RowBox[{
         RowBox[{
         "labels", "\[LeftDoubleBracket]", "s", "\[RightDoubleBracket]"}], 
         "\[NotEqual]", " ", 
         RowBox[{
         "labels", "\[LeftDoubleBracket]", "t", 
          "\[RightDoubleBracket]"}]}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"NewValue", "[", 
        RowBox[{"s_", ",", "t_"}], "]"}], ":=", "\[IndentingNewLine]", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"cellCost", ",", 
           RowBox[{"optSchedule", "=", 
            RowBox[{"TP", "[", 
             RowBox[{"s", ",", "t"}], "]"}]}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"cellCost", "[", 
             RowBox[{"IndexedVertex", "[", 
              RowBox[{"mapS_", ",", "mapT_", ",", "_", ",", "V_"}], "]"}], 
             "]"}], "[", 
            RowBox[{"{", 
             RowBox[{"i_", ",", "j_"}], "}"}], "]"}], ":=", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"getDistValue", "[", 
             RowBox[{"dist", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"i", "/.", "mapS"}], ",", 
                RowBox[{"j", "/.", "mapT"}]}], "}"}]}], "]"}], "*", 
            RowBox[{"EpsilonRemoval", "[", 
             RowBox[{"V", "\[LeftDoubleBracket]", 
              RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"\[Lambda]", " ", "*", 
           RowBox[{"Plus", "@@", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"cellCost", "[", "optSchedule", "]"}], "/@", 
              RowBox[{
              "optSchedule", "\[LeftDoubleBracket]", "3", 
               "\[RightDoubleBracket]"}]}], ")"}]}]}]}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "compute", " ", "the", " ", "new", " ", "values", " ", "for", " ", 
        "each", " ", "pair"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"NewValue", "[", 
         RowBox[{"s", ",", "t"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "size"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "size"}], "}"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.547140155767569*^9, 3.547140205307123*^9}, {
   3.5471405770737247`*^9, 3.547140595296591*^9}, {3.547140730669558*^9, 
   3.5471407337544937`*^9}, {3.5471408066404*^9, 3.547140875446889*^9}, {
   3.5471411831351833`*^9, 3.547141191685452*^9}, 3.547141222864319*^9, {
   3.5471414057861547`*^9, 3.547141418570918*^9}, {3.547141645367477*^9, 
   3.547141762100891*^9}, {3.5471418257361593`*^9, 3.547141826950169*^9}, {
   3.547141982571247*^9, 3.547142068662135*^9}, {3.547142102413205*^9, 
   3.547142376055324*^9}, {3.547142427488476*^9, 3.5471424306302633`*^9}, {
   3.547142598295836*^9, 3.547142611019668*^9}, {3.547142799290077*^9, 
   3.547142846633616*^9}, {3.547142938612383*^9, 3.547142950524295*^9}, {
   3.547142992768116*^9, 3.5471429970954943`*^9}, {3.547143242371579*^9, 
   3.547143245593937*^9}, {3.547143869722313*^9, 3.547143873874814*^9}, {
   3.547182337553239*^9, 3.5471823524761753`*^9}, {3.547182449352953*^9, 
   3.54718251353703*^9}, {3.547182601429929*^9, 3.5471828727866573`*^9}, 
   3.547800722461446*^9, {3.55878646967201*^9, 3.558786506957411*^9}, 
   3.558787449119644*^9, {3.558787500383379*^9, 3.558787502119916*^9}, 
   3.558787538568614*^9, {3.558787588162072*^9, 3.5587876569546432`*^9}, {
   3.558787793983284*^9, 3.55878780055886*^9}, {3.558787928843869*^9, 
   3.558787985484213*^9}, {3.558788060938346*^9, 3.558788177060264*^9}, {
   3.558788288282093*^9, 3.558788462134767*^9}, 3.558789556907159*^9, {
   3.5587896966987333`*^9, 3.558789760295095*^9}, {3.5587897976717854`*^9, 
   3.558789867346282*^9}, {3.558789906342052*^9, 3.558790018035325*^9}, {
   3.55879004820473*^9, 3.558790199349168*^9}, {3.558790908329458*^9, 
   3.558790924239904*^9}, {3.5587929563060637`*^9, 3.558792956981058*^9}, {
   3.558793061386722*^9, 3.5587930687531023`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"IterativeAlg", "[", 
    RowBox[{
     RowBox[{"mc", ":", 
      RowBox[{"MC", "[", 
       RowBox[{"_", ",", "labels_"}], "]"}]}], ",", "\[Lambda]_", ",", 
     RowBox[{"OptionsPattern", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"StoppingTime", " ", "->", " ", "4"}], ",", 
        RowBox[{"Verbose", "\[Rule]", "False"}]}], "}"}], "]"}]}], "]"}], ":=",
    "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"t", "=", "0"}], ",", 
       RowBox[{"iterCount", "=", "0"}], ",", 
       RowBox[{"size", "=", 
        RowBox[{"Length", "[", "labels", "]"}]}], ",", "dt", ",", "old", ",", 
       "curr"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"SetOptions", "[", 
       RowBox[{"ComputeDistances", ",", 
        RowBox[{"Verbose", "\[Rule]", 
         RowBox[{"OptionValue", "[", "Verbose", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", "initialization", " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"old", "=", 
       RowBox[{"TopDist", "[", 
        RowBox[{"Length", "[", "labels", "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"curr", "=", 
       RowBox[{"BottomDist", "[", 
        RowBox[{"Length", "[", "labels", "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"iteratively", " ", "apply", " ", "\[CapitalDelta]"}], ",", 
        " ", 
        RowBox[{
        "until", " ", "the", " ", "extact", " ", "result", " ", "is", " ", 
         "reached", " ", "or", "\[IndentingNewLine]", "the", " ", 
         "StoppingTime", " ", "has", " ", "been", " ", "exceeded"}]}], "  ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"t", " ", "\[LessEqual]", " ", 
          RowBox[{"OptionValue", "[", "StoppingTime", "]"}]}], " ", "\[And]", 
         " ", 
         RowBox[{"curr", " ", "\[NotEqual]", " ", "old"}]}], ",", 
        RowBox[{"(*", "  ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"old", "=", "curr"}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"dt", ",", "curr"}], "}"}], "=", 
          RowBox[{"Timing", "[", 
           RowBox[{
            RowBox[{"\[CapitalDelta]", "[", 
             RowBox[{"mc", ",", "\[Lambda]"}], "]"}], "[", "old", "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{"t", "+=", "dt"}], ";", 
         RowBox[{"iterCount", "++"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"t", ",", 
        RowBox[{"R", "[", 
         RowBox[{"iterCount", ",", 
          RowBox[{"Length", "[", 
           RowBox[{"SameLabelsPairs", "[", "mc", "]"}], "]"}], ",", "curr"}], 
         "]"}]}], "}"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.558790249430909*^9, 3.5587903173227177`*^9}, {
  3.558790353003006*^9, 3.5587906958512487`*^9}, {3.558790735236452*^9, 
  3.5587907881647*^9}, {3.558790832696121*^9, 3.558790841359838*^9}, {
  3.558790944307909*^9, 3.5587909476998158`*^9}, {3.55879099866247*^9, 
  3.558791169832453*^9}, {3.558791209982357*^9, 3.558791254133926*^9}, {
  3.55879152893009*^9, 3.558791538776119*^9}, {3.558791570617309*^9, 
  3.558791583601651*^9}, {3.5587917671128073`*^9, 3.5587918230710793`*^9}, {
  3.558791860721484*^9, 3.558791994493052*^9}, {3.558792051042571*^9, 
  3.5587921239608393`*^9}, {3.55879218385369*^9, 3.5587922047129183`*^9}, {
  3.5587922360998573`*^9, 3.558792248900872*^9}, {3.558792754854328*^9, 
  3.558792781910125*^9}, {3.5587936601396427`*^9, 3.5587937116258783`*^9}, {
  3.5587937450013523`*^9, 3.55879379730829*^9}, {3.558793846757724*^9, 
  3.558793895965179*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["On-the-fly Algorithm for computing Bisimilarity Pseudometric", \
"Subsection",
 InitializationGroup->True,
 CellChangeTimes->{{3.5487308888405447`*^9, 3.548730909832243*^9}, {
  3.557723018995718*^9, 3.557723057587343*^9}}],

Cell[TextData[{
 "Given as input an indexed vertex ",
 StyleBox["v", "Program"],
 ", ",
 StyleBox["SubProblems[v]", "Program"],
 " returns the list of active subproblems. This is simply done by selecting \
the (non-degenerate) basic cells of ",
 StyleBox["\[Omega]", "Program"],
 "."
}], "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.555305189446496*^9, 3.5553053820090313`*^9}, {
  3.555305447987512*^9, 3.5553054656596203`*^9}, {3.5577231200211*^9, 
  3.557723150214588*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"SubProblems", "[", 
    RowBox[{"IndexedVertex", "[", 
     RowBox[{"mapS_", ",", "mapT_", ",", "basicCells_", ",", "V_"}], "]"}], 
    "]"}], ":=", " ", "\[IndentingNewLine]", 
   RowBox[{"DeleteDuplicates", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sort", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "/.", 
           "mapS"}], ",", 
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "/.", 
           "mapT"}]}], "}"}], "]"}], "&"}], ")"}], "/@", 
     RowBox[{"Select", "[", 
      RowBox[{"basicCells", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"EpsilonRemoval", "[", 
          RowBox[{"Extract", "[", 
           RowBox[{"V", ",", "#"}], "]"}], "]"}], ">", "0"}], "&"}]}], 
      "]"}]}], "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.54840955474934*^9, 3.5484097258483057`*^9}, 
   3.548409761945839*^9, {3.548409885100594*^9, 3.548409923548944*^9}, {
   3.555304943323485*^9, 3.5553049469065733`*^9}, {3.555304995828492*^9, 
   3.555305123105094*^9}, {3.555321410444832*^9, 3.555321428310719*^9}, {
   3.555321674200905*^9, 3.555321693952539*^9}, {3.555404067096478*^9, 
   3.5554040738574457`*^9}, {3.555404153667411*^9, 3.555404173844187*^9}, {
   3.555404215256308*^9, 3.555404264769302*^9}, {3.555404310344965*^9, 
   3.555404360386402*^9}, 3.555404439980453*^9, {3.5554048105149517`*^9, 
   3.55540483082402*^9}, {3.555404903258957*^9, 3.555404929378317*^9}, {
   3.55540686236094*^9, 3.555406867158803*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FixedDistance", "[", 
     RowBox[{"dist_", ",", 
      RowBox[{"{", 
       RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", 
    RowBox[{"MatchQ", "[", 
     RowBox[{
      RowBox[{"dist", "\[LeftDoubleBracket]", 
       RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], ",", "_Fixed"}], 
     "]"}]}], " ", ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "says", " ", "if", " ", "the", " ", "distance", " ", "is", " ", "fixed", 
    " ", "or", " ", "not"}], " ", "*)"}]}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.5484100980742188`*^9, 3.548410216692169*^9}, {
   3.548410259502337*^9, 3.548410317769217*^9}, 3.548410516662448*^9, {
   3.5484105752787657`*^9, 3.548410583740304*^9}, {3.5484106529606247`*^9, 
   3.548410691225809*^9}, {3.548413383661826*^9, 3.5484135786288567`*^9}, {
   3.548489953744808*^9, 3.548489961727195*^9}, {3.548491151355154*^9, 
   3.548491230276663*^9}, {3.54849170757145*^9, 3.5484917770339327`*^9}, {
   3.557723254781063*^9, 3.557723263240636*^9}, {3.557728598420027*^9, 
   3.557728681061214*^9}, {3.557728776156344*^9, 3.557728790728973*^9}, {
   3.557808060321789*^9, 3.557808061228223*^9}, {3.557808253531186*^9, 
   3.557808291697535*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"KnownProblem", "[", 
    RowBox[{"dist_", ",", "problems_", ",", 
     RowBox[{"{", 
      RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", " ", 
   RowBox[{"(*", " ", 
    RowBox[{"decide", " ", "whether", " ", "the", " ", "problem", " ", 
     RowBox[{"(", 
      RowBox[{"i", ",", "j"}], ")"}], " ", "has", " ", "already", " ", "been",
      " ", "considered"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FixedDistance", "[", 
     RowBox[{"dist", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}]}], "]"}], "||", 
    RowBox[{"MatchQ", "[", 
     RowBox[{
      RowBox[{"problems", "\[LeftDoubleBracket]", 
       RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], ",", 
      "_IndexedVertex"}], "]"}]}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.557808070366763*^9, 3.557808231483583*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"AddProblem", "[", 
     RowBox[{
      RowBox[{"mc", ":", 
       RowBox[{"MC", "[", 
        RowBox[{"_", ",", "_"}], "]"}]}], ",", "dist_"}], "]"}], "[", 
    RowBox[{"problems_", ",", 
     RowBox[{"{", 
      RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", " ", 
   RowBox[{"problems", "/;", " ", 
    RowBox[{"KnownProblem", "[", 
     RowBox[{"dist", ",", "problems", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "j"}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"AddProblem", "[", 
     RowBox[{
      RowBox[{"mc", ":", 
       RowBox[{"MC", "[", 
        RowBox[{"TM_", ",", "labels_"}], "]"}]}], ",", "dist_"}], "]"}], "[", 
    
    RowBox[{"problems_", ",", 
     RowBox[{"{", 
      RowBox[{"i_", ",", "j_"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Marginal", ",", "newvertex"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"Marginal", "[", "state_", "]"}], ":=", 
       RowBox[{"Select", "[", 
        RowBox[{
         RowBox[{"indexed", "[", 
          RowBox[{"TM", "\[LeftDoubleBracket]", 
           RowBox[{"state", ",", "All"}], "\[RightDoubleBracket]"}], "]"}], 
         ",", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ">", 
           "0"}], "&"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"newvertex", " ", "=", " ", 
       RowBox[{"GuessVertex", "[", 
        RowBox[{
         RowBox[{"Marginal", "[", "i", "]"}], ",", 
         RowBox[{"Marginal", "[", "j", "]"}]}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
       "guess", " ", "a", " ", "fesible", " ", "transposrtation", " ", 
        "schedule"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"UpdateProblems", "[", 
        RowBox[{"mc", ",", "dist"}], "]"}], "[", 
       RowBox[{"problems", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], ",", "newvertex"}], "]"}]}]}], 
    RowBox[{"(*", " ", 
     RowBox[{
     "recursively", " ", "update", " ", "the", " ", "problems", " ", 
      "matrix"}], " ", "*)"}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.548410693835017*^9, 3.5484107733332243`*^9}, {
   3.5484108359822493`*^9, 3.548411283656493*^9}, {3.548411337938776*^9, 
   3.548411416381794*^9}, {3.548412053986925*^9, 3.5484121827510033`*^9}, {
   3.5484122288044786`*^9, 3.548412236110375*^9}, {3.548412275337579*^9, 
   3.548412347743493*^9}, {3.548412451572068*^9, 3.548412593165634*^9}, 
   3.548412688528235*^9, {3.548413259614853*^9, 3.548413302131357*^9}, {
   3.5484135999735937`*^9, 3.5484138124727077`*^9}, {3.5484140187286777`*^9, 
   3.548414097893231*^9}, 3.548489974847556*^9, 3.548492019701622*^9, {
   3.548495027397201*^9, 3.548495058268861*^9}, {3.548495094773136*^9, 
   3.548495095603156*^9}, {3.548495140702115*^9, 3.548495200247826*^9}, {
   3.548496368505085*^9, 3.54849637427402*^9}, {3.548496410987856*^9, 
   3.548496505340805*^9}, {3.5553209120913963`*^9, 3.555320972369877*^9}, {
   3.5553213108155947`*^9, 3.555321325774867*^9}, 3.555322035308666*^9, {
   3.557723511218916*^9, 3.557723592341134*^9}, 3.557724061929981*^9, {
   3.5577240919553947`*^9, 3.5577241956223383`*^9}, {3.557724226727571*^9, 
   3.5577242400821867`*^9}, {3.5577243879879827`*^9, 
   3.5577243935241547`*^9}, {3.557724507663714*^9, 3.5577245159779243`*^9}, {
   3.557728393668417*^9, 3.557728437218903*^9}, {3.557728521093602*^9, 
   3.55772852811761*^9}, {3.557728708883477*^9, 3.557728727784925*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"AddProblems", "[", 
     RowBox[{
      RowBox[{"mc", ":", 
       RowBox[{"MC", "[", 
        RowBox[{"_", ",", "_"}], "]"}]}], ",", "dist_"}], "]"}], "[", 
    RowBox[{"problems_", ",", "queryLst_"}], "]"}], ":=", 
   RowBox[{"Fold", "[", 
    RowBox[{
     RowBox[{"AddProblem", "[", 
      RowBox[{"mc", ",", "dist"}], "]"}], ",", "problems", ",", "queryLst"}], 
    "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.5578069378736677`*^9, 3.55780700704412*^9}, {
  3.557808347189052*^9, 3.557808376228545*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"UpdateProblems", "[", 
     RowBox[{
      RowBox[{"mc", ":", 
       RowBox[{"MC", "[", 
        RowBox[{"_", ",", "_"}], "]"}]}], ",", "dist_"}], "]"}], "[", 
    RowBox[{"problems_", ",", 
     RowBox[{"{", 
      RowBox[{"i_", ",", "j_"}], "}"}], ",", "newvertex_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AddProblems", "[", 
     RowBox[{"mc", ",", "dist"}], "]"}], "[", 
    RowBox[{
     RowBox[{"ReplacePart", "[", 
      RowBox[{"problems", ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"i", ",", "j"}], "}"}], "\[Rule]", "newvertex"}]}], "]"}], 
     ",", 
     RowBox[{"SubProblems", "[", "newvertex", "]"}]}], "]"}]}], 
  ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.5484948910155783`*^9, 3.548494979939518*^9}, {
  3.557724292524687*^9, 3.5577243018849*^9}, {3.557724359966477*^9, 
  3.5577243715588427`*^9}, {3.557724416832407*^9, 3.557724433791812*^9}, {
  3.557728456677999*^9, 3.557728472862681*^9}, {3.557807038269052*^9, 
  3.5578070811114492`*^9}, {3.55780835030031*^9, 3.557808367577331*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Compute the coefficients ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"VertexCoeffs", "[", 
     RowBox[{
      SubscriptBox[
       RowBox[{"(", " ", 
        RowBox[{"\[Omega]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"s", ",", "t"}], ")"}], 
           StyleBox[",", "Program"], 
           RowBox[{"(", 
            RowBox[{"u", ",", "v"}], ")"}]}], ")"}]}], " ", ")"}], 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"u", ",", "v"}], ")"}], "\[Element]", 
        RowBox[{"S", "?"}]}]], ",", 
      RowBox[{
       UnderscriptBox["\[Sum]", 
        RowBox[{
         RowBox[{"l", "(", "u", ")"}], "\[NotEqual]", " ", 
         RowBox[{"l", "(", "v", ")"}]}]], 
       RowBox[{"\[Omega]", "(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"s", ",", "t"}], ")"}], ",", 
         RowBox[{"(", 
          RowBox[{"u", ",", "v"}], ")"}]}], ")"}]}]}], "]"}], "Program"], 
   TraditionalForm]]],
 " for the given (vertex) schedule"
}], "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.557805772457274*^9, 3.557805815947212*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"VertexCoeffs", "[", 
   RowBox[{
    RowBox[{"MC", "[", 
     RowBox[{"_", ",", "labels_"}], "]"}], ",", "dist_", ",", 
    RowBox[{"IndexedVertex", "[", 
     RowBox[{"mapS_", ",", "mapT_", ",", "basicCells_", ",", "V_"}], "]"}]}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"coeffValue", ",", "gatherFun", ",", "aggr"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"coeffValue", "[", 
       RowBox[{"{", 
        RowBox[{"i_", ",", "j_"}], "}"}], "]"}], ":=", 
      RowBox[{
       RowBox[{"getDistValue", "[", 
        RowBox[{"dist", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"i", "/.", "mapS"}], ",", 
           RowBox[{"j", "/.", "mapT"}]}], "}"}]}], "]"}], "*", 
       RowBox[{"EpsilonRemoval", "[", 
        RowBox[{"V", "\[LeftDoubleBracket]", 
         RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gatherFun", "[", 
       RowBox[{"{", 
        RowBox[{"i_", ",", "j_"}], "}"}], "]"}], ":=", 
      RowBox[{"0", "/;", 
       RowBox[{"FixedDistance", "[", 
        RowBox[{"dist", ",", 
         RowBox[{"Sort", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"i", "/.", "mapS"}], ",", 
            RowBox[{"j", "/.", "mapT"}]}], "}"}], "]"}]}], "]"}]}]}], ";", 
     RowBox[{"(*", " ", "constant", " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gatherFun", "[", 
       RowBox[{"{", 
        RowBox[{"i_", ",", "j_"}], "}"}], "]"}], ":=", 
      RowBox[{"Sort", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"i", "/.", "mapS"}], ",", 
         RowBox[{"j", "/.", "mapT"}]}], "}"}], "]"}]}], ";", 
     RowBox[{"(*", " ", "coefficient", " ", "*)"}], "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"aggr", "[", 
       RowBox[{
        RowBox[{"VCoeffs", "[", 
         RowBox[{"unknown_", ",", "const_"}], "]"}], ",", 
        RowBox[{"lst", ":", 
         RowBox[{"{", 
          RowBox[{"x_", ",", "___"}], "}"}]}]}], "]"}], ":=", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"VCoeffs", "[", 
        RowBox[{"unknown", ",", 
         RowBox[{"Fold", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"#1", "+", 
             RowBox[{"coeffValue", "[", "#2", "]"}]}], "&"}], ",", "const", 
           ",", "lst"}], "]"}]}], "]"}], "/;", 
       RowBox[{
        RowBox[{"gatherFun", "[", "x", "]"}], "\[Equal]", "0"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"aggr", "[", 
       RowBox[{
        RowBox[{"VCoeffs", "[", 
         RowBox[{"unknown_", ",", "const_"}], "]"}], ",", 
        RowBox[{"lst", ":", 
         RowBox[{"{", 
          RowBox[{"x_", ",", "___"}], "}"}]}]}], "]"}], ":=", 
      "\[IndentingNewLine]", 
      RowBox[{"VCoeffs", "[", 
       RowBox[{
        RowBox[{"Append", "[", 
         RowBox[{"unknown", ",", 
          RowBox[{
           RowBox[{"gatherFun", "[", "x", "]"}], "\[Rule]", 
           RowBox[{"Fold", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"#1", "+", 
               RowBox[{"EpsilonRemoval", "[", 
                RowBox[{"Extract", "[", 
                 RowBox[{"V", ",", "#2"}], "]"}], "]"}]}], "&"}], ",", "0", 
             ",", "lst"}], "]"}]}]}], "]"}], ",", "const"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"Fold", "[", 
      RowBox[{"aggr", ",", 
       RowBox[{"VCoeffs", "[", 
        RowBox[{
         RowBox[{"{", "}"}], ",", "0"}], "]"}], ",", 
       RowBox[{"GatherBy", "[", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"basicCells", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"coeffValue", "[", "#", "]"}], ">", "0"}], "&"}]}], 
          "]"}], ",", "gatherFun"}], "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.557735949183509*^9, 3.557735984189633*^9}, 
   3.55773604687383*^9, {3.557736093164826*^9, 3.557736100243455*^9}, {
   3.557736161693543*^9, 3.557736199749853*^9}, {3.557736324204351*^9, 
   3.557736493408805*^9}, 3.5577366251947317`*^9, {3.557736733700088*^9, 
   3.557736811452345*^9}, 3.5577368898004932`*^9, {3.557737113886909*^9, 
   3.557737141947049*^9}, {3.5577373937742853`*^9, 3.557737549418146*^9}, 
   3.5577376315762672`*^9, {3.557737685408556*^9, 3.557738003178013*^9}, {
   3.557738049979857*^9, 3.557738052091338*^9}, 3.557738090757793*^9, {
   3.557738131677957*^9, 3.557738224578422*^9}, {3.5577383129644823`*^9, 
   3.557738319684383*^9}, {3.557738364669355*^9, 3.557738458219314*^9}, {
   3.557738489859024*^9, 3.557738593535697*^9}, {3.557738641242448*^9, 
   3.557738736875345*^9}, {3.557804370495635*^9, 3.557804417090569*^9}, {
   3.557804469579007*^9, 3.557804474767379*^9}, 3.557804911066593*^9, {
   3.5578144253712873`*^9, 3.557814428712068*^9}, {3.558154179051032*^9, 
   3.558154249292386*^9}, {3.5581542918156013`*^9, 3.5581542985007257`*^9}, {
   3.558156137369087*^9, 3.55815615420818*^9}, {3.558156186725149*^9, 
   3.5581562238284197`*^9}, {3.558156268342362*^9, 3.558156284190216*^9}, {
   3.558156331604176*^9, 3.558156358964448*^9}, {3.558156466978052*^9, 
   3.55815653587574*^9}, 3.558156578589476*^9, {3.5581566233340397`*^9, 
   3.5581566279827957`*^9}, {3.5581567079928713`*^9, 
   3.5581568114062557`*^9}, {3.558156857181301*^9, 3.558156862202113*^9}, 
   3.5581569134325037`*^9, {3.5581570378463917`*^9, 3.558157069793376*^9}, {
   3.558158668669486*^9, 3.5581587159786577`*^9}, {3.558158787796562*^9, 
   3.558158787956399*^9}, 3.5593112624969177`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["ActiveProblems", "Program"],
 " maps each active problem to its coefficients ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"s", ",", "t"}], ")"}], "\[RightTeeArrow]", 
     RowBox[{"VertexCoeffs", "[", 
      RowBox[{
       SubscriptBox[
        RowBox[{"(", " ", 
         RowBox[{"\[Omega]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"s", ",", "t"}], ")"}], 
            StyleBox[",", "Program"], 
            RowBox[{"(", 
             RowBox[{"u", ",", "v"}], ")"}]}], ")"}]}], " ", ")"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"u", ",", "v"}], ")"}], "\[Element]", 
         RowBox[{"S", "?"}]}]], ",", 
       RowBox[{
        UnderscriptBox["\[Sum]", 
         RowBox[{
          RowBox[{"l", "(", "u", ")"}], "\[NotEqual]", " ", 
          RowBox[{"l", "(", "v", ")"}]}]], 
        RowBox[{"\[Omega]", "(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"s", ",", "t"}], ")"}], ",", 
          RowBox[{"(", 
           RowBox[{"u", ",", "v"}], ")"}]}], ")"}]}]}], "]"}]}], "Program"], 
   TraditionalForm]]],
 " "
}], "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.557805054661256*^9, 3.557805552317959*^9}, {
  3.557805587466151*^9, 3.557805678384667*^9}, {3.557805720721347*^9, 
  3.557805723066061*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ActiveProblems", "[", 
    RowBox[{
     RowBox[{"mc", ":", 
      RowBox[{"MC", "[", 
       RowBox[{"_", ",", "labels_"}], "]"}]}], ",", "dist_", ",", "problems_",
      ",", "queryLst_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Most", "@", 
    RowBox[{"ArrayRules", "@", 
     RowBox[{"Fold", "[", 
      RowBox[{
       RowBox[{"ActiveProblemsAux", "[", 
        RowBox[{"mc", ",", "dist", ",", "problems"}], "]"}], ",", 
       RowBox[{"ZeroMatrix", "[", 
        RowBox[{"Length", "@", "labels"}], "]"}], ",", "queryLst"}], 
      "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ActiveProblemsAux", "[", 
     RowBox[{
      RowBox[{"MC", "[", 
       RowBox[{"_", ",", "labels_"}], "]"}], ",", "dist_", ",", "_"}], "]"}], 
    "[", 
    RowBox[{"active_", ",", 
     RowBox[{"{", 
      RowBox[{"s_", ",", "t_"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   
   RowBox[{"active", "/;", 
    RowBox[{
     RowBox[{"FixedDistance", "[", 
      RowBox[{"dist", ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", "t"}], "}"}]}], "]"}], "||", 
     RowBox[{"MatchQ", "[", 
      RowBox[{
       RowBox[{"active", "\[LeftDoubleBracket]", 
        RowBox[{"s", ",", "t"}], "\[RightDoubleBracket]"}], ",", "_VCoeffs"}],
       "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ActiveProblemsAux", "[", 
     RowBox[{
      RowBox[{"mc", ":", 
       RowBox[{"MC", "[", 
        RowBox[{"_", ",", "_"}], "]"}]}], ",", "dist_", ",", "problems_"}], 
     "]"}], "[", 
    RowBox[{"active_", ",", 
     RowBox[{"{", 
      RowBox[{"s_", ",", "t_"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   
   RowBox[{"Fold", "[", 
    RowBox[{
     RowBox[{"ActiveProblemsAux", "[", 
      RowBox[{"mc", ",", "dist", ",", "problems"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"ReplacePart", "[", 
      RowBox[{"active", ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"s", ",", "t"}], "}"}], "\[Rule]", 
        RowBox[{"VertexCoeffs", "[", 
         RowBox[{"mc", ",", "dist", ",", 
          RowBox[{"problems", "\[LeftDoubleBracket]", 
           RowBox[{"s", ",", "t"}], "\[RightDoubleBracket]"}]}], "]"}]}]}], 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"SubProblems", "[", 
      RowBox[{"problems", "\[LeftDoubleBracket]", 
       RowBox[{"s", ",", "t"}], "\[RightDoubleBracket]"}], "]"}]}], "]"}]}], 
  ";"}]}], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.548491042291703*^9, 3.5484910706113863`*^9}, {
   3.5484911145728827`*^9, 3.548491142935397*^9}, {3.548491255948078*^9, 
   3.5484913300951023`*^9}, 3.548491365534316*^9, {3.548492065224187*^9, 
   3.548492196661731*^9}, {3.548492306760861*^9, 3.548492395995278*^9}, {
   3.54849243483488*^9, 3.548492480540162*^9}, {3.548492513271441*^9, 
   3.548492525538959*^9}, {3.5484979434750032`*^9, 3.5484979627339497`*^9}, {
   3.548498007169422*^9, 3.54849805731845*^9}, {3.548498180125531*^9, 
   3.548498212477338*^9}, {3.548498259375903*^9, 3.548498335356181*^9}, {
   3.548498372547501*^9, 3.5484983751792927`*^9}, {3.548576829683485*^9, 
   3.5485768571202507`*^9}, {3.5486501208248043`*^9, 3.548650212623702*^9}, {
   3.5486503087060328`*^9, 3.548650316528265*^9}, {3.5486508806495132`*^9, 
   3.548650881407296*^9}, {3.5577291523206*^9, 3.557729186807901*^9}, {
   3.557729371840942*^9, 3.557729458125979*^9}, {3.55772976880236*^9, 
   3.557729922574904*^9}, {3.557738833267334*^9, 3.557738834465823*^9}, {
   3.557741224792252*^9, 3.5577412934556007`*^9}, {3.5577415316385803`*^9, 
   3.5577415324622*^9}, {3.5577450428537617`*^9, 3.557745072085409*^9}, {
   3.557745211225624*^9, 3.557745217056058*^9}, {3.557752962123022*^9, 
   3.557752964851138*^9}}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ReachableProblems", "[", 
    RowBox[{"dist_", ",", "problems_", ",", "queryLst_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Fold", "[", 
    RowBox[{
     RowBox[{"DFS", "[", 
      RowBox[{"dist", ",", "problems"}], "]"}], ",", 
     RowBox[{"SparseArray", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"Dimensions", "@", "dist"}], ",", "False"}], "]"}], ",", 
     "queryLst"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DFS", "[", 
     RowBox[{"dist_", ",", "problems_"}], "]"}], "[", 
    RowBox[{"visited_", ",", 
     RowBox[{"{", 
      RowBox[{"s_", ",", "t_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"visited", "/;", 
    RowBox[{
     RowBox[{"visited", "\[LeftDoubleBracket]", 
      RowBox[{"s", ",", "t"}], "\[RightDoubleBracket]"}], "\[Or]", 
     RowBox[{"FixedDistance", "[", 
      RowBox[{"dist", ",", 
       RowBox[{"{", 
        RowBox[{"s", ",", "t"}], "}"}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DFS", "[", 
     RowBox[{"dist_", ",", "problems_"}], "]"}], "[", 
    RowBox[{"visited_", ",", 
     RowBox[{"{", 
      RowBox[{"s_", ",", "t_"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   
   RowBox[{"Fold", "[", 
    RowBox[{
     RowBox[{"DFS", "[", 
      RowBox[{"dist", ",", "problems"}], "]"}], ",", 
     RowBox[{"ReplacePart", "[", 
      RowBox[{"visited", ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"s", ",", "t"}], "}"}], "\[Rule]", "True"}]}], "]"}], ",", 
     RowBox[{"SubProblems", "[", 
      RowBox[{"problems", "\[LeftDoubleBracket]", 
       RowBox[{"s", ",", "t"}], "\[RightDoubleBracket]"}], "]"}]}], "]"}]}], 
  ";"}]}], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.55661716824327*^9, 3.556617498454319*^9}, {
   3.556617530768977*^9, 3.5566176936935387`*^9}, {3.55661772680634*^9, 
   3.556617816264862*^9}, 3.5566178471299143`*^9, {3.5566179342445374`*^9, 
   3.556618120034441*^9}, {3.556618234187376*^9, 3.556618352752921*^9}, {
   3.556618425591381*^9, 3.556618532247924*^9}, {3.5566185991797323`*^9, 
   3.5566186622112293`*^9}, {3.556618694492076*^9, 3.556618745062121*^9}, {
   3.556618780840324*^9, 3.556618856549015*^9}, {3.55661895101989*^9, 
   3.5566189665021753`*^9}, {3.556619144548918*^9, 3.556619144674431*^9}, {
   3.557734962735187*^9, 3.5577349951190453`*^9}, {3.557735035709859*^9, 
   3.5577350659561977`*^9}, {3.5577351006531878`*^9, 
   3.5577351365538883`*^9}, {3.557735361229686*^9, 3.557735389953826*^9}, {
   3.557742141199963*^9, 3.557742202811125*^9}, {3.557752951120697*^9, 
   3.557752954207262*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"UpdateWithDiscrepancy", "[", 
    RowBox[{"\[Lambda]_", ",", 
     RowBox[{"mc", ":", 
      RowBox[{"MC", "[", 
       RowBox[{"_", ",", "labels_"}], "]"}]}], ",", "dist_", ",", "problems_",
      ",", "queryLst_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"aggr", ",", 
       RowBox[{"V0", "=", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"V", "=", 
        RowBox[{"{", "}"}]}], ",", 
       RowBox[{"AdjList", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"{", "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Length", "@", "labels"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"Length", "@", "labels"}], "}"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", "eqrules", ",", "DFS", ",", "notFree", ",", 
       "zeroVars", ",", "freeVariables", ",", "RemoveFree", ",", "PrintD", 
       ",", "d", ",", "\[IndentingNewLine]", "toBind", ",", "makeRow", ",", 
       "A", ",", "b", ",", "sol", ",", "eqNumber", ",", "varMap", ",", 
       "invVarMap", ",", "constMap"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"PrintD", "[", 
        RowBox[{"{", 
         RowBox[{"x_", ",", "y_"}], "}"}], "]"}], ":=", 
       RowBox[{"\"\<d(\>\"", "<>", 
        RowBox[{"ToString", "[", "x", "]"}], "<>", "\"\<,\>\"", "<>", 
        RowBox[{"ToString", "[", "y", "]"}], "<>", "\"\<)\>\""}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"aggr", "[", 
        RowBox[{"id_", "->", 
         RowBox[{"VCoeffs", "[", 
          RowBox[{"lst_", ",", "n_"}], "]"}]}], "]"}], ":=", 
       "\[IndentingNewLine]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"n", "\[Equal]", "0"}], ",", 
           RowBox[{"V0", " ", "=", 
            RowBox[{"Append", "[", 
             RowBox[{"V0", ",", "id"}], "]"}]}], ",", 
           RowBox[{"V", "=", 
            RowBox[{"Append", "[", 
             RowBox[{"V", ",", "id"}], "]"}]}]}], "]"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"AdjList", "=", 
          RowBox[{"Fold", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"ReplacePart", "[", 
              RowBox[{"#1", ",", 
               RowBox[{"#2", "\[Rule]", 
                RowBox[{"Append", "[", 
                 RowBox[{
                  RowBox[{"Extract", "[", 
                   RowBox[{"#1", ",", "#2"}], "]"}], ",", "id"}], "]"}]}]}], 
              "]"}], "&"}], ",", "AdjList", ",", 
            RowBox[{"lst", "\[LeftDoubleBracket]", 
             RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], 
           "]"}]}]}], ")"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"DFS", "[", 
        RowBox[{"visited_", ",", "id_"}], "]"}], ":=", 
       RowBox[{"visited", "/;", 
        RowBox[{"Extract", "[", 
         RowBox[{"visited", ",", "id"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"DFS", "[", 
        RowBox[{"visited_", ",", "id_"}], "]"}], ":=", 
       RowBox[{"Fold", "[", 
        RowBox[{"DFS", ",", 
         RowBox[{"ReplacePart", "[", 
          RowBox[{"visited", ",", 
           RowBox[{"id", "\[Rule]", "True"}]}], "]"}], ",", 
         RowBox[{"Extract", "[", 
          RowBox[{"AdjList", ",", "id"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"RemoveFree", "[", 
        RowBox[{"id_", "->", 
         RowBox[{"VCoeffs", "[", 
          RowBox[{"lst_", ",", "n_"}], "]"}]}], "]"}], ":=", 
       RowBox[{"id", "->", 
        RowBox[{"VCoeffs", "[", 
         RowBox[{
          RowBox[{"Select", "[", 
           RowBox[{"lst", ",", 
            RowBox[{
             RowBox[{"Extract", "[", 
              RowBox[{"notFree", ",", 
               RowBox[{"First", "@", "#"}]}], "]"}], "&"}]}], "]"}], ",", 
          "n"}], "]"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"toBind", "[", 
        RowBox[{
         RowBox[{"index_", "\[Rule]", " ", 
          RowBox[{"VCoeffs", "[", 
           RowBox[{"_", ",", "const_"}], "]"}]}], ",", 
         RowBox[{"{", "n_", "}"}]}], "]"}], ":=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"index", "\[Rule]", "n"}], ",", 
         RowBox[{"n", "\[Rule]", "index"}], ",", 
         RowBox[{"n", "\[Rule]", "const"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"makeRow", "[", 
        RowBox[{"index_", "\[Rule]", " ", 
         RowBox[{"VCoeffs", "[", 
          RowBox[{"rules_", ",", "_"}], "]"}]}], "]"}], ":=", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"SparseArray", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", 
              RowBox[{"index", "/.", "varMap"}]}], "}"}], "\[Rule]", " ", 
            "1"}], ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "eqNumber"}], "}"}]}], "]"}], "-", " ", 
         "\[IndentingNewLine]", 
         RowBox[{"\[Lambda]", " ", 
          RowBox[{"SparseArray", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"1", ",", 
                  RowBox[{
                   RowBox[{
                   "#", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "/.", "varMap"}]}], "}"}], 
                "\[Rule]", 
                RowBox[{
                "#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}],
                "&"}], ")"}], "/@", "rules"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "eqNumber"}], "}"}]}], "]"}]}]}], "}"}]}], ";",
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"eqrules", "=", " ", 
       RowBox[{"ActiveProblems", "[", 
        RowBox[{"mc", ",", "dist", ",", "problems", ",", "queryLst"}], 
        "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
       "compute", " ", "coefficients", " ", "of", " ", "active", " ", 
        "problems"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"LOOK", " ", "FOR", " ", "POSSIBLE", " ", "FREE"}], "-", 
        "VARIABLES"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Scan", "[", 
       RowBox[{"aggr", ",", "eqrules"}], "]"}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{"construct", " ", "the", " ", "inverse", " ", "graph"}], " ", 
       "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"notFree", "=", 
       RowBox[{"Fold", "[", 
        RowBox[{"DFS", ",", 
         RowBox[{"SparseArray", "[", 
          RowBox[{
           RowBox[{"{", "}"}], ",", 
           RowBox[{"Dimensions", "@", "dist"}], ",", "False"}], "]"}], ",", 
         "V"}], "]"}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"detect", " ", "non"}], "-", 
        RowBox[{"free", " ", "variables"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"zeroVars", "=", 
       RowBox[{"Select", "[", 
        RowBox[{"V0", ",", 
         RowBox[{
          RowBox[{"Not", "@", 
           RowBox[{"Extract", "[", 
            RowBox[{"notFree", ",", "#"}], "]"}]}], "&"}]}], "]"}]}], ";", 
      " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"detect", " ", "zero"}], "-", "variables"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"DebugPrint", "[", 
       RowBox[{"\"\<Variables detected to be zero:\>\"", ",", 
        RowBox[{"PrintD", "/@", "zeroVars"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", "\"\<GAUSSIAN ELIMINATION\>\"", " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"eqrules", "=", 
       RowBox[{"RemoveFree", "/@", 
        RowBox[{"Select", "[", 
         RowBox[{"eqrules", ",", 
          RowBox[{
           RowBox[{"Extract", "[", 
            RowBox[{"notFree", ",", 
             RowBox[{"First", "@", "#"}]}], "]"}], "&"}]}], "]"}]}]}], ";", 
      RowBox[{"(*", " ", 
       RowBox[{
       "remove", " ", "free", " ", "variables", " ", "from", " ", "eqrules"}],
        " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"sol", "=", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"eqNumber", "=", 
            RowBox[{"Length", "@", "eqrules"}]}], ")"}], ">", "0"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "CONSTRUCT", " ", "THE", " ", "SINGULAR", " ", "EQUATION", " ", 
           "SYSTEM"}], " ", "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"varMap", ",", "invVarMap", ",", "constMap"}], "}"}], "=", 
           RowBox[{"Transpose", "[", 
            RowBox[{"MapIndexed", "[", 
             RowBox[{"toBind", ",", "eqrules"}], "]"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"A", "=", 
           RowBox[{"ArrayFlatten", "[", 
            RowBox[{"makeRow", "/@", "eqrules"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"b", "=", 
           RowBox[{"\[Lambda]", " ", 
            RowBox[{"SparseArray", "[", 
             RowBox[{"constMap", ",", 
              RowBox[{"{", "eqNumber", "}"}]}], "]"}]}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"sol", " ", "=", 
           RowBox[{"LinearSolve", "[", 
            RowBox[{
             RowBox[{"Normal", "@", "A"}], ",", 
             RowBox[{"Normal", "@", "b"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"d", "=", 
           RowBox[{"MatrixForm", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"PrintD", "[", 
                RowBox[{"#", "/.", "invVarMap"}], "]"}], ")"}], "&"}], "/@", 
             RowBox[{"Table", "[", 
              RowBox[{"i", ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", 
                 RowBox[{"Length", "@", "sol"}]}], "}"}]}], "]"}]}], "]"}]}], 
          ";", "\[IndentingNewLine]", 
          RowBox[{"DebugPrint", "[", 
           RowBox[{"\"\<Reduced Linear System: \>\"", ",", 
            RowBox[{"MatrixForm", "@", "A"}], ",", "d", ",", "\"\<==\>\"", 
            ",", 
            RowBox[{"MatrixForm", "@", "b"}], ",", " ", 
            "\[IndentingNewLine]", "\"\<;  Solution:\>\"", ",", "d", ",", 
            "\"\<=\>\"", ",", 
            RowBox[{"sol", "//", "MatrixForm"}]}], "]"}], ";", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", "sol"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
          "DebugPrint", "[", "\"\<Reduced Linear System: it is empty\>\"", 
           "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"ReplacePart", "[", 
       RowBox[{"dist", ",", "\[IndentingNewLine]", 
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"#", "\[Rule]", 
             RowBox[{"Fixed", "[", "0", "]"}]}], "&"}], "/@", "zeroVars"}], 
          ",", 
          RowBox[{"(*", " ", 
           RowBox[{
           "fix", " ", "free", " ", "variables", " ", "to", " ", "zero"}], 
           " ", "*)"}], "\[IndentingNewLine]", 
          RowBox[{"MapIndexed", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                "#2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                "/.", "invVarMap"}], ")"}], "\[Rule]", "#1"}], "&"}], ",", 
            "sol"}], "]"}]}], "]"}]}], 
       RowBox[{"(*", " ", 
        RowBox[{
         RowBox[{"new", " ", "values", " ", "for", " ", "the", " ", "non"}], 
         "-", 
         RowBox[{"free", " ", "variables"}]}], " ", "*)"}], 
       "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.557740827985745*^9, 3.5577408626926928`*^9}, {
   3.55774092575816*^9, 3.557740936502754*^9}, {3.5577409677037888`*^9, 
   3.557741039785945*^9}, {3.557741119676404*^9, 3.557741158429659*^9}, {
   3.557741349565073*^9, 3.5577414323500223`*^9}, {3.5577414630793543`*^9, 
   3.557741505787594*^9}, {3.557741629789399*^9, 3.557741636316948*^9}, 
   3.557743480083641*^9, {3.5577439003765593`*^9, 3.55774393598219*^9}, {
   3.557743972895316*^9, 3.55774399368895*^9}, {3.557744025181006*^9, 
   3.5577440433399343`*^9}, {3.557744144480653*^9, 3.557744513367811*^9}, {
   3.55774454724123*^9, 3.5577446194193077`*^9}, {3.557744729670354*^9, 
   3.557744826281712*^9}, {3.557745273112466*^9, 3.5577452832445*^9}, {
   3.557745443618178*^9, 3.557745637925233*^9}, {3.5577456681034727`*^9, 
   3.557745878645318*^9}, {3.557746380893777*^9, 3.55774642157906*^9}, {
   3.557746452678434*^9, 3.557746492825585*^9}, {3.557746556754115*^9, 
   3.557746640524837*^9}, {3.5577466759419003`*^9, 3.557746693974114*^9}, 
   3.557746731167389*^9, {3.5577471446994057`*^9, 3.557747186860415*^9}, {
   3.557747408140575*^9, 3.557747409698928*^9}, {3.557747541590684*^9, 
   3.557747600144508*^9}, {3.557747669146806*^9, 3.557747741701353*^9}, {
   3.557747778598321*^9, 3.5577478940009212`*^9}, {3.557747932080709*^9, 
   3.557748191163089*^9}, {3.557748558737034*^9, 3.5577486943068542`*^9}, {
   3.5577487560229597`*^9, 3.557748904016939*^9}, {3.5577489984974833`*^9, 
   3.557749063221599*^9}, {3.557749134459049*^9, 3.557749175883254*^9}, {
   3.557749369515232*^9, 3.557749369673091*^9}, {3.557749666939049*^9, 
   3.5577498798335857`*^9}, {3.557749952468712*^9, 3.557750021117573*^9}, {
   3.557750055722267*^9, 3.5577502409958*^9}, 3.557750288487924*^9, {
   3.557750338802792*^9, 3.557750358713832*^9}, {3.557750423764542*^9, 
   3.5577504622987423`*^9}, {3.557750493514983*^9, 3.5577505622916822`*^9}, 
   3.557750640293604*^9, {3.557751278355131*^9, 3.557751307501692*^9}, {
   3.557751386188842*^9, 3.557751747236724*^9}, {3.5577518470847607`*^9, 
   3.5577518553762283`*^9}, {3.557751903708104*^9, 3.557752056217998*^9}, {
   3.557752152345557*^9, 3.557752265182768*^9}, {3.557752295878985*^9, 
   3.557752329294639*^9}, {3.557752563360407*^9, 3.557752628542719*^9}, {
   3.5577529753864937`*^9, 3.557752982010704*^9}, {3.557805864943128*^9, 
   3.557805867787203*^9}, {3.557806229376737*^9, 3.5578063525870934`*^9}, {
   3.557806395380645*^9, 3.557806415551354*^9}, {3.557836092977845*^9, 
   3.557836094572139*^9}, {3.557849895630726*^9, 3.5578499307558107`*^9}, {
   3.5580082049254103`*^9, 3.5580082349492826`*^9}, {3.5580082816482697`*^9, 
   3.558008353624981*^9}, {3.558008408597391*^9, 3.558008549039051*^9}, {
   3.558008800885207*^9, 3.558008870100515*^9}, 3.558155829426207*^9, 
   3.558155864311029*^9, {3.5592808227135963`*^9, 3.5592808297858057`*^9}, {
   3.559280860342955*^9, 3.559280863476316*^9}, {3.559280898700252*^9, 
   3.55928091177242*^9}, {3.559283629464761*^9, 3.5592836336971693`*^9}, {
   3.559283744601091*^9, 3.559283921659543*^9}, {3.559284028097066*^9, 
   3.5592840539020433`*^9}, {3.559284093839027*^9, 3.559284115903817*^9}, {
   3.559284187011962*^9, 3.559284189870997*^9}, {3.559286961333948*^9, 
   3.559287017478796*^9}, {3.559287705356855*^9, 3.5592878515494957`*^9}, 
   3.559287884592066*^9, {3.559297418653808*^9, 3.559297428565168*^9}, 
   3.559297497490494*^9, {3.559297598808498*^9, 3.5592976074293013`*^9}, {
   3.5592976861375732`*^9, 3.559297909842002*^9}, {3.5592979542035723`*^9, 
   3.559298050740417*^9}, {3.559298090460869*^9, 3.559298095421377*^9}, {
   3.5593100135656977`*^9, 3.5593100279247017`*^9}, {3.5593682125041447`*^9, 
   3.559368213304594*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"getDistValue", "[", 
    RowBox[{"dist_", ",", 
     RowBox[{"index", ":", 
      RowBox[{"{", 
       RowBox[{"_", ",", "_"}], "}"}]}]}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "getValue", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"getValue", "[", 
        RowBox[{"Fixed", "[", "v_", "]"}], "]"}], ":=", "v"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"getValue", "[", "v_", "]"}], ":=", "v"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"getValue", "[", 
       RowBox[{"Extract", "[", 
        RowBox[{"dist", ",", 
         RowBox[{"Sort", "@", "index"}]}], "]"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.55773046973501*^9, 3.557730482381431*^9}, {
  3.557730515302746*^9, 3.557730597498432*^9}, {3.557730648623348*^9, 
  3.557730666229064*^9}, {3.5577307270405617`*^9, 3.557730884004253*^9}, {
  3.557730916884616*^9, 3.557730917293212*^9}, {3.5577526452447653`*^9, 
  3.557752648785722*^9}, {3.5578144364339046`*^9, 3.5578145130660543`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"InitDistances", "[", 
    RowBox[{
     RowBox[{"MC", "[", 
      RowBox[{"_", ",", "labels_"}], "]"}], ",", "estimates_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"numStates", "=", 
        RowBox[{"Length", "@", "labels"}]}], ",", "setDist"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"setDist", "[", 
        RowBox[{"s_", ",", "t_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"Fixed", "[", "0", "]"}], "/;", 
        RowBox[{"s", "\[Equal]", "t"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"setDist", "[", 
        RowBox[{"s_", ",", "t_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"Fixed", "[", "1", "]"}], "/;", " ", 
        RowBox[{
         RowBox[{
         "labels", "\[LeftDoubleBracket]", "s", "\[RightDoubleBracket]"}], 
         "\[NotEqual]", 
         RowBox[{
         "labels", "\[LeftDoubleBracket]", "t", 
          "\[RightDoubleBracket]"}]}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"setDist", "[", 
        RowBox[{"s_", ",", "t_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{"Fixed", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"s", ",", "t"}], "}"}], "/.", "estimates"}], "]"}], "/;", 
        " ", 
        RowBox[{"MemberQ", "[", 
         RowBox[{"estimates", ",", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"s", ",", "t"}], "}"}], "\[Rule]", "_"}]}], "]"}]}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"setDist", "[", 
        RowBox[{"s_", ",", "t_"}], "]"}], ":=", "1"}], ";", " ", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"setDist", "[", 
         RowBox[{"s", ",", "t"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "numStates"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t", ",", "numStates"}], "}"}]}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.557726358769553*^9, 3.5577263987025967`*^9}, {
   3.557726436087817*^9, 3.557726673476149*^9}, {3.557726758936894*^9, 
   3.5577267901674643`*^9}, {3.557727120203335*^9, 3.557727124225431*^9}, {
   3.5577271897390747`*^9, 3.557727190498856*^9}, {3.557727248702441*^9, 
   3.557727251204529*^9}, {3.557727474862281*^9, 3.557727547774377*^9}, {
   3.5577275830477953`*^9, 3.557727583134952*^9}, {3.5577276147358027`*^9, 
   3.55772761490266*^9}, {3.557727658137542*^9, 3.557727667945751*^9}, 
   3.557727834672851*^9, 3.557752650548526*^9, {3.5595610327210827`*^9, 
   3.559561038239376*^9}, {3.5595610805106707`*^9, 3.5595611161622953`*^9}, {
   3.559561156427948*^9, 3.5595612012300577`*^9}}],

Cell[TextData[{
 StyleBox["VertexToChange[dist, {s,t}] == {{i,j}, {redCost, nbcell}}", 
  "Program"],
 " if the problem ",
 StyleBox["(i,j)", "Program"],
 " can be further minimized, otherwise it returns ",
 StyleBox["{}", "Program"]
}], "Text",
 InitializationGroup->True,
 CellChangeTimes->{{3.548560643095201*^9, 3.548560698921835*^9}, {
  3.548560767668283*^9, 3.548560900031392*^9}, {3.548646740631967*^9, 
  3.548646756551968*^9}, {3.557807874754126*^9, 3.557807876073214*^9}, {
  3.5578079126032763`*^9, 3.557807925723531*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"VertexToChange", "[", 
    RowBox[{"problems_", ",", "dist_", ",", "queryLst_"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Q", "=", "queryLst"}], ",", "i", ",", "j", ",", "reducedcost",
        ",", "cell", ",", "neighbours", ",", "toVisit", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"visited", "=", 
        RowBox[{"SparseArray", "[", 
         RowBox[{
          RowBox[{"{", "}"}], ",", 
          RowBox[{"Dimensions", "@", "problems"}], ",", "False"}], "]"}]}]}], 
      "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"toVisit", "[", 
        RowBox[{"{", 
         RowBox[{"u_", ",", "v_"}], "}"}], "]"}], ":=", 
       RowBox[{"Not", "[", 
        RowBox[{
         RowBox[{"visited", "\[LeftDoubleBracket]", 
          RowBox[{"u", ",", "v"}], "\[RightDoubleBracket]"}], "\[Or]", 
         RowBox[{"FixedDistance", "[", 
          RowBox[{"dist", ",", 
           RowBox[{"{", 
            RowBox[{"u", ",", "v"}], "}"}]}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "a", " ", "new", " ", "problem", " ", "should", " ", "not", " ", "be", 
        " ", "visited", " ", "if", " ", "it", " ", "has", " ", "been", " ", 
        "visited", " ", "already", " ", "or", " ", "\[IndentingNewLine]", 
        "its", " ", "corresponding", " ", "value", " ", "is", " ", "fixed"}], 
       " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"While", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "@", "Q"}], " ", ">", "0"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "take", " ", "a", " ", "problem", " ", "from", " ", "the", " ", 
          "queue", " ", "and", " ", "set", " ", "it", " ", "as", " ", 
          "already", " ", "visited"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"i", ",", "j"}], "}"}], "=", 
          RowBox[{"First", "@", "Q"}]}], ";", 
         RowBox[{"visited", "=", 
          RowBox[{"ReplacePart", "[", 
           RowBox[{"visited", ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}], "\[Rule]", "True"}]}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"DebugPrint", "[", 
            RowBox[{"\"\<Visited problem:\>\"", ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "j"}], "}"}]}], "]"}], ";"}], "*)"}], 
         "\[IndentingNewLine]", 
         RowBox[{"(*", " ", 
          RowBox[{
          "compute", " ", "the", " ", "least", " ", "reduced", " ", "cost", 
           " ", "for", " ", "the", " ", "current", " ", "problem"}], " ", 
          "*)"}], "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"reducedcost", ",", "cell"}], "}"}], "=", 
          RowBox[{"AddtoBase", "[", 
           RowBox[{"dist", ",", 
            RowBox[{"problems", "\[LeftDoubleBracket]", 
             RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}]}], "]"}]}], 
         ";", "\[IndentingNewLine]", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"reducedcost", "<", "0"}], ",", "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{
            "the", " ", "first", " ", "encoutered", " ", "vertex", " ", "to", 
             " ", "be", " ", "changed"}], " ", "*)"}], "\[IndentingNewLine]", 
           
           RowBox[{
            RowBox[{"DebugPrint", "[", 
             RowBox[{"\"\<Non optimal schedule for: \>\"", ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", "j"}], "}"}], ",", "\"\< reduced cost: \>\"",
               ",", "reducedcost", ",", " ", "\"\< for introducing \>\"", ",",
               "cell", ",", "\"\< as basic\>\""}], "]"}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Return", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"i", ",", "j"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"reducedcost", ",", "cell"}], "}"}]}], "}"}], "]"}]}],
            ",", "\[IndentingNewLine]", 
           RowBox[{"(*", " ", 
            RowBox[{"otherwise", " ", "look", " ", "forward"}], " ", "*)"}], 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"neighbours", " ", "=", 
             RowBox[{"Select", "[", 
              RowBox[{
               RowBox[{"SubProblems", "[", 
                RowBox[{"problems", "\[LeftDoubleBracket]", 
                 RowBox[{"i", ",", "j"}], "\[RightDoubleBracket]"}], "]"}], 
               ",", "toVisit"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"Q", " ", "=", " ", 
             RowBox[{"DeleteDuplicates", "@", 
              RowBox[{"Join", "[", 
               RowBox[{
                RowBox[{"Rest", "@", "Q"}], ",", "neighbours"}], 
               "]"}]}]}]}]}], "\[IndentingNewLine]", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "none", " ", "of", " ", "the", " ", "reached", " ", "problems", " ", 
        "can", " ", "be", " ", "further", " ", "decreased"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"{", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",\

 InitializationGroup->True,
 CellChangeTimes->{{3.555416986725697*^9, 3.555417118570669*^9}, {
   3.555417201445779*^9, 3.555417217062605*^9}, {3.5554172492188463`*^9, 
   3.5554173226221437`*^9}, {3.555417384806202*^9, 3.555417626717548*^9}, {
   3.5554176679535723`*^9, 3.555417673929562*^9}, 3.5554177621561823`*^9, {
   3.55541781599994*^9, 3.555417858134919*^9}, {3.5554179032562027`*^9, 
   3.5554179191060123`*^9}, {3.5556757975753193`*^9, 
   3.5556757989247828`*^9}, {3.555675839416079*^9, 3.555675874288384*^9}, {
   3.5556759153054857`*^9, 3.555675990827755*^9}, {3.5556760832791567`*^9, 
   3.555676164512555*^9}, {3.5556761983134937`*^9, 3.555676330023781*^9}, 
   3.555676406799159*^9, 3.5556765301176977`*^9, {3.555676597840461*^9, 
   3.5556767404685793`*^9}, 3.555676829903543*^9, {3.5556769876354837`*^9, 
   3.55567699841838*^9}, {3.555677136918386*^9, 3.555677342965582*^9}, {
   3.5556773736782637`*^9, 3.555677404680216*^9}, {3.5556774456505632`*^9, 
   3.5556774993944683`*^9}, {3.555677569299902*^9, 3.555677605278926*^9}, {
   3.5556776496188*^9, 3.555677651434226*^9}, {3.555733714228424*^9, 
   3.5557337652366323`*^9}, {3.555733925513824*^9, 3.555733992261586*^9}, {
   3.555844159526887*^9, 3.5558442009041367`*^9}, {3.555850277991357*^9, 
   3.555850285974245*^9}, {3.5558519970092897`*^9, 3.555852013992058*^9}, {
   3.557730961725223*^9, 3.557731092680855*^9}, {3.5577527526923237`*^9, 
   3.5577527807481203`*^9}, {3.557752822443635*^9, 3.5577528287719107`*^9}, {
   3.557807363306252*^9, 3.557807418534465*^9}, 3.5578075619306927`*^9, {
   3.5578077927881517`*^9, 3.5578077965054007`*^9}, {3.559281167935001*^9, 
   3.559281194556653*^9}, {3.5592815950256166`*^9, 3.5592815995974197`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "ComputeDistances", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Verbose", "\[Rule]", "False"}], ",", 
     RowBox[{"ConsistencyCheck", "\[Rule]", "True"}], ",", 
     RowBox[{"Estimates", "\[Rule]", " ", 
      RowBox[{"{", "}"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComputeDistances", "::", "query"}], "=", 
   "\"\<The following queries are ill-formed: `1`.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComputeDistances", "::", "MarkovChain"}], " ", "=", " ", 
   "\"\<The 1-st argument is not a well-formed rational-valued probabilistic \
Markov Chain.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComputeDistances", "::", "DiscountFactor"}], " ", "=", 
   "\"\<The second argument, namely `1`, must be a rational in the interval \
(0,1].\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComputeDistances", "::", "MultipleEstimates"}], "=", 
   "\"\<There must be at most one estimate for each pair\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ComputeDistances", "::", "WrongEstimates"}], "=", 
    "\"\<Estimates must be a rationals in the interval (0,1]\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComputeDistances", "[", 
    RowBox[{
     RowBox[{"mc", ":", 
      RowBox[{"MC", "[", 
       RowBox[{"_", ",", "_"}], "]"}]}], ",", "\[Lambda]_", ",", " ", "All", 
     ",", 
     RowBox[{"options", ":", " ", 
      RowBox[{"OptionsPattern", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Verbose", " ", "->", " ", "False"}], ",", 
         RowBox[{"ConsistencyCheck", "\[Rule]", "True"}], ",", 
         RowBox[{"Estimates", "\[Rule]", " ", 
          RowBox[{"{", "}"}]}]}], "}"}], "]"}]}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"ComputeDistances", "[", 
    RowBox[{"mc", ",", "\[Lambda]", ",", 
     RowBox[{"AllPairs", "@", "mc"}], ",", "options"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComputeDistances", "[", 
    RowBox[{
     RowBox[{"mc", ":", 
      RowBox[{"MC", "[", 
       RowBox[{"_", ",", "_"}], "]"}]}], ",", "\[Lambda]_", ",", " ", 
     "queryLst_", ",", " ", 
     RowBox[{"OptionsPattern", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Verbose", " ", "->", " ", "False"}], ",", 
        RowBox[{"ConsistencyCheck", "\[Rule]", "True"}], ",", 
        RowBox[{"Estimates", "\[Rule]", " ", 
         RowBox[{"{", "}"}]}]}], "}"}], "]"}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"OptionValue", "[", "ConsistencyCheck", "]"}], ",", 
       RowBox[{"CheckInput", "[", 
        RowBox[{"mc", ",", "\[Lambda]", ",", " ", "queryLst"}], "]"}]}], 
      "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Set", " ", "Options", " ", "for", " ", "ComputeDistance"}], 
      " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"SetOptions", "[", 
      RowBox[{"ComputeDistances", ",", 
       RowBox[{"Verbose", "\[Rule]", 
        RowBox[{"OptionValue", "[", "Verbose", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"SetOptions", "[", 
      RowBox[{"ComputeDistances", ",", 
       RowBox[{"ConsistencyCheck", "\[Rule]", 
        RowBox[{"OptionValue", "[", "ConsistencyCheck", "]"}]}]}], "]"}], ";",
      "\[IndentingNewLine]", 
     RowBox[{"SetOptions", "[", 
      RowBox[{"ComputeDistances", ",", 
       RowBox[{"Estimates", "\[Rule]", 
        RowBox[{"OptionValue", "[", "Estimates", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Start", " ", "computing", " ", "the", " ", 
       SubscriptBox["d", "\[Lambda]"], 
       RowBox[{"(", 
        RowBox[{"s", ",", "t"}], ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     
     RowBox[{"ComputeDistancesAux", "[", 
      RowBox[{"mc", ",", "\[Lambda]", ",", "queryLst"}], "]"}]}], 
    "\[IndentingNewLine]", ")"}]}], ";"}]}], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.548569191095557*^9, 3.548569206659737*^9}, {
   3.548569277720902*^9, 3.548569463680194*^9}, {3.548569494208906*^9, 
   3.548569673691698*^9}, {3.548569742512774*^9, 3.548569771159306*^9}, {
   3.548569842746922*^9, 3.5485700820185137`*^9}, {3.5485720560138197`*^9, 
   3.548572080531966*^9}, {3.548573051467022*^9, 3.548573081993548*^9}, {
   3.548573140421441*^9, 3.548573181080573*^9}, {3.548575130091036*^9, 
   3.548575275036784*^9}, {3.5485753974487057`*^9, 3.548575643949705*^9}, {
   3.5485756966820507`*^9, 3.548575707635304*^9}, 3.548576584806301*^9, {
   3.548576627119886*^9, 3.548576628984133*^9}, {3.5485766681757917`*^9, 
   3.5485766704228907`*^9}, {3.5485768869500647`*^9, 3.54857692808385*^9}, {
   3.548585326830559*^9, 3.548585364412815*^9}, {3.548646286388817*^9, 
   3.548646308583246*^9}, {3.548646367994719*^9, 3.548646428241077*^9}, 
   3.5486468515427732`*^9, {3.5486469174860783`*^9, 3.548646937857749*^9}, {
   3.5486472928669357`*^9, 3.5486473113094788`*^9}, {3.548647722736828*^9, 
   3.5486477266968107`*^9}, {3.548647768308642*^9, 3.548647787523468*^9}, {
   3.548647878885569*^9, 3.548647909494916*^9}, {3.548648050787348*^9, 
   3.5486480508970413`*^9}, {3.548648092929554*^9, 3.548648107641574*^9}, {
   3.548648354598465*^9, 3.5486483551651583`*^9}, {3.548649233309044*^9, 
   3.548649239513516*^9}, {3.548649295421492*^9, 3.548649310953459*^9}, {
   3.548652118330711*^9, 3.548652139986348*^9}, {3.548652228126603*^9, 
   3.548652290580119*^9}, {3.548652331254772*^9, 3.548652332014792*^9}, {
   3.5486523627993793`*^9, 3.5486523780388947`*^9}, {3.5486525846573877`*^9, 
   3.5486525923094997`*^9}, {3.548653036296682*^9, 3.5486530391862698`*^9}, {
   3.5486544576658154`*^9, 3.548654472486525*^9}, {3.5486546015529213`*^9, 
   3.5486546109920893`*^9}, {3.548665412679734*^9, 3.548665417678706*^9}, {
   3.5486704809511766`*^9, 3.5486704999866533`*^9}, 3.548675531478917*^9, 
   3.5487017905367823`*^9, {3.5487020045432367`*^9, 3.548702005431344*^9}, {
   3.548702089311489*^9, 3.548702090263064*^9}, {3.548989926620509*^9, 
   3.548989979124897*^9}, {3.548990201969439*^9, 3.548990266301465*^9}, {
   3.548990314864326*^9, 3.548990323919717*^9}, {3.548990358160017*^9, 
   3.548990363926463*^9}, {3.548990403385182*^9, 3.5489904068786507`*^9}, {
   3.5489906119929047`*^9, 3.548990652377421*^9}, {3.548990756465725*^9, 
   3.548990767791533*^9}, {3.548990963915081*^9, 3.548990979967539*^9}, {
   3.548991043946382*^9, 3.548991066253067*^9}, {3.548991246763178*^9, 
   3.548991251128644*^9}, 3.5490001203902283`*^9, {3.549011101282733*^9, 
   3.549011114703404*^9}, {3.549012714142788*^9, 3.549012720718358*^9}, {
   3.549012836739883*^9, 3.549012855522128*^9}, {3.5526326731844378`*^9, 
   3.5526326831693783`*^9}, {3.552632715045991*^9, 3.552632739353314*^9}, {
   3.5550662540374813`*^9, 3.5550662706669493`*^9}, {3.555151722167571*^9, 
   3.5551517328044443`*^9}, {3.555321880722291*^9, 3.55532188514563*^9}, {
   3.555322767931477*^9, 3.555322774164178*^9}, {3.555322895241544*^9, 
   3.555322899880739*^9}, {3.555322939248948*^9, 3.555322939832102*^9}, {
   3.555326124213026*^9, 3.555326134578678*^9}, 3.555389363576645*^9, {
   3.5553894433933*^9, 3.555389484306031*^9}, 3.55538960860561*^9, {
   3.5553896669456177`*^9, 3.555389746722136*^9}, {3.555389777334119*^9, 
   3.555389799102881*^9}, {3.555389946352745*^9, 3.5553899542759237`*^9}, {
   3.555390542349032*^9, 3.555390622751326*^9}, {3.5553906537271957`*^9, 
   3.555390822794668*^9}, {3.5553908735025797`*^9, 3.5553909662006817`*^9}, {
   3.555391820788748*^9, 3.555391831093913*^9}, {3.555391947419435*^9, 
   3.5553919925864162`*^9}, {3.5553920671486807`*^9, 
   3.5553920858141947`*^9}, {3.555392117449849*^9, 3.555392244522231*^9}, {
   3.555392317572625*^9, 3.5553923479178*^9}, {3.5553926233032503`*^9, 
   3.555392635070161*^9}, {3.555394428244444*^9, 3.555394435465308*^9}, {
   3.55539455058305*^9, 3.555394600800983*^9}, {3.555394687522723*^9, 
   3.555394698369679*^9}, {3.555395853501196*^9, 3.5553958538833923`*^9}, {
   3.555395914047359*^9, 3.55539591460532*^9}, 3.55539679837717*^9, 
   3.5554070781101007`*^9, {3.555407159824359*^9, 3.555407205624824*^9}, {
   3.5554072444454813`*^9, 3.5554073515773478`*^9}, {3.5554083633819923`*^9, 
   3.555408392630844*^9}, {3.555408597103302*^9, 3.555408609773355*^9}, {
   3.555414122037825*^9, 3.555414144563388*^9}, {3.555414208924094*^9, 
   3.555414209351861*^9}, {3.5558520727782307`*^9, 3.555852083473687*^9}, {
   3.555911067396549*^9, 3.5559111256184893`*^9}, {3.5559111781033087`*^9, 
   3.555911468630859*^9}, {3.555911514206089*^9, 3.5559115213186417`*^9}, {
   3.555911553185934*^9, 3.555911623624669*^9}, {3.555911661249648*^9, 
   3.555911744034367*^9}, {3.555911776338924*^9, 3.5559120740526867`*^9}, {
   3.5559121780101643`*^9, 3.5559121947764187`*^9}, {3.5559122413816833`*^9, 
   3.555912451618174*^9}, {3.5559124843799267`*^9, 3.5559125154758*^9}, {
   3.5559125752942057`*^9, 3.555912663048086*^9}, {3.55591269899463*^9, 
   3.555912817388501*^9}, {3.55591285482345*^9, 3.555912887303912*^9}, {
   3.555912953170001*^9, 3.555912985067505*^9}, {3.555913085206197*^9, 
   3.5559131354049683`*^9}, {3.555913168934289*^9, 3.5559133055637712`*^9}, 
   3.555913346950769*^9, {3.555913436533462*^9, 3.5559135409645987`*^9}, {
   3.555914763455724*^9, 3.5559147689892607`*^9}, {3.5559148082846527`*^9, 
   3.555914908894438*^9}, {3.55591506946966*^9, 3.555915121006929*^9}, {
   3.555922877995311*^9, 3.555923005964419*^9}, {3.555923078282372*^9, 
   3.555923112501934*^9}, {3.555924976484909*^9, 3.555925018709757*^9}, {
   3.5559250728634977`*^9, 3.5559250834473753`*^9}, {3.555925115619665*^9, 
   3.555925193251012*^9}, {3.5559261340613747`*^9, 3.555926195208336*^9}, {
   3.555930670353339*^9, 3.5559308772007008`*^9}, 3.555996517362914*^9, 
   3.555996560682497*^9, {3.5568836365865593`*^9, 3.5568836421863413`*^9}, {
   3.5568836844774113`*^9, 3.5568836915784187`*^9}, {3.557723347022546*^9, 
   3.557723348756291*^9}, {3.5578107730715637`*^9, 3.55781080256065*^9}, {
   3.5578117720664454`*^9, 3.5578117827054253`*^9}, {3.557811840254054*^9, 
   3.557811841420846*^9}, {3.557812069283329*^9, 3.5578121696557083`*^9}, {
   3.557812260459509*^9, 3.5578126952846947`*^9}, {3.557812747542594*^9, 
   3.55781278623446*^9}, {3.5578128258832207`*^9, 3.557812851986134*^9}, {
   3.557812889395705*^9, 3.5578129446443996`*^9}, {3.5578130043377934`*^9, 
   3.557813360406931*^9}, {3.55781339206642*^9, 3.557813402817926*^9}, {
   3.557835466134326*^9, 3.55783547508632*^9}, {3.5578355094977627`*^9, 
   3.557835528272224*^9}, {3.557835951188566*^9, 3.557835968141111*^9}, {
   3.557836012262925*^9, 3.557836021245957*^9}, {3.557851410971889*^9, 
   3.55785141140456*^9}, {3.558005238429266*^9, 3.5580053432799788`*^9}, {
   3.558007575169417*^9, 3.558007579742235*^9}, 3.559297307582871*^9, {
   3.5592982733819103`*^9, 3.559298321933462*^9}, 3.5592984500293617`*^9, {
   3.559298503040021*^9, 3.559298546539605*^9}, 3.559298627365633*^9, 
   3.559298669990142*^9, {3.5592987861125603`*^9, 3.559298813366879*^9}, {
   3.559298880625902*^9, 3.559298970132753*^9}, {3.559299115311494*^9, 
   3.55929912646916*^9}, {3.559299208726503*^9, 3.559299275542768*^9}, {
   3.55929965659324*^9, 3.5592996579867573`*^9}, {3.559299751525083*^9, 
   3.559299761148251*^9}, {3.559300521045332*^9, 3.5593005320251007`*^9}, {
   3.5593720348679934`*^9, 3.55937204332819*^9}, 3.5595561583784103`*^9, {
   3.559558813160327*^9, 3.559558960194663*^9}, {3.559560139805255*^9, 
   3.5595602011273613`*^9}, {3.559560896365741*^9, 3.559560937099496*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CheckInput", "[", 
    RowBox[{
     RowBox[{"mc", ":", 
      RowBox[{"MC", "[", 
       RowBox[{"_", ",", "labels_"}], "]"}]}], ",", "\[Lambda]_", ",", " ", 
     "queryLst_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "BadQuery", ",", "badqueries", ",", "estimates", ",", "BadEstimate"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"BadQuery", "[", "size_", "]"}], "[", 
        RowBox[{"pair", ":", 
         RowBox[{"{", 
          RowBox[{"_Integer", ",", "_Integer"}], "}"}]}], "]"}], ":=", 
       RowBox[{"Not", "[", 
        RowBox[{"And", "@@", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"IntervalMemberQ", "[", 
             RowBox[{
              RowBox[{"Interval", "[", 
               RowBox[{"{", 
                RowBox[{"1", ",", "size"}], "}"}], "]"}], ",", "#"}], "]"}], 
            "&"}], "/@", "pair"}], ")"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"BadQuery", "[", "_", "]"}], "[", "_", "]"}], ":=", "True"}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"BadEstimate", "[", "size_", "]"}], "[", 
        RowBox[{"pair_", "\[Rule]", "value_"}], "]"}], ":=", 
       RowBox[{
        RowBox[{
         RowBox[{"BadQuery", "[", "size", "]"}], "[", "pair", "]"}], " ", 
        "\[Or]", " ", 
        RowBox[{"value", "<", "0"}], "\[Or]", " ", 
        RowBox[{"value", ">", "1"}], "\[Or]", 
        RowBox[{"Not", "@", 
         RowBox[{"MatchQ", "[", 
          RowBox[{"value", ",", 
           RowBox[{"_Rational", "|", "1"}]}], "]"}]}]}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"estimates", " ", "=", " ", 
       RowBox[{"OptionValue", "[", 
        RowBox[{"ComputeDistances", ",", "Estimates"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Which", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Not", "@", 
         RowBox[{"MarkovChainQ", "[", "mc", "]"}]}], ",", 
        "\[IndentingNewLine]", "\t", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{"ComputeDistances", "::", "MarkovChain"}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Lambda]", "\[LessEqual]", "0"}], "\[Or]", " ", 
         RowBox[{"\[Lambda]", ">", "1"}], "\[Or]", 
         RowBox[{"Not", "@", 
          RowBox[{"MatchQ", "[", 
           RowBox[{"\[Lambda]", ",", 
            RowBox[{"_Rational", "|", "1"}]}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", "\t ", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"ComputeDistances", "::", "DiscountFactor"}], ",", 
           "\[Lambda]"}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Length", "@", "estimates"}], " ", ">", 
         RowBox[{"Length", "@", 
          RowBox[{"DeleteDuplicates", "[", 
           RowBox[{"estimates", ",", 
            RowBox[{
             RowBox[{
              RowBox[{"First", "@", "#1"}], " ", "\[Equal]", " ", 
              RowBox[{"First", "@", "#2"}]}], "&"}]}], "]"}]}]}], ",", 
        "\[IndentingNewLine]", "\t", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{"ComputeDistances", "::", "MultipleEstimates"}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Select", "[", 
          RowBox[{"estimates", ",", 
           RowBox[{"BadQuery", "[", 
            RowBox[{"Length", "@", "labels"}], "]"}]}], "]"}], ">", "0"}], 
        ",", "\[IndentingNewLine]", "\t", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{"ComputeDistances", "::", "WrongEstimates"}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"badqueries", " ", "=", 
           RowBox[{"Select", "[", 
            RowBox[{"queryLst", ",", 
             RowBox[{"BadQuery", "[", 
              RowBox[{"Length", "@", "labels"}], "]"}]}], "]"}]}], ")"}], ">",
          "0"}], " ", ",", "\[IndentingNewLine]", "\t", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{
           RowBox[{"ComputeDistances", "::", "pair"}], ",", "badqueries"}], 
          "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.559298599660507*^9, 3.559298697991884*^9}, {
   3.5592987374928093`*^9, 3.55929878038031*^9}, {3.559298824763123*^9, 
   3.559298869759284*^9}, 3.5592989787033577`*^9, {3.559299016002536*^9, 
   3.5592990892772503`*^9}, {3.559300467596963*^9, 3.559300504026204*^9}, {
   3.559556101413623*^9, 3.559556102369409*^9}, {3.559560256647039*^9, 
   3.559560826753776*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ComputeDistancesAux", "[", 
    RowBox[{
     RowBox[{"mc", ":", 
      RowBox[{"MC", "[", 
       RowBox[{"TM_", ",", " ", "labels_"}], "]"}]}], ",", " ", "\[Lambda]_", 
     ",", " ", "queryLst_"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "sortedQuery", ",", "query", ",", "FixDistance", ",", "currProblems", 
       ",", " ", "time", ",", "\[IndentingNewLine]", 
       RowBox[{"currDist", "=", 
        RowBox[{"InitDistances", "[", 
         RowBox[{"mc", ",", 
          RowBox[{"OptionValue", "[", 
           RowBox[{"ComputeDistances", ",", "Estimates"}], "]"}]}], "]"}]}], 
       ",", "vtc", ",", " ", "prb", ",", " ", "rcCell", ",", " ", "newvertex",
        ",", 
       RowBox[{"iterations", "=", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"FixDistance", "[", 
        RowBox[{"dist_", ",", 
         RowBox[{"{", 
          RowBox[{"s_", ",", "t_"}], "}"}]}], "]"}], ":=", 
       RowBox[{"dist", "/;", 
        RowBox[{"FixedDistance", "[", 
         RowBox[{"dist", ",", 
          RowBox[{"{", 
           RowBox[{"s", ",", "t"}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"FixDistance", "[", 
        RowBox[{"dist_", ",", 
         RowBox[{"index", ":", 
          RowBox[{"{", 
           RowBox[{"s_", ",", "t_"}], "}"}]}]}], "]"}], ":=", 
       "\[IndentingNewLine]", 
       RowBox[{"Fold", "[", 
        RowBox[{"FixDistance", ",", 
         RowBox[{"ReplacePart", "[", 
          RowBox[{"dist", ",", 
           RowBox[{"index", "\[Rule]", 
            RowBox[{"Fixed", "[", 
             RowBox[{"getDistValue", "[", 
              RowBox[{"dist", ",", "index"}], "]"}], "]"}]}]}], "]"}], ",", 
         RowBox[{"SubProblems", "[", 
          RowBox[{"currProblems", "\[LeftDoubleBracket]", 
           RowBox[{"s", ",", "t"}], "\[RightDoubleBracket]"}], "]"}]}], 
        "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", "Initialization", " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"time", " ", "=", 
       RowBox[{"First", "@", 
        RowBox[{"Timing", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"sortedQuery", "=", 
           RowBox[{"DeleteDuplicates", "[", 
            RowBox[{"Sort", "/@", 
             RowBox[{"Select", "[", 
              RowBox[{"queryLst", ",", 
               RowBox[{
                RowBox[{"Not", "@", 
                 RowBox[{"FixedDistance", "[", 
                  RowBox[{"currDist", ",", "#"}], "]"}]}], "&"}]}], "]"}]}], 
            "]"}]}], ";", "\[IndentingNewLine]", 
          RowBox[{"While", "[", 
           RowBox[{
            RowBox[{"sortedQuery", "\[NotEqual]", 
             RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"DebugPrint", "[", 
              RowBox[{"\"\<Pairs to compute: \>\"", ",", "sortedQuery"}], 
              "]"}], ";", "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
              "pick", " ", "at", " ", "random", " ", "a", " ", "pair", " ", 
               "from", " ", "the", " ", "query"}], " ", "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"query", "=", 
              RowBox[{"sortedQuery", "\[LeftDoubleBracket]", 
               RowBox[{"RandomInteger", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"1", ",", 
                   RowBox[{"Length", "@", "sortedQuery"}]}], "}"}], ",", 
                 "1"}], "]"}], "\[RightDoubleBracket]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"DebugPrint", "[", 
              RowBox[{"\"\<Picked pair: \>\"", ",", "query"}], "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"currProblems", " ", "=", " ", 
              RowBox[{
               RowBox[{"AddProblems", "[", 
                RowBox[{"mc", ",", "currDist"}], "]"}], "[", 
               RowBox[{
                RowBox[{"ZeroMatrix", "@", 
                 RowBox[{"Length", "@", "labels"}]}], ",", "query"}], "]"}]}],
              ";", "\[IndentingNewLine]", 
             RowBox[{"PrintActiveProblems", "[", 
              RowBox[{"currDist", ",", "currProblems", ",", "query"}], "]"}], 
             ";", "\[IndentingNewLine]", 
             RowBox[{"currDist", " ", "=", 
              RowBox[{"UpdateWithDiscrepancy", "[", 
               RowBox[{
               "\[Lambda]", ",", " ", "mc", ",", "currDist", ",", 
                "currProblems", ",", "query"}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"DebugPrint", "[", 
                RowBox[{"MatrixForm", "@", "currDist"}], "]"}], ";"}], "*)"}],
              "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
               RowBox[{"look", " ", "for", " ", "a", " ", "non"}], "-", 
               RowBox[{"optimal", " ", "transportation", " ", "schedule"}]}], 
              " ", "*)"}], "\[IndentingNewLine]", 
             RowBox[{"vtc", " ", "=", " ", 
              RowBox[{"VertexToChange", "[", 
               RowBox[{
               "currProblems", ",", " ", "currDist", ",", " ", "query"}], 
               "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"While", "[", 
              RowBox[{
               RowBox[{"vtc", "\[NotEqual]", " ", 
                RowBox[{"{", "}"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"iterations", "++"}], ";", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"prb", ",", " ", "rcCell"}], "}"}], " ", "=", " ", 
                 "vtc"}], ";", 
                RowBox[{"(*", " ", 
                 RowBox[{
                 "consider", " ", "the", " ", "schedule", " ", "to", " ", 
                  "be", " ", "optimized"}], " ", "*)"}], 
                "\[IndentingNewLine]", 
                RowBox[{"(*", " ", 
                 RowBox[{
                 "move", " ", "to", " ", "a", " ", "better", " ", 
                  "coupling"}], " ", "*)"}], "\[IndentingNewLine]", 
                RowBox[{"newvertex", " ", "=", " ", 
                 RowBox[{"BestVertex", "[", 
                  RowBox[{"currDist", ",", " ", "rcCell", ",", " ", 
                   RowBox[{"Extract", "[", 
                    RowBox[{"currProblems", ",", "prb"}], "]"}]}], "]"}]}], 
                ";", "\[IndentingNewLine]", 
                RowBox[{"currProblems", " ", "=", " ", 
                 RowBox[{
                  RowBox[{"UpdateProblems", "[", 
                   RowBox[{"mc", ",", "currDist"}], "]"}], "[", 
                  RowBox[{"currProblems", ",", "prb", ",", " ", "newvertex"}],
                   "]"}]}], ";", "\[IndentingNewLine]", 
                RowBox[{"PrintActiveProblems", "[", 
                 RowBox[{"currDist", ",", "currProblems", ",", "query"}], 
                 "]"}], ";", "\[IndentingNewLine]", 
                RowBox[{"(*", " ", 
                 RowBox[{
                 "update", " ", "the", " ", "current", " ", "distance", " ", 
                  "with", " ", "the", " ", 
                  RowBox[{"(", "locally", ")"}], " ", "computed", " ", 
                  "discrepancy"}], " ", "*)"}], "\[IndentingNewLine]", 
                RowBox[{"currDist", " ", "=", " ", 
                 RowBox[{"UpdateWithDiscrepancy", "[", 
                  RowBox[{
                  "\[Lambda]", ",", " ", "mc", ",", "currDist", ",", 
                   "currProblems", ",", "query"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"(*", 
                 RowBox[{
                  RowBox[{"DebugPrint", "[", 
                   RowBox[{"MatrixForm", "@", "currDist"}], "]"}], ";"}], 
                 "*)"}], "\[IndentingNewLine]", 
                RowBox[{"(*", " ", 
                 RowBox[{
                  RowBox[{
                  "look", " ", "for", " ", "the", " ", "next", " ", "non"}], 
                  "-", 
                  RowBox[{
                  "optimal", " ", "transportation", " ", "schedule"}]}], " ", 
                 "*)"}], "\[IndentingNewLine]", 
                RowBox[{"vtc", " ", "=", " ", 
                 RowBox[{"VertexToChange", "[", 
                  RowBox[{
                  "currProblems", ",", " ", "currDist", ",", " ", "query"}], 
                  "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{
              "Set", " ", "the", " ", "current", " ", "active", " ", 
               "problems", " ", "as", " ", "fixed"}], " ", "*)"}], 
             "\[IndentingNewLine]", 
             RowBox[{"currDist", "=", 
              RowBox[{"FixDistance", "[", 
               RowBox[{"currDist", ",", " ", 
                RowBox[{"First", "@", "query"}]}], "]"}]}], ";", 
             "\[IndentingNewLine]", 
             RowBox[{"(*", 
              RowBox[{
               RowBox[{"DebugPrint", "[", 
                RowBox[{"MatrixForm", "@", "currDist"}], "]"}], ";"}], "*)"}],
              "\[IndentingNewLine]", 
             RowBox[{"(*", " ", 
              RowBox[{"update", " ", "the", " ", "query", " ", "list"}], " ", 
              "*)"}], "\[IndentingNewLine]", 
             RowBox[{"sortedQuery", " ", "=", 
              RowBox[{"Select", "[", 
               RowBox[{"sortedQuery", ",", 
                RowBox[{
                 RowBox[{"Not", "@", 
                  RowBox[{"FixedDistance", "[", 
                   RowBox[{"currDist", ",", "#"}], "]"}]}], "&"}]}], "]"}]}], 
             ";"}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
      "DebugPrint", "[", "\"\<There are no more pairs to process.\>\"", "]"}],
       ";", "\[IndentingNewLine]", 
      RowBox[{"DebugPrint", "[", 
       RowBox[{"\"\<Total solved TPs: \>\"", ",", "iterations"}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"DebugPrint", "[", 
       RowBox[{
       "\"\<Execution Time: \>\"", ",", "time", ",", " ", "\"\< sec\>\""}], 
       "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"#", "\[Rule]", 
          RowBox[{"getDistValue", "[", 
           RowBox[{"currDist", ",", "#"}], "]"}]}], "&"}], ")"}], "/@", 
       "queryLst"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 InitializationGroup->True,
 CellChangeTimes->{{3.557810025251397*^9, 3.557810130841151*^9}, {
   3.5578101798595877`*^9, 3.557810708303841*^9}, 3.5578144031011467`*^9, {
   3.557835840690097*^9, 3.55783587625457*^9}, {3.557849480287166*^9, 
   3.557849500258189*^9}, {3.5578497013118477`*^9, 3.557849733942443*^9}, 
   3.5578500620163593`*^9, {3.557850243327771*^9, 3.557850248098641*^9}, {
   3.557850359334963*^9, 3.557850383869664*^9}, {3.557850429417139*^9, 
   3.557850446237915*^9}, {3.557850602687758*^9, 3.5578506086555443`*^9}, {
   3.5578508302918577`*^9, 3.557850833759166*^9}, {3.557851306522908*^9, 
   3.5578513407332277`*^9}, {3.5578514331981783`*^9, 3.55785146131315*^9}, {
   3.557851544808264*^9, 3.557851641410055*^9}, {3.557851735921565*^9, 
   3.557851795854272*^9}, {3.5580053650042553`*^9, 3.558005412477303*^9}, {
   3.558094605058631*^9, 3.558094686631752*^9}, {3.558094940866856*^9, 
   3.558094953297103*^9}, 3.558159050035013*^9, {3.558159094606505*^9, 
   3.558159347442398*^9}, 3.5581593812102203`*^9, {3.5581594182075*^9, 
   3.558159546849409*^9}, {3.5581596501302643`*^9, 3.5581596737302027`*^9}, {
   3.558159710891663*^9, 3.558159711267426*^9}, {3.5581597618559713`*^9, 
   3.558159791277738*^9}, {3.558159829727683*^9, 3.5581598386392097`*^9}, {
   3.558159898768199*^9, 3.558159899860221*^9}, {3.558159963599443*^9, 
   3.55816010735356*^9}, {3.5581602076145163`*^9, 3.5581603080256777`*^9}, {
   3.558160360320629*^9, 3.5581603986923923`*^9}, {3.558160438902094*^9, 
   3.558160535679843*^9}, {3.558160583838851*^9, 3.558160598061726*^9}, 
   3.558160760557919*^9, {3.558161198640913*^9, 3.5581612040000687`*^9}, {
   3.55816135752922*^9, 3.5581613576770563`*^9}, {3.5581616425351973`*^9, 
   3.5581616668224497`*^9}, {3.5581636112698812`*^9, 
   3.5581636454450283`*^9}, {3.558163766004322*^9, 3.558163772207534*^9}, {
   3.558163945691854*^9, 3.5581639813879642`*^9}, {3.558164019589172*^9, 
   3.558164024349278*^9}, {3.558164146989399*^9, 3.558164151026576*^9}, {
   3.558164205353531*^9, 3.5581642144235373`*^9}, {3.558164264202283*^9, 
   3.558164268842276*^9}, {3.5581643209420958`*^9, 3.558164328245153*^9}, {
   3.558164551966593*^9, 3.558164644925302*^9}, {3.5581646945371323`*^9, 
   3.558164727022665*^9}, 3.558677415594365*^9, {3.559281660469974*^9, 
   3.5592816613966513`*^9}, {3.559281840462479*^9, 3.55928203214072*^9}, {
   3.559282065195725*^9, 3.559282068413447*^9}, {3.5592883013526373`*^9, 
   3.559288625713686*^9}, {3.559288661169736*^9, 3.559288750200871*^9}, {
   3.559297376614573*^9, 3.55929738114148*^9}, {3.559298151397668*^9, 
   3.559298151947708*^9}, {3.559299392744809*^9, 3.5592995539212017`*^9}, {
   3.559299600767252*^9, 3.5592996065915613`*^9}, {3.5593107834936647`*^9, 
   3.559310822837289*^9}, {3.559368236695114*^9, 3.559368267514761*^9}, {
   3.559561017995576*^9, 3.559561020099519*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bisimilarity ", "Subsection",
 CellChangeTimes->{{3.559367837719322*^9, 3.559367852348876*^9}}],

Cell[CellGroupData[{

Cell["\<\
BisimQuotient[mc] returns an MC with all bisimilar states lumped together\
\>", "Text",
 CellChangeTimes->{{3.5593679390562077`*^9, 3.559367941751894*^9}, {
  3.559368057971428*^9, 3.5593681457499933`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BisimQuotient", "[", 
    RowBox[{"mc", ":", 
     RowBox[{"MC", "[", 
      RowBox[{"tm_", ",", "labels_"}], "]"}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Rate", ",", "Quo"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Quo", "=", 
       RowBox[{"BisimClasses", "@", "mc"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Rate", "[", 
        RowBox[{"class1_", ",", "class2_"}], "]"}], ":=", 
       RowBox[{"Plus", "@@", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"tm", "\[LeftDoubleBracket]", 
            RowBox[{
             RowBox[{"First", "@", "class1"}], ",", "#"}], 
            "\[RightDoubleBracket]"}], "&"}], "/@", "class2"}], ")"}]}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"MC", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Rate", "[", 
           RowBox[{"i", ",", "j"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", 
            FormBox["Quo",
             TraditionalForm]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "Quo"}], "}"}]}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"labels", "\[LeftDoubleBracket]", 
           RowBox[{"First", "@", "#"}], "\[RightDoubleBracket]"}], "&"}], "/@",
          "Quo"}]}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.559366917781954*^9, 3.559367035207986*^9}, {
   3.559367182110381*^9, 3.5593675683811283`*^9}, 3.559367667297641*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
BisimClasses[mc] returns the quotient w.r.t. bisimilarity\
\>", "Text",
 CellChangeTimes->{{3.5593678712720623`*^9, 3.559367921495393*^9}, {
  3.559367956224596*^9, 3.5593680530753593`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BisimClasses", "[", 
    RowBox[{"mc", ":", 
     RowBox[{"MC", "[", 
      RowBox[{"_", ",", "_"}], "]"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{
    FormBox["FixedPoint",
     TraditionalForm], "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Union", "@@", "#"}], "&"}], ")"}], "/@", 
       RowBox[{"Gather", "[", 
        RowBox[{"#", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"Intersection", "[", 
            RowBox[{"#1", ",", "#2"}], "]"}], "\[NotEqual]", " ", 
           RowBox[{"{", "}"}]}], "&"}]}], "]"}]}], "&"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Select", "[", 
       RowBox[{
        RowBox[{"ComputeDistances", "[", 
         RowBox[{"mc", ",", "1", ",", "All", ",", " ", 
          RowBox[{"Verbose", "\[Rule]", "False"}]}], "]"}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}],
           "\[Equal]", "0"}], "&"}]}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.55935930466625*^9, 3.559359393043251*^9}, {
  3.5593595493681173`*^9, 3.559359563949181*^9}, {3.5593596207908707`*^9, 
  3.5593596232543087`*^9}, {3.5593596603653717`*^9, 3.5593598806440067`*^9}, {
  3.559359923573073*^9, 3.559359943701544*^9}, {3.559360124786091*^9, 
  3.559360162363605*^9}, {3.559360279614812*^9, 3.559360299175469*^9}, {
  3.5593604224193*^9, 3.559360521959156*^9}, {3.5593605554482937`*^9, 
  3.559360561744382*^9}, {3.559361139051309*^9, 3.5593612550275583`*^9}, {
  3.5593613092451897`*^9, 3.559361569281638*^9}, {3.5593616514800158`*^9, 
  3.559361656397406*^9}, {3.559364722634613*^9, 3.559364722783642*^9}, {
  3.559366361942811*^9, 3.559366368707946*^9}, {3.559366461277184*^9, 
  3.559366462817581*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1159, 762},
WindowMargins->{{6, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
CellLabelAutoDelete->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 121, 3, 154, "Title"],
Cell[681, 25, 135, 3, 57, "Subtitle"],
Cell[819, 30, 216, 4, 32, "Subsubtitle"],
Cell[1038, 36, 1157, 25, 51, "Text"],
Cell[CellGroupData[{
Cell[2220, 65, 167, 2, 83, "Section"],
Cell[CellGroupData[{
Cell[2412, 71, 214, 5, 42, "Subsection"],
Cell[2629, 78, 1271, 26, 89, "Text"],
Cell[3903, 106, 522, 12, 32, "Text"],
Cell[CellGroupData[{
Cell[4450, 122, 1927, 55, 237, "Input"],
Cell[6380, 179, 419, 7, 32, "Text"],
Cell[CellGroupData[{
Cell[6824, 190, 118, 3, 33, "Input"],
Cell[6945, 195, 30817, 627, 494, "Output"]
}, Open  ]]
}, Open  ]],
Cell[37789, 826, 583, 14, 32, "Text"],
Cell[38375, 842, 3542, 87, 110, "Input"],
Cell[41920, 931, 374, 7, 32, "Text"],
Cell[CellGroupData[{
Cell[42319, 942, 251, 5, 33, "Input"],
Cell[42573, 949, 2238, 60, 251, "Output"]
}, Open  ]],
Cell[44826, 1012, 234, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[45085, 1021, 190, 4, 33, "Input"],
Cell[45278, 1027, 146, 2, 33, "Output"]
}, Open  ]]
}, Open  ]],
Cell[45451, 1033, 420, 11, 32, "Text"],
Cell[CellGroupData[{
Cell[45896, 1048, 2820, 79, 110, "Input"],
Cell[48719, 1129, 24064, 509, 620, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[72820, 1643, 116, 1, 42, "Subsection"],
Cell[72939, 1646, 389, 7, 32, "Text"],
Cell[CellGroupData[{
Cell[73353, 1657, 768, 19, 53, "Input"],
Cell[74124, 1678, 613, 17, 54, "Output"]
}, Open  ]],
Cell[74752, 1698, 287, 7, 32, "Text"],
Cell[CellGroupData[{
Cell[75064, 1709, 349, 8, 33, "Input"],
Cell[75416, 1719, 416, 10, 25, "Print"],
Cell[75835, 1731, 406, 10, 25, "Print"],
Cell[76244, 1743, 511, 11, 25, "Print"],
Cell[76758, 1756, 3337, 100, 155, "Print"],
Cell[80098, 1858, 2629, 78, 91, "Print"],
Cell[82730, 1938, 376, 8, 25, "Print"],
Cell[83109, 1948, 4565, 129, 69, "Print"],
Cell[87677, 2079, 741, 16, 25, "Print"],
Cell[88421, 2097, 511, 11, 25, "Print"],
Cell[88935, 2110, 3335, 100, 155, "Print"],
Cell[92273, 2212, 376, 8, 25, "Print"],
Cell[92652, 2222, 4209, 115, 38, "Print"],
Cell[96864, 2339, 777, 16, 50, "Print"],
Cell[97644, 2357, 513, 11, 25, "Print"],
Cell[98160, 2370, 3335, 100, 152, "Print"],
Cell[101498, 2472, 378, 8, 25, "Print"],
Cell[101879, 2482, 4209, 115, 38, "Print"],
Cell[106091, 2599, 332, 7, 25, "Print"],
Cell[106426, 2608, 414, 8, 25, "Print"],
Cell[106843, 2618, 318, 8, 58, "Output"]
}, Open  ]],
Cell[107176, 2629, 239, 6, 32, "Text"],
Cell[CellGroupData[{
Cell[107440, 2639, 376, 6, 33, "Input"],
Cell[107819, 2647, 5293, 174, 243, "Output"]
}, Open  ]],
Cell[113127, 2824, 270, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[113422, 2833, 381, 9, 33, "Input"],
Cell[113806, 2844, 2586, 62, 248, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[116453, 2913, 146, 2, 83, "Section"],
Cell[CellGroupData[{
Cell[116624, 2919, 442, 7, 42, "Subsection"],
Cell[117069, 2928, 224, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[117318, 2936, 4017, 101, 166, "Input"],
Cell[121338, 3039, 30935, 629, 493, "Output"]
}, Open  ]],
Cell[152288, 3671, 159, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[152472, 3678, 916, 16, 33, "Input"],
Cell[153391, 3696, 417, 10, 25, "Print"],
Cell[153811, 3708, 407, 10, 25, "Print"],
Cell[154221, 3720, 514, 11, 25, "Print"],
Cell[154738, 3733, 3340, 100, 152, "Print"],
Cell[158081, 3835, 2632, 78, 90, "Print"],
Cell[160716, 3915, 381, 8, 25, "Print"],
Cell[161100, 3925, 4568, 129, 70, "Print"],
Cell[165671, 4056, 747, 16, 25, "Print"],
Cell[166421, 4074, 516, 11, 25, "Print"],
Cell[166940, 4087, 3337, 100, 152, "Print"],
Cell[170280, 4189, 379, 8, 25, "Print"],
Cell[170662, 4199, 4211, 115, 38, "Print"],
Cell[174876, 4316, 780, 16, 50, "Print"],
Cell[175659, 4334, 516, 11, 25, "Print"],
Cell[176178, 4347, 3340, 100, 152, "Print"],
Cell[179521, 4449, 379, 8, 25, "Print"],
Cell[179903, 4459, 4214, 115, 38, "Print"],
Cell[184120, 4576, 335, 7, 25, "Print"],
Cell[184458, 4585, 419, 8, 25, "Print"],
Cell[184880, 4595, 764, 15, 58, "Output"]
}, Open  ]],
Cell[185659, 4613, 565, 10, 70, "Text"],
Cell[186227, 4625, 395, 7, 32, "Text"],
Cell[CellGroupData[{
Cell[186647, 4636, 699, 13, 33, "Input"],
Cell[187349, 4651, 348, 9, 25, "Print"],
Cell[187700, 4662, 338, 9, 25, "Print"],
Cell[188041, 4673, 447, 10, 25, "Print"],
Cell[188491, 4685, 2563, 77, 90, "Print"],
Cell[191057, 4764, 312, 7, 25, "Print"],
Cell[191372, 4773, 4079, 111, 38, "Print"],
Cell[195454, 4886, 676, 15, 25, "Print"],
Cell[196133, 4903, 445, 10, 25, "Print"],
Cell[196581, 4915, 2948, 90, 152, "Print"],
Cell[199532, 5007, 2563, 77, 90, "Print"],
Cell[202098, 5086, 310, 7, 25, "Print"],
Cell[202411, 5095, 4609, 131, 70, "Print"],
Cell[207023, 5228, 675, 15, 25, "Print"],
Cell[207701, 5245, 445, 10, 25, "Print"],
Cell[208149, 5257, 2921, 89, 152, "Print"],
Cell[211073, 5348, 3268, 99, 152, "Print"],
Cell[214344, 5449, 3290, 99, 122, "Print"],
Cell[217637, 5550, 2563, 77, 90, "Print"],
Cell[220203, 5629, 310, 7, 25, "Print"],
Cell[220516, 5638, 5594, 159, 132, "Print"],
Cell[226113, 5799, 676, 15, 25, "Print"],
Cell[226792, 5816, 445, 10, 25, "Print"],
Cell[227240, 5828, 2921, 89, 152, "Print"],
Cell[230164, 5919, 3295, 100, 152, "Print"],
Cell[233462, 6021, 3292, 99, 122, "Print"],
Cell[236757, 6122, 2565, 77, 90, "Print"],
Cell[239325, 6201, 309, 7, 25, "Print"],
Cell[239637, 6210, 5723, 164, 132, "Print"],
Cell[245363, 6376, 717, 15, 50, "Print"],
Cell[246083, 6393, 447, 10, 25, "Print"],
Cell[246533, 6405, 2921, 89, 152, "Print"],
Cell[249457, 6496, 3269, 99, 152, "Print"],
Cell[252729, 6597, 3290, 99, 122, "Print"],
Cell[256022, 6698, 2563, 77, 90, "Print"],
Cell[258588, 6777, 310, 7, 25, "Print"],
Cell[258901, 6786, 5530, 158, 132, "Print"],
Cell[264434, 6946, 268, 6, 25, "Print"],
Cell[264705, 6954, 348, 7, 25, "Print"],
Cell[265056, 6963, 567, 12, 58, "Output"]
}, Open  ]],
Cell[265638, 6978, 688, 11, 88, "Text"],
Cell[CellGroupData[{
Cell[266351, 6993, 737, 16, 33, "Input"],
Cell[267091, 7011, 524, 14, 25, "Print"],
Cell[267618, 7027, 355, 9, 25, "Print"],
Cell[267976, 7038, 462, 10, 25, "Print"],
Cell[268441, 7050, 2965, 90, 152, "Print"],
Cell[271409, 7142, 3288, 99, 152, "Print"],
Cell[274700, 7243, 3307, 99, 122, "Print"],
Cell[278010, 7344, 2582, 77, 90, "Print"],
Cell[280595, 7423, 327, 7, 25, "Print"],
Cell[280925, 7432, 5458, 157, 132, "Print"],
Cell[286386, 7591, 736, 15, 50, "Print"],
Cell[287125, 7608, 462, 10, 25, "Print"],
Cell[287590, 7620, 2940, 89, 152, "Print"],
Cell[290533, 7711, 3286, 99, 152, "Print"],
Cell[293822, 7812, 3307, 99, 122, "Print"],
Cell[297132, 7913, 2579, 77, 90, "Print"],
Cell[299714, 7992, 329, 7, 25, "Print"],
Cell[300046, 8001, 5486, 156, 132, "Print"],
Cell[305535, 8159, 693, 15, 25, "Print"],
Cell[306231, 8176, 462, 10, 25, "Print"],
Cell[306696, 8188, 2938, 89, 152, "Print"],
Cell[309637, 8279, 3313, 100, 152, "Print"],
Cell[312953, 8381, 3307, 99, 122, "Print"],
Cell[316263, 8482, 2580, 77, 90, "Print"],
Cell[318846, 8561, 329, 7, 25, "Print"],
Cell[319178, 8570, 5590, 159, 132, "Print"],
Cell[324771, 8731, 732, 15, 50, "Print"],
Cell[325506, 8748, 462, 10, 25, "Print"],
Cell[325971, 8760, 2940, 89, 152, "Print"],
Cell[328914, 8851, 3288, 99, 152, "Print"],
Cell[332205, 8952, 3307, 99, 122, "Print"],
Cell[335515, 9053, 2579, 77, 90, "Print"],
Cell[338097, 9132, 327, 7, 25, "Print"],
Cell[338427, 9141, 5439, 155, 132, "Print"],
Cell[343869, 9298, 733, 15, 50, "Print"],
Cell[344605, 9315, 462, 10, 25, "Print"],
Cell[345070, 9327, 2938, 89, 152, "Print"],
Cell[348011, 9418, 3288, 99, 152, "Print"],
Cell[351302, 9519, 3307, 99, 122, "Print"],
Cell[354612, 9620, 2580, 77, 90, "Print"],
Cell[357195, 9699, 329, 7, 25, "Print"],
Cell[357527, 9708, 5547, 158, 132, "Print"],
Cell[363077, 9868, 730, 15, 50, "Print"],
Cell[363810, 9885, 462, 10, 25, "Print"],
Cell[364275, 9897, 2938, 89, 152, "Print"],
Cell[367216, 9988, 3286, 99, 152, "Print"],
Cell[370505, 10089, 3307, 99, 122, "Print"],
Cell[373815, 10190, 2580, 77, 90, "Print"],
Cell[376398, 10269, 327, 7, 25, "Print"],
Cell[376728, 10278, 5549, 158, 132, "Print"],
Cell[382280, 10438, 283, 6, 25, "Print"],
Cell[382566, 10446, 366, 7, 25, "Print"],
Cell[382935, 10455, 836, 21, 58, "Output"]
}, Open  ]],
Cell[383786, 10479, 508, 9, 51, "Text"],
Cell[CellGroupData[{
Cell[384319, 10492, 485, 13, 58, "Input"],
Cell[384807, 10507, 318, 8, 25, "Print"],
Cell[385128, 10517, 308, 8, 25, "Print"],
Cell[385439, 10527, 414, 9, 25, "Print"],
Cell[385856, 10538, 2533, 76, 90, "Print"],
Cell[388392, 10616, 280, 6, 25, "Print"],
Cell[388675, 10624, 4049, 110, 38, "Print"],
Cell[392727, 10736, 646, 14, 25, "Print"],
Cell[393376, 10752, 415, 9, 25, "Print"],
Cell[393794, 10763, 2918, 89, 152, "Print"],
Cell[396715, 10854, 2535, 76, 90, "Print"],
Cell[399253, 10932, 279, 6, 25, "Print"],
Cell[399535, 10940, 4579, 130, 70, "Print"],
Cell[404117, 11072, 687, 14, 50, "Print"],
Cell[404807, 11088, 415, 9, 25, "Print"],
Cell[405225, 11099, 2891, 88, 152, "Print"],
Cell[408119, 11189, 2535, 76, 90, "Print"],
Cell[410657, 11267, 280, 6, 25, "Print"],
Cell[410940, 11275, 4604, 130, 70, "Print"],
Cell[415547, 11407, 238, 5, 25, "Print"],
Cell[415788, 11414, 318, 6, 25, "Print"],
Cell[416109, 11422, 222, 6, 58, "Output"]
}, Open  ]],
Cell[416346, 11431, 403, 9, 45, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[416786, 11445, 161, 2, 43, "Subsection"],
Cell[416950, 11449, 141, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[417116, 11456, 1717, 49, 91, "Input"],
Cell[418836, 11507, 16627, 344, 335, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[435500, 11856, 424, 7, 33, "Input"],
Cell[435927, 11865, 582, 14, 25, "Print"],
Cell[436512, 11881, 483, 11, 25, "Print"],
Cell[436998, 11894, 593, 12, 25, "Print"],
Cell[437594, 11908, 2346, 67, 90, "Print"],
Cell[439943, 11977, 2344, 67, 90, "Print"],
Cell[442290, 12046, 456, 9, 25, "Print"],
Cell[442749, 12057, 4797, 133, 70, "Print"],
Cell[447549, 12192, 414, 8, 25, "Print"],
Cell[447966, 12202, 496, 9, 25, "Print"],
Cell[448465, 12213, 1893, 56, 53, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[450407, 12275, 180, 2, 42, "Subsection"],
Cell[450590, 12279, 930, 18, 51, "Text"],
Cell[451523, 12299, 3656, 90, 128, "Input"],
Cell[CellGroupData[{
Cell[455204, 12393, 616, 14, 33, "Input"],
Cell[455823, 12409, 28602, 602, 407, "Output"]
}, Open  ]],
Cell[484440, 13014, 3577, 96, 147, "Input"],
Cell[CellGroupData[{
Cell[488042, 13114, 565, 13, 33, "Input"],
Cell[488610, 13129, 31979, 680, 491, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[520626, 13814, 460, 11, 33, "Input"],
Cell[521089, 13827, 372, 10, 25, "Print"],
Cell[521464, 13839, 362, 10, 25, "Print"],
Cell[521829, 13851, 472, 12, 25, "Print"],
Cell[522304, 13865, 6672, 199, 277, "Print"],
Cell[528979, 14066, 1456, 41, 47, "Print"],
Cell[530438, 14109, 1458, 41, 47, "Print"],
Cell[531899, 14152, 2921, 88, 122, "Print"],
Cell[534823, 14242, 2924, 88, 122, "Print"],
Cell[537750, 14332, 2979, 90, 122, "Print"],
Cell[540732, 14424, 2215, 65, 60, "Print"],
Cell[542950, 14491, 2214, 65, 60, "Print"],
Cell[545167, 14558, 2215, 65, 60, "Print"],
Cell[547385, 14625, 495, 12, 25, "Print"],
Cell[547883, 14639, 5865, 168, 162, "Print"],
Cell[553751, 14809, 737, 16, 48, "Print"],
Cell[554491, 14827, 474, 12, 25, "Print"],
Cell[554968, 14841, 6672, 199, 277, "Print"],
Cell[561643, 15042, 2979, 90, 122, "Print"],
Cell[564625, 15134, 2214, 65, 60, "Print"],
Cell[566842, 15201, 2216, 65, 60, "Print"],
Cell[569061, 15268, 2213, 65, 60, "Print"],
Cell[571277, 15335, 332, 8, 25, "Print"],
Cell[571612, 15345, 5863, 168, 162, "Print"],
Cell[577478, 15515, 700, 16, 25, "Print"],
Cell[578181, 15533, 472, 12, 25, "Print"],
Cell[578656, 15547, 6672, 199, 277, "Print"],
Cell[585331, 15748, 2950, 89, 122, "Print"],
Cell[588284, 15839, 2215, 65, 60, "Print"],
Cell[590502, 15906, 2214, 65, 60, "Print"],
Cell[592719, 15973, 2213, 65, 60, "Print"],
Cell[594935, 16040, 332, 8, 25, "Print"],
Cell[595270, 16050, 5867, 168, 162, "Print"],
Cell[601140, 16220, 288, 7, 25, "Print"],
Cell[601431, 16229, 368, 8, 25, "Print"],
Cell[601802, 16239, 321, 8, 58, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[602172, 16253, 291, 5, 43, "Subsection"],
Cell[602466, 16260, 286, 6, 32, "Text"],
Cell[CellGroupData[{
Cell[602777, 16270, 1126, 20, 72, "Input"],
Cell[603906, 16292, 75772, 1789, 452, "Output"]
}, Open  ]],
Cell[679693, 18084, 642, 12, 32, "Text"],
Cell[CellGroupData[{
Cell[680360, 18100, 353, 5, 33, "Input"],
Cell[680716, 18107, 1453, 35, 53, "Output"]
}, Open  ]],
Cell[682184, 18145, 383, 7, 32, "Text"],
Cell[CellGroupData[{
Cell[682592, 18156, 215, 4, 33, "Input"],
Cell[682810, 18162, 30900, 722, 420, "Output"]
}, Open  ]],
Cell[713725, 18887, 249, 5, 32, "Text"],
Cell[CellGroupData[{
Cell[713999, 18896, 197, 5, 33, "Input"],
Cell[714199, 18903, 61838, 1324, 558, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[776074, 20232, 235, 6, 33, "Input"],
Cell[776312, 20240, 30799, 627, 493, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[807172, 20874, 131, 2, 83, "Section",
 InitializationGroup->True],
Cell[CellGroupData[{
Cell[807328, 20880, 174, 3, 42, "Subsection",
 InitializationGroup->True],
Cell[807505, 20885, 378, 10, 33, "Input"],
Cell[807886, 20897, 413, 11, 33, "Input",
 InitializationGroup->True],
Cell[808302, 20910, 366, 10, 33, "Input",
 InitializationGroup->True],
Cell[808671, 20922, 425, 11, 33, "Input",
 InitializationGroup->True],
Cell[809099, 20935, 2900, 64, 147, "Input",
 InitializationGroup->True],
Cell[812002, 21001, 665, 15, 53, "Input",
 InitializationGroup->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[812704, 21021, 221, 4, 42, "Subsection",
 InitializationGroup->True],
Cell[812928, 21027, 813, 24, 33, "Input"],
Cell[813744, 21053, 642, 18, 33, "Input"],
Cell[814389, 21073, 2726, 72, 166, "Input",
 InitializationGroup->True],
Cell[817118, 21147, 610, 14, 52, "Text",
 InitializationGroup->True],
Cell[817731, 21163, 1154, 29, 110, "Input",
 InitializationGroup->True],
Cell[818888, 21194, 268, 6, 32, "Text",
 InitializationGroup->True],
Cell[819159, 21202, 1774, 52, 128, "Input"],
Cell[820936, 21256, 219, 5, 32, "Text",
 InitializationGroup->True],
Cell[821158, 21263, 3472, 87, 241, "Input",
 InitializationGroup->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[824667, 21355, 192, 3, 42, "Subsection",
 InitializationGroup->True],
Cell[824862, 21360, 730, 19, 53, "Input",
 InitializationGroup->True],
Cell[825595, 21381, 930, 25, 37, "Text",
 InitializationGroup->True],
Cell[826528, 21408, 1035, 25, 110, "Input",
 InitializationGroup->True],
Cell[827566, 21435, 2105, 52, 147, "Input",
 InitializationGroup->True],
Cell[829674, 21489, 324, 9, 33, "Input",
 InitializationGroup->True,
 CellID->390751893],
Cell[830001, 21500, 616, 17, 53, "Input",
 InitializationGroup->True],
Cell[830620, 21519, 1709, 43, 128, "Input",
 InitializationCell->True,
 InitializationGroup->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[832366, 21567, 138, 2, 42, "Subsection",
 InitializationGroup->True],
Cell[832507, 21571, 503, 16, 32, "Text",
 InitializationGroup->True],
Cell[833013, 21589, 1827, 43, 110, "Input",
 InitializationGroup->True],
Cell[834843, 21634, 369, 11, 33, "Input",
 InitializationGroup->True],
Cell[835215, 21647, 1317, 35, 110, "Input",
 InitializationGroup->True],
Cell[836535, 21684, 340, 10, 33, "Input",
 InitializationGroup->True],
Cell[836878, 21696, 317, 8, 33, "Input",
 InitializationGroup->True],
Cell[837198, 21706, 459, 14, 33, "Input",
 InitializationGroup->True],
Cell[837660, 21722, 5929, 126, 241, "Input",
 InitializationGroup->True],
Cell[843592, 21850, 430, 10, 33, "Input",
 InitializationGroup->True],
Cell[844025, 21862, 3514, 85, 222, "Input",
 InitializationGroup->True],
Cell[847542, 21949, 1145, 26, 110, "Input",
 InitializationGroup->True],
Cell[848690, 21977, 641, 10, 51, "Text",
 InitializationGroup->True],
Cell[849334, 21989, 9070, 199, 466, "Input",
 InitializationGroup->True],
Cell[858407, 22190, 271, 6, 32, "Text",
 InitializationGroup->True],
Cell[858681, 22198, 6223, 118, 222, "Input",
 InitializationGroup->True],
Cell[864907, 22318, 11903, 273, 616, "Input",
 InitializationGroup->True],
Cell[876813, 22593, 2415, 53, 203, "Input",
 InitializationGroup->True],
Cell[879231, 22648, 2358, 58, 147, "Input",
 InitializationGroup->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[881626, 22711, 188, 3, 32, "Subsection",
 InitializationGroup->True],
Cell[881817, 22716, 235, 7, 32, "Text"],
Cell[882055, 22725, 480, 11, 33, "Input",
 InitializationGroup->True],
Cell[882538, 22738, 301, 8, 33, "Input"],
Cell[882842, 22748, 153, 3, 32, "Text"],
Cell[882998, 22753, 6077, 137, 316, "Input",
 InitializationGroup->True],
Cell[889078, 22892, 3881, 87, 297, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[892996, 22984, 229, 4, 32, "Subsection",
 InitializationGroup->True],
Cell[893228, 22990, 489, 13, 32, "Text",
 InitializationGroup->True],
Cell[893720, 23005, 1714, 40, 53, "Input",
 InitializationGroup->True],
Cell[895437, 23047, 1257, 27, 33, "Input",
 InitializationGroup->True],
Cell[896697, 23076, 904, 23, 53, "Input",
 InitializationGroup->True],
Cell[897604, 23101, 3767, 89, 147, "Input",
 InitializationGroup->True],
Cell[901374, 23192, 600, 17, 33, "Input",
 InitializationGroup->True],
Cell[901977, 23211, 1138, 30, 53, "Input",
 InitializationGroup->True],
Cell[CellGroupData[{
Cell[903140, 23245, 1133, 36, 41, "Text",
 InitializationGroup->True],
Cell[904276, 23283, 5801, 137, 278, "Input",
 InitializationGroup->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[910114, 23425, 1381, 42, 41, "Text",
 InitializationGroup->True],
Cell[911498, 23469, 3813, 91, 166, "Input",
 InitializationGroup->True]
}, Open  ]],
Cell[915326, 23563, 2699, 67, 110, "Input",
 InitializationGroup->True],
Cell[918028, 23632, 16032, 362, 935, "Input",
 InitializationGroup->True],
Cell[934063, 23996, 1219, 29, 147, "Input",
 InitializationGroup->True],
Cell[935285, 24027, 2864, 72, 185, "Input",
 InitializationGroup->True],
Cell[938152, 24101, 534, 12, 32, "Text",
 InitializationGroup->True],
Cell[938689, 24115, 7239, 154, 466, "Input",
 InitializationGroup->True],
Cell[945931, 24271, 11820, 211, 353, "Input",
 InitializationGroup->True],
Cell[957754, 24484, 5080, 124, 396, "Input"],
Cell[962837, 24610, 13540, 275, 878, "Input",
 InitializationGroup->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[976414, 24890, 101, 1, 42, "Subsection"],
Cell[CellGroupData[{
Cell[976540, 24895, 216, 4, 32, "Text"],
Cell[976759, 24901, 1662, 46, 128, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[978458, 24952, 200, 4, 32, "Text"],
Cell[978661, 24958, 1951, 46, 72, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
